declare const _default: {
    "kind": string;
    "etag": string;
    "discoveryVersion": string;
    "id": string;
    "name": string;
    "version": string;
    "revision": string;
    "title": string;
    "description": string;
    "ownerDomain": string;
    "ownerName": string;
    "icons": {
        "x16": string;
        "x32": string;
    };
    "documentationLink": string;
    "protocol": string;
    "baseUrl": string;
    "basePath": string;
    "rootUrl": string;
    "servicePath": string;
    "batchPath": string;
    "parameters": {
        "alt": {
            "type": string;
            "description": string;
            "default": string;
            "enum": string[];
            "enumDescriptions": string[];
            "location": string;
        };
        "fields": {
            "type": string;
            "description": string;
            "location": string;
        };
        "key": {
            "type": string;
            "description": string;
            "location": string;
        };
        "oauth_token": {
            "type": string;
            "description": string;
            "location": string;
        };
        "prettyPrint": {
            "type": string;
            "description": string;
            "default": string;
            "location": string;
        };
        "quotaUser": {
            "type": string;
            "description": string;
            "location": string;
        };
        "userIp": {
            "type": string;
            "description": string;
            "location": string;
        };
    };
    "auth": {
        "oauth2": {
            "scopes": {
                "https://www.googleapis.com/auth/fitness.activity.read": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.activity.write": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.blood_glucose.read": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.blood_glucose.write": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.blood_pressure.read": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.blood_pressure.write": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.body.read": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.body.write": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.body_temperature.read": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.body_temperature.write": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.location.read": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.location.write": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.nutrition.read": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.nutrition.write": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.oxygen_saturation.read": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.oxygen_saturation.write": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.reproductive_health.read": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/fitness.reproductive_health.write": {
                    "description": string;
                };
            };
        };
    };
    "schemas": {
        "AggregateBucket": {
            "id": string;
            "type": string;
            "properties": {
                "activity": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
                "dataset": {
                    "type": string;
                    "description": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "endTimeMillis": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
                "session": {
                    "$ref": string;
                    "description": string;
                };
                "startTimeMillis": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
                "type": {
                    "type": string;
                    "description": string;
                    "enum": string[];
                    "enumDescriptions": string[];
                };
            };
        };
        "AggregateBy": {
            "id": string;
            "type": string;
            "description": string;
            "properties": {
                "dataSourceId": {
                    "type": string;
                    "description": string;
                };
                "dataTypeName": {
                    "type": string;
                    "description": string;
                };
            };
        };
        "AggregateRequest": {
            "id": string;
            "type": string;
            "description": string;
            "properties": {
                "aggregateBy": {
                    "type": string;
                    "description": string;
                    "items": {
                        "$ref": string;
                    };
                    "annotations": {
                        "required": string[];
                    };
                };
                "bucketByActivitySegment": {
                    "$ref": string;
                    "description": string;
                };
                "bucketByActivityType": {
                    "$ref": string;
                    "description": string;
                };
                "bucketBySession": {
                    "$ref": string;
                    "description": string;
                };
                "bucketByTime": {
                    "$ref": string;
                    "description": string;
                };
                "endTimeMillis": {
                    "type": string;
                    "description": string;
                    "format": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "filteredDataQualityStandard": {
                    "type": string;
                    "description": string;
                    "items": {
                        "type": string;
                        "enum": string[];
                        "enumDescriptions": string[];
                    };
                };
                "startTimeMillis": {
                    "type": string;
                    "description": string;
                    "format": string;
                    "annotations": {
                        "required": string[];
                    };
                };
            };
        };
        "AggregateResponse": {
            "id": string;
            "type": string;
            "properties": {
                "bucket": {
                    "type": string;
                    "description": string;
                    "items": {
                        "$ref": string;
                    };
                };
            };
        };
        "Application": {
            "id": string;
            "type": string;
            "description": string;
            "properties": {
                "detailsUrl": {
                    "type": string;
                    "description": string;
                };
                "name": {
                    "type": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "packageName": {
                    "type": string;
                    "description": string;
                };
                "version": {
                    "type": string;
                    "description": string;
                };
            };
        };
        "BucketByActivity": {
            "id": string;
            "type": string;
            "properties": {
                "activityDataSourceId": {
                    "type": string;
                    "description": string;
                };
                "minDurationMillis": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
            };
        };
        "BucketBySession": {
            "id": string;
            "type": string;
            "properties": {
                "minDurationMillis": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
            };
        };
        "BucketByTime": {
            "id": string;
            "type": string;
            "properties": {
                "durationMillis": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
                "period": {
                    "$ref": string;
                };
            };
        };
        "BucketByTimePeriod": {
            "id": string;
            "type": string;
            "properties": {
                "timeZoneId": {
                    "type": string;
                    "description": string;
                };
                "type": {
                    "type": string;
                    "enum": string[];
                    "enumDescriptions": string[];
                };
                "value": {
                    "type": string;
                    "format": string;
                };
            };
        };
        "DataPoint": {
            "id": string;
            "type": string;
            "description": string;
            "properties": {
                "computationTimeMillis": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
                "dataTypeName": {
                    "type": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "endTimeNanos": {
                    "type": string;
                    "description": string;
                    "format": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "modifiedTimeMillis": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
                "originDataSourceId": {
                    "type": string;
                    "description": string;
                };
                "rawTimestampNanos": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
                "startTimeNanos": {
                    "type": string;
                    "description": string;
                    "format": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "value": {
                    "type": string;
                    "description": string;
                    "items": {
                        "$ref": string;
                    };
                    "annotations": {
                        "required": string[];
                    };
                };
            };
        };
        "DataSource": {
            "id": string;
            "type": string;
            "description": string;
            "properties": {
                "application": {
                    "$ref": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "dataQualityStandard": {
                    "type": string;
                    "description": string;
                    "items": {
                        "type": string;
                        "enum": string[];
                        "enumDescriptions": string[];
                    };
                };
                "dataStreamId": {
                    "type": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "dataStreamName": {
                    "type": string;
                    "description": string;
                };
                "dataType": {
                    "$ref": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "device": {
                    "$ref": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "name": {
                    "type": string;
                    "description": string;
                };
                "type": {
                    "type": string;
                    "description": string;
                    "enum": string[];
                    "enumDescriptions": string[];
                    "annotations": {
                        "required": string[];
                    };
                };
            };
        };
        "DataType": {
            "id": string;
            "type": string;
            "description": string;
            "properties": {
                "field": {
                    "type": string;
                    "description": string;
                    "items": {
                        "$ref": string;
                    };
                    "annotations": {
                        "required": string[];
                    };
                };
                "name": {
                    "type": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
            };
        };
        "DataTypeField": {
            "id": string;
            "type": string;
            "description": string;
            "properties": {
                "format": {
                    "type": string;
                    "description": string;
                    "enum": string[];
                    "enumDescriptions": string[];
                    "annotations": {
                        "required": string[];
                    };
                };
                "name": {
                    "type": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "optional": {
                    "type": string;
                };
            };
        };
        "Dataset": {
            "id": string;
            "type": string;
            "description": string;
            "properties": {
                "dataSourceId": {
                    "type": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "maxEndTimeNs": {
                    "type": string;
                    "description": string;
                    "format": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "minStartTimeNs": {
                    "type": string;
                    "description": string;
                    "format": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "nextPageToken": {
                    "type": string;
                    "description": string;
                };
                "point": {
                    "type": string;
                    "description": string;
                    "items": {
                        "$ref": string;
                    };
                    "annotations": {
                        "required": string[];
                    };
                };
            };
        };
        "Device": {
            "id": string;
            "type": string;
            "description": string;
            "properties": {
                "manufacturer": {
                    "type": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "model": {
                    "type": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "type": {
                    "type": string;
                    "description": string;
                    "enum": string[];
                    "enumDescriptions": string[];
                    "annotations": {
                        "required": string[];
                    };
                };
                "uid": {
                    "type": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "version": {
                    "type": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
            };
        };
        "ListDataPointChangesResponse": {
            "id": string;
            "type": string;
            "properties": {
                "dataSourceId": {
                    "type": string;
                    "description": string;
                };
                "deletedDataPoint": {
                    "type": string;
                    "description": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "insertedDataPoint": {
                    "type": string;
                    "description": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "nextPageToken": {
                    "type": string;
                    "description": string;
                };
            };
        };
        "ListDataSourcesResponse": {
            "id": string;
            "type": string;
            "properties": {
                "dataSource": {
                    "type": string;
                    "description": string;
                    "items": {
                        "$ref": string;
                    };
                };
            };
        };
        "ListSessionsResponse": {
            "id": string;
            "type": string;
            "properties": {
                "deletedSession": {
                    "type": string;
                    "description": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "hasMoreData": {
                    "type": string;
                    "description": string;
                };
                "nextPageToken": {
                    "type": string;
                    "description": string;
                };
                "session": {
                    "type": string;
                    "description": string;
                    "items": {
                        "$ref": string;
                    };
                };
            };
        };
        "MapValue": {
            "id": string;
            "type": string;
            "description": string;
            "properties": {
                "fpVal": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
            };
        };
        "Session": {
            "id": string;
            "type": string;
            "description": string;
            "properties": {
                "activeTimeMillis": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
                "activityType": {
                    "type": string;
                    "description": string;
                    "format": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "application": {
                    "$ref": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "description": {
                    "type": string;
                    "description": string;
                };
                "endTimeMillis": {
                    "type": string;
                    "description": string;
                    "format": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "id": {
                    "type": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "modifiedTimeMillis": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
                "name": {
                    "type": string;
                    "description": string;
                    "annotations": {
                        "required": string[];
                    };
                };
                "startTimeMillis": {
                    "type": string;
                    "description": string;
                    "format": string;
                    "annotations": {
                        "required": string[];
                    };
                };
            };
        };
        "Value": {
            "id": string;
            "type": string;
            "description": string;
            "properties": {
                "fpVal": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
                "intVal": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
                "mapVal": {
                    "type": string;
                    "description": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "stringVal": {
                    "type": string;
                    "description": string;
                };
            };
        };
        "ValueMapValEntry": {
            "id": string;
            "type": string;
            "properties": {
                "key": {
                    "type": string;
                };
                "value": {
                    "$ref": string;
                };
            };
        };
    };
    "resources": {
        "users": {
            "resources": {
                "dataSources": {
                    "methods": {
                        "create": {
                            "id": string;
                            "path": string;
                            "httpMethod": string;
                            "description": string;
                            "parameters": {
                                "userId": {
                                    "type": string;
                                    "description": string;
                                    "required": boolean;
                                    "location": string;
                                };
                            };
                            "parameterOrder": string[];
                            "request": {
                                "$ref": string;
                            };
                            "response": {
                                "$ref": string;
                            };
                            "scopes": string[];
                        };
                        "delete": {
                            "id": string;
                            "path": string;
                            "httpMethod": string;
                            "description": string;
                            "parameters": {
                                "dataSourceId": {
                                    "type": string;
                                    "description": string;
                                    "required": boolean;
                                    "location": string;
                                };
                                "userId": {
                                    "type": string;
                                    "description": string;
                                    "required": boolean;
                                    "location": string;
                                };
                            };
                            "parameterOrder": string[];
                            "response": {
                                "$ref": string;
                            };
                            "scopes": string[];
                        };
                        "get": {
                            "id": string;
                            "path": string;
                            "httpMethod": string;
                            "description": string;
                            "parameters": {
                                "dataSourceId": {
                                    "type": string;
                                    "description": string;
                                    "required": boolean;
                                    "location": string;
                                };
                                "userId": {
                                    "type": string;
                                    "description": string;
                                    "required": boolean;
                                    "location": string;
                                };
                            };
                            "parameterOrder": string[];
                            "response": {
                                "$ref": string;
                            };
                            "scopes": string[];
                        };
                        "list": {
                            "id": string;
                            "path": string;
                            "httpMethod": string;
                            "description": string;
                            "parameters": {
                                "dataTypeName": {
                                    "type": string;
                                    "description": string;
                                    "repeated": boolean;
                                    "location": string;
                                };
                                "userId": {
                                    "type": string;
                                    "description": string;
                                    "required": boolean;
                                    "location": string;
                                };
                            };
                            "parameterOrder": string[];
                            "response": {
                                "$ref": string;
                            };
                            "scopes": string[];
                        };
                        "update": {
                            "id": string;
                            "path": string;
                            "httpMethod": string;
                            "description": string;
                            "parameters": {
                                "dataSourceId": {
                                    "type": string;
                                    "description": string;
                                    "required": boolean;
                                    "location": string;
                                };
                                "userId": {
                                    "type": string;
                                    "description": string;
                                    "required": boolean;
                                    "location": string;
                                };
                            };
                            "parameterOrder": string[];
                            "request": {
                                "$ref": string;
                            };
                            "response": {
                                "$ref": string;
                            };
                            "scopes": string[];
                        };
                    };
                    "resources": {
                        "dataPointChanges": {
                            "methods": {
                                "list": {
                                    "id": string;
                                    "path": string;
                                    "httpMethod": string;
                                    "description": string;
                                    "parameters": {
                                        "dataSourceId": {
                                            "type": string;
                                            "description": string;
                                            "required": boolean;
                                            "location": string;
                                        };
                                        "limit": {
                                            "type": string;
                                            "description": string;
                                            "format": string;
                                            "location": string;
                                        };
                                        "pageToken": {
                                            "type": string;
                                            "description": string;
                                            "location": string;
                                        };
                                        "userId": {
                                            "type": string;
                                            "description": string;
                                            "required": boolean;
                                            "location": string;
                                        };
                                    };
                                    "parameterOrder": string[];
                                    "response": {
                                        "$ref": string;
                                    };
                                    "scopes": string[];
                                };
                            };
                        };
                        "datasets": {
                            "methods": {
                                "delete": {
                                    "id": string;
                                    "path": string;
                                    "httpMethod": string;
                                    "description": string;
                                    "parameters": {
                                        "currentTimeMillis": {
                                            "type": string;
                                            "description": string;
                                            "format": string;
                                            "location": string;
                                        };
                                        "dataSourceId": {
                                            "type": string;
                                            "description": string;
                                            "required": boolean;
                                            "location": string;
                                        };
                                        "datasetId": {
                                            "type": string;
                                            "description": string;
                                            "required": boolean;
                                            "location": string;
                                        };
                                        "modifiedTimeMillis": {
                                            "type": string;
                                            "description": string;
                                            "format": string;
                                            "location": string;
                                        };
                                        "userId": {
                                            "type": string;
                                            "description": string;
                                            "required": boolean;
                                            "location": string;
                                        };
                                    };
                                    "parameterOrder": string[];
                                    "scopes": string[];
                                };
                                "get": {
                                    "id": string;
                                    "path": string;
                                    "httpMethod": string;
                                    "description": string;
                                    "parameters": {
                                        "dataSourceId": {
                                            "type": string;
                                            "description": string;
                                            "required": boolean;
                                            "location": string;
                                        };
                                        "datasetId": {
                                            "type": string;
                                            "description": string;
                                            "required": boolean;
                                            "location": string;
                                        };
                                        "limit": {
                                            "type": string;
                                            "description": string;
                                            "format": string;
                                            "location": string;
                                        };
                                        "pageToken": {
                                            "type": string;
                                            "description": string;
                                            "location": string;
                                        };
                                        "userId": {
                                            "type": string;
                                            "description": string;
                                            "required": boolean;
                                            "location": string;
                                        };
                                    };
                                    "parameterOrder": string[];
                                    "response": {
                                        "$ref": string;
                                    };
                                    "scopes": string[];
                                };
                                "patch": {
                                    "id": string;
                                    "path": string;
                                    "httpMethod": string;
                                    "description": string;
                                    "parameters": {
                                        "currentTimeMillis": {
                                            "type": string;
                                            "description": string;
                                            "format": string;
                                            "location": string;
                                        };
                                        "dataSourceId": {
                                            "type": string;
                                            "description": string;
                                            "required": boolean;
                                            "location": string;
                                        };
                                        "datasetId": {
                                            "type": string;
                                            "description": string;
                                            "required": boolean;
                                            "location": string;
                                        };
                                        "userId": {
                                            "type": string;
                                            "description": string;
                                            "required": boolean;
                                            "location": string;
                                        };
                                    };
                                    "parameterOrder": string[];
                                    "request": {
                                        "$ref": string;
                                    };
                                    "response": {
                                        "$ref": string;
                                    };
                                    "scopes": string[];
                                };
                            };
                        };
                    };
                };
                "dataset": {
                    "methods": {
                        "aggregate": {
                            "id": string;
                            "path": string;
                            "httpMethod": string;
                            "description": string;
                            "parameters": {
                                "userId": {
                                    "type": string;
                                    "description": string;
                                    "required": boolean;
                                    "location": string;
                                };
                            };
                            "parameterOrder": string[];
                            "request": {
                                "$ref": string;
                            };
                            "response": {
                                "$ref": string;
                            };
                            "scopes": string[];
                        };
                    };
                };
                "sessions": {
                    "methods": {
                        "delete": {
                            "id": string;
                            "path": string;
                            "httpMethod": string;
                            "description": string;
                            "parameters": {
                                "currentTimeMillis": {
                                    "type": string;
                                    "description": string;
                                    "format": string;
                                    "location": string;
                                };
                                "sessionId": {
                                    "type": string;
                                    "description": string;
                                    "required": boolean;
                                    "location": string;
                                };
                                "userId": {
                                    "type": string;
                                    "description": string;
                                    "required": boolean;
                                    "location": string;
                                };
                            };
                            "parameterOrder": string[];
                            "scopes": string[];
                        };
                        "list": {
                            "id": string;
                            "path": string;
                            "httpMethod": string;
                            "description": string;
                            "parameters": {
                                "endTime": {
                                    "type": string;
                                    "description": string;
                                    "location": string;
                                };
                                "includeDeleted": {
                                    "type": string;
                                    "description": string;
                                    "location": string;
                                };
                                "pageToken": {
                                    "type": string;
                                    "description": string;
                                    "location": string;
                                };
                                "startTime": {
                                    "type": string;
                                    "description": string;
                                    "location": string;
                                };
                                "userId": {
                                    "type": string;
                                    "description": string;
                                    "required": boolean;
                                    "location": string;
                                };
                            };
                            "parameterOrder": string[];
                            "response": {
                                "$ref": string;
                            };
                            "scopes": string[];
                        };
                        "update": {
                            "id": string;
                            "path": string;
                            "httpMethod": string;
                            "description": string;
                            "parameters": {
                                "currentTimeMillis": {
                                    "type": string;
                                    "description": string;
                                    "format": string;
                                    "location": string;
                                };
                                "sessionId": {
                                    "type": string;
                                    "description": string;
                                    "required": boolean;
                                    "location": string;
                                };
                                "userId": {
                                    "type": string;
                                    "description": string;
                                    "required": boolean;
                                    "location": string;
                                };
                            };
                            "parameterOrder": string[];
                            "request": {
                                "$ref": string;
                            };
                            "response": {
                                "$ref": string;
                            };
                            "scopes": string[];
                        };
                    };
                };
            };
        };
    };
};
export default _default;
//# sourceMappingURL=fitness-v1.d.ts.map