declare const _default: {
    "title": string;
    "discoveryVersion": string;
    "ownerName": string;
    "resources": {
        "operations": {
            "methods": {
                "cancel": {
                    "response": {
                        "$ref": string;
                    };
                    "parameterOrder": string[];
                    "httpMethod": string;
                    "scopes": string[];
                    "parameters": {
                        "name": {
                            "location": string;
                            "description": string;
                            "required": boolean;
                            "type": string;
                            "pattern": string;
                        };
                    };
                    "flatPath": string;
                    "path": string;
                    "id": string;
                    "request": {
                        "$ref": string;
                    };
                    "description": string;
                };
                "list": {
                    "flatPath": string;
                    "id": string;
                    "path": string;
                    "description": string;
                    "httpMethod": string;
                    "response": {
                        "$ref": string;
                    };
                    "parameterOrder": string[];
                    "parameters": {
                        "filter": {
                            "description": string;
                            "type": string;
                            "location": string;
                        };
                        "name": {
                            "description": string;
                            "required": boolean;
                            "type": string;
                            "pattern": string;
                            "location": string;
                        };
                        "pageToken": {
                            "location": string;
                            "description": string;
                            "type": string;
                        };
                        "pageSize": {
                            "location": string;
                            "description": string;
                            "format": string;
                            "type": string;
                        };
                    };
                    "scopes": string[];
                };
                "get": {
                    "flatPath": string;
                    "path": string;
                    "id": string;
                    "description": string;
                    "response": {
                        "$ref": string;
                    };
                    "parameterOrder": string[];
                    "httpMethod": string;
                    "scopes": string[];
                    "parameters": {
                        "name": {
                            "description": string;
                            "required": boolean;
                            "type": string;
                            "pattern": string;
                            "location": string;
                        };
                    };
                };
            };
        };
    };
    "parameters": {
        "key": {
            "description": string;
            "type": string;
            "location": string;
        };
        "access_token": {
            "description": string;
            "type": string;
            "location": string;
        };
        "upload_protocol": {
            "description": string;
            "type": string;
            "location": string;
        };
        "prettyPrint": {
            "location": string;
            "description": string;
            "type": string;
            "default": string;
        };
        "quotaUser": {
            "type": string;
            "location": string;
            "description": string;
        };
        "uploadType": {
            "type": string;
            "location": string;
            "description": string;
        };
        "fields": {
            "location": string;
            "description": string;
            "type": string;
        };
        "$.xgafv": {
            "location": string;
            "enum": string[];
            "description": string;
            "type": string;
            "enumDescriptions": string[];
        };
        "oauth_token": {
            "type": string;
            "location": string;
            "description": string;
        };
        "callback": {
            "description": string;
            "type": string;
            "location": string;
        };
        "alt": {
            "default": string;
            "enum": string[];
            "type": string;
            "enumDescriptions": string[];
            "location": string;
            "description": string;
        };
    };
    "schemas": {
        "ContainerStoppedEvent": {
            "id": string;
            "description": string;
            "type": string;
            "properties": {
                "stderr": {
                    "description": string;
                    "type": string;
                };
                "exitStatus": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
                "actionId": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
            };
        };
        "ContainerStartedEvent": {
            "id": string;
            "description": string;
            "type": string;
            "properties": {
                "actionId": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
                "ipAddress": {
                    "description": string;
                    "type": string;
                };
                "portMappings": {
                    "additionalProperties": {
                        "format": string;
                        "type": string;
                    };
                    "description": string;
                    "type": string;
                };
            };
        };
        "PullStartedEvent": {
            "type": string;
            "properties": {
                "imageUri": {
                    "type": string;
                    "description": string;
                };
            };
            "id": string;
            "description": string;
        };
        "UnexpectedExitStatusEvent": {
            "description": string;
            "type": string;
            "properties": {
                "exitStatus": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
                "actionId": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "CancelOperationRequest": {
            "id": string;
            "description": string;
            "type": string;
            "properties": {};
        };
        "ComputeEngine": {
            "type": string;
            "properties": {
                "machineType": {
                    "description": string;
                    "type": string;
                };
                "diskNames": {
                    "description": string;
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
                "instanceName": {
                    "type": string;
                    "description": string;
                };
                "zone": {
                    "type": string;
                    "description": string;
                };
            };
            "id": string;
            "description": string;
        };
        "PullStoppedEvent": {
            "description": string;
            "type": string;
            "properties": {
                "imageUri": {
                    "type": string;
                    "description": string;
                };
            };
            "id": string;
        };
        "RuntimeMetadata": {
            "description": string;
            "type": string;
            "properties": {
                "computeEngine": {
                    "$ref": string;
                    "description": string;
                };
            };
            "id": string;
        };
        "Operation": {
            "type": string;
            "properties": {
                "metadata": {
                    "additionalProperties": {
                        "description": string;
                        "type": string;
                    };
                    "description": string;
                    "type": string;
                };
                "done": {
                    "type": string;
                    "description": string;
                };
                "response": {
                    "description": string;
                    "type": string;
                    "additionalProperties": {
                        "description": string;
                        "type": string;
                    };
                };
                "name": {
                    "description": string;
                    "type": string;
                };
                "error": {
                    "$ref": string;
                    "description": string;
                };
            };
            "id": string;
            "description": string;
        };
        "WorkerAssignedEvent": {
            "id": string;
            "description": string;
            "type": string;
            "properties": {
                "zone": {
                    "description": string;
                    "type": string;
                };
                "instance": {
                    "type": string;
                    "description": string;
                };
            };
        };
        "RunPipelineResponse": {
            "description": string;
            "type": string;
            "properties": {};
            "id": string;
        };
        "DelayedEvent": {
            "type": string;
            "properties": {
                "metrics": {
                    "description": string;
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
                "cause": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
            "description": string;
        };
        "Status": {
            "description": string;
            "type": string;
            "properties": {
                "message": {
                    "description": string;
                    "type": string;
                };
                "details": {
                    "description": string;
                    "type": string;
                    "items": {
                        "type": string;
                        "additionalProperties": {
                            "description": string;
                            "type": string;
                        };
                    };
                };
                "code": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "Event": {
            "type": string;
            "properties": {
                "timestamp": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
                "details": {
                    "type": string;
                    "additionalProperties": {
                        "description": string;
                        "type": string;
                    };
                    "description": string;
                };
                "description": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
            "description": string;
        };
        "Empty": {
            "type": string;
            "properties": {};
            "id": string;
            "description": string;
        };
        "WorkerReleasedEvent": {
            "description": string;
            "type": string;
            "properties": {
                "instance": {
                    "description": string;
                    "type": string;
                };
                "zone": {
                    "type": string;
                    "description": string;
                };
            };
            "id": string;
        };
        "OperationEvent": {
            "description": string;
            "type": string;
            "properties": {
                "endTime": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
                "startTime": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
                "description": {
                    "description": string;
                    "type": string;
                };
            };
            "id": string;
        };
        "ListOperationsResponse": {
            "description": string;
            "type": string;
            "properties": {
                "nextPageToken": {
                    "description": string;
                    "type": string;
                };
                "operations": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
            };
            "id": string;
        };
        "OperationMetadata": {
            "id": string;
            "description": string;
            "type": string;
            "properties": {
                "clientId": {
                    "description": string;
                    "type": string;
                };
                "events": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
                "endTime": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
                "startTime": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
                "request": {
                    "description": string;
                    "type": string;
                    "additionalProperties": {
                        "description": string;
                        "type": string;
                    };
                };
                "runtimeMetadata": {
                    "additionalProperties": {
                        "description": string;
                        "type": string;
                    };
                    "description": string;
                    "type": string;
                };
                "createTime": {
                    "type": string;
                    "description": string;
                    "format": string;
                };
                "labels": {
                    "description": string;
                    "type": string;
                    "additionalProperties": {
                        "type": string;
                    };
                };
                "projectId": {
                    "description": string;
                    "type": string;
                };
            };
        };
        "FailedEvent": {
            "description": string;
            "type": string;
            "properties": {
                "cause": {
                    "description": string;
                    "type": string;
                };
                "code": {
                    "type": string;
                    "enumDescriptions": string[];
                    "enum": string[];
                    "description": string;
                };
            };
            "id": string;
        };
        "ContainerKilledEvent": {
            "description": string;
            "type": string;
            "properties": {
                "actionId": {
                    "description": string;
                    "format": string;
                    "type": string;
                };
            };
            "id": string;
        };
    };
    "icons": {
        "x16": string;
        "x32": string;
    };
    "protocol": string;
    "version": string;
    "baseUrl": string;
    "auth": {
        "oauth2": {
            "scopes": {
                "https://www.googleapis.com/auth/cloud-platform": {
                    "description": string;
                };
                "https://www.googleapis.com/auth/genomics": {
                    "description": string;
                };
            };
        };
    };
    "description": string;
    "servicePath": string;
    "kind": string;
    "rootUrl": string;
    "basePath": string;
    "ownerDomain": string;
    "name": string;
    "batchPath": string;
    "revision": string;
    "documentationLink": string;
    "id": string;
    "fullyEncodeReservedExpansion": boolean;
};
export default _default;
//# sourceMappingURL=genomics-v1.d.ts.map