"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "resources": { "apps": { "methods": { "repair": { "description": "Recreates the required App Engine features for the specified App Engine application, for example a Cloud Storage bucket or App Engine service account. Use this method if you receive an error message about a missing feature, for example, Error retrieving the App Engine service account. If you have deleted your App Engine service account, this will not be able to recreate it. Instead, you should attempt to use the IAM undelete API if possible at https://cloud.google.com/iam/reference/rest/v1/projects.serviceAccounts/undelete?apix_params=%7B\"name\"%3A\"projects%2F-%2FserviceAccounts%2Funique_id\"%2C\"resource\"%3A%7B%7D%7D . If the deletion was recent, the numeric ID can be found in the Cloud Console Activity Log.", "request": { "$ref": "RepairApplicationRequest" }, "response": { "$ref": "Operation" }, "parameterOrder": ["appsId"], "httpMethod": "POST", "parameters": { "appsId": { "location": "path", "description": "Part of `name`. Name of the application to repair. Example: apps/myapp", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1/apps/{appsId}:repair", "path": "v1/apps/{appsId}:repair", "id": "appengine.apps.repair" }, "get": { "httpMethod": "GET", "parameterOrder": ["appsId"], "response": { "$ref": "Application" }, "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "appsId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. Name of the Application resource to get. Example: apps/myapp." } }, "flatPath": "v1/apps/{appsId}", "id": "appengine.apps.get", "path": "v1/apps/{appsId}", "description": "Gets information about an application." }, "patch": { "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "updateMask": { "description": "Standard field mask for the set of fields to be updated.", "format": "google-fieldmask", "type": "string", "location": "query" }, "appsId": { "location": "path", "description": "Part of `name`. Name of the Application resource to update. Example: apps/myapp.", "required": true, "type": "string" } }, "flatPath": "v1/apps/{appsId}", "id": "appengine.apps.patch", "path": "v1/apps/{appsId}", "request": { "$ref": "Application" }, "description": "Updates the specified Application resource. You can update the following fields:\nauth_domain - Google authentication domain for controlling user access to the application.\ndefault_cookie_expiration - Cookie expiration policy for the application.", "httpMethod": "PATCH", "parameterOrder": ["appsId"], "response": { "$ref": "Operation" } }, "create": { "flatPath": "v1/apps", "path": "v1/apps", "id": "appengine.apps.create", "description": "Creates an App Engine application for a Google Cloud Platform project. Required fields:\nid - The ID of the target Cloud Platform project.\nlocation - The region (https://cloud.google.com/appengine/docs/locations) where you want the App Engine application located.For more information about App Engine applications, see Managing Projects, Applications, and Billing (https://cloud.google.com/appengine/docs/standard/python/console/).", "request": { "$ref": "Application" }, "response": { "$ref": "Operation" }, "parameterOrder": [], "httpMethod": "POST", "parameters": {}, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] } }, "resources": { "domainMappings": { "methods": { "list": { "parameters": { "appsId": { "description": "Part of `parent`. Name of the parent Application resource. Example: apps/myapp.", "required": true, "type": "string", "location": "path" }, "pageToken": { "location": "query", "description": "Continuation token for fetching the next page of results.", "type": "string" }, "pageSize": { "description": "Maximum results to return per page.", "format": "int32", "type": "integer", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/apps/{appsId}/domainMappings", "path": "v1/apps/{appsId}/domainMappings", "id": "appengine.apps.domainMappings.list", "description": "Lists the domain mappings on an application.", "response": { "$ref": "ListDomainMappingsResponse" }, "parameterOrder": ["appsId"], "httpMethod": "GET" }, "get": { "response": { "$ref": "DomainMapping" }, "parameterOrder": ["appsId", "domainMappingsId"], "httpMethod": "GET", "parameters": { "appsId": { "location": "path", "description": "Part of `name`. Name of the resource requested. Example: apps/myapp/domainMappings/example.com.", "required": true, "type": "string" }, "domainMappingsId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. See documentation of `appsId`." } }, "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/apps/{appsId}/domainMappings/{domainMappingsId}", "path": "v1/apps/{appsId}/domainMappings/{domainMappingsId}", "id": "appengine.apps.domainMappings.get", "description": "Gets the specified domain mapping." }, "patch": { "description": "Updates the specified domain mapping. To map an SSL certificate to a domain mapping, update certificate_id to point to an AuthorizedCertificate resource. A user must be authorized to administer the associated domain in order to update a DomainMapping resource.", "request": { "$ref": "DomainMapping" }, "httpMethod": "PATCH", "parameterOrder": ["appsId", "domainMappingsId"], "response": { "$ref": "Operation" }, "parameters": { "appsId": { "location": "path", "description": "Part of `name`. Name of the resource to update. Example: apps/myapp/domainMappings/example.com.", "required": true, "type": "string" }, "domainMappingsId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. See documentation of `appsId`." }, "updateMask": { "description": "Standard field mask for the set of fields to be updated.", "format": "google-fieldmask", "type": "string", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1/apps/{appsId}/domainMappings/{domainMappingsId}", "id": "appengine.apps.domainMappings.patch", "path": "v1/apps/{appsId}/domainMappings/{domainMappingsId}" }, "create": { "httpMethod": "POST", "parameterOrder": ["appsId"], "response": { "$ref": "Operation" }, "parameters": { "appsId": { "description": "Part of `parent`. Name of the parent Application resource. Example: apps/myapp.", "required": true, "type": "string", "location": "path" }, "overrideStrategy": { "location": "query", "enum": ["UNSPECIFIED_DOMAIN_OVERRIDE_STRATEGY", "STRICT", "OVERRIDE"], "description": "Whether the domain creation should override any existing mappings for this domain. By default, overrides are rejected.", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1/apps/{appsId}/domainMappings", "id": "appengine.apps.domainMappings.create", "path": "v1/apps/{appsId}/domainMappings", "description": "Maps a domain to an application. A user must be authorized to administer a domain in order to map it to an application. For a list of available authorized domains, see AuthorizedDomains.ListAuthorizedDomains.", "request": { "$ref": "DomainMapping" } }, "delete": { "flatPath": "v1/apps/{appsId}/domainMappings/{domainMappingsId}", "path": "v1/apps/{appsId}/domainMappings/{domainMappingsId}", "id": "appengine.apps.domainMappings.delete", "description": "Deletes the specified domain mapping. A user must be authorized to administer the associated domain in order to delete a DomainMapping resource.", "response": { "$ref": "Operation" }, "parameterOrder": ["appsId", "domainMappingsId"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "appsId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. Name of the resource to delete. Example: apps/myapp/domainMappings/example.com." }, "domainMappingsId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" } } } } }, "firewall": { "resources": { "ingressRules": { "methods": { "create": { "httpMethod": "POST", "parameterOrder": ["appsId"], "response": { "$ref": "FirewallRule" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "appsId": { "required": true, "type": "string", "location": "path", "description": "Part of `parent`. Name of the parent Firewall collection in which to create a new rule. Example: apps/myapp/firewall/ingressRules." } }, "flatPath": "v1/apps/{appsId}/firewall/ingressRules", "id": "appengine.apps.firewall.ingressRules.create", "path": "v1/apps/{appsId}/firewall/ingressRules", "request": { "$ref": "FirewallRule" }, "description": "Creates a firewall rule for the application." }, "get": { "response": { "$ref": "FirewallRule" }, "parameterOrder": ["appsId", "ingressRulesId"], "httpMethod": "GET", "parameters": { "appsId": { "location": "path", "description": "Part of `name`. Name of the Firewall resource to retrieve. Example: apps/myapp/firewall/ingressRules/100.", "required": true, "type": "string" }, "ingressRulesId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/apps/{appsId}/firewall/ingressRules/{ingressRulesId}", "path": "v1/apps/{appsId}/firewall/ingressRules/{ingressRulesId}", "id": "appengine.apps.firewall.ingressRules.get", "description": "Gets the specified firewall rule." }, "patch": { "flatPath": "v1/apps/{appsId}/firewall/ingressRules/{ingressRulesId}", "path": "v1/apps/{appsId}/firewall/ingressRules/{ingressRulesId}", "id": "appengine.apps.firewall.ingressRules.patch", "description": "Updates the specified firewall rule.", "request": { "$ref": "FirewallRule" }, "response": { "$ref": "FirewallRule" }, "parameterOrder": ["appsId", "ingressRulesId"], "httpMethod": "PATCH", "parameters": { "appsId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. Name of the Firewall resource to update. Example: apps/myapp/firewall/ingressRules/100." }, "ingressRulesId": { "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string", "location": "path" }, "updateMask": { "description": "Standard field mask for the set of fields to be updated.", "format": "google-fieldmask", "type": "string", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] }, "batchUpdate": { "flatPath": "v1/apps/{appsId}/firewall/ingressRules:batchUpdate", "id": "appengine.apps.firewall.ingressRules.batchUpdate", "path": "v1/apps/{appsId}/firewall/ingressRules:batchUpdate", "description": "Replaces the entire firewall ruleset in one bulk operation. This overrides and replaces the rules of an existing firewall with the new rules.If the final rule does not match traffic with the '*' wildcard IP range, then an \"allow all\" rule is explicitly added to the end of the list.", "request": { "$ref": "BatchUpdateIngressRulesRequest" }, "httpMethod": "POST", "parameterOrder": ["appsId"], "response": { "$ref": "BatchUpdateIngressRulesResponse" }, "parameters": { "appsId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. Name of the Firewall collection to set. Example: apps/myapp/firewall/ingressRules." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] }, "delete": { "description": "Deletes the specified firewall rule.", "response": { "$ref": "Empty" }, "parameterOrder": ["appsId", "ingressRulesId"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "appsId": { "description": "Part of `name`. Name of the Firewall resource to delete. Example: apps/myapp/firewall/ingressRules/100.", "required": true, "type": "string", "location": "path" }, "ingressRulesId": { "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/apps/{appsId}/firewall/ingressRules/{ingressRulesId}", "path": "v1/apps/{appsId}/firewall/ingressRules/{ingressRulesId}", "id": "appengine.apps.firewall.ingressRules.delete" }, "list": { "response": { "$ref": "ListIngressRulesResponse" }, "parameterOrder": ["appsId"], "httpMethod": "GET", "parameters": { "appsId": { "location": "path", "description": "Part of `parent`. Name of the Firewall collection to retrieve. Example: apps/myapp/firewall/ingressRules.", "required": true, "type": "string" }, "pageToken": { "location": "query", "description": "Continuation token for fetching the next page of results.", "type": "string" }, "pageSize": { "location": "query", "description": "Maximum results to return per page.", "format": "int32", "type": "integer" }, "matchingAddress": { "type": "string", "location": "query", "description": "A valid IP Address. If set, only rules matching this address will be returned. The first returned rule will be the rule that fires on requests from this IP." } }, "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/apps/{appsId}/firewall/ingressRules", "path": "v1/apps/{appsId}/firewall/ingressRules", "id": "appengine.apps.firewall.ingressRules.list", "description": "Lists the firewall rules of an application." } } } } }, "locations": { "methods": { "list": { "id": "appengine.apps.locations.list", "path": "v1/apps/{appsId}/locations", "description": "Lists information about the supported locations for this service.", "httpMethod": "GET", "parameterOrder": ["appsId"], "response": { "$ref": "ListLocationsResponse" }, "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "appsId": { "location": "path", "description": "Part of `name`. The resource that owns the locations collection, if applicable.", "required": true, "type": "string" }, "pageToken": { "type": "string", "location": "query", "description": "The standard list page token." }, "pageSize": { "location": "query", "description": "The standard list page size.", "format": "int32", "type": "integer" }, "filter": { "type": "string", "location": "query", "description": "The standard list filter." } }, "flatPath": "v1/apps/{appsId}/locations" }, "get": { "response": { "$ref": "Location" }, "parameterOrder": ["appsId", "locationsId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "appsId": { "location": "path", "description": "Part of `name`. Resource name for the location.", "required": true, "type": "string" }, "locationsId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. See documentation of `appsId`." } }, "flatPath": "v1/apps/{appsId}/locations/{locationsId}", "path": "v1/apps/{appsId}/locations/{locationsId}", "id": "appengine.apps.locations.get", "description": "Gets information about a location." } } }, "authorizedCertificates": { "methods": { "delete": { "flatPath": "v1/apps/{appsId}/authorizedCertificates/{authorizedCertificatesId}", "path": "v1/apps/{appsId}/authorizedCertificates/{authorizedCertificatesId}", "id": "appengine.apps.authorizedCertificates.delete", "description": "Deletes the specified SSL certificate.", "response": { "$ref": "Empty" }, "parameterOrder": ["appsId", "authorizedCertificatesId"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "authorizedCertificatesId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" }, "appsId": { "location": "path", "description": "Part of `name`. Name of the resource to delete. Example: apps/myapp/authorizedCertificates/12345.", "required": true, "type": "string" } } }, "list": { "description": "Lists all SSL certificates the user is authorized to administer.", "response": { "$ref": "ListAuthorizedCertificatesResponse" }, "parameterOrder": ["appsId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "appsId": { "location": "path", "description": "Part of `parent`. Name of the parent Application resource. Example: apps/myapp.", "required": true, "type": "string" }, "pageToken": { "description": "Continuation token for fetching the next page of results.", "type": "string", "location": "query" }, "pageSize": { "description": "Maximum results to return per page.", "format": "int32", "type": "integer", "location": "query" }, "view": { "type": "string", "location": "query", "enum": ["BASIC_CERTIFICATE", "FULL_CERTIFICATE"], "description": "Controls the set of fields returned in the LIST response." } }, "flatPath": "v1/apps/{appsId}/authorizedCertificates", "path": "v1/apps/{appsId}/authorizedCertificates", "id": "appengine.apps.authorizedCertificates.list" }, "get": { "flatPath": "v1/apps/{appsId}/authorizedCertificates/{authorizedCertificatesId}", "id": "appengine.apps.authorizedCertificates.get", "path": "v1/apps/{appsId}/authorizedCertificates/{authorizedCertificatesId}", "description": "Gets the specified SSL certificate.", "httpMethod": "GET", "parameterOrder": ["appsId", "authorizedCertificatesId"], "response": { "$ref": "AuthorizedCertificate" }, "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "appsId": { "description": "Part of `name`. Name of the resource requested. Example: apps/myapp/authorizedCertificates/12345.", "required": true, "type": "string", "location": "path" }, "view": { "type": "string", "location": "query", "enum": ["BASIC_CERTIFICATE", "FULL_CERTIFICATE"], "description": "Controls the set of fields returned in the GET response." }, "authorizedCertificatesId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. See documentation of `appsId`." } } }, "patch": { "response": { "$ref": "AuthorizedCertificate" }, "parameterOrder": ["appsId", "authorizedCertificatesId"], "httpMethod": "PATCH", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "appsId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. Name of the resource to update. Example: apps/myapp/authorizedCertificates/12345." }, "authorizedCertificatesId": { "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string", "location": "path" }, "updateMask": { "location": "query", "description": "Standard field mask for the set of fields to be updated. Updates are only supported on the certificate_raw_data and display_name fields.", "format": "google-fieldmask", "type": "string" } }, "flatPath": "v1/apps/{appsId}/authorizedCertificates/{authorizedCertificatesId}", "path": "v1/apps/{appsId}/authorizedCertificates/{authorizedCertificatesId}", "id": "appengine.apps.authorizedCertificates.patch", "request": { "$ref": "AuthorizedCertificate" }, "description": "Updates the specified SSL certificate. To renew a certificate and maintain its existing domain mappings, update certificate_data with a new certificate. The new certificate must be applicable to the same domains as the original certificate. The certificate display_name may also be updated." }, "create": { "response": { "$ref": "AuthorizedCertificate" }, "parameterOrder": ["appsId"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "appsId": { "description": "Part of `parent`. Name of the parent Application resource. Example: apps/myapp.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/apps/{appsId}/authorizedCertificates", "path": "v1/apps/{appsId}/authorizedCertificates", "id": "appengine.apps.authorizedCertificates.create", "request": { "$ref": "AuthorizedCertificate" }, "description": "Uploads the specified SSL certificate." } } }, "services": { "methods": { "delete": { "response": { "$ref": "Operation" }, "parameterOrder": ["appsId", "servicesId"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "servicesId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" }, "appsId": { "location": "path", "description": "Part of `name`. Name of the resource requested. Example: apps/myapp/services/default.", "required": true, "type": "string" } }, "flatPath": "v1/apps/{appsId}/services/{servicesId}", "path": "v1/apps/{appsId}/services/{servicesId}", "id": "appengine.apps.services.delete", "description": "Deletes the specified service and all enclosed versions." }, "list": { "httpMethod": "GET", "parameterOrder": ["appsId"], "response": { "$ref": "ListServicesResponse" }, "parameters": { "appsId": { "required": true, "type": "string", "location": "path", "description": "Part of `parent`. Name of the parent Application resource. Example: apps/myapp." }, "pageToken": { "location": "query", "description": "Continuation token for fetching the next page of results.", "type": "string" }, "pageSize": { "location": "query", "description": "Maximum results to return per page.", "format": "int32", "type": "integer" } }, "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/apps/{appsId}/services", "id": "appengine.apps.services.list", "path": "v1/apps/{appsId}/services", "description": "Lists all the services in the application." }, "get": { "description": "Gets the current configuration of the specified service.", "response": { "$ref": "Service" }, "parameterOrder": ["appsId", "servicesId"], "httpMethod": "GET", "parameters": { "servicesId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" }, "appsId": { "location": "path", "description": "Part of `name`. Name of the resource requested. Example: apps/myapp/services/default.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/apps/{appsId}/services/{servicesId}", "path": "v1/apps/{appsId}/services/{servicesId}", "id": "appengine.apps.services.get" }, "patch": { "flatPath": "v1/apps/{appsId}/services/{servicesId}", "path": "v1/apps/{appsId}/services/{servicesId}", "id": "appengine.apps.services.patch", "request": { "$ref": "Service" }, "description": "Updates the configuration of the specified service.", "response": { "$ref": "Operation" }, "parameterOrder": ["appsId", "servicesId"], "httpMethod": "PATCH", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "updateMask": { "description": "Standard field mask for the set of fields to be updated.", "format": "google-fieldmask", "type": "string", "location": "query" }, "servicesId": { "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string", "location": "path" }, "appsId": { "location": "path", "description": "Part of `name`. Name of the resource to update. Example: apps/myapp/services/default.", "required": true, "type": "string" }, "migrateTraffic": { "type": "boolean", "location": "query", "description": "Set to true to gradually shift traffic to one or more versions that you specify. By default, traffic is shifted immediately. For gradual traffic migration, the target versions must be located within instances that are configured for both warmup requests (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#InboundServiceType) and automatic scaling (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#AutomaticScaling). You must specify the shardBy (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services#ShardBy) field in the Service resource. Gradual traffic migration is not supported in the App Engine flexible environment. For examples, see Migrating and Splitting Traffic (https://cloud.google.com/appengine/docs/admin-api/migrating-splitting-traffic)." } } } }, "resources": { "versions": { "methods": { "delete": { "description": "Deletes an existing Version resource.", "response": { "$ref": "Operation" }, "parameterOrder": ["appsId", "servicesId", "versionsId"], "httpMethod": "DELETE", "parameters": { "servicesId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" }, "appsId": { "description": "Part of `name`. Name of the resource requested. Example: apps/myapp/services/default/versions/v1.", "required": true, "type": "string", "location": "path" }, "versionsId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1/apps/{appsId}/services/{servicesId}/versions/{versionsId}", "path": "v1/apps/{appsId}/services/{servicesId}/versions/{versionsId}", "id": "appengine.apps.services.versions.delete" }, "list": { "flatPath": "v1/apps/{appsId}/services/{servicesId}/versions", "path": "v1/apps/{appsId}/services/{servicesId}/versions", "id": "appengine.apps.services.versions.list", "description": "Lists the versions of a service.", "response": { "$ref": "ListVersionsResponse" }, "parameterOrder": ["appsId", "servicesId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "appsId": { "required": true, "type": "string", "location": "path", "description": "Part of `parent`. Name of the parent Service resource. Example: apps/myapp/services/default." }, "pageToken": { "location": "query", "description": "Continuation token for fetching the next page of results.", "type": "string" }, "pageSize": { "type": "integer", "location": "query", "description": "Maximum results to return per page.", "format": "int32" }, "view": { "type": "string", "location": "query", "enum": ["BASIC", "FULL"], "description": "Controls the set of fields returned in the List response." }, "servicesId": { "description": "Part of `parent`. See documentation of `appsId`.", "required": true, "type": "string", "location": "path" } } }, "get": { "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "appsId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. Name of the resource requested. Example: apps/myapp/services/default/versions/v1." }, "versionsId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" }, "view": { "location": "query", "enum": ["BASIC", "FULL"], "description": "Controls the set of fields returned in the Get response.", "type": "string" }, "servicesId": { "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string", "location": "path" } }, "flatPath": "v1/apps/{appsId}/services/{servicesId}/versions/{versionsId}", "path": "v1/apps/{appsId}/services/{servicesId}/versions/{versionsId}", "id": "appengine.apps.services.versions.get", "description": "Gets the specified Version resource. By default, only a BASIC_VIEW will be returned. Specify the FULL_VIEW parameter to get the full resource.", "response": { "$ref": "Version" }, "parameterOrder": ["appsId", "servicesId", "versionsId"], "httpMethod": "GET" }, "patch": { "httpMethod": "PATCH", "parameterOrder": ["appsId", "servicesId", "versionsId"], "response": { "$ref": "Operation" }, "parameters": { "servicesId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" }, "appsId": { "location": "path", "description": "Part of `name`. Name of the resource to update. Example: apps/myapp/services/default/versions/1.", "required": true, "type": "string" }, "versionsId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" }, "updateMask": { "location": "query", "description": "Standard field mask for the set of fields to be updated.", "format": "google-fieldmask", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1/apps/{appsId}/services/{servicesId}/versions/{versionsId}", "id": "appengine.apps.services.versions.patch", "path": "v1/apps/{appsId}/services/{servicesId}/versions/{versionsId}", "description": "Updates the specified Version resource. You can specify the following fields depending on the App Engine environment and type of scaling that the version resource uses:Standard environment\ninstance_class (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#Version.FIELDS.instance_class)automatic scaling in the standard environment:\nautomatic_scaling.min_idle_instances (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#Version.FIELDS.automatic_scaling)\nautomatic_scaling.max_idle_instances (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#Version.FIELDS.automatic_scaling)\nautomaticScaling.standard_scheduler_settings.max_instances (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#StandardSchedulerSettings)\nautomaticScaling.standard_scheduler_settings.min_instances (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#StandardSchedulerSettings)\nautomaticScaling.standard_scheduler_settings.target_cpu_utilization (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#StandardSchedulerSettings)\nautomaticScaling.standard_scheduler_settings.target_throughput_utilization (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#StandardSchedulerSettings)basic scaling or manual scaling in the standard environment:\nserving_status (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#Version.FIELDS.serving_status)Flexible environment\nserving_status (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#Version.FIELDS.serving_status)automatic scaling in the flexible environment:\nautomatic_scaling.min_total_instances (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#Version.FIELDS.automatic_scaling)\nautomatic_scaling.max_total_instances (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#Version.FIELDS.automatic_scaling)\nautomatic_scaling.cool_down_period_sec (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#Version.FIELDS.automatic_scaling)\nautomatic_scaling.cpu_utilization.target_utilization (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#Version.FIELDS.automatic_scaling)", "request": { "$ref": "Version" } }, "create": { "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "servicesId": { "required": true, "type": "string", "location": "path", "description": "Part of `parent`. See documentation of `appsId`." }, "appsId": { "required": true, "type": "string", "location": "path", "description": "Part of `parent`. Name of the parent resource to create this version under. Example: apps/myapp/services/default." } }, "flatPath": "v1/apps/{appsId}/services/{servicesId}/versions", "path": "v1/apps/{appsId}/services/{servicesId}/versions", "id": "appengine.apps.services.versions.create", "request": { "$ref": "Version" }, "description": "Deploys code and resource files to a new version.", "response": { "$ref": "Operation" }, "parameterOrder": ["appsId", "servicesId"], "httpMethod": "POST" } }, "resources": { "instances": { "methods": { "list": { "description": "Lists the instances of a version.Tip: To aggregate details about instances over time, see the Stackdriver Monitoring API (https://cloud.google.com/monitoring/api/ref_v3/rest/v3/projects.timeSeries/list).", "httpMethod": "GET", "parameterOrder": ["appsId", "servicesId", "versionsId"], "response": { "$ref": "ListInstancesResponse" }, "parameters": { "servicesId": { "description": "Part of `parent`. See documentation of `appsId`.", "required": true, "type": "string", "location": "path" }, "appsId": { "description": "Part of `parent`. Name of the parent Version resource. Example: apps/myapp/services/default/versions/v1.", "required": true, "type": "string", "location": "path" }, "pageToken": { "location": "query", "description": "Continuation token for fetching the next page of results.", "type": "string" }, "pageSize": { "location": "query", "description": "Maximum results to return per page.", "format": "int32", "type": "integer" }, "versionsId": { "location": "path", "description": "Part of `parent`. See documentation of `appsId`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/apps/{appsId}/services/{servicesId}/versions/{versionsId}/instances", "id": "appengine.apps.services.versions.instances.list", "path": "v1/apps/{appsId}/services/{servicesId}/versions/{versionsId}/instances" }, "get": { "description": "Gets instance information.", "httpMethod": "GET", "response": { "$ref": "Instance" }, "parameterOrder": ["appsId", "servicesId", "versionsId", "instancesId"], "parameters": { "versionsId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" }, "servicesId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" }, "appsId": { "location": "path", "description": "Part of `name`. Name of the resource requested. Example: apps/myapp/services/default/versions/v1/instances/instance-1.", "required": true, "type": "string" }, "instancesId": { "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/apps/{appsId}/services/{servicesId}/versions/{versionsId}/instances/{instancesId}", "id": "appengine.apps.services.versions.instances.get", "path": "v1/apps/{appsId}/services/{servicesId}/versions/{versionsId}/instances/{instancesId}" }, "debug": { "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "servicesId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" }, "appsId": { "description": "Part of `name`. Name of the resource requested. Example: apps/myapp/services/default/versions/v1/instances/instance-1.", "required": true, "type": "string", "location": "path" }, "instancesId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. See documentation of `appsId`." }, "versionsId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. See documentation of `appsId`." } }, "flatPath": "v1/apps/{appsId}/services/{servicesId}/versions/{versionsId}/instances/{instancesId}:debug", "path": "v1/apps/{appsId}/services/{servicesId}/versions/{versionsId}/instances/{instancesId}:debug", "id": "appengine.apps.services.versions.instances.debug", "request": { "$ref": "DebugInstanceRequest" }, "description": "Enables debugging on a VM instance. This allows you to use the SSH command to connect to the virtual machine where the instance lives. While in \"debug mode\", the instance continues to serve live traffic. You should delete the instance when you are done debugging and then allow the system to take over and determine if another instance should be started.Only applicable for instances in App Engine flexible environment.", "response": { "$ref": "Operation" }, "parameterOrder": ["appsId", "servicesId", "versionsId", "instancesId"], "httpMethod": "POST" }, "delete": { "description": "Stops a running instance.", "response": { "$ref": "Operation" }, "parameterOrder": ["appsId", "servicesId", "versionsId", "instancesId"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "appsId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. Name of the resource requested. Example: apps/myapp/services/default/versions/v1/instances/instance-1." }, "instancesId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" }, "versionsId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. See documentation of `appsId`." }, "servicesId": { "location": "path", "description": "Part of `name`. See documentation of `appsId`.", "required": true, "type": "string" } }, "flatPath": "v1/apps/{appsId}/services/{servicesId}/versions/{versionsId}/instances/{instancesId}", "path": "v1/apps/{appsId}/services/{servicesId}/versions/{versionsId}/instances/{instancesId}", "id": "appengine.apps.services.versions.instances.delete" } } } } } } }, "authorizedDomains": { "methods": { "list": { "response": { "$ref": "ListAuthorizedDomainsResponse" }, "parameterOrder": ["appsId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "appsId": { "location": "path", "description": "Part of `parent`. Name of the parent Application resource. Example: apps/myapp.", "required": true, "type": "string" }, "pageToken": { "type": "string", "location": "query", "description": "Continuation token for fetching the next page of results." }, "pageSize": { "description": "Maximum results to return per page.", "format": "int32", "type": "integer", "location": "query" } }, "flatPath": "v1/apps/{appsId}/authorizedDomains", "path": "v1/apps/{appsId}/authorizedDomains", "id": "appengine.apps.authorizedDomains.list", "description": "Lists all domains the user is authorized to administer." } } }, "operations": { "methods": { "list": { "description": "Lists operations that match the specified filter in the request. If the server doesn't support this method, it returns UNIMPLEMENTED.NOTE: the name binding allows API services to override the binding to use different resource name schemes, such as users/*/operations. To override the binding, API services can add a binding such as \"/v1/{name=users/*}/operations\" to their service configuration. For backwards compatibility, the default name includes the operations collection id, however overriding users must ensure the name binding is the parent resource, without the operations collection id.", "response": { "$ref": "ListOperationsResponse" }, "parameterOrder": ["appsId"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "parameters": { "filter": { "location": "query", "description": "The standard list filter.", "type": "string" }, "appsId": { "description": "Part of `name`. The name of the operation's parent resource.", "required": true, "type": "string", "location": "path" }, "pageToken": { "location": "query", "description": "The standard list page token.", "type": "string" }, "pageSize": { "description": "The standard list page size.", "format": "int32", "type": "integer", "location": "query" } }, "flatPath": "v1/apps/{appsId}/operations", "path": "v1/apps/{appsId}/operations", "id": "appengine.apps.operations.list" }, "get": { "id": "appengine.apps.operations.get", "path": "v1/apps/{appsId}/operations/{operationsId}", "description": "Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.", "httpMethod": "GET", "response": { "$ref": "Operation" }, "parameterOrder": ["appsId", "operationsId"], "parameters": { "operationsId": { "required": true, "type": "string", "location": "path", "description": "Part of `name`. See documentation of `appsId`." }, "appsId": { "location": "path", "description": "Part of `name`. The name of the operation resource.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/appengine.admin", "https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/cloud-platform.read-only"], "flatPath": "v1/apps/{appsId}/operations/{operationsId}" } } } } } }, "parameters": { "key": { "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string" }, "access_token": { "location": "query", "description": "OAuth access token.", "type": "string" }, "upload_protocol": { "location": "query", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string" }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" }, "quotaUser": { "type": "string", "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters." }, "fields": { "description": "Selector specifying which fields to include in a partial response.", "type": "string", "location": "query" }, "uploadType": { "location": "query", "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string" }, "$.xgafv": { "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query", "enum": ["1", "2"], "description": "V1 error format.", "type": "string" }, "oauth_token": { "description": "OAuth 2.0 token for the current user.", "type": "string", "location": "query" }, "callback": { "location": "query", "description": "JSONP", "type": "string" }, "alt": { "enum": ["json", "media", "proto"], "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json" } }, "schemas": { "UrlDispatchRule": { "id": "UrlDispatchRule", "description": "Rules to match an HTTP request and dispatch that request to a service.", "type": "object", "properties": { "path": { "type": "string", "description": "Pathname within the host. Must start with a \"/\". A single \"*\" can be included at the end of the path.The sum of the lengths of the domain and path may not exceed 100 characters." }, "domain": { "description": "Domain name to match against. The wildcard \"*\" is supported if specified before a period: \"*.\".Defaults to matching all domains: \"*\".", "type": "string" }, "service": { "description": "Resource ID of a service in this application that should serve the matched request. The service must already exist. Example: default.", "type": "string" } } }, "ListVersionsResponse": { "description": "Response message for Versions.ListVersions.", "type": "object", "properties": { "versions": { "type": "array", "items": { "$ref": "Version" }, "description": "The versions belonging to the requested service." }, "nextPageToken": { "type": "string", "description": "Continuation token for fetching the next page of results." } }, "id": "ListVersionsResponse" }, "ListAuthorizedDomainsResponse": { "description": "Response message for AuthorizedDomains.ListAuthorizedDomains.", "type": "object", "properties": { "nextPageToken": { "description": "Continuation token for fetching the next page of results.", "type": "string" }, "domains": { "description": "The authorized domains belonging to the user.", "type": "array", "items": { "$ref": "AuthorizedDomain" } } }, "id": "ListAuthorizedDomainsResponse" }, "ApiEndpointHandler": { "description": "Uses Google Cloud Endpoints to handle requests.", "type": "object", "properties": { "scriptPath": { "description": "Path to the script from the application root directory.", "type": "string" } }, "id": "ApiEndpointHandler" }, "Empty": { "description": "A generic empty message that you can re-use to avoid defining duplicated empty messages in your APIs. A typical example is to use it as the request or the response type of an API method. For instance:\nservice Foo {\n  rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n}\nThe JSON representation for Empty is empty JSON object {}.", "type": "object", "properties": {}, "id": "Empty" }, "DomainMapping": { "description": "A domain serving an App Engine application.", "type": "object", "properties": { "id": { "type": "string", "description": "Relative name of the domain serving the application. Example: example.com." }, "resourceRecords": { "description": "The resource records required to configure this domain mapping. These records must be added to the domain's DNS configuration in order to serve the application via this domain mapping.@OutputOnly", "type": "array", "items": { "$ref": "ResourceRecord" } }, "name": { "description": "Full path to the DomainMapping resource in the API. Example: apps/myapp/domainMapping/example.com.@OutputOnly", "type": "string" }, "sslSettings": { "description": "SSL configuration for this domain. If unconfigured, this domain will not serve with SSL.", "$ref": "SslSettings" } }, "id": "DomainMapping" }, "VpcAccessConnector": { "description": "VPC access connector specification.", "type": "object", "properties": { "name": { "description": "Full Serverless VPC Access Connector name e.g. /projects/my-project/locations/us-central1/connectors/c1.", "type": "string" } }, "id": "VpcAccessConnector" }, "ZipInfo": { "description": "The zip file information for a zip deployment.", "type": "object", "properties": { "filesCount": { "description": "An estimate of the number of files in a zip for a zip deployment. If set, must be greater than or equal to the actual number of files. Used for optimizing performance; if not provided, deployment may be slow.", "format": "int32", "type": "integer" }, "sourceUrl": { "description": "URL of the zip file to deploy from. Must be a URL to a resource in Google Cloud Storage in the form 'http(s)://storage.googleapis.com/<bucket>/<object>'.", "type": "string" } }, "id": "ZipInfo" }, "AutomaticScaling": { "id": "AutomaticScaling", "description": "Automatic scaling is based on request rate, response latencies, and other application metrics.", "type": "object", "properties": { "minTotalInstances": { "description": "Minimum number of running instances that should be maintained for this version.", "format": "int32", "type": "integer" }, "networkUtilization": { "description": "Target scaling by network usage.", "$ref": "NetworkUtilization" }, "maxConcurrentRequests": { "description": "Number of concurrent requests an automatic scaling instance can accept before the scheduler spawns a new instance.Defaults to a runtime-specific value.", "format": "int32", "type": "integer" }, "coolDownPeriod": { "description": "The time period that the Autoscaler (https://cloud.google.com/compute/docs/autoscaler/) should wait before it starts collecting information from a new instance. This prevents the autoscaler from collecting information when the instance is initializing, during which the collected usage would not be reliable. Only applicable in the App Engine flexible environment.", "format": "google-duration", "type": "string" }, "maxPendingLatency": { "description": "Maximum amount of time that a request should wait in the pending queue before starting a new instance to handle it.", "format": "google-duration", "type": "string" }, "cpuUtilization": { "description": "Target scaling by CPU usage.", "$ref": "CpuUtilization" }, "diskUtilization": { "$ref": "DiskUtilization", "description": "Target scaling by disk usage." }, "minPendingLatency": { "description": "Minimum amount of time a request should wait in the pending queue before starting a new instance to handle it.", "format": "google-duration", "type": "string" }, "requestUtilization": { "$ref": "RequestUtilization", "description": "Target scaling by request utilization." }, "maxIdleInstances": { "description": "Maximum number of idle instances that should be maintained for this version.", "format": "int32", "type": "integer" }, "standardSchedulerSettings": { "$ref": "StandardSchedulerSettings", "description": "Scheduler settings for standard environment." }, "minIdleInstances": { "type": "integer", "description": "Minimum number of idle instances that should be maintained for this version. Only applicable for the default version of a service.", "format": "int32" }, "maxTotalInstances": { "type": "integer", "description": "Maximum number of instances that should be started to handle requests for this version.", "format": "int32" } } }, "AuthorizedCertificate": { "description": "An SSL certificate that a user has been authorized to administer. A user is authorized to administer any certificate that applies to one of their authorized domains.", "type": "object", "properties": { "domainMappingsCount": { "description": "Aggregate count of the domain mappings with this certificate mapped. This count includes domain mappings on applications for which the user does not have VIEWER permissions.Only returned by GET or LIST requests when specifically requested by the view=FULL_CERTIFICATE option.@OutputOnly", "format": "int32", "type": "integer" }, "domainNames": { "description": "Topmost applicable domains of this certificate. This certificate applies to these domains and their subdomains. Example: example.com.@OutputOnly", "type": "array", "items": { "type": "string" } }, "id": { "description": "Relative name of the certificate. This is a unique value autogenerated on AuthorizedCertificate resource creation. Example: 12345.@OutputOnly", "type": "string" }, "displayName": { "description": "The user-specified display name of the certificate. This is not guaranteed to be unique. Example: My Certificate.", "type": "string" }, "managedCertificate": { "$ref": "ManagedCertificate", "description": "Only applicable if this certificate is managed by App Engine. Managed certificates are tied to the lifecycle of a DomainMapping and cannot be updated or deleted via the AuthorizedCertificates API. If this certificate is manually administered by the user, this field will be empty.@OutputOnly" }, "certificateRawData": { "$ref": "CertificateRawData", "description": "The SSL certificate serving the AuthorizedCertificate resource. This must be obtained independently from a certificate authority." }, "visibleDomainMappings": { "type": "array", "items": { "type": "string" }, "description": "The full paths to user visible Domain Mapping resources that have this certificate mapped. Example: apps/myapp/domainMappings/example.com.This may not represent the full list of mapped domain mappings if the user does not have VIEWER permissions on all of the applications that have this certificate mapped. See domain_mappings_count for a complete count.Only returned by GET or LIST requests when specifically requested by the view=FULL_CERTIFICATE option.@OutputOnly" }, "expireTime": { "description": "The time when this certificate expires. To update the renewal time on this certificate, upload an SSL certificate with a different expiration time using AuthorizedCertificates.UpdateAuthorizedCertificate.@OutputOnly", "format": "google-datetime", "type": "string" }, "name": { "type": "string", "description": "Full path to the AuthorizedCertificate resource in the API. Example: apps/myapp/authorizedCertificates/12345.@OutputOnly" } }, "id": "AuthorizedCertificate" }, "ResourceRecord": { "type": "object", "properties": { "name": { "description": "Relative name of the object affected by this record. Only applicable for CNAME records. Example: 'www'.", "type": "string" }, "type": { "type": "string", "enumDescriptions": ["An unknown resource record.", "An A resource record. Data is an IPv4 address.", "An AAAA resource record. Data is an IPv6 address.", "A CNAME resource record. Data is a domain name to be aliased."], "enum": ["RECORD_TYPE_UNSPECIFIED", "A", "AAAA", "CNAME"], "description": "Resource record type. Example: AAAA." }, "rrdata": { "description": "Data for this record. Values vary by record type, as defined in RFC 1035 (section 5) and RFC 1034 (section 3.6.1).", "type": "string" } }, "id": "ResourceRecord", "description": "A DNS resource record." }, "Library": { "description": "Third-party Python runtime library that is required by the application.", "type": "object", "properties": { "name": { "description": "Name of the library. Example: \"django\".", "type": "string" }, "version": { "type": "string", "description": "Version of the library to select, or \"latest\"." } }, "id": "Library" }, "ListLocationsResponse": { "type": "object", "properties": { "locations": { "description": "A list of locations that matches the specified filter in the request.", "type": "array", "items": { "$ref": "Location" } }, "nextPageToken": { "description": "The standard List next-page token.", "type": "string" } }, "id": "ListLocationsResponse", "description": "The response message for Locations.ListLocations." }, "ContainerInfo": { "type": "object", "properties": { "image": { "description": "URI to the hosted container image in Google Container Registry. The URI must be fully qualified and include a tag or digest. Examples: \"gcr.io/my-project/image:tag\" or \"gcr.io/my-project/image@digest\"", "type": "string" } }, "id": "ContainerInfo", "description": "Docker image that is used to create a container and start a VM instance for the version that you deploy. Only applicable for instances running in the App Engine flexible environment." }, "RequestUtilization": { "type": "object", "properties": { "targetRequestCountPerSecond": { "description": "Target requests per second.", "format": "int32", "type": "integer" }, "targetConcurrentRequests": { "description": "Target number of concurrent requests.", "format": "int32", "type": "integer" } }, "id": "RequestUtilization", "description": "Target scaling by request utilization. Only applicable in the App Engine flexible environment." }, "UrlMap": { "type": "object", "properties": { "redirectHttpResponseCode": { "description": "30x code to use when performing redirects for the secure field. Defaults to 302.", "type": "string", "enumDescriptions": ["Not specified. 302 is assumed.", "301 Moved Permanently code.", "302 Moved Temporarily code.", "303 See Other code.", "307 Temporary Redirect code."], "enum": ["REDIRECT_HTTP_RESPONSE_CODE_UNSPECIFIED", "REDIRECT_HTTP_RESPONSE_CODE_301", "REDIRECT_HTTP_RESPONSE_CODE_302", "REDIRECT_HTTP_RESPONSE_CODE_303", "REDIRECT_HTTP_RESPONSE_CODE_307"] }, "securityLevel": { "description": "Security (HTTPS) enforcement for this URL.", "type": "string", "enumDescriptions": ["Not specified.", "Both HTTP and HTTPS requests with URLs that match the handler succeed without redirects. The application can examine the request to determine which protocol was used, and respond accordingly.", "Requests for a URL that match this handler that use HTTPS are automatically redirected to the HTTP equivalent URL.", "Both HTTP and HTTPS requests with URLs that match the handler succeed without redirects. The application can examine the request to determine which protocol was used and respond accordingly.", "Requests for a URL that match this handler that do not use HTTPS are automatically redirected to the HTTPS URL with the same path. Query parameters are reserved for the redirect."], "enum": ["SECURE_UNSPECIFIED", "SECURE_DEFAULT", "SECURE_NEVER", "SECURE_OPTIONAL", "SECURE_ALWAYS"] }, "authFailAction": { "type": "string", "enumDescriptions": ["Not specified. AUTH_FAIL_ACTION_REDIRECT is assumed.", "Redirects user to \"accounts.google.com\". The user is redirected back to the application URL after signing in or creating an account.", "Rejects request with a 401 HTTP status code and an error message."], "enum": ["AUTH_FAIL_ACTION_UNSPECIFIED", "AUTH_FAIL_ACTION_REDIRECT", "AUTH_FAIL_ACTION_UNAUTHORIZED"], "description": "Action to take when users access resources that require authentication. Defaults to redirect." }, "script": { "$ref": "ScriptHandler", "description": "Executes a script to handle the requests that match this URL pattern. Only the auto value is supported for Node.js in the App Engine standard environment, for example \"script\": \"auto\"." }, "urlRegex": { "description": "URL prefix. Uses regular expression syntax, which means regexp special characters must be escaped, but should not contain groupings. All URLs that begin with this prefix are handled by this handler, using the portion of the URL after the prefix as part of the file path.", "type": "string" }, "login": { "enumDescriptions": ["Not specified. LOGIN_OPTIONAL is assumed.", "Does not require that the user is signed in.", "If the user is not signed in, the auth_fail_action is taken. In addition, if the user is not an administrator for the application, they are given an error message regardless of auth_fail_action. If the user is an administrator, the handler proceeds.", "If the user has signed in, the handler proceeds normally. Otherwise, the auth_fail_action is taken."], "enum": ["LOGIN_UNSPECIFIED", "LOGIN_OPTIONAL", "LOGIN_ADMIN", "LOGIN_REQUIRED"], "description": "Level of login required to access this resource. Not supported for Node.js in the App Engine standard environment.", "type": "string" }, "apiEndpoint": { "$ref": "ApiEndpointHandler", "description": "Uses API Endpoints to handle requests." }, "staticFiles": { "description": "Returns the contents of a file, such as an image, as the response.", "$ref": "StaticFilesHandler" } }, "id": "UrlMap", "description": "URL pattern and description of how the URL should be handled. App Engine can handle URLs by executing application code or by serving static files uploaded with the version, such as images, CSS, or JavaScript." }, "EndpointsApiService": { "description": "Cloud Endpoints (https://cloud.google.com/endpoints) configuration. The Endpoints API Service provides tooling for serving Open API and gRPC endpoints via an NGINX proxy. Only valid for App Engine Flexible environment deployments.The fields here refer to the name and configuration ID of a \"service\" resource in the Service Management API (https://cloud.google.com/service-management/overview).", "type": "object", "properties": { "name": { "description": "Endpoints service name which is the name of the \"service\" resource in the Service Management API. For example \"myapi.endpoints.myproject.cloud.goog\"", "type": "string" }, "configId": { "description": "Endpoints service configuration ID as specified by the Service Management API. For example \"2016-09-19r1\".By default, the rollout strategy for Endpoints is RolloutStrategy.FIXED. This means that Endpoints starts up with a particular configuration ID. When a new configuration is rolled out, Endpoints must be given the new configuration ID. The config_id field is used to give the configuration ID and is required in this case.Endpoints also has a rollout strategy called RolloutStrategy.MANAGED. When using this, Endpoints fetches the latest configuration and does not need the configuration ID. In this case, config_id must be omitted.", "type": "string" }, "disableTraceSampling": { "description": "Enable or disable trace sampling. By default, this is set to false for enabled.", "type": "boolean" }, "rolloutStrategy": { "description": "Endpoints rollout strategy. If FIXED, config_id must be specified. If MANAGED, config_id must be omitted.", "type": "string", "enumDescriptions": ["Not specified. Defaults to FIXED.", "Endpoints service configuration ID will be fixed to the configuration ID specified by config_id.", "Endpoints service configuration ID will be updated with each rollout."], "enum": ["UNSPECIFIED_ROLLOUT_STRATEGY", "FIXED", "MANAGED"] } }, "id": "EndpointsApiService" }, "Operation": { "description": "This resource represents a long-running operation that is the result of a network API call.", "type": "object", "properties": { "response": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "The normal response of the operation in case of success. If the original method returns no data on success, such as Delete, the response is google.protobuf.Empty. If the original method is standard Get/Create/Update, the response should be the resource. For other methods, the response should have the type XxxResponse, where Xxx is the original method name. For example, if the original method name is TakeSnapshot(), the inferred response type is TakeSnapshotResponse.", "type": "object" }, "name": { "description": "The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the name should be a resource name ending with operations/{unique_id}.", "type": "string" }, "error": { "$ref": "Status", "description": "The error result of the operation in case of failure or cancellation." }, "metadata": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any.", "type": "object" }, "done": { "description": "If the value is false, it means the operation is still in progress. If true, the operation is completed, and either error or response is available.", "type": "boolean" } }, "id": "Operation" }, "ApiConfigHandler": { "description": "Google Cloud Endpoints (https://cloud.google.com/appengine/docs/python/endpoints/) configuration for API handlers.", "type": "object", "properties": { "url": { "description": "URL to serve the endpoint at.", "type": "string" }, "securityLevel": { "type": "string", "enumDescriptions": ["Not specified.", "Both HTTP and HTTPS requests with URLs that match the handler succeed without redirects. The application can examine the request to determine which protocol was used, and respond accordingly.", "Requests for a URL that match this handler that use HTTPS are automatically redirected to the HTTP equivalent URL.", "Both HTTP and HTTPS requests with URLs that match the handler succeed without redirects. The application can examine the request to determine which protocol was used and respond accordingly.", "Requests for a URL that match this handler that do not use HTTPS are automatically redirected to the HTTPS URL with the same path. Query parameters are reserved for the redirect."], "enum": ["SECURE_UNSPECIFIED", "SECURE_DEFAULT", "SECURE_NEVER", "SECURE_OPTIONAL", "SECURE_ALWAYS"], "description": "Security (HTTPS) enforcement for this URL." }, "authFailAction": { "type": "string", "enumDescriptions": ["Not specified. AUTH_FAIL_ACTION_REDIRECT is assumed.", "Redirects user to \"accounts.google.com\". The user is redirected back to the application URL after signing in or creating an account.", "Rejects request with a 401 HTTP status code and an error message."], "enum": ["AUTH_FAIL_ACTION_UNSPECIFIED", "AUTH_FAIL_ACTION_REDIRECT", "AUTH_FAIL_ACTION_UNAUTHORIZED"], "description": "Action to take when users access resources that require authentication. Defaults to redirect." }, "script": { "description": "Path to the script from the application root directory.", "type": "string" }, "login": { "enumDescriptions": ["Not specified. LOGIN_OPTIONAL is assumed.", "Does not require that the user is signed in.", "If the user is not signed in, the auth_fail_action is taken. In addition, if the user is not an administrator for the application, they are given an error message regardless of auth_fail_action. If the user is an administrator, the handler proceeds.", "If the user has signed in, the handler proceeds normally. Otherwise, the auth_fail_action is taken."], "enum": ["LOGIN_UNSPECIFIED", "LOGIN_OPTIONAL", "LOGIN_ADMIN", "LOGIN_REQUIRED"], "description": "Level of login required to access this resource. Defaults to optional.", "type": "string" } }, "id": "ApiConfigHandler" }, "StaticFilesHandler": { "description": "Files served directly to the user for a given URL, such as images, CSS stylesheets, or JavaScript source files. Static file handlers describe which files in the application directory are static files, and which URLs serve them.", "type": "object", "properties": { "expiration": { "description": "Time a static file served by this handler should be cached by web proxies and browsers.", "format": "google-duration", "type": "string" }, "applicationReadable": { "type": "boolean", "description": "Whether files should also be uploaded as code data. By default, files declared in static file handlers are uploaded as static data and are only served to end users; they cannot be read by the application. If enabled, uploads are charged against both your code and static data storage resource quotas." }, "httpHeaders": { "additionalProperties": { "type": "string" }, "description": "HTTP headers to use for all responses from these URLs.", "type": "object" }, "uploadPathRegex": { "description": "Regular expression that matches the file paths for all files that should be referenced by this handler.", "type": "string" }, "path": { "description": "Path to the static files matched by the URL pattern, from the application root directory. The path can refer to text matched in groupings in the URL pattern.", "type": "string" }, "mimeType": { "description": "MIME type used to serve all files served by this handler.Defaults to file-specific MIME types, which are derived from each file's filename extension.", "type": "string" }, "requireMatchingFile": { "type": "boolean", "description": "Whether this handler should match the request if the file referenced by the handler does not exist." } }, "id": "StaticFilesHandler" }, "BasicScaling": { "type": "object", "properties": { "maxInstances": { "type": "integer", "description": "Maximum number of instances to create for this version.", "format": "int32" }, "idleTimeout": { "description": "Duration of time after the last request that an instance must wait before the instance is shut down.", "format": "google-duration", "type": "string" } }, "id": "BasicScaling", "description": "A service with basic scaling will create an instance when the application receives a request. The instance will be turned down when the app becomes idle. Basic scaling is ideal for work that is intermittent or driven by user activity." }, "DiskUtilization": { "description": "Target scaling by disk usage. Only applicable in the App Engine flexible environment.", "type": "object", "properties": { "targetWriteBytesPerSecond": { "type": "integer", "description": "Target bytes written per second.", "format": "int32" }, "targetReadBytesPerSecond": { "type": "integer", "description": "Target bytes read per second.", "format": "int32" }, "targetReadOpsPerSecond": { "description": "Target ops read per seconds.", "format": "int32", "type": "integer" }, "targetWriteOpsPerSecond": { "description": "Target ops written per second.", "format": "int32", "type": "integer" } }, "id": "DiskUtilization" }, "CpuUtilization": { "description": "Target scaling by CPU usage.", "type": "object", "properties": { "aggregationWindowLength": { "description": "Period of time over which CPU utilization is calculated.", "format": "google-duration", "type": "string" }, "targetUtilization": { "description": "Target CPU utilization ratio to maintain when scaling. Must be between 0 and 1.", "format": "double", "type": "number" } }, "id": "CpuUtilization" }, "Status": { "id": "Status", "description": "The Status type defines a logical error model that is suitable for different programming environments, including REST APIs and RPC APIs. It is used by gRPC (https://github.com/grpc). Each Status message contains three pieces of data: error code, error message, and error details.You can find out more about this error model and how to work with it in the API Design Guide (https://cloud.google.com/apis/design/errors).", "type": "object", "properties": { "code": { "description": "The status code, which should be an enum value of google.rpc.Code.", "format": "int32", "type": "integer" }, "message": { "description": "A developer-facing error message, which should be in English. Any user-facing error message should be localized and sent in the google.rpc.Status.details field, or localized by the client.", "type": "string" }, "details": { "type": "array", "items": { "additionalProperties": { "type": "any", "description": "Properties of the object. Contains field @type with type URL." }, "type": "object" }, "description": "A list of messages that carry the error details. There is a common set of message types for APIs to use." } } }, "IdentityAwareProxy": { "id": "IdentityAwareProxy", "description": "Identity-Aware Proxy", "type": "object", "properties": { "oauth2ClientId": { "description": "OAuth2 client ID to use for the authentication flow.", "type": "string" }, "oauth2ClientSecretSha256": { "description": "Hex-encoded SHA-256 hash of the client secret.@OutputOnly", "type": "string" }, "enabled": { "description": "Whether the serving infrastructure will authenticate and authorize all incoming requests.If true, the oauth2_client_id and oauth2_client_secret fields must be non-empty.", "type": "boolean" }, "oauth2ClientSecret": { "description": "OAuth2 client secret to use for the authentication flow.For security reasons, this value cannot be retrieved via the API. Instead, the SHA-256 hash of the value is returned in the oauth2_client_secret_sha256 field.@InputOnly", "type": "string" } } }, "ManualScaling": { "id": "ManualScaling", "description": "A service with manual scaling runs continuously, allowing you to perform complex initialization and rely on the state of its memory over time.", "type": "object", "properties": { "instances": { "type": "integer", "description": "Number of instances to assign to the service at the start. This number can later be altered by using the Modules API (https://cloud.google.com/appengine/docs/python/modules/functions) set_num_instances() function.", "format": "int32" } } }, "LocationMetadata": { "id": "LocationMetadata", "description": "Metadata for the given google.cloud.location.Location.", "type": "object", "properties": { "standardEnvironmentAvailable": { "type": "boolean", "description": "App Engine standard environment is available in the given location.@OutputOnly" }, "flexibleEnvironmentAvailable": { "type": "boolean", "description": "App Engine flexible environment is available in the given location.@OutputOnly" } } }, "CreateVersionMetadataV1": { "description": "Metadata for the given google.longrunning.Operation during a google.appengine.v1.CreateVersionRequest.", "type": "object", "properties": { "cloudBuildId": { "description": "The Cloud Build ID if one was created as part of the version create. @OutputOnly", "type": "string" } }, "id": "CreateVersionMetadataV1" }, "Service": { "description": "A Service resource is a logical component of an application that can share state and communicate in a secure fashion with other services. For example, an application that handles customer requests might include separate services to handle tasks such as backend data analysis or API requests from mobile devices. Each service has a collection of versions that define a specific set of code used to implement the functionality of that service.", "type": "object", "properties": { "name": { "description": "Full path to the Service resource in the API. Example: apps/myapp/services/default.@OutputOnly", "type": "string" }, "split": { "$ref": "TrafficSplit", "description": "Mapping that defines fractional HTTP traffic diversion to different versions within the service." }, "id": { "description": "Relative name of the service within the application. Example: default.@OutputOnly", "type": "string" } }, "id": "Service" }, "ListOperationsResponse": { "type": "object", "properties": { "nextPageToken": { "description": "The standard List next-page token.", "type": "string" }, "operations": { "type": "array", "items": { "$ref": "Operation" }, "description": "A list of operations that matches the specified filter in the request." } }, "id": "ListOperationsResponse", "description": "The response message for Operations.ListOperations." }, "FirewallRule": { "id": "FirewallRule", "description": "A single firewall rule that is evaluated against incoming traffic and provides an action to take on matched requests.", "type": "object", "properties": { "sourceRange": { "description": "IP address or range, defined using CIDR notation, of requests that this rule applies to. You can use the wildcard character \"*\" to match all IPs equivalent to \"0/0\" and \"::/0\" together. Examples: 192.168.1.1 or 192.168.0.0/16 or 2001:db8::/32  or 2001:0db8:0000:0042:0000:8a2e:0370:7334.<p>Truncation will be silently performed on addresses which are not properly truncated. For example, 1.2.3.4/24 is accepted as the same address as 1.2.3.0/24. Similarly, for IPv6, 2001:db8::1/32 is accepted as the same address as 2001:db8::/32.", "type": "string" }, "priority": { "description": "A positive integer between 1, Int32.MaxValue-1 that defines the order of rule evaluation. Rules with the lowest priority are evaluated first.A default rule at priority Int32.MaxValue matches all IPv4 and IPv6 traffic when no previous rule matches. Only the action of this rule can be modified by the user.", "format": "int32", "type": "integer" }, "action": { "enum": ["UNSPECIFIED_ACTION", "ALLOW", "DENY"], "description": "The action to take on matched requests.", "type": "string", "enumDescriptions": ["", "Matching requests are allowed.", "Matching requests are denied."] }, "description": { "description": "An optional string description of this rule. This field has a maximum length of 100 characters.", "type": "string" } } }, "ListAuthorizedCertificatesResponse": { "description": "Response message for AuthorizedCertificates.ListAuthorizedCertificates.", "type": "object", "properties": { "nextPageToken": { "description": "Continuation token for fetching the next page of results.", "type": "string" }, "certificates": { "description": "The SSL certificates the user is authorized to administer.", "type": "array", "items": { "$ref": "AuthorizedCertificate" } } }, "id": "ListAuthorizedCertificatesResponse" }, "CreateVersionMetadataV1Beta": { "description": "Metadata for the given google.longrunning.Operation during a google.appengine.v1beta.CreateVersionRequest.", "type": "object", "properties": { "cloudBuildId": { "type": "string", "description": "The Cloud Build ID if one was created as part of the version create. @OutputOnly" } }, "id": "CreateVersionMetadataV1Beta" }, "FeatureSettings": { "type": "object", "properties": { "useContainerOptimizedOs": { "type": "boolean", "description": "If true, use Container-Optimized OS (https://cloud.google.com/container-optimized-os/) base image for VMs, rather than a base Debian image." }, "splitHealthChecks": { "description": "Boolean value indicating if split health checks should be used instead of the legacy health checks. At an app.yaml level, this means defaulting to 'readiness_check' and 'liveness_check' values instead of 'health_check' ones. Once the legacy 'health_check' behavior is deprecated, and this value is always true, this setting can be removed.", "type": "boolean" } }, "id": "FeatureSettings", "description": "The feature specific settings to be used in the application. These define behaviors that are user configurable." }, "ErrorHandler": { "description": "Custom static error page to be served when an error occurs.", "type": "object", "properties": { "errorCode": { "description": "Error condition this handler applies to.", "type": "string", "enumDescriptions": ["Not specified. ERROR_CODE_DEFAULT is assumed.", "All other error types.", "Application has exceeded a resource quota.", "Client blocked by the application's Denial of Service protection configuration.", "Deadline reached before the application responds."], "enum": ["ERROR_CODE_UNSPECIFIED", "ERROR_CODE_DEFAULT", "ERROR_CODE_OVER_QUOTA", "ERROR_CODE_DOS_API_DENIAL", "ERROR_CODE_TIMEOUT"] }, "mimeType": { "description": "MIME type of file. Defaults to text/html.", "type": "string" }, "staticFile": { "type": "string", "description": "Static file content to be served for this error." } }, "id": "ErrorHandler" }, "OperationMetadataV1": { "type": "object", "properties": { "insertTime": { "description": "Time that this operation was created.@OutputOnly", "format": "google-datetime", "type": "string" }, "warning": { "description": "Durable messages that persist on every operation poll. @OutputOnly", "type": "array", "items": { "type": "string" } }, "user": { "type": "string", "description": "User who requested this operation.@OutputOnly" }, "target": { "type": "string", "description": "Name of the resource that this operation is acting on. Example: apps/myapp/services/default.@OutputOnly" }, "ephemeralMessage": { "description": "Ephemeral message that may change every time the operation is polled. @OutputOnly", "type": "string" }, "method": { "description": "API method that initiated this operation. Example: google.appengine.v1.Versions.CreateVersion.@OutputOnly", "type": "string" }, "endTime": { "description": "Time that this operation completed.@OutputOnly", "format": "google-datetime", "type": "string" }, "createVersionMetadata": { "$ref": "CreateVersionMetadataV1" } }, "id": "OperationMetadataV1", "description": "Metadata for the given google.longrunning.Operation." }, "SslSettings": { "id": "SslSettings", "description": "SSL configuration for a DomainMapping resource.", "type": "object", "properties": { "pendingManagedCertificateId": { "description": "ID of the managed AuthorizedCertificate resource currently being provisioned, if applicable. Until the new managed certificate has been successfully provisioned, the previous SSL state will be preserved. Once the provisioning process completes, the certificate_id field will reflect the new managed certificate and this field will be left empty. To remove SSL support while there is still a pending managed certificate, clear the certificate_id field with an UpdateDomainMappingRequest.@OutputOnly", "type": "string" }, "certificateId": { "description": "ID of the AuthorizedCertificate resource configuring SSL for the application. Clearing this field will remove SSL support.By default, a managed certificate is automatically created for every domain mapping. To omit SSL support or to configure SSL manually, specify SslManagementType.MANUAL on a CREATE or UPDATE request. You must be authorized to administer the AuthorizedCertificate resource to manually map it to a DomainMapping resource. Example: 12345.", "type": "string" }, "sslManagementType": { "enumDescriptions": ["Defaults to AUTOMATIC.", "SSL support for this domain is configured automatically. The mapped SSL certificate will be automatically renewed.", "SSL support for this domain is configured manually by the user. Either the domain has no SSL support or a user-obtained SSL certificate has been explictly mapped to this domain."], "enum": ["SSL_MANAGEMENT_TYPE_UNSPECIFIED", "AUTOMATIC", "MANUAL"], "description": "SSL management type for this domain. If AUTOMATIC, a managed certificate is automatically provisioned. If MANUAL, certificate_id must be manually specified in order to configure SSL for this domain.", "type": "string" } } }, "Application": { "id": "Application", "description": "An Application resource contains the top-level configuration of an App Engine application.", "type": "object", "properties": { "servingStatus": { "type": "string", "enumDescriptions": ["Serving status is unspecified.", "Application is serving.", "Application has been disabled by the user.", "Application has been disabled by the system."], "enum": ["UNSPECIFIED", "SERVING", "USER_DISABLED", "SYSTEM_DISABLED"], "description": "Serving status of this application." }, "defaultHostname": { "description": "Hostname used to reach this application, as resolved by App Engine.@OutputOnly", "type": "string" }, "featureSettings": { "$ref": "FeatureSettings", "description": "The feature specific settings to be used in the application." }, "authDomain": { "description": "Google Apps authentication domain that controls which users can access this application.Defaults to open access for any Google Account.", "type": "string" }, "iap": { "$ref": "IdentityAwareProxy" }, "codeBucket": { "description": "Google Cloud Storage bucket that can be used for storing files associated with this application. This bucket is associated with the application and can be used by the gcloud deployment commands.@OutputOnly", "type": "string" }, "defaultBucket": { "description": "Google Cloud Storage bucket that can be used by this application to store content.@OutputOnly", "type": "string" }, "dispatchRules": { "description": "HTTP path dispatch rules for requests to the application that do not explicitly target a service or version. Rules are order-dependent. Up to 20 dispatch rules can be supported.", "type": "array", "items": { "$ref": "UrlDispatchRule" } }, "gcrDomain": { "type": "string", "description": "The Google Container Registry domain used for storing managed build docker images for this application." }, "name": { "description": "Full path to the Application resource in the API. Example: apps/myapp.@OutputOnly", "type": "string" }, "defaultCookieExpiration": { "description": "Cookie expiration policy for this application.", "format": "google-duration", "type": "string" }, "id": { "description": "Identifier of the Application resource. This identifier is equivalent to the project ID of the Google Cloud Platform project where you want to deploy your application. Example: myapp.", "type": "string" }, "locationId": { "description": "Location from which this application runs. Application instances run out of the data centers in the specified location, which is also where all of the application's end user content is stored.Defaults to us-central.View the list of supported locations (https://cloud.google.com/appengine/docs/locations).", "type": "string" } } }, "Network": { "id": "Network", "description": "Extra network settings. Only applicable in the App Engine flexible environment.", "type": "object", "properties": { "name": { "description": "Google Compute Engine network where the virtual machines are created. Specify the short name, not the resource path.Defaults to default.", "type": "string" }, "sessionAffinity": { "description": "Enable session affinity. Only applicable in the App Engine flexible environment.", "type": "boolean" }, "forwardedPorts": { "description": "List of ports, or port pairs, to forward from the virtual machine to the application container. Only applicable in the App Engine flexible environment.", "type": "array", "items": { "type": "string" } }, "instanceTag": { "description": "Tag to apply to the instance during creation. Only applicable in the App Engine flexible environment.", "type": "string" }, "subnetworkName": { "type": "string", "description": "Google Cloud Platform sub-network where the virtual machines are created. Specify the short name, not the resource path.If a subnetwork name is specified, a network name will also be required unless it is for the default network.\nIf the network that the instance is being created in is a Legacy network, then the IP address is allocated from the IPv4Range.\nIf the network that the instance is being created in is an auto Subnet Mode Network, then only network name should be specified (not the subnetwork_name) and the IP address is created from the IPCidrRange of the subnetwork that exists in that zone for that network.\nIf the network that the instance is being created in is a custom Subnet Mode Network, then the subnetwork_name must be specified and the IP address is created from the IPCidrRange of the subnetwork.If specified, the subnetwork must exist in the same region as the App Engine flexible environment application." } } }, "Instance": { "id": "Instance", "description": "An Instance resource is the computing unit that App Engine uses to automatically scale an application.", "type": "object", "properties": { "vmDebugEnabled": { "description": "Whether this instance is in debug mode. Only applicable for instances in App Engine flexible environment.@OutputOnly", "type": "boolean" }, "requests": { "description": "Number of requests since this instance was started.@OutputOnly", "format": "int32", "type": "integer" }, "appEngineRelease": { "description": "App Engine release this instance is running on.@OutputOnly", "type": "string" }, "vmName": { "description": "Name of the virtual machine where this instance lives. Only applicable for instances in App Engine flexible environment.@OutputOnly", "type": "string" }, "qps": { "description": "Average queries per second (QPS) over the last minute.@OutputOnly", "format": "float", "type": "number" }, "vmId": { "type": "string", "description": "Virtual machine ID of this instance. Only applicable for instances in App Engine flexible environment.@OutputOnly" }, "vmZoneName": { "description": "Zone where the virtual machine is located. Only applicable for instances in App Engine flexible environment.@OutputOnly", "type": "string" }, "name": { "description": "Full path to the Instance resource in the API. Example: apps/myapp/services/default/versions/v1/instances/instance-1.@OutputOnly", "type": "string" }, "averageLatency": { "description": "Average latency (ms) over the last minute.@OutputOnly", "format": "int32", "type": "integer" }, "memoryUsage": { "description": "Total memory in use (bytes).@OutputOnly", "format": "int64", "type": "string" }, "vmIp": { "description": "The IP address of this instance. Only applicable for instances in App Engine flexible environment.@OutputOnly", "type": "string" }, "id": { "description": "Relative name of the instance within the version. Example: instance-1.@OutputOnly", "type": "string" }, "vmStatus": { "type": "string", "description": "Status of the virtual machine where this instance lives. Only applicable for instances in App Engine flexible environment.@OutputOnly" }, "availability": { "description": "Availability of the instance.@OutputOnly", "type": "string", "enumDescriptions": ["", "", ""], "enum": ["UNSPECIFIED", "RESIDENT", "DYNAMIC"] }, "errors": { "type": "integer", "description": "Number of errors since this instance was started.@OutputOnly", "format": "int32" }, "startTime": { "description": "Time that this instance was started.@OutputOnly", "format": "google-datetime", "type": "string" } } }, "LivenessCheck": { "description": "Health checking configuration for VM instances. Unhealthy instances are killed and replaced with new instances.", "type": "object", "properties": { "checkInterval": { "description": "Interval between health checks.", "format": "google-duration", "type": "string" }, "timeout": { "description": "Time before the check is considered failed.", "format": "google-duration", "type": "string" }, "failureThreshold": { "type": "integer", "description": "Number of consecutive failed checks required before considering the VM unhealthy.", "format": "uint32" }, "initialDelay": { "description": "The initial delay before starting to execute the checks.", "format": "google-duration", "type": "string" }, "path": { "description": "The request path.", "type": "string" }, "successThreshold": { "type": "integer", "description": "Number of consecutive successful checks required before considering the VM healthy.", "format": "uint32" }, "host": { "description": "Host header to send when performing a HTTP Liveness check. Example: \"myapp.appspot.com\"", "type": "string" } }, "id": "LivenessCheck" }, "BatchUpdateIngressRulesRequest": { "description": "Request message for Firewall.BatchUpdateIngressRules.", "type": "object", "properties": { "ingressRules": { "description": "A list of FirewallRules to replace the existing set.", "type": "array", "items": { "$ref": "FirewallRule" } } }, "id": "BatchUpdateIngressRulesRequest" }, "CloudBuildOptions": { "description": "Options for the build operations performed as a part of the version deployment. Only applicable for App Engine flexible environment when creating a version using source code directly.", "type": "object", "properties": { "cloudBuildTimeout": { "description": "The Cloud Build timeout used as part of any dependent builds performed by version creation. Defaults to 10 minutes.", "format": "google-duration", "type": "string" }, "appYamlPath": { "type": "string", "description": "Path to the yaml file used in deployment, used to determine runtime configuration details.Required for flexible environment builds.See https://cloud.google.com/appengine/docs/standard/python/config/appref for more details." } }, "id": "CloudBuildOptions" }, "NetworkUtilization": { "type": "object", "properties": { "targetSentBytesPerSecond": { "type": "integer", "description": "Target bytes sent per second.", "format": "int32" }, "targetSentPacketsPerSecond": { "description": "Target packets sent per second.", "format": "int32", "type": "integer" }, "targetReceivedBytesPerSecond": { "description": "Target bytes received per second.", "format": "int32", "type": "integer" }, "targetReceivedPacketsPerSecond": { "type": "integer", "description": "Target packets received per second.", "format": "int32" } }, "id": "NetworkUtilization", "description": "Target scaling by network usage. Only applicable in the App Engine flexible environment." }, "Location": { "description": "A resource that represents Google Cloud Platform location.", "type": "object", "properties": { "metadata": { "type": "object", "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "Service-specific metadata. For example the available capacity at the given location." }, "labels": { "type": "object", "additionalProperties": { "type": "string" }, "description": "Cross-service attributes for the location. For example\n{\"cloud.googleapis.com/region\": \"us-east1\"}\n" }, "name": { "type": "string", "description": "Resource name for the location, which may vary between implementations. For example: \"projects/example-project/locations/us-east1\"" }, "locationId": { "description": "The canonical id for this location. For example: \"us-east1\".", "type": "string" }, "displayName": { "description": "The friendly name for this location, typically a nearby city name. For example, \"Tokyo\".", "type": "string" } }, "id": "Location" }, "HealthCheck": { "description": "Health checking configuration for VM instances. Unhealthy instances are killed and replaced with new instances. Only applicable for instances in App Engine flexible environment.", "type": "object", "properties": { "timeout": { "description": "Time before the health check is considered failed.", "format": "google-duration", "type": "string" }, "unhealthyThreshold": { "description": "Number of consecutive failed health checks required before removing traffic.", "format": "uint32", "type": "integer" }, "disableHealthCheck": { "description": "Whether to explicitly disable health checks for this instance.", "type": "boolean" }, "host": { "type": "string", "description": "Host header to send when performing an HTTP health check. Example: \"myapp.appspot.com\"" }, "healthyThreshold": { "description": "Number of consecutive successful health checks required before receiving traffic.", "format": "uint32", "type": "integer" }, "restartThreshold": { "description": "Number of consecutive failed health checks required before an instance is restarted.", "format": "uint32", "type": "integer" }, "checkInterval": { "description": "Interval between health checks.", "format": "google-duration", "type": "string" } }, "id": "HealthCheck" }, "ReadinessCheck": { "type": "object", "properties": { "checkInterval": { "type": "string", "description": "Interval between health checks.", "format": "google-duration" }, "timeout": { "description": "Time before the check is considered failed.", "format": "google-duration", "type": "string" }, "failureThreshold": { "description": "Number of consecutive failed checks required before removing traffic.", "format": "uint32", "type": "integer" }, "appStartTimeout": { "description": "A maximum time limit on application initialization, measured from moment the application successfully replies to a healthcheck until it is ready to serve traffic.", "format": "google-duration", "type": "string" }, "path": { "description": "The request path.", "type": "string" }, "successThreshold": { "description": "Number of consecutive successful checks required before receiving traffic.", "format": "uint32", "type": "integer" }, "host": { "description": "Host header to send when performing a HTTP Readiness check. Example: \"myapp.appspot.com\"", "type": "string" } }, "id": "ReadinessCheck", "description": "Readiness checking configuration for VM instances. Unhealthy instances are removed from traffic rotation." }, "DebugInstanceRequest": { "description": "Request message for Instances.DebugInstance.", "type": "object", "properties": { "sshKey": { "description": "Public SSH key to add to the instance. Examples:\n[USERNAME]:ssh-rsa [KEY_VALUE] [USERNAME]\n[USERNAME]:ssh-rsa [KEY_VALUE] google-ssh {\"userName\":\"[USERNAME]\",\"expireOn\":\"[EXPIRE_TIME]\"}For more information, see Adding and Removing SSH Keys (https://cloud.google.com/compute/docs/instances/adding-removing-ssh-keys).", "type": "string" } }, "id": "DebugInstanceRequest" }, "StandardSchedulerSettings": { "description": "Scheduler settings for standard environment.", "type": "object", "properties": { "targetThroughputUtilization": { "description": "Target throughput utilization ratio to maintain when scaling", "format": "double", "type": "number" }, "maxInstances": { "description": "Maximum number of instances to run for this version. Set to zero to disable max_instances configuration.", "format": "int32", "type": "integer" }, "minInstances": { "description": "Minimum number of instances to run for this version. Set to zero to disable min_instances configuration.", "format": "int32", "type": "integer" }, "targetCpuUtilization": { "description": "Target CPU utilization ratio to maintain when scaling.", "format": "double", "type": "number" } }, "id": "StandardSchedulerSettings" }, "CreateVersionMetadataV1Alpha": { "type": "object", "properties": { "cloudBuildId": { "description": "The Cloud Build ID if one was created as part of the version create. @OutputOnly", "type": "string" } }, "id": "CreateVersionMetadataV1Alpha", "description": "Metadata for the given google.longrunning.Operation during a google.appengine.v1alpha.CreateVersionRequest." }, "Version": { "id": "Version", "description": "A Version resource is a specific set of source code and configuration files that are deployed into a service.", "type": "object", "properties": { "zones": { "type": "array", "items": { "type": "string" }, "description": "The Google Compute Engine zones that are supported by this version in the App Engine flexible environment. Deprecated." }, "entrypoint": { "$ref": "Entrypoint", "description": "The entrypoint for the application." }, "automaticScaling": { "$ref": "AutomaticScaling", "description": "Automatic scaling is based on request rate, response latencies, and other application metrics." }, "runtimeChannel": { "description": "The channel of the runtime to use. Only available for some runtimes. Defaults to the default channel.", "type": "string" }, "diskUsageBytes": { "description": "Total size in bytes of all the files that are included in this version and currently hosted on the App Engine disk.@OutputOnly", "format": "int64", "type": "string" }, "healthCheck": { "$ref": "HealthCheck", "description": "Configures health checking for instances. Unhealthy instances are stopped and replaced with new instances. Only applicable in the App Engine flexible environment.Only returned in GET requests if view=FULL is set." }, "threadsafe": { "description": "Whether multiple requests can be dispatched to this version at once.", "type": "boolean" }, "readinessCheck": { "description": "Configures readiness health checking for instances. Unhealthy instances are not put into the backend traffic rotation.Only returned in GET requests if view=FULL is set.", "$ref": "ReadinessCheck" }, "manualScaling": { "$ref": "ManualScaling", "description": "A service with manual scaling runs continuously, allowing you to perform complex initialization and rely on the state of its memory over time." }, "name": { "description": "Full path to the Version resource in the API. Example: apps/myapp/services/default/versions/v1.@OutputOnly", "type": "string" }, "apiConfig": { "description": "Serving configuration for Google Cloud Endpoints (https://cloud.google.com/appengine/docs/python/endpoints/).Only returned in GET requests if view=FULL is set.", "$ref": "ApiConfigHandler" }, "endpointsApiService": { "description": "Cloud Endpoints configuration.If endpoints_api_service is set, the Cloud Endpoints Extensible Service Proxy will be provided to serve the API implemented by the app.", "$ref": "EndpointsApiService" }, "vm": { "description": "Whether to deploy this version in a container on a virtual machine.", "type": "boolean" }, "versionUrl": { "type": "string", "description": "Serving URL for this version. Example: \"https://myversion-dot-myservice-dot-myapp.appspot.com\"@OutputOnly" }, "vpcAccessConnector": { "$ref": "VpcAccessConnector", "description": "Enables VPC connectivity for standard apps." }, "instanceClass": { "type": "string", "description": "Instance class that is used to run this version. Valid values are:\nAutomaticScaling: F1, F2, F4, F4_1G\nManualScaling or BasicScaling: B1, B2, B4, B8, B4_1GDefaults to F1 for AutomaticScaling and B1 for ManualScaling or BasicScaling." }, "servingStatus": { "enumDescriptions": ["Not specified.", "Currently serving. Instances are created according to the scaling settings of the version.", "Disabled. No instances will be created and the scaling settings are ignored until the state of the version changes to SERVING."], "enum": ["SERVING_STATUS_UNSPECIFIED", "SERVING", "STOPPED"], "description": "Current serving status of this version. Only the versions with a SERVING status create instances and can be billed.SERVING_STATUS_UNSPECIFIED is an invalid value. Defaults to SERVING.", "type": "string" }, "runtimeApiVersion": { "type": "string", "description": "The version of the API in the given runtime environment. Please see the app.yaml reference for valid values at https://cloud.google.com/appengine/docs/standard/<language>/config/appref" }, "deployment": { "description": "Code and application artifacts that make up this version.Only returned in GET requests if view=FULL is set.", "$ref": "Deployment" }, "createTime": { "type": "string", "description": "Time that this version was created.@OutputOnly", "format": "google-datetime" }, "inboundServices": { "type": "array", "items": { "type": "string", "enum": ["INBOUND_SERVICE_UNSPECIFIED", "INBOUND_SERVICE_MAIL", "INBOUND_SERVICE_MAIL_BOUNCE", "INBOUND_SERVICE_XMPP_ERROR", "INBOUND_SERVICE_XMPP_MESSAGE", "INBOUND_SERVICE_XMPP_SUBSCRIBE", "INBOUND_SERVICE_XMPP_PRESENCE", "INBOUND_SERVICE_CHANNEL_PRESENCE", "INBOUND_SERVICE_WARMUP"] }, "enumDescriptions": ["Not specified.", "Allows an application to receive mail.", "Allows an application to receive email-bound notifications.", "Allows an application to receive error stanzas.", "Allows an application to receive instant messages.", "Allows an application to receive user subscription POSTs.", "Allows an application to receive a user's chat presence.", "Registers an application for notifications when a client connects or disconnects from a channel.", "Enables warmup requests."], "description": "Before an application can receive email or XMPP messages, the application must be configured to enable the service." }, "resources": { "$ref": "Resources", "description": "Machine resources for this version. Only applicable in the App Engine flexible environment." }, "errorHandlers": { "type": "array", "items": { "$ref": "ErrorHandler" }, "description": "Custom static error pages. Limited to 10KB per page.Only returned in GET requests if view=FULL is set." }, "defaultExpiration": { "description": "Duration that static files should be cached by web proxies and browsers. Only applicable if the corresponding StaticFilesHandler (https://cloud.google.com/appengine/docs/admin-api/reference/rest/v1/apps.services.versions#StaticFilesHandler) does not specify its own expiration time.Only returned in GET requests if view=FULL is set.", "format": "google-duration", "type": "string" }, "libraries": { "description": "Configuration for third-party Python runtime libraries that are required by the application.Only returned in GET requests if view=FULL is set.", "type": "array", "items": { "$ref": "Library" } }, "nobuildFilesRegex": { "description": "Files that match this pattern will not be built into this version. Only applicable for Go runtimes.Only returned in GET requests if view=FULL is set.", "type": "string" }, "basicScaling": { "$ref": "BasicScaling", "description": "A service with basic scaling will create an instance when the application receives a request. The instance will be turned down when the app becomes idle. Basic scaling is ideal for work that is intermittent or driven by user activity." }, "runtimeMainExecutablePath": { "type": "string", "description": "The path or name of the app's main executable." }, "runtime": { "description": "Desired runtime. Example: python27.", "type": "string" }, "createdBy": { "description": "Email address of the user who created this version.@OutputOnly", "type": "string" }, "id": { "description": "Relative name of the version within the service. Example: v1. Version names can contain only lowercase letters, numbers, or hyphens. Reserved names: \"default\", \"latest\", and any name with the prefix \"ah-\".", "type": "string" }, "envVariables": { "additionalProperties": { "type": "string" }, "description": "Environment variables available to the application.Only returned in GET requests if view=FULL is set.", "type": "object" }, "livenessCheck": { "$ref": "LivenessCheck", "description": "Configures liveness health checking for instances. Unhealthy instances are stopped and replaced with new instancesOnly returned in GET requests if view=FULL is set." }, "network": { "$ref": "Network", "description": "Extra network settings. Only applicable in the App Engine flexible environment." }, "betaSettings": { "type": "object", "additionalProperties": { "type": "string" }, "description": "Metadata settings that are supplied to this version to enable beta runtime features." }, "env": { "description": "App Engine execution environment for this version.Defaults to standard.", "type": "string" }, "handlers": { "description": "An ordered list of URL-matching patterns that should be applied to incoming requests. The first matching URL handles the request and other request handlers are not attempted.Only returned in GET requests if view=FULL is set.", "type": "array", "items": { "$ref": "UrlMap" } } } }, "RepairApplicationRequest": { "description": "Request message for 'Applications.RepairApplication'.", "type": "object", "properties": {}, "id": "RepairApplicationRequest" }, "CertificateRawData": { "type": "object", "properties": { "publicCertificate": { "description": "PEM encoded x.509 public key certificate. This field is set once on certificate creation. Must include the header and footer. Example: <pre> -----BEGIN CERTIFICATE----- <certificate_value> -----END CERTIFICATE----- </pre>", "type": "string" }, "privateKey": { "description": "Unencrypted PEM encoded RSA private key. This field is set once on certificate creation and then encrypted. The key size must be 2048 bits or fewer. Must include the header and footer. Example: <pre> -----BEGIN RSA PRIVATE KEY----- <unencrypted_key_value> -----END RSA PRIVATE KEY----- </pre> @InputOnly", "type": "string" } }, "id": "CertificateRawData", "description": "An SSL certificate obtained from a certificate authority." }, "FileInfo": { "description": "Single source file that is part of the version to be deployed. Each source file that is deployed must be specified separately.", "type": "object", "properties": { "sourceUrl": { "description": "URL source to use to fetch this file. Must be a URL to a resource in Google Cloud Storage in the form 'http(s)://storage.googleapis.com/<bucket>/<object>'.", "type": "string" }, "sha1Sum": { "description": "The SHA1 hash of the file, in hex.", "type": "string" }, "mimeType": { "type": "string", "description": "The MIME type of the file.Defaults to the value from Google Cloud Storage." } }, "id": "FileInfo" }, "ScriptHandler": { "id": "ScriptHandler", "description": "Executes a script to handle the request that matches the URL pattern.", "type": "object", "properties": { "scriptPath": { "type": "string", "description": "Path to the script from the application root directory." } } }, "Entrypoint": { "type": "object", "properties": { "shell": { "type": "string", "description": "The format should be a shell command that can be fed to bash -c." } }, "id": "Entrypoint", "description": "The entrypoint for the application." }, "AuthorizedDomain": { "description": "A domain that a user has been authorized to administer. To authorize use of a domain, verify ownership via Webmaster Central (https://www.google.com/webmasters/verification/home).", "type": "object", "properties": { "name": { "type": "string", "description": "Full path to the AuthorizedDomain resource in the API. Example: apps/myapp/authorizedDomains/example.com.@OutputOnly" }, "id": { "description": "Fully qualified domain name of the domain authorized for use. Example: example.com.", "type": "string" } }, "id": "AuthorizedDomain" }, "TrafficSplit": { "description": "Traffic routing configuration for versions within a single service. Traffic splits define how traffic directed to the service is assigned to versions.", "type": "object", "properties": { "shardBy": { "description": "Mechanism used to determine which version a request is sent to. The traffic selection algorithm will be stable for either type until allocations are changed.", "type": "string", "enumDescriptions": ["Diversion method unspecified.", "Diversion based on a specially named cookie, \"GOOGAPPUID.\" The cookie must be set by the application itself or no diversion will occur.", "Diversion based on applying the modulus operation to a fingerprint of the IP address.", "Diversion based on weighted random assignment. An incoming request is randomly routed to a version in the traffic split, with probability proportional to the version's traffic share."], "enum": ["UNSPECIFIED", "COOKIE", "IP", "RANDOM"] }, "allocations": { "additionalProperties": { "format": "double", "type": "number" }, "description": "Mapping from version IDs within the service to fractional (0.000, 1] allocations of traffic for that version. Each version can be specified only once, but some versions in the service may not have any traffic allocation. Services that have traffic allocated cannot be deleted until either the service is deleted or their traffic allocation is removed. Allocations must sum to 1. Up to two decimal place precision is supported for IP-based splits and up to three decimal places is supported for cookie-based splits.", "type": "object" } }, "id": "TrafficSplit" }, "OperationMetadataV1Beta": { "type": "object", "properties": { "endTime": { "description": "Time that this operation completed.@OutputOnly", "format": "google-datetime", "type": "string" }, "createVersionMetadata": { "$ref": "CreateVersionMetadataV1Beta" }, "warning": { "description": "Durable messages that persist on every operation poll. @OutputOnly", "type": "array", "items": { "type": "string" } }, "insertTime": { "description": "Time that this operation was created.@OutputOnly", "format": "google-datetime", "type": "string" }, "user": { "description": "User who requested this operation.@OutputOnly", "type": "string" }, "target": { "description": "Name of the resource that this operation is acting on. Example: apps/myapp/services/default.@OutputOnly", "type": "string" }, "ephemeralMessage": { "description": "Ephemeral message that may change every time the operation is polled. @OutputOnly", "type": "string" }, "method": { "type": "string", "description": "API method that initiated this operation. Example: google.appengine.v1beta.Versions.CreateVersion.@OutputOnly" } }, "id": "OperationMetadataV1Beta", "description": "Metadata for the given google.longrunning.Operation." }, "ListIngressRulesResponse": { "description": "Response message for Firewall.ListIngressRules.", "type": "object", "properties": { "nextPageToken": { "type": "string", "description": "Continuation token for fetching the next page of results." }, "ingressRules": { "type": "array", "items": { "$ref": "FirewallRule" }, "description": "The ingress FirewallRules for this application." } }, "id": "ListIngressRulesResponse" }, "ListServicesResponse": { "type": "object", "properties": { "services": { "description": "The services belonging to the requested application.", "type": "array", "items": { "$ref": "Service" } }, "nextPageToken": { "description": "Continuation token for fetching the next page of results.", "type": "string" } }, "id": "ListServicesResponse", "description": "Response message for Services.ListServices." }, "Deployment": { "type": "object", "properties": { "files": { "additionalProperties": { "$ref": "FileInfo" }, "description": "Manifest of the files stored in Google Cloud Storage that are included as part of this version. All files must be readable using the credentials supplied with this call.", "type": "object" }, "cloudBuildOptions": { "$ref": "CloudBuildOptions", "description": "Options for any Google Cloud Build builds created as a part of this deployment.These options will only be used if a new build is created, such as when deploying to the App Engine flexible environment using files or zip." }, "zip": { "description": "The zip file for this deployment, if this is a zip deployment.", "$ref": "ZipInfo" }, "container": { "$ref": "ContainerInfo", "description": "The Docker image for the container that runs the version. Only applicable for instances running in the App Engine flexible environment." } }, "id": "Deployment", "description": "Code and application artifacts used to deploy a version to App Engine." }, "Resources": { "description": "Machine resources for a version.", "type": "object", "properties": { "cpu": { "description": "Number of CPU cores needed.", "format": "double", "type": "number" }, "memoryGb": { "description": "Memory (GB) needed.", "format": "double", "type": "number" }, "volumes": { "type": "array", "items": { "$ref": "Volume" }, "description": "User specified volumes." }, "diskGb": { "description": "Disk size (GB) needed.", "format": "double", "type": "number" } }, "id": "Resources" }, "BatchUpdateIngressRulesResponse": { "description": "Response message for Firewall.UpdateAllIngressRules.", "type": "object", "properties": { "ingressRules": { "description": "The full list of ingress FirewallRules for this application.", "type": "array", "items": { "$ref": "FirewallRule" } } }, "id": "BatchUpdateIngressRulesResponse" }, "Volume": { "id": "Volume", "description": "Volumes mounted within the app container. Only applicable in the App Engine flexible environment.", "type": "object", "properties": { "name": { "description": "Unique name for the volume.", "type": "string" }, "volumeType": { "description": "Underlying volume type, e.g. 'tmpfs'.", "type": "string" }, "sizeGb": { "type": "number", "description": "Volume size in gigabytes.", "format": "double" } } }, "ManagedCertificate": { "id": "ManagedCertificate", "description": "A certificate managed by App Engine.", "type": "object", "properties": { "lastRenewalTime": { "type": "string", "description": "Time at which the certificate was last renewed. The renewal process is fully managed. Certificate renewal will automatically occur before the certificate expires. Renewal errors can be tracked via ManagementStatus.@OutputOnly", "format": "google-datetime" }, "status": { "description": "Status of certificate management. Refers to the most recent certificate acquisition or renewal attempt.@OutputOnly", "type": "string", "enumDescriptions": ["", "Certificate was successfully obtained and inserted into the serving system.", "Certificate is under active attempts to acquire or renew.", "Most recent renewal failed due to an invalid DNS setup and will be retried. Renewal attempts will continue to fail until the certificate domain's DNS configuration is fixed. The last successfully provisioned certificate may still be serving.", "All renewal attempts have been exhausted, likely due to an invalid DNS setup.", "Most recent renewal failed due to an explicit CAA record that does not include the in-use CA, Let's Encrypt. Renewals will continue to fail until the CAA is reconfigured. The last successfully provisioned certificate may still be serving.", "Most recent renewal failed due to a CAA retrieval failure. This means that the domain's DNS provider does not properly handle CAA records, failing requests for CAA records when no CAA records are defined. Renewals will continue to fail until the DNS provider is changed or a CAA record is added for the given domain. The last successfully provisioned certificate may still be serving."], "enum": ["MANAGEMENT_STATUS_UNSPECIFIED", "OK", "PENDING", "FAILED_RETRYING_NOT_VISIBLE", "FAILED_PERMANENT", "FAILED_RETRYING_CAA_FORBIDDEN", "FAILED_RETRYING_CAA_CHECKING"] } } }, "ListInstancesResponse": { "description": "Response message for Instances.ListInstances.", "type": "object", "properties": { "instances": { "description": "The instances belonging to the requested version.", "type": "array", "items": { "$ref": "Instance" } }, "nextPageToken": { "description": "Continuation token for fetching the next page of results.", "type": "string" } }, "id": "ListInstancesResponse" }, "ListDomainMappingsResponse": { "id": "ListDomainMappingsResponse", "description": "Response message for DomainMappings.ListDomainMappings.", "type": "object", "properties": { "domainMappings": { "description": "The domain mappings for the application.", "type": "array", "items": { "$ref": "DomainMapping" } }, "nextPageToken": { "description": "Continuation token for fetching the next page of results.", "type": "string" } } }, "OperationMetadataV1Alpha": { "description": "Metadata for the given google.longrunning.Operation.", "type": "object", "properties": { "method": { "description": "API method that initiated this operation. Example: google.appengine.v1alpha.Versions.CreateVersion.@OutputOnly", "type": "string" }, "endTime": { "description": "Time that this operation completed.@OutputOnly", "format": "google-datetime", "type": "string" }, "createVersionMetadata": { "$ref": "CreateVersionMetadataV1Alpha" }, "insertTime": { "type": "string", "description": "Time that this operation was created.@OutputOnly", "format": "google-datetime" }, "warning": { "description": "Durable messages that persist on every operation poll. @OutputOnly", "type": "array", "items": { "type": "string" } }, "user": { "description": "User who requested this operation.@OutputOnly", "type": "string" }, "target": { "description": "Name of the resource that this operation is acting on. Example: apps/myapp/services/default.@OutputOnly", "type": "string" }, "ephemeralMessage": { "description": "Ephemeral message that may change every time the operation is polled. @OutputOnly", "type": "string" } }, "id": "OperationMetadataV1Alpha" } }, "icons": { "x32": "http://www.google.com/images/icons/product/search-32.gif", "x16": "http://www.google.com/images/icons/product/search-16.gif" }, "protocol": "rest", "version": "v1", "baseUrl": "https://appengine.googleapis.com/", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/appengine.admin": { "description": "View and manage your applications deployed on Google App Engine" }, "https://www.googleapis.com/auth/cloud-platform.read-only": { "description": "View your data across Google Cloud Platform services" }, "https://www.googleapis.com/auth/cloud-platform": { "description": "View and manage your data across Google Cloud Platform services" } } } }, "kind": "discovery#restDescription", "description": "Provisions and manages developers' App Engine applications.", "servicePath": "", "rootUrl": "https://appengine.googleapis.com/", "basePath": "", "ownerDomain": "google.com", "name": "appengine", "batchPath": "batch", "id": "appengine:v1", "documentationLink": "https://cloud.google.com/appengine/docs/admin-api/", "revision": "20190618", "title": "App Engine Admin API", "ownerName": "Google", "discoveryVersion": "v1", "version_module": true };
//# sourceMappingURL=appengine-v1.js.map