"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "title": "Genomics API", "discoveryVersion": "v1", "ownerName": "Google", "resources": { "operations": { "methods": { "cancel": { "response": { "$ref": "Empty" }, "parameterOrder": ["name"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/genomics"], "parameters": { "name": { "location": "path", "description": "The name of the operation resource to be cancelled.", "required": true, "type": "string", "pattern": "^operations/.+$" } }, "flatPath": "v1/operations/{operationsId}:cancel", "path": "v1/{+name}:cancel", "id": "genomics.operations.cancel", "request": { "$ref": "CancelOperationRequest" }, "description": "Starts asynchronous cancellation on a long-running operation.\nThe server makes a best effort to cancel the operation, but success is not\nguaranteed. Clients may use Operations.GetOperation\nor Operations.ListOperations\nto check whether the cancellation succeeded or the operation completed\ndespite cancellation.\nAuthorization requires the following [Google IAM](https://cloud.google.com/iam) permission&#58;\n\n* `genomics.operations.cancel`" }, "list": { "flatPath": "v1/operations", "id": "genomics.operations.list", "path": "v1/{+name}", "description": "Lists operations that match the specified filter in the request.\nAuthorization requires the following [Google IAM](https://cloud.google.com/iam) permission&#58;\n\n* `genomics.operations.list`", "httpMethod": "GET", "response": { "$ref": "ListOperationsResponse" }, "parameterOrder": ["name"], "parameters": { "filter": { "description": "A string for filtering Operations.\nIn v2alpha1, the following filter fields are supported&#58;\n\n* createTime&#58; The time this job was created\n* events&#58; The set of event (names) that have occurred while running\n  the pipeline.  The &#58; operator can be used to determine if a\n  particular event has occurred.\n* error&#58; If the pipeline is running, this value is NULL.  Once the\n  pipeline finishes, the value is the standard Google error code.\n* labels.key or labels.\"key with space\" where key is a label key.\n* done&#58; If the pipeline is running, this value is false. Once the\n  pipeline finishes, the value is true.\n\nIn v1 and v1alpha2, the following filter fields are supported&#58;\n\n* projectId&#58; Required. Corresponds to\n  OperationMetadata.projectId.\n* createTime&#58; The time this job was created, in seconds from the\n  [epoch](http://en.wikipedia.org/wiki/Unix_time). Can use `>=` and/or `<=`\n  operators.\n* status&#58; Can be `RUNNING`, `SUCCESS`, `FAILURE`, or `CANCELED`. Only\n  one status may be specified.\n* labels.key where key is a label key.\n\nExamples&#58;\n\n* `projectId = my-project AND createTime >= 1432140000`\n* `projectId = my-project AND createTime >= 1432140000 AND createTime <= 1432150000 AND status = RUNNING`\n* `projectId = my-project AND labels.color = *`\n* `projectId = my-project AND labels.color = red`", "type": "string", "location": "query" }, "name": { "description": "The name of the operation's parent resource.", "required": true, "type": "string", "pattern": "^operations$", "location": "path" }, "pageToken": { "location": "query", "description": "The standard list page token.", "type": "string" }, "pageSize": { "location": "query", "description": "The maximum number of results to return. The maximum value is 256.", "format": "int32", "type": "integer" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/genomics"] }, "get": { "flatPath": "v1/operations/{operationsId}", "path": "v1/{+name}", "id": "genomics.operations.get", "description": "Gets the latest state of a long-running operation.\nClients can use this method to poll the operation result at intervals as\nrecommended by the API service.\nAuthorization requires the following [Google IAM](https://cloud.google.com/iam) permission&#58;\n\n* `genomics.operations.get`", "response": { "$ref": "Operation" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform", "https://www.googleapis.com/auth/genomics"], "parameters": { "name": { "description": "The name of the operation resource.", "required": true, "type": "string", "pattern": "^operations/.+$", "location": "path" } } } } } }, "parameters": { "key": { "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string", "location": "query" }, "access_token": { "description": "OAuth access token.", "type": "string", "location": "query" }, "upload_protocol": { "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string", "location": "query" }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" }, "quotaUser": { "type": "string", "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters." }, "uploadType": { "type": "string", "location": "query", "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\")." }, "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" }, "$.xgafv": { "location": "query", "enum": ["1", "2"], "description": "V1 error format.", "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"] }, "oauth_token": { "type": "string", "location": "query", "description": "OAuth 2.0 token for the current user." }, "callback": { "description": "JSONP", "type": "string", "location": "query" }, "alt": { "default": "json", "enum": ["json", "media", "proto"], "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response." } }, "schemas": { "ContainerStoppedEvent": { "id": "ContainerStoppedEvent", "description": "An event generated when a container exits.", "type": "object", "properties": { "stderr": { "description": "The tail end of any content written to standard error by the container.\nIf the content emits large amounts of debugging noise or contains\nsensitive information, you can prevent the content from being printed by\nsetting the `DISABLE_STANDARD_ERROR_CAPTURE` flag.\n\nNote that only a small amount of the end of the stream is captured here.\nThe entire stream is stored in the `/google/logs` directory mounted into\neach action, and can be copied off the machine as described elsewhere.", "type": "string" }, "exitStatus": { "description": "The exit status of the container.", "format": "int32", "type": "integer" }, "actionId": { "type": "integer", "description": "The numeric ID of the action that started this container.", "format": "int32" } } }, "ContainerStartedEvent": { "id": "ContainerStartedEvent", "description": "An event generated when a container starts.", "type": "object", "properties": { "actionId": { "description": "The numeric ID of the action that started this container.", "format": "int32", "type": "integer" }, "ipAddress": { "description": "The public IP address that can be used to connect to the container. This\nfield is only populated when at least one port mapping is present. If the\ninstance was created with a private address, this field will be empty even\nif port mappings exist.", "type": "string" }, "portMappings": { "additionalProperties": { "format": "int32", "type": "integer" }, "description": "The container-to-host port mappings installed for this container. This\nset will contain any ports exposed using the `PUBLISH_EXPOSED_PORTS` flag\nas well as any specified in the `Action` definition.", "type": "object" } } }, "PullStartedEvent": { "type": "object", "properties": { "imageUri": { "type": "string", "description": "The URI of the image that was pulled." } }, "id": "PullStartedEvent", "description": "An event generated when the worker starts pulling an image." }, "UnexpectedExitStatusEvent": { "description": "An event generated when the execution of a container results in a\nnon-zero exit status that was not otherwise ignored. Execution will\ncontinue, but only actions that are flagged as `ALWAYS_RUN` will be\nexecuted. Other actions will be skipped.", "type": "object", "properties": { "exitStatus": { "type": "integer", "description": "The exit status of the container.", "format": "int32" }, "actionId": { "description": "The numeric ID of the action that started the container.", "format": "int32", "type": "integer" } }, "id": "UnexpectedExitStatusEvent" }, "CancelOperationRequest": { "id": "CancelOperationRequest", "description": "The request message for Operations.CancelOperation.", "type": "object", "properties": {} }, "ComputeEngine": { "type": "object", "properties": { "machineType": { "description": "The machine type of the instance.", "type": "string" }, "diskNames": { "description": "The names of the disks that were created for this pipeline.", "type": "array", "items": { "type": "string" } }, "instanceName": { "type": "string", "description": "The instance on which the operation is running." }, "zone": { "type": "string", "description": "The availability zone in which the instance resides." } }, "id": "ComputeEngine", "description": "Describes a Compute Engine resource that is being managed by a running\npipeline." }, "PullStoppedEvent": { "description": "An event generated when the worker stops pulling an image.", "type": "object", "properties": { "imageUri": { "type": "string", "description": "The URI of the image that was pulled." } }, "id": "PullStoppedEvent" }, "RuntimeMetadata": { "description": "Runtime metadata that will be populated in the\nruntimeMetadata\nfield of the Operation associated with a RunPipeline execution.", "type": "object", "properties": { "computeEngine": { "$ref": "ComputeEngine", "description": "Execution information specific to Google Compute Engine." } }, "id": "RuntimeMetadata" }, "Operation": { "type": "object", "properties": { "metadata": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "An OperationMetadata or Metadata object. This will always be returned with the Operation.", "type": "object" }, "done": { "type": "boolean", "description": "If the value is `false`, it means the operation is still in progress.\nIf `true`, the operation is completed, and either `error` or `response` is\navailable." }, "response": { "description": "An Empty object.", "type": "object", "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" } }, "name": { "description": "The server-assigned name, which is only unique within the same service that originally returns it. For example&#58; `operations/CJHU7Oi_ChDrveSpBRjfuL-qzoWAgEw`", "type": "string" }, "error": { "$ref": "Status", "description": "The error result of the operation in case of failure or cancellation." } }, "id": "Operation", "description": "This resource represents a long-running operation that is the result of a\nnetwork API call." }, "WorkerAssignedEvent": { "id": "WorkerAssignedEvent", "description": "An event generated after a worker VM has been assigned to run the\npipeline.", "type": "object", "properties": { "zone": { "description": "The zone the worker is running in.", "type": "string" }, "instance": { "type": "string", "description": "The worker's instance name." } } }, "RunPipelineResponse": { "description": "The response to the RunPipeline method, returned in the operation's result\nfield on success.", "type": "object", "properties": {}, "id": "RunPipelineResponse" }, "DelayedEvent": { "type": "object", "properties": { "metrics": { "description": "If the delay was caused by a resource shortage, this field lists the\nCompute Engine metrics that are preventing this operation from running\n(for example, `CPUS` or `INSTANCES`). If the particular metric is not\nknown, a single `UNKNOWN` metric will be present.", "type": "array", "items": { "type": "string" } }, "cause": { "description": "A textual description of the cause of the delay. The string can change\nwithout notice because it is often generated by another service (such as\nCompute Engine).", "type": "string" } }, "id": "DelayedEvent", "description": "An event generated whenever a resource limitation or transient error\ndelays execution of a pipeline that was otherwise ready to run." }, "Status": { "description": "The `Status` type defines a logical error model that is suitable for\ndifferent programming environments, including REST APIs and RPC APIs. It is\nused by [gRPC](https://github.com/grpc). Each `Status` message contains\nthree pieces of data: error code, error message, and error details.\n\nYou can find out more about this error model and how to work with it in the\n[API Design Guide](https://cloud.google.com/apis/design/errors).", "type": "object", "properties": { "message": { "description": "A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.", "type": "string" }, "details": { "description": "A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.", "type": "array", "items": { "type": "object", "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" } } }, "code": { "description": "The status code, which should be an enum value of google.rpc.Code.", "format": "int32", "type": "integer" } }, "id": "Status" }, "Event": { "type": "object", "properties": { "timestamp": { "description": "The time at which the event occurred.", "format": "google-datetime", "type": "string" }, "details": { "type": "object", "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "Machine-readable details about the event." }, "description": { "description": "A human-readable description of the event. Note that these strings can\nchange at any time without notice. Any application logic must use the\ninformation in the `details` field.", "type": "string" } }, "id": "Event", "description": "Carries information about events that occur during pipeline execution." }, "Empty": { "type": "object", "properties": {}, "id": "Empty", "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`." }, "WorkerReleasedEvent": { "description": "An event generated when the worker VM that was assigned to the pipeline\nhas been released (deleted).", "type": "object", "properties": { "instance": { "description": "The worker's instance name.", "type": "string" }, "zone": { "type": "string", "description": "The zone the worker was running in." } }, "id": "WorkerReleasedEvent" }, "OperationEvent": { "description": "An event that occurred during an Operation.", "type": "object", "properties": { "endTime": { "description": "Optional time of when event finished. An event can have a start time and no\nfinish time. If an event has a finish time, there must be a start time.", "format": "google-datetime", "type": "string" }, "startTime": { "description": "Optional time of when event started.", "format": "google-datetime", "type": "string" }, "description": { "description": "Required description of event.", "type": "string" } }, "id": "OperationEvent" }, "ListOperationsResponse": { "description": "The response message for Operations.ListOperations.", "type": "object", "properties": { "nextPageToken": { "description": "The standard List next-page token.", "type": "string" }, "operations": { "description": "A list of operations that matches the specified filter in the request.", "type": "array", "items": { "$ref": "Operation" } } }, "id": "ListOperationsResponse" }, "OperationMetadata": { "id": "OperationMetadata", "description": "Metadata describing an Operation.", "type": "object", "properties": { "clientId": { "description": "This field is deprecated. Use `labels` instead. Optionally provided by the\ncaller when submitting the request that creates the operation.", "type": "string" }, "events": { "description": "Optional event messages that were generated during the job's execution.\nThis also contains any warnings that were generated during import\nor export.", "type": "array", "items": { "$ref": "OperationEvent" } }, "endTime": { "type": "string", "description": "The time at which the job stopped running.", "format": "google-datetime" }, "startTime": { "description": "The time at which the job began to run.", "format": "google-datetime", "type": "string" }, "request": { "description": "The original request that started the operation. Note that this will be in\ncurrent version of the API. If the operation was started with v1beta2 API\nand a GetOperation is performed on v1 API, a v1 request will be returned.", "type": "object", "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" } }, "runtimeMetadata": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "Runtime metadata on this Operation.", "type": "object" }, "createTime": { "type": "string", "description": "The time at which the job was submitted to the Genomics service.", "format": "google-datetime" }, "labels": { "description": "Optionally provided by the caller when submitting the request that creates\nthe operation.", "type": "object", "additionalProperties": { "type": "string" } }, "projectId": { "description": "The Google Cloud Project in which the job is scoped.", "type": "string" } } }, "FailedEvent": { "description": "An event generated when the execution of a pipeline has failed. Note\nthat other events can continue to occur after this event.", "type": "object", "properties": { "cause": { "description": "The human-readable description of the cause of the failure.", "type": "string" }, "code": { "type": "string", "enumDescriptions": ["Not an error; returned on success\n\nHTTP Mapping: 200 OK", "The operation was cancelled, typically by the caller.\n\nHTTP Mapping: 499 Client Closed Request", "Unknown error.  For example, this error may be returned when\na `Status` value received from another address space belongs to\nan error space that is not known in this address space.  Also\nerrors raised by APIs that do not return enough error information\nmay be converted to this error.\n\nHTTP Mapping: 500 Internal Server Error", "The client specified an invalid argument.  Note that this differs\nfrom `FAILED_PRECONDITION`.  `INVALID_ARGUMENT` indicates arguments\nthat are problematic regardless of the state of the system\n(e.g., a malformed file name).\n\nHTTP Mapping: 400 Bad Request", "The deadline expired before the operation could complete. For operations\nthat change the state of the system, this error may be returned\neven if the operation has completed successfully.  For example, a\nsuccessful response from a server could have been delayed long\nenough for the deadline to expire.\n\nHTTP Mapping: 504 Gateway Timeout", "Some requested entity (e.g., file or directory) was not found.\n\nNote to server developers: if a request is denied for an entire class\nof users, such as gradual feature rollout or undocumented whitelist,\n`NOT_FOUND` may be used. If a request is denied for some users within\na class of users, such as user-based access control, `PERMISSION_DENIED`\nmust be used.\n\nHTTP Mapping: 404 Not Found", "The entity that a client attempted to create (e.g., file or directory)\nalready exists.\n\nHTTP Mapping: 409 Conflict", "The caller does not have permission to execute the specified\noperation. `PERMISSION_DENIED` must not be used for rejections\ncaused by exhausting some resource (use `RESOURCE_EXHAUSTED`\ninstead for those errors). `PERMISSION_DENIED` must not be\nused if the caller can not be identified (use `UNAUTHENTICATED`\ninstead for those errors). This error code does not imply the\nrequest is valid or the requested entity exists or satisfies\nother pre-conditions.\n\nHTTP Mapping: 403 Forbidden", "The request does not have valid authentication credentials for the\noperation.\n\nHTTP Mapping: 401 Unauthorized", "Some resource has been exhausted, perhaps a per-user quota, or\nperhaps the entire file system is out of space.\n\nHTTP Mapping: 429 Too Many Requests", "The operation was rejected because the system is not in a state\nrequired for the operation's execution.  For example, the directory\nto be deleted is non-empty, an rmdir operation is applied to\na non-directory, etc.\n\nService implementors can use the following guidelines to decide\nbetween `FAILED_PRECONDITION`, `ABORTED`, and `UNAVAILABLE`:\n (a) Use `UNAVAILABLE` if the client can retry just the failing call.\n (b) Use `ABORTED` if the client should retry at a higher level\n     (e.g., when a client-specified test-and-set fails, indicating the\n     client should restart a read-modify-write sequence).\n (c) Use `FAILED_PRECONDITION` if the client should not retry until\n     the system state has been explicitly fixed.  E.g., if an \"rmdir\"\n     fails because the directory is non-empty, `FAILED_PRECONDITION`\n     should be returned since the client should not retry unless\n     the files are deleted from the directory.\n\nHTTP Mapping: 400 Bad Request", "The operation was aborted, typically due to a concurrency issue such as\na sequencer check failure or transaction abort.\n\nSee the guidelines above for deciding between `FAILED_PRECONDITION`,\n`ABORTED`, and `UNAVAILABLE`.\n\nHTTP Mapping: 409 Conflict", "The operation was attempted past the valid range.  E.g., seeking or\nreading past end-of-file.\n\nUnlike `INVALID_ARGUMENT`, this error indicates a problem that may\nbe fixed if the system state changes. For example, a 32-bit file\nsystem will generate `INVALID_ARGUMENT` if asked to read at an\noffset that is not in the range [0,2^32-1], but it will generate\n`OUT_OF_RANGE` if asked to read from an offset past the current\nfile size.\n\nThere is a fair bit of overlap between `FAILED_PRECONDITION` and\n`OUT_OF_RANGE`.  We recommend using `OUT_OF_RANGE` (the more specific\nerror) when it applies so that callers who are iterating through\na space can easily look for an `OUT_OF_RANGE` error to detect when\nthey are done.\n\nHTTP Mapping: 400 Bad Request", "The operation is not implemented or is not supported/enabled in this\nservice.\n\nHTTP Mapping: 501 Not Implemented", "Internal errors.  This means that some invariants expected by the\nunderlying system have been broken.  This error code is reserved\nfor serious errors.\n\nHTTP Mapping: 500 Internal Server Error", "The service is currently unavailable.  This is most likely a\ntransient condition, which can be corrected by retrying with\na backoff. Note that it is not always safe to retry\nnon-idempotent operations.\n\nSee the guidelines above for deciding between `FAILED_PRECONDITION`,\n`ABORTED`, and `UNAVAILABLE`.\n\nHTTP Mapping: 503 Service Unavailable", "Unrecoverable data loss or corruption.\n\nHTTP Mapping: 500 Internal Server Error"], "enum": ["OK", "CANCELLED", "UNKNOWN", "INVALID_ARGUMENT", "DEADLINE_EXCEEDED", "NOT_FOUND", "ALREADY_EXISTS", "PERMISSION_DENIED", "UNAUTHENTICATED", "RESOURCE_EXHAUSTED", "FAILED_PRECONDITION", "ABORTED", "OUT_OF_RANGE", "UNIMPLEMENTED", "INTERNAL", "UNAVAILABLE", "DATA_LOSS"], "description": "The Google standard error code that best describes this failure." } }, "id": "FailedEvent" }, "ContainerKilledEvent": { "description": "An event generated when a container is forcibly terminated by the\nworker. Currently, this only occurs when the container outlives the\ntimeout specified by the user.", "type": "object", "properties": { "actionId": { "description": "The numeric ID of the action that started the container.", "format": "int32", "type": "integer" } }, "id": "ContainerKilledEvent" } }, "icons": { "x16": "http://www.google.com/images/icons/product/search-16.gif", "x32": "http://www.google.com/images/icons/product/search-32.gif" }, "protocol": "rest", "version": "v1", "baseUrl": "https://genomics.googleapis.com/", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloud-platform": { "description": "View and manage your data across Google Cloud Platform services" }, "https://www.googleapis.com/auth/genomics": { "description": "View and manage Genomics data" } } } }, "description": "Uploads, processes, queries, and searches Genomics data in the cloud.", "servicePath": "", "kind": "discovery#restDescription", "rootUrl": "https://genomics.googleapis.com/", "basePath": "", "ownerDomain": "google.com", "name": "genomics", "batchPath": "batch", "revision": "20190626", "documentationLink": "https://cloud.google.com/genomics", "id": "genomics:v1", "fullyEncodeReservedExpansion": true };
//# sourceMappingURL=genomics-v1.js.map