"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "fullyEncodeReservedExpansion": true, "title": "Cloud Healthcare API", "ownerName": "Google", "resources": { "projects": { "resources": { "locations": { "methods": { "list": { "response": { "$ref": "ListLocationsResponse" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "pattern": "^projects/[^/]+$", "location": "path", "description": "The resource that owns the locations collection, if applicable.", "required": true, "type": "string" }, "pageToken": { "location": "query", "description": "The standard list page token.", "type": "string" }, "pageSize": { "description": "The standard list page size.", "format": "int32", "type": "integer", "location": "query" }, "filter": { "location": "query", "description": "The standard list filter.", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations", "path": "v1alpha2/{+name}/locations", "id": "healthcare.projects.locations.list", "description": "Lists information about the supported locations for this service." }, "get": { "response": { "$ref": "Location" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "location": "path", "description": "Resource name for the location.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.get", "description": "Gets information about a location." } }, "resources": { "datasets": { "methods": { "testIamPermissions": { "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "resource": { "location": "path", "description": "REQUIRED: The resource for which the policy detail is being requested.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}:testIamPermissions", "path": "v1alpha2/{+resource}:testIamPermissions", "id": "healthcare.projects.locations.datasets.testIamPermissions", "request": { "$ref": "TestIamPermissionsRequest" }, "description": "Returns permissions that a caller has on the specified resource.\nIf the resource does not exist, this will return an empty set of\npermissions, not a NOT_FOUND error.\n\nNote: This operation is designed to be used for building permission-aware\nUIs and command-line tools, not for authorization checking. This operation\nmay \"fail open\" without warning.", "response": { "$ref": "TestIamPermissionsResponse" }, "parameterOrder": ["resource"], "httpMethod": "POST" }, "deidentify": { "parameters": { "sourceDataset": { "location": "path", "description": "Source dataset resource name. (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}:deidentify", "id": "healthcare.projects.locations.datasets.deidentify", "path": "v1alpha2/{+sourceDataset}:deidentify", "description": "Creates a new dataset containing de-identified data from the source\ndataset. The metadata field type\nis OperationMetadata.\nIf the request is successful, the\nresponse field type is\nDeidentifySummary.\nIf errors occur,\ndetails field type is\nDeidentifyErrorDetails.", "request": { "$ref": "DeidentifyDatasetRequest" }, "httpMethod": "POST", "parameterOrder": ["sourceDataset"], "response": { "$ref": "Operation" } }, "delete": { "httpMethod": "DELETE", "parameterOrder": ["name"], "response": { "$ref": "Empty" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$", "location": "path", "description": "The name of the dataset to delete (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}`)." } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}", "id": "healthcare.projects.locations.datasets.delete", "path": "v1alpha2/{+name}", "description": "Deletes the specified health dataset and all data contained in the dataset.\nDeleting a dataset does not affect the sources from which the dataset was\nimported (if any)." }, "list": { "response": { "$ref": "ListDatasetsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "pageToken": { "description": "The next_page_token value returned from a previous List request, if any.", "type": "string", "location": "query" }, "pageSize": { "type": "integer", "location": "query", "description": "The maximum number of items to return. Capped to 100 if not specified.\nMay not be larger than 1000.", "format": "int32" }, "parent": { "pattern": "^projects/[^/]+/locations/[^/]+$", "location": "path", "description": "The name of the project whose datasets should be listed (e.g.,\n`projects/{project_id}/locations/{location_id}`).", "required": true, "type": "string" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets", "path": "v1alpha2/{+parent}/datasets", "id": "healthcare.projects.locations.datasets.list", "description": "Lists the health datasets in the current project." }, "create": { "response": { "$ref": "Operation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "pattern": "^projects/[^/]+/locations/[^/]+$", "location": "path", "description": "The name of the project in which the dataset should be created (e.g.,\n`projects/{project_id}/locations/{location_id}`).", "required": true, "type": "string" }, "datasetId": { "description": "The ID of the dataset that is being created.\nThe string must match the following regex: `[\\p{L}\\p{N}_\\-\\.]{1,256}`.", "type": "string", "location": "query" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets", "path": "v1alpha2/{+parent}/datasets", "id": "healthcare.projects.locations.datasets.create", "request": { "$ref": "Dataset" }, "description": "Creates a new health dataset. Results are returned through the\nOperation interface which returns either an\n`Operation.response` which contains a Dataset or\n`Operation.error`. The metadata\nfield type is OperationMetadata.\nA Google Cloud Platform project can contain up to 500 datasets across all\nregions." }, "setIamPolicy": { "parameters": { "resource": { "description": "REQUIRED: The resource for which the policy is being specified.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}:setIamPolicy", "path": "v1alpha2/{+resource}:setIamPolicy", "id": "healthcare.projects.locations.datasets.setIamPolicy", "description": "Sets the access control policy on the specified resource. Replaces any\nexisting policy.", "request": { "$ref": "SetIamPolicyRequest" }, "response": { "$ref": "Policy" }, "parameterOrder": ["resource"], "httpMethod": "POST" }, "getIamPolicy": { "path": "v1alpha2/{+resource}:getIamPolicy", "id": "healthcare.projects.locations.datasets.getIamPolicy", "description": "Gets the access control policy for a resource.\nReturns an empty policy if the resource exists and does not have a policy\nset.", "response": { "$ref": "Policy" }, "parameterOrder": ["resource"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "options.requestedPolicyVersion": { "type": "integer", "location": "query", "description": "Optional. The policy format version to be returned.\nAcceptable values are 0 and 1.\nIf the value is 0, or the field is omitted, policy format version 1 will be\nreturned.", "format": "int32" }, "resource": { "location": "path", "description": "REQUIRED: The resource for which the policy is being requested.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}:getIamPolicy" }, "patch": { "description": "Updates dataset metadata.", "request": { "$ref": "Dataset" }, "response": { "$ref": "Dataset" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$", "location": "path", "description": "Output only. Resource name of the dataset, of the form\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}`.", "required": true, "type": "string" }, "updateMask": { "location": "query", "description": "The update mask applies to the resource. For the `FieldMask` definition,\nsee\nhttps://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask", "format": "google-fieldmask", "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.patch" }, "get": { "description": "Gets any metadata associated with a dataset.", "response": { "$ref": "Dataset" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "description": "The name of the dataset to read (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.get" } }, "resources": { "dicomStores": { "resources": { "dicomWeb": { "methods": { "storeInstances": { "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`)." }, "dicomWebPath": { "description": "The path of the StoreInstances DICOMweb request (e.g.,\n`studies/[{study_id}]`). Note that the `study_uid` is optional.", "required": true, "type": "string", "pattern": "^studies$", "location": "path" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.storeInstances", "request": { "$ref": "HttpBody" }, "description": "StoreInstances stores DICOM instances associated with study instance unique\nidentifiers (SUID). See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.5." }, "searchForSeries": { "description": "SearchForSeries returns a list of matching series. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.6.", "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$" }, "dicomWebPath": { "description": "The path of the SearchForSeries DICOMweb request(e.g., `series` or\n`studies/{study_uid}/series`).", "required": true, "type": "string", "pattern": "^series$", "location": "path" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/series", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.searchForSeries" }, "searchForInstances": { "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path" }, "dicomWebPath": { "pattern": "^instances$", "location": "path", "description": "The path of the SearchForInstancesRequest DICOMweb request (e.g.,\n`instances` or `series/{series_uid}/instances` or\n`studies/{study_uid}/instances`).", "required": true, "type": "string" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/instances", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.searchForInstances", "description": "SearchForInstances returns a list of matching instances. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.6." }, "searchForStudies": { "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "dicomWebPath": { "location": "path", "description": "The path of the SearchForStudies DICOMweb request (e.g., `studies`).", "required": true, "type": "string", "pattern": "^studies$" }, "parent": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.searchForStudies", "description": "SearchForStudies returns a list of matching studies. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.6." } }, "resources": { "studies": { "methods": { "storeInstances": { "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string" }, "dicomWebPath": { "pattern": "^studies/[^/]+$", "location": "path", "description": "The path of the StoreInstances DICOMweb request (e.g.,\n`studies/[{study_id}]`). Note that the `study_uid` is optional.", "required": true, "type": "string" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.storeInstances", "request": { "$ref": "HttpBody" }, "description": "StoreInstances stores DICOM instances associated with study instance unique\nidentifiers (SUID). See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.5." }, "retrieveStudy": { "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "GET", "parameters": { "parent": { "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$" }, "dicomWebPath": { "pattern": "^studies/[^/]+$", "location": "path", "description": "The path of the RetrieveStudy DICOMweb request (e.g.,\n`studies/{study_id}`).", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.retrieveStudy", "description": "RetrieveStudy returns all instances within the given study. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4." }, "searchForSeries": { "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$" }, "dicomWebPath": { "pattern": "^studies/[^/]+/series$", "location": "path", "description": "The path of the SearchForSeries DICOMweb request(e.g., `series` or\n`studies/{study_uid}/series`).", "required": true, "type": "string" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.searchForSeries", "description": "SearchForSeries returns a list of matching series. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.6." }, "searchForInstances": { "description": "SearchForInstances returns a list of matching instances. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.6.", "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "GET", "parameters": { "parent": { "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path" }, "dicomWebPath": { "description": "The path of the SearchForInstancesRequest DICOMweb request (e.g.,\n`instances` or `series/{series_uid}/instances` or\n`studies/{study_uid}/instances`).", "required": true, "type": "string", "pattern": "^studies/[^/]+/instances$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/instances", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.searchForInstances" }, "delete": { "description": "DeleteStudy deletes all instances within the given study. Delete requests\nare equivalent to the GET requests specified in the WADO-RS standard.", "response": { "$ref": "Empty" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$" }, "dicomWebPath": { "location": "path", "description": "The path of the DeleteStudy request (e.g., `studies/{study_id}`).", "required": true, "type": "string", "pattern": "^studies/[^/]+$" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.delete" }, "metadata": { "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.metadata", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "description": "RetrieveStudyMetadata returns instance associated with the given study\npresented as metadata with the bulk data removed. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4.", "httpMethod": "GET", "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "parameters": { "parent": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string" }, "dicomWebPath": { "pattern": "^studies/[^/]+/metadata$", "location": "path", "description": "The path of the RetrieveStudyMetadata DICOMweb request (e.g.,\n`studies/{study_id}/metadata`).", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/metadata" } }, "resources": { "series": { "methods": { "retrieveSeries": { "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.series.retrieveSeries", "description": "RetrieveSeries returns all instances within the given study and series. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4.", "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "dicomWebPath": { "description": "The path of the RetrieveSeries DICOMweb request (e.g.,\n`studies/{study_id}/series/{series_id}`).", "required": true, "type": "string", "pattern": "^studies/[^/]+/series/[^/]+$", "location": "path" }, "parent": { "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}" }, "searchForInstances": { "httpMethod": "GET", "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "parameters": { "dicomWebPath": { "description": "The path of the SearchForInstancesRequest DICOMweb request (e.g.,\n`instances` or `series/{series_uid}/instances` or\n`studies/{study_uid}/instances`).", "required": true, "type": "string", "pattern": "^studies/[^/]+/series/[^/]+/instances$", "location": "path" }, "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`)." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/instances", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.series.searchForInstances", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "description": "SearchForInstances returns a list of matching instances. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.6." }, "delete": { "response": { "$ref": "Empty" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`)." }, "dicomWebPath": { "description": "The path of the DeleteSeries request (e.g.,\n`studies/{study_id}/series/{series_id}`).", "required": true, "type": "string", "pattern": "^studies/[^/]+/series/[^/]+$", "location": "path" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.series.delete", "description": "DeleteSeries deletes all instances within the given study and series.\nDelete requests are equivalent to the GET requests specified in the WADO-RS\nstandard." }, "metadata": { "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "GET", "parameters": { "dicomWebPath": { "required": true, "type": "string", "pattern": "^studies/[^/]+/series/[^/]+/metadata$", "location": "path", "description": "The path of the RetrieveSeriesMetadata DICOMweb request (e.g.,\n`studies/{study_id}/series/{series_id}/metadata`)." }, "parent": { "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/metadata", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.series.metadata", "description": "RetrieveSeriesMetadata returns instance associated with the given study and\nseries, presented as metadata with the bulk data removed. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4." } }, "resources": { "instances": { "methods": { "retrieveInstance": { "description": "RetrieveInstance returns instance associated with the given study, series,\nand SOP Instance UID. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4.", "httpMethod": "GET", "parameterOrder": ["parent", "dicomWebPath"], "response": { "$ref": "HttpBody" }, "parameters": { "parent": { "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path" }, "dicomWebPath": { "pattern": "^studies/[^/]+/series/[^/]+/instances/[^/]+$", "location": "path", "description": "The path of the RetrieveInstance DICOMweb request (e.g.,\n`studies/{study_id}/series/{series_id}/instances/{instance_id}`).", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/instances/{instancesId}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.series.instances.retrieveInstance", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}" }, "rendered": { "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "dicomWebPath": { "pattern": "^studies/[^/]+/series/[^/]+/instances/[^/]+/rendered$", "location": "path", "description": "The path of the RetrieveRenderedInstance DICOMweb request (e.g.,\n`studies/{study_id}/series/{series_id}/instances/{instance_id}/rendered`).", "required": true, "type": "string" }, "parent": { "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/instances/{instancesId}/rendered", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.series.instances.rendered", "description": "RetrieveRenderedInstance returns instance associated with the given study,\nseries, and SOP Instance UID in an acceptable Rendered Media Type. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4." }, "metadata": { "httpMethod": "GET", "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "parameters": { "parent": { "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$" }, "dicomWebPath": { "location": "path", "description": "The path of the RetrieveInstanceMetadata DICOMweb request (e.g.,\n`studies/{study_id}/series/{series_id}/instances/{instance_id}/metadata`).", "required": true, "type": "string", "pattern": "^studies/[^/]+/series/[^/]+/instances/[^/]+/metadata$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/instances/{instancesId}/metadata", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.series.instances.metadata", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "description": "RetrieveInstanceMetadata returns instance associated with the given study,\nseries, and SOP Instance UID presented as metadata with the bulk data\nremoved. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4." }, "delete": { "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.series.instances.delete", "description": "DeleteInstance deletes an instance associated with the given study, series,\nand SOP Instance UID. Delete requests are equivalent to the GET requests\nspecified in the WADO-RS standard.", "response": { "$ref": "Empty" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string" }, "dicomWebPath": { "pattern": "^studies/[^/]+/series/[^/]+/instances/[^/]+$", "location": "path", "description": "The path of the DeleteInstance request (e.g.,\n`studies/{study_id}/series/{series_id}/instances/{instance_id}`).", "required": true, "type": "string" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/instances/{instancesId}" } }, "resources": { "frames": { "methods": { "retrieveFrames": { "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string" }, "dicomWebPath": { "description": "The path of the RetrieveFrames DICOMweb request (e.g.,\n`studies/{study_id}/series/{series_id}/instances/{instance_id}/frames/{frame_list}`).", "required": true, "type": "string", "pattern": "^studies/[^/]+/series/[^/]+/instances/[^/]+/frames/[^/]+$", "location": "path" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/instances/{instancesId}/frames/{framesId}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.series.instances.frames.retrieveFrames", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "description": "RetrieveFrames returns instances associated with the given study, series,\nSOP Instance UID and frame numbers. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4.", "httpMethod": "GET", "parameterOrder": ["parent", "dicomWebPath"], "response": { "$ref": "HttpBody" } }, "rendered": { "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/instances/{instancesId}/frames/{framesId}/rendered", "path": "v1alpha2/{+parent}/dicomWeb/{+dicomWebPath}", "id": "healthcare.projects.locations.datasets.dicomStores.dicomWeb.studies.series.instances.frames.rendered", "description": "RetrieveRenderedFrames returns instances associated with the given study,\nseries, SOP Instance UID and frame numbers in an acceptable Rendered Media\nType. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4.", "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "dicomWebPath"], "httpMethod": "GET", "parameters": { "parent": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path", "description": "The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string" }, "dicomWebPath": { "description": "The path of the RetrieveRenderedFrames DICOMweb request (e.g.,\n`studies/{study_id}/series/{series_id}/instances/{instance_id}/frames/{frame_list}/rendered`).", "required": true, "type": "string", "pattern": "^studies/[^/]+/series/[^/]+/instances/[^/]+/frames/[^/]+/rendered$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] } } } } } } } } } } } }, "methods": { "export": { "response": { "$ref": "Operation" }, "parameterOrder": ["name"], "httpMethod": "POST", "parameters": { "name": { "location": "path", "description": "The DICOM store resource name from which the data should be exported (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}:export", "path": "v1alpha2/{+name}:export", "id": "healthcare.projects.locations.datasets.dicomStores.export", "description": "Exports data to the specified destination by copying it from the DICOM\nstore.\nThe metadata field type is\nOperationMetadata.", "request": { "$ref": "ExportDicomDataRequest" } }, "getIamPolicy": { "httpMethod": "GET", "parameterOrder": ["resource"], "response": { "$ref": "Policy" }, "parameters": { "options.requestedPolicyVersion": { "description": "Optional. The policy format version to be returned.\nAcceptable values are 0 and 1.\nIf the value is 0, or the field is omitted, policy format version 1 will be\nreturned.", "format": "int32", "type": "integer", "location": "query" }, "resource": { "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path", "description": "REQUIRED: The resource for which the policy is being requested.\nSee the operation documentation for the appropriate value for this field." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}:getIamPolicy", "id": "healthcare.projects.locations.datasets.dicomStores.getIamPolicy", "path": "v1alpha2/{+resource}:getIamPolicy", "description": "Gets the access control policy for a resource.\nReturns an empty policy if the resource exists and does not have a policy\nset." }, "patch": { "parameters": { "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path", "description": "Output only. Resource name of the DICOM store, of the form\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`.", "required": true, "type": "string" }, "updateMask": { "description": "The update mask applies to the resource. For the `FieldMask` definition,\nsee\nhttps://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask", "format": "google-fieldmask", "type": "string", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}", "id": "healthcare.projects.locations.datasets.dicomStores.patch", "path": "v1alpha2/{+name}", "description": "Updates the specified DICOM store.", "request": { "$ref": "DicomStore" }, "httpMethod": "PATCH", "parameterOrder": ["name"], "response": { "$ref": "DicomStore" } }, "get": { "description": "Gets the specified DICOM store.", "httpMethod": "GET", "parameterOrder": ["name"], "response": { "$ref": "DicomStore" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path", "description": "The resource name of the DICOM store to get.", "required": true, "type": "string" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}", "id": "healthcare.projects.locations.datasets.dicomStores.get", "path": "v1alpha2/{+name}" }, "testIamPermissions": { "path": "v1alpha2/{+resource}:testIamPermissions", "id": "healthcare.projects.locations.datasets.dicomStores.testIamPermissions", "description": "Returns permissions that a caller has on the specified resource.\nIf the resource does not exist, this will return an empty set of\npermissions, not a NOT_FOUND error.\n\nNote: This operation is designed to be used for building permission-aware\nUIs and command-line tools, not for authorization checking. This operation\nmay \"fail open\" without warning.", "request": { "$ref": "TestIamPermissionsRequest" }, "response": { "$ref": "TestIamPermissionsResponse" }, "parameterOrder": ["resource"], "httpMethod": "POST", "parameters": { "resource": { "description": "REQUIRED: The resource for which the policy detail is being requested.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}:testIamPermissions" }, "delete": { "description": "Deletes the specified DICOM store and removes all images that are contained\nwithin it.", "response": { "$ref": "Empty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path", "description": "The resource name of the DICOM store to delete." } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.dicomStores.delete" }, "import": { "httpMethod": "POST", "parameterOrder": ["name"], "response": { "$ref": "Operation" }, "parameters": { "name": { "location": "path", "description": "The name of the DICOM store resource into which the data is imported (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}:import", "id": "healthcare.projects.locations.datasets.dicomStores.import", "path": "v1alpha2/{+name}:import", "description": "Imports data into the DICOM store by copying it from the specified source.\nFor errors, the Operation will be populated with error details (in the form\nof ImportDicomDataErrorDetails in error.details), which will hold\nfiner-grained error information.\nThe metadata field type is\nOperationMetadata.", "request": { "$ref": "ImportDicomDataRequest" } }, "list": { "id": "healthcare.projects.locations.datasets.dicomStores.list", "path": "v1alpha2/{+parent}/dicomStores", "description": "Lists the DICOM stores in the given dataset.", "httpMethod": "GET", "response": { "$ref": "ListDicomStoresResponse" }, "parameterOrder": ["parent"], "parameters": { "pageToken": { "location": "query", "description": "The next_page_token value returned from the previous List request, if any.", "type": "string" }, "pageSize": { "location": "query", "description": "Limit on the number of DICOM stores to return in a single response.\nIf zero the default page size of 100 is used.", "format": "int32", "type": "integer" }, "parent": { "description": "Name of the dataset.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$", "location": "path" }, "filter": { "type": "string", "location": "query", "description": "Restricts stores returned to those matching a filter. Syntax:\nhttps://cloud.google.com/appengine/docs/standard/python/search/query_strings\nOnly filtering on labels is supported, for example `labels.key=value`." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores" }, "create": { "request": { "$ref": "DicomStore" }, "description": "Creates a new DICOM store within the parent dataset.", "response": { "$ref": "DicomStore" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$", "location": "path", "description": "The name of the dataset this DICOM store belongs to.", "required": true, "type": "string" }, "dicomStoreId": { "location": "query", "description": "The ID of the DICOM store that is being created.\nAny string value up to 256 characters in length.", "type": "string" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores", "path": "v1alpha2/{+parent}/dicomStores", "id": "healthcare.projects.locations.datasets.dicomStores.create" }, "setIamPolicy": { "request": { "$ref": "SetIamPolicyRequest" }, "description": "Sets the access control policy on the specified resource. Replaces any\nexisting policy.", "response": { "$ref": "Policy" }, "parameterOrder": ["resource"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "resource": { "description": "REQUIRED: The resource for which the policy is being specified.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$", "location": "path" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}:setIamPolicy", "path": "v1alpha2/{+resource}:setIamPolicy", "id": "healthcare.projects.locations.datasets.dicomStores.setIamPolicy" } } }, "hl7V2Stores": { "methods": { "testIamPermissions": { "response": { "$ref": "TestIamPermissionsResponse" }, "parameterOrder": ["resource"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "resource": { "description": "REQUIRED: The resource for which the policy detail is being requested.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$", "location": "path" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}:testIamPermissions", "path": "v1alpha2/{+resource}:testIamPermissions", "id": "healthcare.projects.locations.datasets.hl7V2Stores.testIamPermissions", "request": { "$ref": "TestIamPermissionsRequest" }, "description": "Returns permissions that a caller has on the specified resource.\nIf the resource does not exist, this will return an empty set of\npermissions, not a NOT_FOUND error.\n\nNote: This operation is designed to be used for building permission-aware\nUIs and command-line tools, not for authorization checking. This operation\nmay \"fail open\" without warning." }, "delete": { "description": "Deletes the specified HL7v2 store and removes all messages that are\ncontained within it.", "response": { "$ref": "Empty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "parameters": { "name": { "location": "path", "description": "The resource name of the HL7v2 store to delete.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.hl7V2Stores.delete" }, "list": { "httpMethod": "GET", "response": { "$ref": "ListHl7V2StoresResponse" }, "parameterOrder": ["parent"], "parameters": { "parent": { "location": "path", "description": "Name of the dataset.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$" }, "filter": { "location": "query", "description": "Restricts stores returned to those matching a filter. Syntax:\nhttps://cloud.google.com/appengine/docs/standard/python/search/query_strings\nOnly filtering on labels is supported, for example `labels.key=value`.", "type": "string" }, "pageToken": { "type": "string", "location": "query", "description": "The next_page_token value returned from the previous List request, if any." }, "pageSize": { "location": "query", "description": "Limit on the number of HL7v2 stores to return in a single response.\nIf zero the default page size of 100 is used.", "format": "int32", "type": "integer" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores", "id": "healthcare.projects.locations.datasets.hl7V2Stores.list", "path": "v1alpha2/{+parent}/hl7V2Stores", "description": "Lists the HL7v2 stores in the given dataset." }, "setIamPolicy": { "parameters": { "resource": { "description": "REQUIRED: The resource for which the policy is being specified.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}:setIamPolicy", "path": "v1alpha2/{+resource}:setIamPolicy", "id": "healthcare.projects.locations.datasets.hl7V2Stores.setIamPolicy", "description": "Sets the access control policy on the specified resource. Replaces any\nexisting policy.", "request": { "$ref": "SetIamPolicyRequest" }, "response": { "$ref": "Policy" }, "parameterOrder": ["resource"], "httpMethod": "POST" }, "create": { "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores", "id": "healthcare.projects.locations.datasets.hl7V2Stores.create", "path": "v1alpha2/{+parent}/hl7V2Stores", "description": "Creates a new HL7v2 store within the parent dataset.", "request": { "$ref": "Hl7V2Store" }, "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "Hl7V2Store" }, "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$", "location": "path", "description": "The name of the dataset this HL7v2 store belongs to." }, "hl7V2StoreId": { "type": "string", "location": "query", "description": "The ID of the HL7v2 store that is being created.\nThe string must match the following regex: `[\\p{L}\\p{N}_\\-\\.]{1,256}`." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] }, "getIamPolicy": { "response": { "$ref": "Policy" }, "parameterOrder": ["resource"], "httpMethod": "GET", "parameters": { "resource": { "description": "REQUIRED: The resource for which the policy is being requested.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$", "location": "path" }, "options.requestedPolicyVersion": { "location": "query", "description": "Optional. The policy format version to be returned.\nAcceptable values are 0 and 1.\nIf the value is 0, or the field is omitted, policy format version 1 will be\nreturned.", "format": "int32", "type": "integer" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}:getIamPolicy", "path": "v1alpha2/{+resource}:getIamPolicy", "id": "healthcare.projects.locations.datasets.hl7V2Stores.getIamPolicy", "description": "Gets the access control policy for a resource.\nReturns an empty policy if the resource exists and does not have a policy\nset." }, "patch": { "response": { "$ref": "Hl7V2Store" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$", "location": "path", "description": "Output only. Resource name of the HL7v2 store, of the form\n`projects/{project_id}/datasets/{dataset_id}/hl7V2Stores/{hl7v2_store_id}`." }, "updateMask": { "description": "The update mask applies to the resource. For the `FieldMask` definition,\nsee\nhttps://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask", "format": "google-fieldmask", "type": "string", "location": "query" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.hl7V2Stores.patch", "request": { "$ref": "Hl7V2Store" }, "description": "Updates the HL7v2 store." }, "get": { "response": { "$ref": "Hl7V2Store" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$", "location": "path", "description": "The resource name of the HL7v2 store to get.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.hl7V2Stores.get", "description": "Gets the specified HL7v2 store." } }, "resources": { "messages": { "methods": { "ingest": { "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}/messages:ingest", "path": "v1alpha2/{+parent}/messages:ingest", "id": "healthcare.projects.locations.datasets.hl7V2Stores.messages.ingest", "request": { "$ref": "IngestMessageRequest" }, "description": "Ingests a new HL7v2 message from the hospital and sends a notification to\nthe Cloud Pub/Sub topic. Return is an HL7v2 ACK message if the message was\nsuccessfully stored. Otherwise an error is returned.  If an identical\nHL7v2 message is created twice only one resource is created on the server\nand no error is reported.", "response": { "$ref": "IngestMessageResponse" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$", "location": "path", "description": "The name of the HL7v2 store this message belongs to.", "required": true, "type": "string" } } }, "get": { "response": { "$ref": "Message" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "view": { "location": "query", "enum": ["MESSAGE_VIEW_UNSPECIFIED", "RAW_ONLY", "PARSED_ONLY", "FULL"], "description": "Specifies which parts of the Message resource should be returned\nin the response.", "type": "string" }, "name": { "description": "The resource name of the HL7v2 message to retrieve.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+/messages/[^/]+$", "location": "path" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}/messages/{messagesId}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.hl7V2Stores.messages.get", "description": "Gets an HL7v2 message." }, "patch": { "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}/messages/{messagesId}", "id": "healthcare.projects.locations.datasets.hl7V2Stores.messages.patch", "path": "v1alpha2/{+name}", "request": { "$ref": "Message" }, "description": "Update the message.", "httpMethod": "PATCH", "parameterOrder": ["name"], "response": { "$ref": "Message" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "updateMask": { "type": "string", "location": "query", "description": "The update mask applies to the resource. For the `FieldMask` definition,\nsee\nhttps://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask\nOnly the `labels` field is allowed to be updated.\nThe labels in the request will be merged with the existing set of labels.\nExisting labels with the same keys will be updated.", "format": "google-fieldmask" }, "name": { "location": "path", "description": "Resource name of the Message, of the form\n`projects/{project_id}/datasets/{dataset_id}/hl7V2Stores/{hl7_v2_store_id}/messages/{message_id}`.\nAssigned by the server.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+/messages/[^/]+$" } } }, "delete": { "id": "healthcare.projects.locations.datasets.hl7V2Stores.messages.delete", "path": "v1alpha2/{+name}", "description": "Deletes an HL7v2 message.", "httpMethod": "DELETE", "parameterOrder": ["name"], "response": { "$ref": "Empty" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "description": "The resource name of the HL7v2 message to delete.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+/messages/[^/]+$", "location": "path" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}/messages/{messagesId}" }, "list": { "httpMethod": "GET", "response": { "$ref": "ListMessagesResponse" }, "parameterOrder": ["parent"], "parameters": { "pageToken": { "type": "string", "location": "query", "description": "The next_page_token value returned from the previous List request, if any." }, "orderBy": { "type": "string", "location": "query", "description": "Orders messages returned by the specified order_by clause.\nSyntax: https://cloud.google.com/apis/design/design_patterns#sorting_order\n\nFields available for ordering are:\n\n*  `send_time`" }, "pageSize": { "location": "query", "description": "Limit on the number of messages to return in a single response.\nIf zero the default page size of 100 is used.", "format": "int32", "type": "integer" }, "parent": { "location": "path", "description": "Name of the HL7v2 store to retrieve messages from.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$" }, "filter": { "description": "Restricts messages returned to those matching a filter. Syntax:\nhttps://cloud.google.com/appengine/docs/standard/python/search/query_strings\n\nFields/functions available for filtering are:\n\n*  `message_type`, from the MSH-9 segment; for example\n`NOT message_type = \"ADT\"`\n*  `send_date` or `sendDate`, the YYYY-MM-DD date the message was sent in\nthe dataset's time_zone, from the MSH-7 segment; for example\n`send_date < \"2017-01-02\"`\n*  `send_time`, the timestamp of when the message was sent, using the\nRFC3339 time format for comparisons, from the MSH-7 segment; for example\n`send_time < \"2017-01-02T00:00:00-05:00\"`\n*  `send_facility`, the care center that the message came from, from the\nMSH-4 segment; for example `send_facility = \"ABC\"`\n*  `HL7RegExp(expr)`, which does regular expression matching of `expr`\nagainst the message payload using re2 (http://code.google.com/p/re2/)\nsyntax; for example `HL7RegExp(\"^.*\\|.*\\|EMERG\")`\n*  `PatientId(value, type)`, which matches if the message lists a patient\nhaving an ID of the given value and type in the PID-2, PID-3, or PID-4\nsegments; for example `PatientId(\"123456\", \"MRN\")`\n*  `labels.x`, a string value of the label with key `x` as set using the\nMessage.labels\nmap, for example `labels.\"priority\"=\"high\"`. The operator `:*` can be used\nto assert the existence of a label, for example `labels.\"priority\":*`.\n\nLimitations on conjunctions:\n\n*  Negation on the patient ID function or the labels field is not\nsupported, for example these queries are invalid:\n`NOT PatientId(\"123456\", \"MRN\")`, `NOT labels.\"tag1\":*`,\n`NOT labels.\"tag2\"=\"val2\"`.\n*  Conjunction of multiple patient ID functions is not supported, for\nexample this query is invalid:\n`PatientId(\"123456\", \"MRN\") AND PatientId(\"456789\", \"MRN\")`.\n*  Conjunction of multiple labels fields is also not supported, for\nexample this query is invalid: `labels.\"tag1\":* AND labels.\"tag2\"=\"val2\"`.\n*  Conjunction of one patient ID function, one labels field and conditions\non other fields is supported, for example this query is valid:\n`PatientId(\"123456\", \"MRN\") AND labels.\"tag1\":* AND message_type = \"ADT\"`.\n\nThe HasLabel(x) and Label(x) syntax from previous API versions are\ndeprecated; replaced by the `labels.x` syntax.", "type": "string", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}/messages", "id": "healthcare.projects.locations.datasets.hl7V2Stores.messages.list", "path": "v1alpha2/{+parent}/messages", "description": "Lists all the messages in the given HL7v2 store with support for filtering." }, "create": { "response": { "$ref": "Message" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "location": "path", "description": "The name of the dataset this message belongs to.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}/messages", "path": "v1alpha2/{+parent}/messages", "id": "healthcare.projects.locations.datasets.hl7V2Stores.messages.create", "request": { "$ref": "CreateMessageRequest" }, "description": "Creates a message and sends a notification to the Cloud Pub/Sub topic. If\nconfigured, the MLLP adapter listens to messages created by this method and\nsends those back to the hospital. A successful response indicates the\nmessage has been persisted to storage and a Cloud Pub/Sub notification has\nbeen sent. Sending to the hospital by the MLLP adapter happens\nasynchronously." } } } } }, "annotationStores": { "methods": { "getIamPolicy": { "description": "Gets the access control policy for a resource. Returns NOT_FOUND error if\nthe resource does not exist. Returns an empty policy if the resource exists\nbut does not have a policy set.\n\nAuthorization requires the Google IAM permission\n`healthcare.AnnotationStores.getIamPolicy` on the specified resource", "request": { "$ref": "GetIamPolicyRequest" }, "httpMethod": "POST", "parameterOrder": ["resource"], "response": { "$ref": "Policy" }, "parameters": { "resource": { "description": "REQUIRED: The resource for which the policy is being requested.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/annotationStores/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/annotationStores/{annotationStoresId}:getIamPolicy", "id": "healthcare.projects.locations.datasets.annotationStores.getIamPolicy", "path": "v1alpha2/{+resource}:getIamPolicy" }, "get": { "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.annotationStores.get", "description": "Gets the specified Annotation store or returns NOT_FOUND if it does not\nexist.", "response": { "$ref": "AnnotationStore" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/annotationStores/[^/]+$", "location": "path", "description": "The resource name of the Annotation store to get." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/annotationStores/{annotationStoresId}" }, "patch": { "description": "Updates the specified Annotation store.", "request": { "$ref": "AnnotationStore" }, "response": { "$ref": "AnnotationStore" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "updateMask": { "location": "query", "description": "The update mask applies to the resource. For the `FieldMask` definition,\nsee\nhttps://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask", "format": "google-fieldmask", "type": "string" }, "name": { "description": "Output only. Resource name of the Annotation store, of the form\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/annotationStores/{annotation_store_id}`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/annotationStores/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/annotationStores/{annotationStoresId}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.annotationStores.patch" }, "testIamPermissions": { "response": { "$ref": "TestIamPermissionsResponse" }, "parameterOrder": ["resource"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "resource": { "description": "REQUIRED: The resource for which the policy detail is being requested.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/annotationStores/[^/]+$", "location": "path" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/annotationStores/{annotationStoresId}:testIamPermissions", "path": "v1alpha2/{+resource}:testIamPermissions", "id": "healthcare.projects.locations.datasets.annotationStores.testIamPermissions", "request": { "$ref": "TestIamPermissionsRequest" }, "description": "Returns permissions that a caller has on the specified resource.\nIf the resource does not exist, this will return an empty set of\npermissions, not a NOT_FOUND error.\n\nThere is no permission required to make this API call." }, "delete": { "httpMethod": "DELETE", "response": { "$ref": "Empty" }, "parameterOrder": ["name"], "parameters": { "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/annotationStores/[^/]+$", "location": "path", "description": "The resource name of the Annotation store to delete.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/annotationStores/{annotationStoresId}", "id": "healthcare.projects.locations.datasets.annotationStores.delete", "path": "v1alpha2/{+name}", "description": "Deletes the specified Annotation store and removes all annotations that are\ncontained within it." }, "list": { "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "location": "path", "description": "Name of the dataset.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$" }, "filter": { "type": "string", "location": "query", "description": "Restricts stores returned to those matching a filter. Syntax:\nhttps://cloud.google.com/appengine/docs/standard/python/search/query_strings\nOnly filtering on labels is supported, for example `labels.key=value`." }, "pageToken": { "location": "query", "description": "The next_page_token value returned from the previous List request, if any.", "type": "string" }, "pageSize": { "location": "query", "description": "Limit on the number of Annotation stores to return in a single response.\nIf zero the default page size of 100 is used.", "format": "int32", "type": "integer" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/annotationStores", "path": "v1alpha2/{+parent}/annotationStores", "id": "healthcare.projects.locations.datasets.annotationStores.list", "description": "Lists the Annotation stores in the given dataset for a source store.", "response": { "$ref": "ListAnnotationStoresResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET" }, "setIamPolicy": { "request": { "$ref": "SetIamPolicyRequest" }, "description": "POLICIES\nSets the access control policy for a resource. Replaces any existing\npolicy.\n\nAuthorization requires the Google IAM permission\n'healthcare.annotationStores.setIamPolicy' on the specified resource", "response": { "$ref": "Policy" }, "parameterOrder": ["resource"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "resource": { "location": "path", "description": "REQUIRED: The resource for which the policy is being specified.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/annotationStores/[^/]+$" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/annotationStores/{annotationStoresId}:setIamPolicy", "path": "v1alpha2/{+resource}:setIamPolicy", "id": "healthcare.projects.locations.datasets.annotationStores.setIamPolicy" }, "create": { "request": { "$ref": "AnnotationStore" }, "description": "Creates a new Annotation store within the parent dataset.", "response": { "$ref": "AnnotationStore" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "description": "The name of the dataset this Annotation store belongs to.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$", "location": "path" }, "annotationStoreId": { "type": "string", "location": "query", "description": "The ID of the Annotation store that is being created.\nThe string must match the following regex: `[\\p{L}\\p{N}_\\-\\.]{1,256}`." } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/annotationStores", "path": "v1alpha2/{+parent}/annotationStores", "id": "healthcare.projects.locations.datasets.annotationStores.create" } }, "resources": { "annotations": { "methods": { "create": { "response": { "$ref": "Annotation" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "description": "The name of the Annotation store this annotation belongs to. For example,\n`projects/my-project/locations/us-central1/datasets/mydataset/annotationStores/myannotationstore`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/annotationStores/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/annotationStores/{annotationStoresId}/annotations", "path": "v1alpha2/{+parent}/annotations", "id": "healthcare.projects.locations.datasets.annotationStores.annotations.create", "description": "Creates a new Annotation record. It is\nvalid to create Annotation objects for the same source more than once since\na unique ID is assigned to each record by this service.", "request": { "$ref": "Annotation" } }, "delete": { "httpMethod": "DELETE", "response": { "$ref": "Empty" }, "parameterOrder": ["name"], "parameters": { "name": { "description": "The resource name of the Annotation to delete.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/annotationStores/[^/]+/annotations/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/annotationStores/{annotationStoresId}/annotations/{annotationsId}", "id": "healthcare.projects.locations.datasets.annotationStores.annotations.delete", "path": "v1alpha2/{+name}", "description": "Deletes an Annotation or returns\nNOT_FOUND if it does not exist." }, "get": { "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.annotationStores.annotations.get", "description": "Gets an Annotation.", "response": { "$ref": "Annotation" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/annotationStores/[^/]+/annotations/[^/]+$", "location": "path", "description": "The resource name of the Annotation to retrieve.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/annotationStores/{annotationStoresId}/annotations/{annotationsId}" }, "patch": { "response": { "$ref": "Annotation" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "updateMask": { "location": "query", "description": "The update mask applies to the resource. For the `FieldMask` definition,\nsee\nhttps://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask", "format": "google-fieldmask", "type": "string" }, "name": { "description": "Output only. Resource name of the Annotation, of the form\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/annotationStores/{annotation_store_id}/annotations/{annotation_id}`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/annotationStores/[^/]+/annotations/[^/]+$", "location": "path" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/annotationStores/{annotationStoresId}/annotations/{annotationsId}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.annotationStores.annotations.patch", "request": { "$ref": "Annotation" }, "description": "Updates the Annotation." }, "list": { "response": { "$ref": "ListAnnotationsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "filter": { "description": "Restricts Annotations returned to those matching a filter. Syntax:\nhttps://cloud.google.com/appengine/docs/standard/python/search/query_strings\nFields/functions available for filtering are:\n- source_version", "type": "string", "location": "query" }, "pageToken": { "description": "The next_page_token value returned from the previous List request, if any.", "type": "string", "location": "query" }, "pageSize": { "type": "integer", "location": "query", "description": "Limit on the number of Annotations to return in a single response.\nIf zero the default page size of 100 is used.", "format": "int32" }, "parent": { "description": "Name of the Annotation store to retrieve Annotations from.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/annotationStores/[^/]+$", "location": "path" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/annotationStores/{annotationStoresId}/annotations", "path": "v1alpha2/{+parent}/annotations", "id": "healthcare.projects.locations.datasets.annotationStores.annotations.list", "description": "Lists the Annotations in the given\nAnnotation store for a source\nresource." } } } } }, "fhirStores": { "methods": { "testIamPermissions": { "httpMethod": "POST", "parameterOrder": ["resource"], "response": { "$ref": "TestIamPermissionsResponse" }, "parameters": { "resource": { "description": "REQUIRED: The resource for which the policy detail is being requested.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/.+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}:testIamPermissions", "id": "healthcare.projects.locations.datasets.fhirStores.testIamPermissions", "path": "v1alpha2/{+resource}:testIamPermissions", "description": "Returns permissions that a caller has on the specified resource.  If the\nresource does not exist, this will return an empty set of permissions, not\na NOT_FOUND error.\n\nThere is no permission required to make this API call.", "request": { "$ref": "TestIamPermissionsRequest" } }, "capabilities": { "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/metadata", "path": "v1alpha2/{+name}/metadata", "id": "healthcare.projects.locations.datasets.fhirStores.capabilities", "description": "Gets the FHIR [capability\nstatement](http://hl7.org/implement/standards/fhir/STU3/capabilitystatement.html)\nfor the store, which contains a description of functionality supported by\nthe server.\n\nImplements the FHIR standard [capabilities\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#capabilities).\n\nOn success, the response body will contain a JSON-encoded representation\nof a `CapabilityStatement` resource.", "response": { "$ref": "HttpBody" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$", "location": "path", "description": "Name of the FHIR store to retrieve the capabilities for.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] }, "import": { "response": { "$ref": "Operation" }, "parameterOrder": ["name"], "httpMethod": "POST", "parameters": { "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$", "location": "path", "description": "The name of the FHIR store to import FHIR resources to. The name should be\nin the format of\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}:import", "path": "v1alpha2/{+name}:import", "id": "healthcare.projects.locations.datasets.fhirStores.import", "description": "Import resources to the FHIR store by loading data from the specified\nsources. Each resource must have a client-supplied ID, which is retained\nby the server.\n\nThe import operation is idempotent. Upon retry, the most recent data\n(matching the client-supplied ID) is overwritten, without creating a new\nresource version. If partial failures occur during the import, successful\nchanges are not rolled back.\n\nIf history imports are enabled\n(enable_history_import is set in the\nFHIR store's configuration), you can import historical versions of a\nresource by supplying a bundle of type `history`. The historical versions\nin the bundle must have `lastUpdated` timestamps. If a current or\nhistorical version with the supplied resource ID already exists, the\nbundle is rejected.\n\nThis method returns an Operation that can\nbe used to track the status of the import by calling\nGetOperation.\n\nImmediate fatal errors appear in the\nerror field.\nOtherwise, when the operation finishes, a detailed response of type\nImportResourcesResponse is returned in the\nresponse field.\nThe metadata field type for this\noperation is OperationMetadata.", "request": { "$ref": "ImportResourcesRequest" } }, "delete": { "httpMethod": "DELETE", "response": { "$ref": "Empty" }, "parameterOrder": ["name"], "parameters": { "name": { "description": "The resource name of the FHIR store to delete.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}", "id": "healthcare.projects.locations.datasets.fhirStores.delete", "path": "v1alpha2/{+name}", "description": "Deletes the specified FHIR store and removes all resources within it." }, "list": { "response": { "$ref": "ListFhirStoresResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "location": "path", "description": "Name of the dataset.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$" }, "filter": { "location": "query", "description": "Restricts stores returned to those matching a filter. Syntax:\nhttps://cloud.google.com/appengine/docs/standard/python/search/query_strings\nOnly filtering on labels is supported, for example `labels.key=value`.", "type": "string" }, "pageToken": { "location": "query", "description": "The next_page_token value returned from the previous List request, if any.", "type": "string" }, "pageSize": { "location": "query", "description": "Limit on the number of FHIR stores to return in a single response.  If zero\nthe default page size of 100 is used.", "format": "int32", "type": "integer" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores", "path": "v1alpha2/{+parent}/fhirStores", "id": "healthcare.projects.locations.datasets.fhirStores.list", "description": "Lists the FHIR stores in the given dataset." }, "create": { "response": { "$ref": "FhirStore" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "description": "The name of the dataset this FHIR store belongs to.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$", "location": "path" }, "fhirStoreId": { "description": "The ID of the FHIR store that is being created.\nThe string must match the following regex: `[\\p{L}\\p{N}_\\-\\.]{1,256}`.", "type": "string", "location": "query" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores", "path": "v1alpha2/{+parent}/fhirStores", "id": "healthcare.projects.locations.datasets.fhirStores.create", "request": { "$ref": "FhirStore" }, "description": "Creates a new FHIR store within the parent dataset." }, "setIamPolicy": { "httpMethod": "POST", "parameterOrder": ["resource"], "response": { "$ref": "Policy" }, "parameters": { "resource": { "description": "REQUIRED: The resource for which the policy is being specified.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}:setIamPolicy", "id": "healthcare.projects.locations.datasets.fhirStores.setIamPolicy", "path": "v1alpha2/{+resource}:setIamPolicy", "description": "Sets the access control policy for a FHIR store or security label within a\nFHIR store. Replaces any existing policy.\n\nAuthorization requires the Google IAM permission\n'healthcare.fhirStores.setIamPolicy' for a FHIR store or\n'healthcare.securityLabels.setIamPolicy' for a security label", "request": { "$ref": "SetIamPolicyRequest" } }, "export": { "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}:export", "path": "v1alpha2/{+name}:export", "id": "healthcare.projects.locations.datasets.fhirStores.export", "request": { "$ref": "ExportResourcesRequest" }, "description": "Export resources from the FHIR store to the specified destination.\n\nThis method returns an Operation that can\nbe used to track the status of the export by calling\nGetOperation.\n\nImmediate fatal errors appear in the\nerror field.\nOtherwise, when the operation finishes, a detailed response of type\nExportResourcesResponse is returned in the\nresponse field.\nThe metadata field type for this\noperation is OperationMetadata.", "response": { "$ref": "Operation" }, "parameterOrder": ["name"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "description": "The name of the FHIR store to export resource from. The name should be in\nthe format of\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}`.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$", "location": "path" } } }, "getIamPolicy": { "description": "Gets the access control policy for a FHIR store or security label within a\nFHIR store. Returns NOT_FOUND error if the resource does not exist. Returns\nan empty policy if the resource exists but does not have a policy set.\n\nAuthorization requires the Google IAM permission\n'healthcare.fhirStores.getIamPolicy' for a FHIR store or\n'healthcare.securityLabels.getIamPolicy' for a security label", "response": { "$ref": "Policy" }, "parameterOrder": ["resource"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "options.requestedPolicyVersion": { "description": "Optional. The policy format version to be returned.\nAcceptable values are 0 and 1.\nIf the value is 0, or the field is omitted, policy format version 1 will be\nreturned.", "format": "int32", "type": "integer", "location": "query" }, "resource": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$", "location": "path", "description": "REQUIRED: The resource for which the policy is being requested.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}:getIamPolicy", "path": "v1alpha2/{+resource}:getIamPolicy", "id": "healthcare.projects.locations.datasets.fhirStores.getIamPolicy" }, "patch": { "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.fhirStores.patch", "description": "Updates the configuration of the specified FHIR store.", "request": { "$ref": "FhirStore" }, "response": { "$ref": "FhirStore" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "parameters": { "updateMask": { "location": "query", "description": "The update mask applies to the resource. For the `FieldMask` definition,\nsee\nhttps://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask", "format": "google-fieldmask", "type": "string" }, "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$", "location": "path", "description": "Output only. Resource name of the FHIR store, of the form\n`projects/{project_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}`.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] }, "get": { "response": { "$ref": "FhirStore" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$", "location": "path", "description": "The resource name of the FHIR store to get.", "required": true, "type": "string" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.fhirStores.get", "description": "Gets the configuration of the specified FHIR store." } }, "resources": { "securityLabels": { "methods": { "setIamPolicy": { "id": "healthcare.projects.locations.datasets.fhirStores.securityLabels.setIamPolicy", "path": "v1alpha2/{+resource}:setIamPolicy", "request": { "$ref": "SetIamPolicyRequest" }, "description": "Sets the access control policy for a FHIR store or security label within a\nFHIR store. Replaces any existing policy.\n\nAuthorization requires the Google IAM permission\n'healthcare.fhirStores.setIamPolicy' for a FHIR store or\n'healthcare.securityLabels.setIamPolicy' for a security label", "httpMethod": "POST", "parameterOrder": ["resource"], "response": { "$ref": "Policy" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "resource": { "description": "REQUIRED: The resource for which the policy is being specified.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/securityLabels/[^/]+$", "location": "path" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/securityLabels/{securityLabelsId}:setIamPolicy" }, "getIamPolicy": { "parameters": { "options.requestedPolicyVersion": { "location": "query", "description": "Optional. The policy format version to be returned.\nAcceptable values are 0 and 1.\nIf the value is 0, or the field is omitted, policy format version 1 will be\nreturned.", "format": "int32", "type": "integer" }, "resource": { "description": "REQUIRED: The resource for which the policy is being requested.\nSee the operation documentation for the appropriate value for this field.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/securityLabels/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/securityLabels/{securityLabelsId}:getIamPolicy", "path": "v1alpha2/{+resource}:getIamPolicy", "id": "healthcare.projects.locations.datasets.fhirStores.securityLabels.getIamPolicy", "description": "Gets the access control policy for a FHIR store or security label within a\nFHIR store. Returns NOT_FOUND error if the resource does not exist. Returns\nan empty policy if the resource exists but does not have a policy set.\n\nAuthorization requires the Google IAM permission\n'healthcare.fhirStores.getIamPolicy' for a FHIR store or\n'healthcare.securityLabels.getIamPolicy' for a security label", "response": { "$ref": "Policy" }, "parameterOrder": ["resource"], "httpMethod": "GET" } } }, "fhir": { "methods": { "conditionalDelete": { "path": "v1alpha2/{+parent}/fhir/{+type}", "id": "healthcare.projects.locations.datasets.fhirStores.fhir.conditionalDelete", "description": "Deletes FHIR resources that match a search query.\n\nImplements the FHIR standard [conditional delete\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#2.21.0.13.1).\nIf multiple resources match, all of them will be deleted.\n\nSearch terms are provided as query parameters following the same pattern as\nthe search method.\n\nNote: Unless resource versioning is disabled by setting the\ndisable_resource_versioning flag\non the FHIR store, the deleted resources will be moved to a history\nrepository that can still be retrieved through vread\nand related methods, unless they are removed by the\npurge method.", "response": { "$ref": "Empty" }, "parameterOrder": ["parent", "type"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "type": { "location": "path", "description": "The FHIR resource type to delete, such as Patient or Observation. For a\ncomplete list, see the [FHIR Resource\nIndex](http://hl7.org/implement/standards/fhir/STU3/resourcelist.html).", "required": true, "type": "string", "pattern": "^[^/]+$" }, "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$", "location": "path", "description": "The name of the FHIR store this resource belongs to." } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}" }, "Observation-lastn": { "id": "healthcare.projects.locations.datasets.fhirStores.fhir.Observation-lastn", "path": "v1alpha2/{+parent}/fhir/Observation/$lastn", "description": "Retrieves the N most recent `Observation` resources for a subject matching\nsearch criteria specified as query parameters, grouped by\n`Observation.code`, sorted from most recent to oldest.\n\nImplements the FHIR extended operation\n[Observation-lastn](http://hl7.org/implement/standards/fhir/STU3/observation-operations.html#lastn).\n\nSearch terms are provided as query parameters following the same pattern as\nthe search method. This operation accepts an additional\nquery parameter `max`, which specifies N, the maximum number of\nObservations to return from each group, with a default of 1.\n\nOn success, the response body will contain a JSON-encoded representation\nof a `Bundle` resource of type `searchset`, containing the results of the\noperation.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.", "httpMethod": "GET", "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent"], "parameters": { "parent": { "location": "path", "description": "Name of the FHIR store to retrieve resources from.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/Observation/$lastn" }, "create": { "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "type"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "type": { "pattern": "^[^/]+$", "location": "path", "description": "The FHIR resource type to create, such as Patient or Observation. For a\ncomplete list, see the [FHIR Resource\nIndex](http://hl7.org/implement/standards/fhir/STU3/resourcelist.html).\nMust match the resource type in the provided content.", "required": true, "type": "string" }, "parent": { "description": "The name of the FHIR store this resource belongs to.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$", "location": "path" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}", "path": "v1alpha2/{+parent}/fhir/{+type}", "id": "healthcare.projects.locations.datasets.fhirStores.fhir.create", "request": { "$ref": "HttpBody" }, "description": "Creates a FHIR resource.\n\nImplements the FHIR standard [create\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#create),\nwhich creates a new resource with a server-assigned resource ID.\n\nAlso supports the FHIR standard [conditional create\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#ccreate),\nspecified by supplying an `If-None-Exist` header containing a FHIR search\nquery. If no resources match this search query, the server processes the\ncreate operation as normal.\n\nThe request body must contain a JSON-encoded FHIR resource, and the request\nheaders must contain `Content-Type: application/fhir+json`.\n\nOn success, the response body will contain a JSON-encoded representation\nof the resource as it was created on the server, including the\nserver-assigned resource ID and version ID.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead." }, "Patient-everything": { "response": { "$ref": "HttpBody" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/Patient/[^/]+$", "location": "path", "description": "Name of the `Patient` resource for which the information is required.", "required": true, "type": "string" }, "start": { "location": "query", "description": "The response includes records subsequent to the start date. If no start\ndate is provided, all records prior to the end date are in scope.", "type": "string" }, "end": { "type": "string", "location": "query", "description": "The response includes records prior to the end date. If no end date is\nprovided, all records subsequent to the start date are in scope." } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/Patient/{PatientId}/$everything", "path": "v1alpha2/{+name}/$everything", "id": "healthcare.projects.locations.datasets.fhirStores.fhir.Patient-everything", "description": "Retrieves all the resources in the patient compartment for a `Patient`\nresource.\n\nImplements the FHIR extended operation\n[Patient-everything](http://hl7.org/implement/standards/fhir/STU3/patient-operations.html#everything).\n\nOn success, the response body will contain a JSON-encoded representation\nof a `Bundle` resource of type `searchset`, containing the results of the\noperation.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead." }, "read": { "response": { "$ref": "HttpBody" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "location": "path", "description": "The name of the resource to retrieve.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/[^/]+/[^/]+$" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}/{fhirId1}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.fhirStores.fhir.read", "description": "Gets the contents of a FHIR resource.\n\nImplements the FHIR standard [read\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#read).\n\nAlso supports the FHIR standard [conditional read\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#cread)\nspecified by supplying an `If-Modified-Since` header with a date/time value\nor an `If-None-Match` header with an ETag value.\n\nOn success, the response body will contain a JSON-encoded representation\nof the resource.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead." }, "search": { "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/_search", "path": "v1alpha2/{+parent}/fhir/_search", "id": "healthcare.projects.locations.datasets.fhirStores.fhir.search", "request": { "$ref": "SearchResourcesRequest" }, "description": "Searches for resources in the given FHIR store according to criteria\nspecified as query parameters.\n\nImplements the FHIR standard [search\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#search)\nusing the search semantics described in the [FHIR Search\nspecification](http://hl7.org/implement/standards/fhir/STU3/search.html).\n\nSupports three methods of search defined by the specification:\n\n*  `GET [base]?[parameters]` to search across all resources.\n*  `GET [base]/[type]?[parameters]` to search resources of a specified\ntype.\n*  `POST [base]/[type]/_search?[parameters]` as an alternate form having\nthe same semantics as the `GET` method.\n\nThe `GET` methods do not support compartment searches. The `POST` method\ndoes not support `application/x-www-form-urlencoded` search parameters.\n\nOn success, the response body will contain a JSON-encoded representation\nof a `Bundle` resource of type `searchset`, containing the results of the\nsearch.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.\n\nThe server's capability statement, retrieved through\ncapabilities, indicates what search parameters\nare supported on each FHIR resource. A list of all search parameters\ndefined by the specification can be found in the [FHIR Search Parameter\nRegistry](http://hl7.org/implement/standards/fhir/STU3/searchparameter-registry.html).\n\nSupported search modifiers: `:missing`, `:exact`, `:contains`, `:text`,\n`:in`, `:not-in`, `:above`, `:below`, `:[type]`, `:not`, and `:recurse`.\n\nSupported search result parameters: `_sort`, `_count`, `_include`,\n`_revinclude`, `_summary=text`, `_summary=data`, and `_elements`.\n\nThe maximum number of search results returned defaults to 100, which can\nbe overridden by the `_count` parameter up to a maximum limit of 1000. If\nthere are additional results, the returned `Bundle` will contain\npagination links.", "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "location": "path", "description": "Name of the FHIR store to retrieve resources from.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$" } } }, "patch": { "response": { "$ref": "HttpBody" }, "parameterOrder": ["name"], "httpMethod": "PATCH", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "location": "path", "description": "The name of the resource to update.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/[^/]+/[^/]+$" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}/{fhirId1}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.fhirStores.fhir.patch", "request": { "$ref": "HttpBody" }, "description": "Updates part of an existing resource by applying the operations specified\nin a [JSON Patch](http://jsonpatch.com/) document.\n\nImplements the FHIR standard [patch\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#patch).\n\nThe request body must contain a JSON Patch document, and the request\nheaders must contain `Content-Type: application/json-patch+json`.\n\nOn success, the response body will contain a JSON-encoded representation\nof the updated resource, including the server-assigned version ID.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead." }, "executeBundle": { "id": "healthcare.projects.locations.datasets.fhirStores.fhir.executeBundle", "path": "v1alpha2/{+parent}/fhir", "request": { "$ref": "HttpBody" }, "description": "Executes all the requests in the given Bundle.\n\nImplements the FHIR standard [batch/transaction\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#transaction).\n\nSupports all interactions within a bundle, except search. This method\naccepts Bundles of type `batch` and `transaction`, processing them\naccording to the [batch processing\nrules](http://hl7.org/implement/standards/fhir/STU3/http.html#2.21.0.17.1)\nand [transaction processing\nrules](http://hl7.org/implement/standards/fhir/STU3/http.html#2.21.0.17.2).\n\nThe request body must contain a JSON-encoded FHIR `Bundle` resource, and\nthe request headers must contain `Content-Type: application/fhir+json`.\n\nFor a batch bundle or a successful transaction the response body will\ncontain a JSON-encoded representation of a `Bundle` resource of type\n`batch-response` or `transaction-response` containing one entry for each\nentry in the request, with the outcome of processing the entry. In the\ncase of an error for a transaction bundle, the response body will contain\na JSON-encoded `OperationOutcome` resource describing the reason for the\nerror. If the request cannot be mapped to a valid API method on a FHIR\nstore, a generic GCP error might be returned instead.", "httpMethod": "POST", "parameterOrder": ["parent"], "response": { "$ref": "HttpBody" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$", "location": "path", "description": "Name of the FHIR store in which this bundle will be executed.", "required": true, "type": "string" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir" }, "capabilities": { "response": { "$ref": "HttpBody" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "location": "path", "description": "Name of the FHIR store to retrieve the capabilities for.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/metadata", "path": "v1alpha2/{+name}/fhir/metadata", "id": "healthcare.projects.locations.datasets.fhirStores.fhir.capabilities", "description": "Gets the FHIR [capability\nstatement](http://hl7.org/implement/standards/fhir/STU3/capabilitystatement.html)\nfor the store, which contains a description of functionality supported by\nthe server.\n\nImplements the FHIR standard [capabilities\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#capabilities).\n\nOn success, the response body will contain a JSON-encoded representation\nof a `CapabilityStatement` resource." }, "conditionalPatch": { "request": { "$ref": "HttpBody" }, "description": "If a resource is found based on the search criteria specified in the query\nparameters, updates part of that resource by applying the operations\nspecified in a [JSON Patch](http://jsonpatch.com/) document.\n\nImplements the FHIR standard [conditional patch\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#patch).\n\nSearch terms are provided as query parameters following the same pattern as\nthe search method.\n\nIf the search criteria identify more than one match, the request will\nreturn a `412 Precondition Failed` error.\n\nThe request body must contain a JSON Patch document, and the request\nheaders must contain `Content-Type: application/json-patch+json`.\n\nOn success, the response body will contain a JSON-encoded representation\nof the updated resource, including the server-assigned version ID.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.", "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "type"], "httpMethod": "PATCH", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "type": { "required": true, "type": "string", "pattern": "^[^/]+$", "location": "path", "description": "The FHIR resource type to update, such as Patient or Observation. For a\ncomplete list, see the [FHIR Resource\nIndex](http://hl7.org/implement/standards/fhir/STU3/resourcelist.html)." }, "parent": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$", "location": "path", "description": "The name of the FHIR store this resource belongs to.", "required": true, "type": "string" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}", "path": "v1alpha2/{+parent}/fhir/{+type}", "id": "healthcare.projects.locations.datasets.fhirStores.fhir.conditionalPatch" }, "history": { "response": { "$ref": "HttpBody" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "at": { "location": "query", "description": "Only include resource versions that were current at some point during the\ntime period specified in the date time value. The date parameter format is\nyyyy-mm-ddThh:mm:ss[Z|(+|-)hh:mm]\n\nClients may specify any of the following:\n\n*  An entire year: `_at=2019`\n*  An entire month: `_at=2019-01`\n*  A specific day: `_at=2019-01-20`\n*  A specific second: `_at=2018-12-31T23:59:58Z`", "type": "string" }, "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/[^/]+/[^/]+$", "location": "path", "description": "The name of the resource to retrieve.", "required": true, "type": "string" }, "count": { "description": "The maximum number of search results on a page. Defaults to 1000.", "format": "int32", "type": "integer", "location": "query" }, "since": { "location": "query", "description": "Only include resource versions that were created at or after the given\ninstant in time. The instant in time uses the format\nYYYY-MM-DDThh:mm:ss.sss+zz:zz (for example 2015-02-07T13:28:17.239+02:00 or\n2017-01-01T00:00:00Z). The time must be specified to the second and\ninclude a time zone.", "type": "string" }, "page": { "location": "query", "description": "Used to retrieve the first, previous, next, or last page of resource\nversions when using pagination. Value should be set to the value of the\n`link.url` field returned in the response to the previous request, where\n`link.relation` is \"first\", \"previous\", \"next\" or \"last\".\n\nOmit `page` if no previous request has been made.", "type": "string" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}/{fhirId1}/_history", "path": "v1alpha2/{+name}/_history", "id": "healthcare.projects.locations.datasets.fhirStores.fhir.history", "description": "Lists all the versions of a resource (including the current version and\ndeleted versions) from the FHIR store.\n\nImplements the per-resource form of the FHIR standard [history\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#history).\n\nOn success, the response body will contain a JSON-encoded representation\nof a `Bundle` resource of type `history`, containing the version history\nsorted from most recent to oldest versions.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead." }, "delete": { "description": "Deletes a FHIR resource.\n\nImplements the FHIR standard [delete\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#delete).\n\nNote: Unless resource versioning is disabled by setting the\ndisable_resource_versioning flag\non the FHIR store, the deleted resources will be moved to a history\nrepository that can still be retrieved through vread\nand related methods, unless they are removed by the\npurge method.", "response": { "$ref": "HttpBody" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "parameters": { "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/[^/]+/[^/]+$", "location": "path", "description": "The name of the resource to delete.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}/{fhirId1}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.fhirStores.fhir.delete" }, "vread": { "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}/{fhirId1}/_history/{_historyId}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.fhirStores.fhir.vread", "description": "Gets the contents of a version (current or historical) of a FHIR resource\nby version ID.\n\nImplements the FHIR standard [vread\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#vread).\n\nOn success, the response body will contain a JSON-encoded representation\nof the resource.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.", "response": { "$ref": "HttpBody" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/[^/]+/[^/]+/_history/[^/]+$", "location": "path", "description": "The name of the resource version to retrieve." } } }, "update": { "request": { "$ref": "HttpBody" }, "description": "Updates the entire contents of a resource.\n\nImplements the FHIR standard [update\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#update).\n\nIf the specified resource does\nnot exist and the FHIR store has\nenable_update_create set, creates the\nresource with the client-specified ID.\n\nThe request body must contain a JSON-encoded FHIR resource, and the request\nheaders must contain `Content-Type: application/fhir+json`. The resource\nmust contain an `id` element having an identical value to the ID in the\nREST path of the request.\n\nOn success, the response body will contain a JSON-encoded representation\nof the updated resource, including the server-assigned version ID.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.", "response": { "$ref": "HttpBody" }, "parameterOrder": ["name"], "httpMethod": "PUT", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "location": "path", "description": "The name of the resource to update.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/[^/]+/[^/]+$" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}/{fhirId1}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.fhirStores.fhir.update" }, "Resource-purge": { "description": "Deletes all the historical versions of a resource (excluding the current\nversion) from the FHIR store. To remove all versions of a resource, first\ndelete the current version and then call this method.\n\nThis is not a FHIR standard operation.", "response": { "$ref": "Empty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "parameters": { "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/[^/]+/[^/]+$", "location": "path", "description": "The name of the resource to purge.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}/{fhirId1}/$purge", "path": "v1alpha2/{+name}/$purge", "id": "healthcare.projects.locations.datasets.fhirStores.fhir.Resource-purge" }, "conditionalUpdate": { "request": { "$ref": "HttpBody" }, "description": "If a resource is found based on the search criteria specified in the query\nparameters, updates the entire contents of that resource.\n\nImplements the FHIR standard [conditional update\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#cond-update).\n\nSearch terms are provided as query parameters following the same pattern as\nthe search method.\n\nIf the search criteria identify more than one match, the request will\nreturn a `412 Precondition Failed` error.\nIf the search criteria identify zero matches, and the supplied resource\nbody contains an `id`, and the FHIR store has\nenable_update_create set, creates the\nresource with the client-specified ID. If the search criteria identify zero\nmatches, and the supplied resource body does not contain an `id`, the\nresource will be created with a server-assigned ID as per the\ncreate method.\n\nThe request body must contain a JSON-encoded FHIR resource, and the request\nheaders must contain `Content-Type: application/fhir+json`.\n\nOn success, the response body will contain a JSON-encoded representation\nof the updated resource, including the server-assigned version ID.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.", "response": { "$ref": "HttpBody" }, "parameterOrder": ["parent", "type"], "httpMethod": "PUT", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "type": { "description": "The FHIR resource type to update, such as Patient or Observation. For a\ncomplete list, see the [FHIR Resource\nIndex](http://hl7.org/implement/standards/fhir/STU3/resourcelist.html).\nMust match the resource type in the provided content.", "required": true, "type": "string", "pattern": "^[^/]+$", "location": "path" }, "parent": { "description": "The name of the FHIR store this resource belongs to.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$", "location": "path" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}", "path": "v1alpha2/{+parent}/fhir/{+type}", "id": "healthcare.projects.locations.datasets.fhirStores.fhir.conditionalUpdate" } } } } }, "operations": { "methods": { "list": { "description": "Lists operations that match the specified filter in the request. If the\nserver doesn't support this method, it returns `UNIMPLEMENTED`.\n\nNOTE: the `name` binding allows API services to override the binding\nto use different resource name schemes, such as `users/*/operations`. To\noverride the binding, API services can add a binding such as\n`\"/v1/{name=users/*}/operations\"` to their service configuration.\nFor backwards compatibility, the default name includes the operations\ncollection id, however overriding users must ensure the name binding\nis the parent resource, without the operations collection id.", "response": { "$ref": "ListOperationsResponse" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "location": "path", "description": "The name of the operation's parent resource.", "required": true, "type": "string", "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+$" }, "pageToken": { "location": "query", "description": "The standard list page token.", "type": "string" }, "pageSize": { "type": "integer", "location": "query", "description": "The standard list page size.", "format": "int32" }, "filter": { "description": "The standard list filter.", "type": "string", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/operations", "path": "v1alpha2/{+name}/operations", "id": "healthcare.projects.locations.datasets.operations.list" }, "get": { "description": "Gets the latest state of a long-running operation.  Clients can use this\nmethod to poll the operation result at intervals as recommended by the API\nservice.", "response": { "$ref": "Operation" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "pattern": "^projects/[^/]+/locations/[^/]+/datasets/[^/]+/operations/[^/]+$", "location": "path", "description": "The name of the operation resource.", "required": true, "type": "string" } }, "flatPath": "v1alpha2/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/operations/{operationsId}", "path": "v1alpha2/{+name}", "id": "healthcare.projects.locations.datasets.operations.get" } } } } } } } } } }, "parameters": { "access_token": { "description": "OAuth access token.", "type": "string", "location": "query" }, "key": { "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string" }, "upload_protocol": { "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string", "location": "query" }, "quotaUser": { "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string", "location": "query" }, "prettyPrint": { "type": "boolean", "default": "true", "location": "query", "description": "Returns response with indentations and line breaks." }, "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" }, "uploadType": { "location": "query", "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string" }, "callback": { "location": "query", "description": "JSONP", "type": "string" }, "oauth_token": { "location": "query", "description": "OAuth 2.0 token for the current user.", "type": "string" }, "$.xgafv": { "location": "query", "enum": ["1", "2"], "description": "V1 error format.", "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"] }, "alt": { "default": "json", "enum": ["json", "media", "proto"], "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response." } }, "version": "v1alpha2", "baseUrl": "https://healthcare.googleapis.com/", "description": "Manage, store, and access healthcare data in Google Cloud Platform.", "kind": "discovery#restDescription", "servicePath": "", "basePath": "", "id": "healthcare:v1alpha2", "documentationLink": "https://cloud.google.com/healthcare", "revision": "20190626", "discoveryVersion": "v1", "version_module": true, "schemas": { "FhirConfig": { "description": "Specifies how de-identification of a FHIR store should be handled.", "type": "object", "properties": { "fieldMetadataList": { "type": "array", "items": { "$ref": "FieldMetadata" }, "description": "Specifies FHIR paths to match and how to transform them. Any field that\nis not matched by a FieldMetadata will be passed through to the output\ndataset unmodified. All extensions are removed in the output." } }, "id": "FhirConfig" }, "AuditConfig": { "description": "Specifies the audit configuration for a service.\nThe configuration determines which permission types are logged, and what\nidentities, if any, are exempted from logging.\nAn AuditConfig must have one or more AuditLogConfigs.\n\nIf there are AuditConfigs for both `allServices` and a specific service,\nthe union of the two AuditConfigs is used for that service: the log_types\nspecified in each AuditConfig are enabled, and the exempted_members in each\nAuditLogConfig are exempted.\n\nExample Policy with multiple AuditConfigs:\n\n    {\n      \"audit_configs\": [\n        {\n          \"service\": \"allServices\"\n          \"audit_log_configs\": [\n            {\n              \"log_type\": \"DATA_READ\",\n              \"exempted_members\": [\n                \"user:foo@gmail.com\"\n              ]\n            },\n            {\n              \"log_type\": \"DATA_WRITE\",\n            },\n            {\n              \"log_type\": \"ADMIN_READ\",\n            }\n          ]\n        },\n        {\n          \"service\": \"fooservice.googleapis.com\"\n          \"audit_log_configs\": [\n            {\n              \"log_type\": \"DATA_READ\",\n            },\n            {\n              \"log_type\": \"DATA_WRITE\",\n              \"exempted_members\": [\n                \"user:bar@gmail.com\"\n              ]\n            }\n          ]\n        }\n      ]\n    }\n\nFor fooservice, this policy enables DATA_READ, DATA_WRITE and ADMIN_READ\nlogging. It also exempts foo@gmail.com from DATA_READ logging, and\nbar@gmail.com from DATA_WRITE logging.", "type": "object", "properties": { "service": { "description": "Specifies a service that will be enabled for audit logging.\nFor example, `storage.googleapis.com`, `cloudsql.googleapis.com`.\n`allServices` is a special value that covers all services.", "type": "string" }, "auditLogConfigs": { "description": "The configuration for logging of each type of permission.", "type": "array", "items": { "$ref": "AuditLogConfig" } } }, "id": "AuditConfig" }, "DeidentifyDatasetRequest": { "description": "Redacts identifying information from the specified dataset.", "type": "object", "properties": { "destinationDataset": { "description": "The name of the dataset resource to create and write the redacted data to\n(e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}`).\n\n * The destination dataset must not exist.\n * The destination dataset must be in the same project as the source\n   dataset. De-identifying data across multiple projects is not supported.", "type": "string" }, "config": { "$ref": "DeidentifyConfig", "description": "Deidentify configuration." } }, "id": "DeidentifyDatasetRequest" }, "ListFhirStoresResponse": { "description": "Lists the FHIR stores in the given dataset.", "type": "object", "properties": { "fhirStores": { "description": "The returned FHIR stores. Won't be more FHIR stores than the value of\npage_size in the request.", "type": "array", "items": { "$ref": "FhirStore" } }, "nextPageToken": { "type": "string", "description": "Token to retrieve the next page of results or empty if there are no more\nresults in the list." } }, "id": "ListFhirStoresResponse" }, "SearchResourcesRequest": { "description": "Request to search the resources in the specified FHIR store.", "type": "object", "properties": { "resourceType": { "description": "The FHIR resource type to search, such as Patient or Observation. For a\ncomplete list, see the [FHIR Resource\nIndex](http://hl7.org/implement/standards/fhir/STU3/resourcelist.html).", "type": "string" } }, "id": "SearchResourcesRequest" }, "Expr": { "type": "object", "properties": { "title": { "description": "An optional title for the expression, i.e. a short string describing\nits purpose. This can be used e.g. in UIs which allow to enter the\nexpression.", "type": "string" }, "location": { "description": "An optional string indicating the location of the expression for error\nreporting, e.g. a file name and a position in the file.", "type": "string" }, "description": { "type": "string", "description": "An optional description of the expression. This is a longer text which\ndescribes the expression, e.g. when hovered over it in a UI." }, "expression": { "description": "Textual representation of an expression in\nCommon Expression Language syntax.\n\nThe application context of the containing message determines which\nwell-known feature set of CEL is supported.", "type": "string" } }, "id": "Expr", "description": "Represents an expression text. Example:\n\n    title: \"User account presence\"\n    description: \"Determines whether the request has a user account\"\n    expression: \"size(request.user) > 0\"" }, "ParserConfig": { "description": "The configuration for the parser. It determines how the server parses the\nmessages.", "type": "object", "properties": { "allowNullHeader": { "description": "Determines whether messages with no header are allowed.", "type": "boolean" }, "segmentTerminator": { "description": "Byte(s) to be used as the segment terminator. If this is unset, '\\r' will\nbe used as the segment terminator, matching the HL7 version 2\nspecification.", "format": "byte", "type": "string" } }, "id": "ParserConfig" }, "PatientId": { "description": "A patient identifier and associated type.", "type": "object", "properties": { "value": { "description": "The patient's unique identifier.", "type": "string" }, "type": { "description": "ID type, e.g. MRN or NHS.", "type": "string" } }, "id": "PatientId" }, "GoogleCloudHealthcareV1alpha2FhirBigQueryDestination": { "description": "The configuration for exporting to BigQuery.", "type": "object", "properties": { "datasetUri": { "description": "BigQuery URI to a dataset, up to 2000 characters long, in the format\n`bq://projectId.bqDatasetId`", "type": "string" }, "schemaConfig": { "$ref": "SchemaConfig", "description": "The configuration for the exported BigQuery schema." } }, "id": "GoogleCloudHealthcareV1alpha2FhirBigQueryDestination" }, "GetPolicyOptions": { "description": "Encapsulates settings provided to GetIamPolicy.", "type": "object", "properties": { "requestedPolicyVersion": { "description": "Optional. The policy format version to be returned.\nAcceptable values are 0 and 1.\nIf the value is 0, or the field is omitted, policy format version 1 will be\nreturned.", "format": "int32", "type": "integer" } }, "id": "GetPolicyOptions" }, "GoogleCloudHealthcareV1alpha2FhirRestImportResourcesResponse": { "description": "Final response of importing resources.\nThis structure will be included in the\nresponse to describe the detailed\noutcome. It will only be included when the operation finishes successfully.", "type": "object", "properties": { "fhirStore": { "description": "The name of the FHIR store where the resources have been imported, in the\nformat\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}`.", "type": "string" }, "inputSize": { "description": "The total number of resources included in the source data.", "format": "int64", "type": "string" } }, "id": "GoogleCloudHealthcareV1alpha2FhirRestImportResourcesResponse" }, "IngestMessageRequest": { "id": "IngestMessageRequest", "description": "Ingests a message into the specified HL7v2 store.", "type": "object", "properties": { "message": { "$ref": "Message", "description": "HL7v2 message to ingest." } } }, "Detail": { "description": "Contains multiple sensitive information findings for each resource slice.", "type": "object", "properties": { "findings": { "type": "array", "items": { "$ref": "Finding" } } }, "id": "Detail" }, "GetIamPolicyRequest": { "description": "Request message for `GetIamPolicy` method.", "type": "object", "properties": { "options": { "$ref": "GetPolicyOptions", "description": "OPTIONAL: A GetPolicyOptions object for specifying options to GetIamPolicy\nThis field is only used by Cloud IAM." } }, "id": "GetIamPolicyRequest" }, "TestIamPermissionsResponse": { "id": "TestIamPermissionsResponse", "description": "Response message for `TestIamPermissions` method.", "type": "object", "properties": { "permissions": { "description": "A subset of `TestPermissionsRequest.permissions` that the caller is\nallowed.", "type": "array", "items": { "type": "string" } } } }, "ListAnnotationStoresResponse": { "description": "Lists the Annotation stores\nin the given dataset.", "type": "object", "properties": { "nextPageToken": { "description": "Token to retrieve the next page of results or empty if there are no more\nresults in the list.", "type": "string" }, "annotationStores": { "description": "The returned Annotation stores. Won't be more Annotation stores than the\nvalue of page_size in the request.", "type": "array", "items": { "$ref": "AnnotationStore" } } }, "id": "ListAnnotationStoresResponse" }, "GoogleCloudHealthcareV1alpha2FhirRestGcsDestination": { "description": "The configuration for exporting to Cloud Storage.", "type": "object", "properties": { "uriPrefix": { "description": "URI for a Cloud Storage directory where result files should be written (in\nthe format `gs://{bucket-id}/{path/to/destination/dir}`). If there is no\ntrailing slash, the service will append one when composing the object path.\nThe user is responsible for creating the Cloud Storage bucket referenced in\n`uri_prefix`.", "type": "string" } }, "id": "GoogleCloudHealthcareV1alpha2FhirRestGcsDestination" }, "ImportDicomDataErrorDetails": { "description": "Returns the errors encountered during DICOM store import.", "type": "object", "properties": { "sampleErrors": { "description": "Deprecated. Use only for debugging purposes.\n\nContains sample errors encountered in imports of individual resources\n(for example, a Cloud Storage object).", "type": "array", "items": { "$ref": "ErrorDetail" } } }, "id": "ImportDicomDataErrorDetails" }, "DeidentifySummary": { "properties": { "successStoreCount": { "description": "Number of stores successfully processed.", "format": "int64", "type": "string" }, "successResourceCount": { "description": "Number of resources successfully processed.", "format": "int64", "type": "string" } }, "id": "DeidentifySummary", "description": "Contains a detailed summary of the Deidentify operation.", "type": "object" }, "FhirStore": { "description": "Represents a FHIR store.", "type": "object", "properties": { "enableUpdateCreate": { "description": "Whether this FHIR store has the [updateCreate\ncapability](https://www.hl7.org/fhir/capabilitystatement-definitions.html#CapabilityStatement.rest.resource.updateCreate).\nThis determines if the client can use an Update operation to create a new\nresource with a client-specified ID. If false, all IDs are server-assigned\nthrough the Create operation and attempts to Update a non-existent resource\nwill return errors. Please treat the audit logs with appropriate levels of\ncare if client-specified resource IDs contain sensitive data such as\npatient identifiers, those IDs will be part of the FHIR resource path\nrecorded in Cloud audit logs and Cloud Pub/Sub notifications.", "type": "boolean" }, "streamConfigs": { "description": "A list of streaming configs that configure the destinations of streaming\nexport for every resource mutation in this FHIR store. Each store is\nallowed to have up to 10 streaming configs.\nAfter a new config is added, the next resource mutation will be streamed to\nthe new location in addition to the existing ones.\nWhen a location is removed from the list, the server will simply stop\nstreaming to that location. Before adding a new config, you must add the\nrequired\n[`bigquery.dataEditor`](https://cloud.google.com/bigquery/docs/access-control#bigquery.dataEditor)\nrole to your project's **Cloud Healthcare Service Agent**\n[service account](https://cloud.google.com/iam/docs/service-accounts).\nSome lag (typically on the order of dozens of seconds) is expected before\nthe results show up in the streaming destination.", "type": "array", "items": { "$ref": "StreamConfig" } }, "labels": { "additionalProperties": { "type": "string" }, "description": "User-supplied key-value pairs used to organize FHIR stores.\n\nLabel keys must be between 1 and 63 characters long, have a UTF-8 encoding\nof maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression:\n\\p{Ll}\\p{Lo}{0,62}\n\nLabel values are optional, must be between 1 and 63 characters long, have\na UTF-8 encoding of maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression: [\\p{Ll}\\p{Lo}\\p{N}_-]{0,63}\n\nNo more than 64 labels can be associated with a given store.", "type": "object" }, "notificationConfig": { "description": "If non-empty, publish all resource modifications of this FHIR store to\nthis destination. The Cloud Pub/Sub message attributes will contain a map\nwith a string describing the action that has triggered the notification,\ne.g. \"action\":\"CreateResource\".", "$ref": "NotificationConfig" }, "name": { "description": "Output only. Resource name of the FHIR store, of the form\n`projects/{project_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}`.", "type": "string" }, "disableReferentialIntegrity": { "description": "Whether to disable referential integrity in this FHIR store. This field is\nimmutable after FHIR store creation.\nThe default value is false, meaning that the API will enforce referential\nintegrity and fail the requests that will result in inconsistent state in\nthe FHIR store.\nWhen this field is set to true, the API will skip referential integrity\ncheck. Consequently, operations that rely on references, such as\nGetPatientEverything, will not return all the results if broken references\nexist.", "type": "boolean" }, "enableHistoryImport": { "description": "Whether to allow the bulk import API to accept history bundles and directly\ninsert historical resource versions into the FHIR store. Importing resource\nhistories creates resource interactions that appear to have occurred in the\npast, which clients may not want to allow. If set to false, history bundles\nwithin an import will fail with an error.", "type": "boolean" }, "disableResourceVersioning": { "description": "Whether to disable resource versioning for this FHIR store. This field can\nnot be changed after the creation of FHIR store.\nIf set to false, which is the default behavior, all write operations will\ncause historical versions to be recorded automatically. The historical\nversions can be fetched through the history APIs, but cannot be updated.\nIf set to true, no historical versions will be kept. The server will send\nback errors for attempts to read the historical versions.", "type": "boolean" } }, "id": "FhirStore" }, "ImageConfig": { "id": "ImageConfig", "description": "Specifies how de-identification of image pixel should be handled.", "type": "object", "properties": { "textRedactionMode": { "enum": ["TEXT_REDACTION_MODE_UNSPECIFIED", "REDACT_ALL_TEXT", "REDACT_SENSITIVE_TEXT", "REDACT_NO_TEXT"], "description": "Determines how to redact text from image.", "type": "string", "enumDescriptions": ["No text redaction specified. Same as REDACT_NO_TEXT.", "Redact all text.", "Redact sensitive text.", "Do not redact text."] } } }, "Dataset": { "description": "A message representing a health dataset.\n\nA health dataset represents a collection of healthcare data pertaining to one\nor more patients. This may include multiple modalities of healthcare data,\nsuch as electronic medical records or medical imaging data.", "type": "object", "properties": { "timeZone": { "description": "The default timezone used by this dataset. Must be a either a valid IANA\ntime zone name such as \"America/New_York\" or empty, which defaults to UTC.\nThis is used for parsing times in resources (e.g., HL7 messages) where no\nexplicit timezone is specified.", "type": "string" }, "name": { "description": "Output only. Resource name of the dataset, of the form\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}`.", "type": "string" } }, "id": "Dataset" }, "ProgressCounter": { "id": "ProgressCounter", "description": "ProgressCounter provides counters to describe an operation's progress.", "type": "object", "properties": { "success": { "description": "The number of units that succeeded in the operation.", "format": "int64", "type": "string" }, "pending": { "description": "The number of units that are pending in the operation.", "format": "int64", "type": "string" }, "failure": { "description": "The number of units that failed in the operation.", "format": "int64", "type": "string" } } }, "TagFilterList": { "description": "List of tags to be filtered.", "type": "object", "properties": { "tags": { "description": "Tags to be filtered. Tags must be DICOM Data Elements, File Meta\nElements, or Directory Structuring Elements, as defined at:\nhttp://dicom.nema.org/medical/dicom/current/output/html/part06.html#table_6-1,.\nThey may be provided by \"Keyword\" or \"Tag\". For example \"PatientID\",\n\"00100010\".", "type": "array", "items": { "type": "string" } } }, "id": "TagFilterList" }, "ListAnnotationsResponse": { "description": "Lists the Annotations in the specified\nAnnotation store.", "type": "object", "properties": { "nextPageToken": { "description": "Token to retrieve the next page of results or empty if there are no more\nresults in the list.", "type": "string" }, "annotations": { "description": "The returned Annotations names. Won't be more values than the value of\npage_size in the request.", "type": "array", "items": { "type": "string" } } }, "id": "ListAnnotationsResponse" }, "ParsedData": { "description": "The content of a HL7v2 message in a structured format.", "type": "object", "properties": { "segments": { "type": "array", "items": { "$ref": "Segment" } } }, "id": "ParsedData" }, "GoogleCloudHealthcareV1alpha2DicomGcsSource": { "properties": { "uri": { "description": "Points to a Cloud Storage URI containing file(s) with\ncontent only. The URI must be in the following format:\n`gs://{bucket_id}/{object_id}`. The URI can include wildcards in\n`object_id` and thus identify multiple files. Supported wildcards:\n '*' to match 0 or more non-separator characters\n '**' to match 0 or more characters (including separators). Must be used at\n      the end of a path and with no other wildcards in the\n      path. Can also be used with a file extension (such as .dcm), which\n      imports all files with the extension in the specified directory and\n      its sub-directories. For example,\n      `gs://my-bucket/my-directory/**.dcm` imports all files with .dcm\n      extensions in `my-directory/` and its sub-directories.\n '?' to match 1 character\nAll other URI formats are invalid.\nFiles matching the wildcard are expected to contain content only, no\nmetadata.", "type": "string" } }, "id": "GoogleCloudHealthcareV1alpha2DicomGcsSource", "description": "Specifies the configuration for importing data from Cloud Storage.", "type": "object" }, "ReplaceWithInfoTypeConfig": { "properties": {}, "id": "ReplaceWithInfoTypeConfig", "description": "When using the INSPECT_AND_TRANSFORM action, each match is replaced with\nthe name of the info_type. For example, \"My name is Jake\" becomes \"My name is\n[PERSON_NAME].\" The TRANSFORM action is equivalent to redacting.", "type": "object" }, "DicomConfig": { "description": "Specifies the parameters needed for de-identification of DICOM stores.", "type": "object", "properties": { "filterProfile": { "enum": ["TAG_FILTER_PROFILE_UNSPECIFIED", "MINIMAL_KEEP_LIST_PROFILE", "ATTRIBUTE_CONFIDENTIALITY_BASIC_PROFILE", "KEEP_ALL_PROFILE", "DEIDENTIFY_TAG_CONTENTS"], "description": "Tag filtering profile that determines which tags to keep/remove.", "type": "string", "enumDescriptions": ["No tag filtration profile provided. Same as KEEP_ALL_PROFILE.", "Keep only tags required to produce valid DICOM.", "Remove tags based on DICOM Standard's Attribute Confidentiality Basic\nProfile (DICOM Standard Edition 2018e)\nhttp://dicom.nema.org/medical/dicom/2018e/output/chtml/part15/chapter_E.html.", "Keep all tags.", "Inspects within tag contents and replaces sensitive text. The process\ncan be configured using the TextConfig.\nApplies to all tags with the following Value Representation names:\nAE, LO, LT, PN, SH, ST, UC, UT, DA, DT, AS"] }, "keepList": { "description": "List of tags to keep. Remove all other tags.", "$ref": "TagFilterList" }, "removeList": { "$ref": "TagFilterList", "description": "List of tags to remove. Keep all other tags." } }, "id": "DicomConfig" }, "GoogleCloudHealthcareV1alpha2FhirRestGcsSource": { "properties": { "uri": { "description": "Points to a Cloud Storage URI containing file(s) to import.\n\nThe URI must be in the following format: `gs://{bucket_id}/{object_id}`.\nThe URI can include wildcards in `object_id` and thus identify multiple\nfiles. Supported wildcards:\n\n*  `*` to match 0 or more non-separator characters\n*  `**` to match 0 or more characters (including separators). Must be used\nat the end of a path and with no other wildcards in the\npath. Can also be used with a file extension (such as .ndjson), which\nimports all files with the extension in the specified directory and\nits sub-directories. For example, `gs://my-bucket/my-directory/**.ndjson`\nimports all files with `.ndjson` extensions in `my-directory/` and its\nsub-directories.\n*  `?` to match 1 character\n\nFiles matching the wildcard are expected to contain content only, no\nmetadata.", "type": "string" } }, "id": "GoogleCloudHealthcareV1alpha2FhirRestGcsSource", "description": "Specifies the configuration for importing data from Cloud Storage.", "type": "object" }, "GoogleCloudHealthcareV1alpha2FhirRestImportResourcesErrorDetails": { "description": "Error response of importing resources.\nThis structure will be included in the\nerror details to describe the\ndetailed error. It will only be included when the operation finishes with\nsome failure.", "type": "object", "properties": { "fhirStore": { "description": "The name of the FHIR store where resources have been imported, in the\nformat\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}`.", "type": "string" }, "inputSize": { "description": "The total number of resources included in the source data. This is the sum\nof the success and error counts.", "format": "int64", "type": "string" }, "successCount": { "description": "The number of resources that have been imported.", "format": "int64", "type": "string" }, "errorCount": { "description": "The number of resources that had errors.", "format": "int64", "type": "string" } }, "id": "GoogleCloudHealthcareV1alpha2FhirRestImportResourcesErrorDetails" }, "Empty": { "id": "Empty", "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object", "properties": {} }, "ImageAnnotation": { "description": "Image annotation.", "type": "object", "properties": { "boundingPolys": { "description": "The list of polygons outlining the sensitive regions in the image.", "type": "array", "items": { "$ref": "BoundingPoly" } } }, "id": "ImageAnnotation" }, "ErrorDetail": { "description": "Structure to describe the error encountered during batch operation on one\nresource. This is used both for sample errors in operation response, and\nfor format of errors in error reports.", "type": "object", "properties": { "resource": { "description": "The identifier of the resource.", "type": "string" }, "error": { "$ref": "Status", "description": "The status of the error." } }, "id": "ErrorDetail" }, "CloudHealthcareSource": { "description": "Cloud Healthcare API resource.", "type": "object", "properties": { "name": { "description": "Full path of a Cloud Healthcare API resource.", "type": "string" } }, "id": "CloudHealthcareSource" }, "ListMessagesResponse": { "description": "Lists the messages in the specified HL7v2 store.", "type": "object", "properties": { "nextPageToken": { "description": "Token to retrieve the next page of results or empty if there are no more\nresults in the list.", "type": "string" }, "messages": { "description": "The returned message names. Won't be more values than the value of\npage_size in the request.", "type": "array", "items": { "type": "string" } } }, "id": "ListMessagesResponse" }, "FieldMetadata": { "description": "Specifies FHIR paths to match, and how to handle de-identification of\nmatching fields.", "type": "object", "properties": { "paths": { "description": "List of paths to FHIR fields to be redacted. Each path is a\nperiod-separated list where each component is either a field name or\nFHIR type name, for example: Patient, HumanName.\nFor \"choice\" types (those defined in the FHIR spec with the form:\nfield[x]) we use two separate components. e.g. \"deceasedAge.unit\" is\nmatched by \"Deceased.Age.unit\".\nSupported types are: AdministrativeGenderCode, Code, Date, DateTime,\nDecimal, HumanName, Id, LanguageCode, Markdown, MimeTypeCode, Oid,\nString, Uri, Uuid, Xhtml.", "type": "array", "items": { "type": "string" } }, "action": { "type": "string", "enumDescriptions": ["No action specified.", "Transform the entire field.", "Inspect and transform any found PHI. When `AnnotationConfig` is\nprovided, annotations of PHI will be generated, except for Date and Datetime.", "Do not transform."], "enum": ["ACTION_UNSPECIFIED", "TRANSFORM", "INSPECT_AND_TRANSFORM", "DO_NOT_TRANSFORM"], "description": "Deidentify action for one field." } }, "id": "FieldMetadata" }, "AuditLogConfig": { "type": "object", "properties": { "exemptedMembers": { "description": "Specifies the identities that do not cause logging for this type of\npermission.\nFollows the same format of Binding.members.", "type": "array", "items": { "type": "string" } }, "logType": { "enumDescriptions": ["Default case. Should never be this.", "Admin reads. Example: CloudIAM getIamPolicy", "Data writes. Example: CloudSQL Users create", "Data reads. Example: CloudSQL Users list"], "enum": ["LOG_TYPE_UNSPECIFIED", "ADMIN_READ", "DATA_WRITE", "DATA_READ"], "description": "The log type that this config enables.", "type": "string" } }, "id": "AuditLogConfig", "description": "Provides the configuration for logging a type of permissions.\nExample:\n\n    {\n      \"audit_log_configs\": [\n        {\n          \"log_type\": \"DATA_READ\",\n          \"exempted_members\": [\n            \"user:foo@gmail.com\"\n          ]\n        },\n        {\n          \"log_type\": \"DATA_WRITE\",\n        }\n      ]\n    }\n\nThis enables 'DATA_READ' and 'DATA_WRITE' logging, while exempting\nfoo@gmail.com from DATA_READ logging." }, "ImportDicomDataRequest": { "properties": { "gcsSource": { "$ref": "GoogleCloudHealthcareV1alpha2DicomGcsSource", "description": "Cloud Storage source data location and import configuration.\n\nThe Cloud Storage location requires the `roles/storage.objectViewer`\nCloud IAM role." } }, "id": "ImportDicomDataRequest", "description": "Imports data into the specified DICOM store.\nReturns an error if any of the files to import are not DICOM files. This\nAPI will accept duplicate DICOM instances, by simply ignoring the newly\npushed instance (it will not overwrite).", "type": "object" }, "GoogleCloudHealthcareV1alpha2FhirRestGcsErrorDestination": { "description": "Specifies the Cloud Storage destination where errors will be recorded.", "type": "object", "properties": { "uriPrefix": { "description": "URI for a Cloud Storage directory to which error report files should be\nwritten (in the format `gs://{bucket-id}/{path/to/destination/dir}`). If\nthere is no trailing slash, the service will append one when composing the\nobject path. The user is responsible for creating the Cloud Storage bucket\nreferenced in `uri_prefix`.", "type": "string" } }, "id": "GoogleCloudHealthcareV1alpha2FhirRestGcsErrorDestination" }, "ListDicomStoresResponse": { "id": "ListDicomStoresResponse", "description": "Lists the DICOM stores in the given dataset.", "type": "object", "properties": { "dicomStores": { "description": "The returned DICOM stores. Won't be more DICOM stores than the value of\npage_size in the request.", "type": "array", "items": { "$ref": "DicomStore" } }, "nextPageToken": { "description": "Token to retrieve the next page of results or empty if there are no more\nresults in the list.", "type": "string" } } }, "DeidentifyErrorDetails": { "type": "object", "properties": { "successResourceCount": { "description": "Number of resources successfully processed.", "format": "int64", "type": "string" }, "failureStoreCount": { "description": "Number of stores failed to process.", "format": "int64", "type": "string" }, "failureResourceCount": { "description": "Number of resources failed to process.", "format": "int64", "type": "string" }, "successStoreCount": { "description": "Number of stores successfully processed.", "format": "int64", "type": "string" } }, "id": "DeidentifyErrorDetails", "description": "Contains the status of the Deidentify operation." }, "Policy": { "description": "Defines an Identity and Access Management (IAM) policy. It is used to\nspecify access control policies for Cloud Platform resources.\n\n\nA `Policy` consists of a list of `bindings`. A `binding` binds a list of\n`members` to a `role`, where the members can be user accounts, Google groups,\nGoogle domains, and service accounts. A `role` is a named list of permissions\ndefined by IAM.\n\n**JSON Example**\n\n    {\n      \"bindings\": [\n        {\n          \"role\": \"roles/owner\",\n          \"members\": [\n            \"user:mike@example.com\",\n            \"group:admins@example.com\",\n            \"domain:google.com\",\n            \"serviceAccount:my-other-app@appspot.gserviceaccount.com\"\n          ]\n        },\n        {\n          \"role\": \"roles/viewer\",\n          \"members\": [\"user:sean@example.com\"]\n        }\n      ]\n    }\n\n**YAML Example**\n\n    bindings:\n    - members:\n      - user:mike@example.com\n      - group:admins@example.com\n      - domain:google.com\n      - serviceAccount:my-other-app@appspot.gserviceaccount.com\n      role: roles/owner\n    - members:\n      - user:sean@example.com\n      role: roles/viewer\n\n\nFor a description of IAM and its features, see the\n[IAM developer's guide](https://cloud.google.com/iam/docs).", "type": "object", "properties": { "etag": { "description": "`etag` is used for optimistic concurrency control as a way to help\nprevent simultaneous updates of a policy from overwriting each other.\nIt is strongly suggested that systems make use of the `etag` in the\nread-modify-write cycle to perform policy updates in order to avoid race\nconditions: An `etag` is returned in the response to `getIamPolicy`, and\nsystems are expected to put that etag in the request to `setIamPolicy` to\nensure that their change will be applied to the same version of the policy.\n\nIf no `etag` is provided in the call to `setIamPolicy`, then the existing\npolicy is overwritten blindly.", "format": "byte", "type": "string" }, "version": { "description": "Deprecated.", "format": "int32", "type": "integer" }, "auditConfigs": { "description": "Specifies cloud audit logging configuration for this policy.", "type": "array", "items": { "$ref": "AuditConfig" } }, "bindings": { "description": "Associates a list of `members` to a `role`.\n`bindings` with no members will result in an error.", "type": "array", "items": { "$ref": "Binding" } } }, "id": "Policy" }, "ListLocationsResponse": { "description": "The response message for Locations.ListLocations.", "type": "object", "properties": { "locations": { "description": "A list of locations that matches the specified filter in the request.", "type": "array", "items": { "$ref": "Location" } }, "nextPageToken": { "description": "The standard List next-page token.", "type": "string" } }, "id": "ListLocationsResponse" }, "DateShiftConfig": { "properties": { "cryptoKey": { "description": "An AES 128/192/256 bit key. Causes the shift to be computed based on this\nkey and the patient ID. A default key is generated for each\nDeidentifyDataset operation and is used wherever crypto_key is not\nspecified.", "format": "byte", "type": "string" } }, "id": "DateShiftConfig", "description": "Shift a date forward or backward in time by a random amount which is\nconsistent for a given patient and crypto key combination.", "type": "object" }, "IngestMessageResponse": { "type": "object", "properties": { "message": { "$ref": "Message", "description": "Created message resource." }, "hl7Ack": { "type": "string", "description": "HL7v2 ACK message.", "format": "byte" } }, "id": "IngestMessageResponse", "description": "Acknowledges that a message has been ingested into the specified\nHL7v2 store." }, "RedactConfig": { "id": "RedactConfig", "description": "Define how to redact sensitive values. Default behaviour is erase,\ne.g. \"My name is Jake.\" becomes \"My name is .\"", "type": "object", "properties": {} }, "Annotation": { "description": "An annotation record.", "type": "object", "properties": { "imageAnnotation": { "$ref": "ImageAnnotation", "description": "Annnotations for images, e.g., bounding polygons." }, "name": { "description": "Output only. Resource name of the Annotation, of the form\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/annotationStores/{annotation_store_id}/annotations/{annotation_id}`.", "type": "string" }, "textAnnotation": { "$ref": "SensitiveTextAnnotation", "description": "Annotations for sentitive texts, e.g., range of such texts." }, "annotationSource": { "$ref": "AnnotationSource", "description": "Details of the source." }, "resourceAnnotation": { "description": "Annotations for resource, e.g., classification tags.", "$ref": "ResourceAnnotation" } }, "id": "Annotation" }, "ImportResourcesRequest": { "type": "object", "properties": { "gcsSource": { "$ref": "GoogleCloudHealthcareV1alpha2FhirRestGcsSource", "description": "Cloud Storage source data location and import configuration.\n\nThe Cloud Storage location requires the `roles/storage.objectViewer`\nCloud IAM role.\n\nEach Cloud Storage object should be a text file that contains the format\nspecified in ContentStructu." }, "contentStructure": { "description": "The content structure in the source location. If not specified, the server\ntreats the input source files as BUNDLE.", "type": "string", "enumDescriptions": ["", "The source file contains one or more lines of newline-delimited JSON\n(ndjson). Each line is a bundle, which contains one or more resources.\nSet the bundle type to `history` to import resource versions.", "The source file contains one or more lines of newline-delimited JSON\n(ndjson). Each line is a single resource.", "The entire file is one JSON bundle. The JSON can span multiple lines.", "The entire file is one JSON resource. The JSON can span multiple lines."], "enum": ["CONTENT_STRUCTURE_UNSPECIFIED", "BUNDLE", "RESOURCE", "BUNDLE_PRETTY", "RESOURCE_PRETTY"] }, "gcsErrorDestination": { "description": "The Cloud Storage destination to write the error report to.\n\nThe Cloud Storage location requires the `roles/storage.objectAdmin` Cloud\nIAM role.\n\nNote that writing a file to the same destination multiple times will\nresult in the previous version of the file being overwritten.", "$ref": "GoogleCloudHealthcareV1alpha2FhirRestGcsErrorDestination" } }, "id": "ImportResourcesRequest", "description": "Request to import resources." }, "Operation": { "id": "Operation", "description": "This resource represents a long-running operation that is the result of a\nnetwork API call.", "type": "object", "properties": { "name": { "description": "The server-assigned name, which is only unique within the same service that\noriginally returns it. If you use the default HTTP mapping, the\n`name` should be a resource name ending with `operations/{unique_id}`.", "type": "string" }, "error": { "description": "The error result of the operation in case of failure or cancellation.", "$ref": "Status" }, "metadata": { "description": "Service-specific metadata associated with the operation.  It typically\ncontains progress information and common metadata such as create time.\nSome services might not provide such metadata.  Any method that returns a\nlong-running operation should document the metadata type, if any.", "type": "object", "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" } }, "done": { "description": "If the value is `false`, it means the operation is still in progress.\nIf `true`, the operation is completed, and either `error` or `response` is\navailable.", "type": "boolean" }, "response": { "description": "The normal response of the operation in case of success.  If the original\nmethod returns no data on success, such as `Delete`, the response is\n`google.protobuf.Empty`.  If the original method is standard\n`Get`/`Create`/`Update`, the response should be the resource.  For other\nmethods, the response should have the type `XxxResponse`, where `Xxx`\nis the original method name.  For example, if the original method name\nis `TakeSnapshot()`, the inferred response type is\n`TakeSnapshotResponse`.", "type": "object", "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" } } } }, "ExportResourcesRequest": { "description": "Request to export resources.", "type": "object", "properties": { "gcsDestination": { "description": "The Cloud Storage output destination.\n\nThe Cloud Storage location requires the `roles/storage.objectAdmin` Cloud\nIAM role.\n\nThe exported outputs are\norganized by FHIR resource types. The server will create one object per\nresource type. Each object contains newline delimited JSON, and each line\nis a FHIR resource.", "$ref": "GoogleCloudHealthcareV1alpha2FhirRestGcsDestination" }, "bigqueryDestination": { "description": "The BigQuery output destination.\n\nThe BigQuery location requires two IAM roles:\n`roles/bigquery.dataEditor` and `roles/bigquery.jobUser`.\n\nThe output will be one BigQuery table per resource type.", "$ref": "GoogleCloudHealthcareV1alpha2FhirBigQueryDestination" } }, "id": "ExportResourcesRequest" }, "SensitiveTextAnnotation": { "properties": { "details": { "additionalProperties": { "$ref": "Detail" }, "description": "Maps from a resource slice (e.g. FHIR resource field path) to a set of\nsensitive text findings. For example,\nAppointment.Narrative text1 --> {findings_1, findings_2, findings_3}", "type": "object" } }, "id": "SensitiveTextAnnotation", "description": "A TextAnnotation specifies a text range that includes sensitive information.", "type": "object" }, "ResourceAnnotation": { "type": "object", "properties": { "label": { "type": "string" } }, "id": "ResourceAnnotation", "description": "Resource level annotation." }, "GoogleCloudHealthcareV1alpha2DicomGcsDestination": { "description": "The Cloud Storage location where the output should be written, and the export\nconfiguration.", "type": "object", "properties": { "mimeType": { "description": "MIME types supported by DICOM spec.\nEach file will be written in the following format:\n`.../{study_id}/{series_id}/{instance_id}[/{frame_number}].{extension}`\nThe frame_number component will exist only for multi-frame instances.\n\nRefer to the DICOM conformance statement for permissible MIME types:\nhttps://cloud.google.com/healthcare/docs/dicom#wado-rs\n\nThe following extensions will be used for output files:\n  application/dicom -> .dcm\n  image/jpeg -> .jpg\n  image/png -> .png\n\nIf unspecified, the instances will be exported in their original\nDICOM format.", "type": "string" }, "uriPrefix": { "description": "The Cloud Storage destination to export to.\n\nURI for a Cloud Storage directory where result files should be written (in\nthe format `gs://{bucket-id}/{path/to/destination/dir}`). If there is no\ntrailing slash, the service will append one when composing the object path.\nThe user is responsible for creating the Cloud Storage bucket referenced in\n`uri_prefix`.", "type": "string" } }, "id": "GoogleCloudHealthcareV1alpha2DicomGcsDestination" }, "Status": { "description": "The `Status` type defines a logical error model that is suitable for\ndifferent programming environments, including REST APIs and RPC APIs. It is\nused by [gRPC](https://github.com/grpc). Each `Status` message contains\nthree pieces of data: error code, error message, and error details.\n\nYou can find out more about this error model and how to work with it in the\n[API Design Guide](https://cloud.google.com/apis/design/errors).", "type": "object", "properties": { "message": { "description": "A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.", "type": "string" }, "details": { "description": "A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.", "type": "array", "items": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "type": "object" } }, "code": { "description": "The status code, which should be an enum value of google.rpc.Code.", "format": "int32", "type": "integer" } }, "id": "Status" }, "Binding": { "description": "Associates `members` with a `role`.", "type": "object", "properties": { "members": { "description": "Specifies the identities requesting access for a Cloud Platform resource.\n`members` can have the following values:\n\n* `allUsers`: A special identifier that represents anyone who is\n   on the internet; with or without a Google account.\n\n* `allAuthenticatedUsers`: A special identifier that represents anyone\n   who is authenticated with a Google account or a service account.\n\n* `user:{emailid}`: An email address that represents a specific Google\n   account. For example, `alice@gmail.com` .\n\n\n* `serviceAccount:{emailid}`: An email address that represents a service\n   account. For example, `my-other-app@appspot.gserviceaccount.com`.\n\n* `group:{emailid}`: An email address that represents a Google group.\n   For example, `admins@example.com`.\n\n\n* `domain:{domain}`: The G Suite domain (primary) that represents all the\n   users of that domain. For example, `google.com` or `example.com`.\n\n", "type": "array", "items": { "type": "string" } }, "role": { "description": "Role that is assigned to `members`.\nFor example, `roles/viewer`, `roles/editor`, or `roles/owner`.", "type": "string" }, "condition": { "description": "The condition that is associated with this binding.\nNOTE: An unsatisfied condition will not allow user access via current\nbinding. Different bindings, including their conditions, are examined\nindependently.", "$ref": "Expr" } }, "id": "Binding" }, "ExportDicomDataRequest": { "description": "Exports data from the specified DICOM store.\nIf a given resource (e.g., a DICOM object with the same SOPInstance UID)\nalready exists in the output, it is overwritten with the version\nin the source dataset.\nExported DICOM data will persist when the DICOM store from which it was\nexported is deleted.", "type": "object", "properties": { "bigqueryDestination": { "$ref": "GoogleCloudHealthcareV1alpha2DicomBigQueryDestination", "description": "The BigQuery output destination.\n\nYou can only export to a BigQuery dataset that's in the same project as\nthe DICOM store you're exporting from.\n\nThe BigQuery location requires two IAM roles:\n`roles/bigquery.dataEditor` and `roles/bigquery.jobUser`." }, "gcsDestination": { "$ref": "GoogleCloudHealthcareV1alpha2DicomGcsDestination", "description": "The Cloud Storage output destination.\n\nThe Cloud Storage location requires the `roles/storage.objectAdmin` Cloud\nIAM role." } }, "id": "ExportDicomDataRequest" }, "DeidentifyConfig": { "description": "Configures de-id options specific to different types of content.\nEach submessage customizes the handling of an\nhttps://tools.ietf.org/html/rfc6838 media type or subtype. Configs are\napplied in a nested manner at runtime.", "type": "object", "properties": { "image": { "$ref": "ImageConfig", "description": "Configures de-identification of image pixels wherever they are found in the\nsource_dataset." }, "text": { "description": "Configures de-identification of text wherever it is found in the\nsource_dataset.", "$ref": "TextConfig" }, "dicom": { "$ref": "DicomConfig", "description": "Configures de-id of application/DICOM content." }, "fhir": { "$ref": "FhirConfig", "description": "Configures de-id of application/FHIR content." } }, "id": "DeidentifyConfig" }, "TextConfig": { "type": "object", "properties": { "experimentalConfig": { "type": "string", "description": "Experimental de-identification config to use. For internal use only.\nIf not specified, it is ignored and standard DLP is used." }, "transformations": { "description": "The transformations to apply to the detected data.", "type": "array", "items": { "$ref": "InfoTypeTransformation" } } }, "id": "TextConfig" }, "HttpBody": { "properties": { "contentType": { "type": "string", "description": "The HTTP Content-Type header value specifying the content type of the body." }, "extensions": { "description": "Application specific response metadata. Must be set in the first response\nfor streaming APIs.", "type": "array", "items": { "additionalProperties": { "type": "any", "description": "Properties of the object. Contains field @type with type URL." }, "type": "object" } }, "data": { "description": "The HTTP request/response body as raw binary.", "format": "byte", "type": "string" } }, "id": "HttpBody", "description": "Message that represents an arbitrary HTTP body. It should only be used for\npayload formats that can't be represented as JSON, such as raw binary or\nan HTML page.\n\n\nThis message can be used both in streaming and non-streaming API methods in\nthe request as well as the response.\n\nIt can be used as a top-level request field, which is convenient if one\nwants to extract parameters from either the URL or HTTP template into the\nrequest fields and also want access to the raw HTTP body.\n\nExample:\n\n    message GetResourceRequest {\n      // A unique request id.\n      string request_id = 1;\n\n      // The raw HTTP body is bound to this field.\n      google.api.HttpBody http_body = 2;\n    }\n\n    service ResourceService {\n      rpc GetResource(GetResourceRequest) returns (google.api.HttpBody);\n      rpc UpdateResource(google.api.HttpBody) returns\n      (google.protobuf.Empty);\n    }\n\nExample with streaming methods:\n\n    service CaldavService {\n      rpc GetCalendar(stream google.api.HttpBody)\n        returns (stream google.api.HttpBody);\n      rpc UpdateCalendar(stream google.api.HttpBody)\n        returns (stream google.api.HttpBody);\n    }\n\nUse of this type only changes how the request and response bodies are\nhandled, all other features will continue to work unchanged.", "type": "object" }, "ListOperationsResponse": { "type": "object", "properties": { "nextPageToken": { "description": "The standard List next-page token.", "type": "string" }, "operations": { "description": "A list of operations that matches the specified filter in the request.", "type": "array", "items": { "$ref": "Operation" } } }, "id": "ListOperationsResponse", "description": "The response message for Operations.ListOperations." }, "OperationMetadata": { "description": "OperationMetadata provides information about the operation execution.\nReturned in the long-running operation's metadata field.", "type": "object", "properties": { "counter": { "$ref": "ProgressCounter" }, "createTime": { "description": "The time at which the operation was created by the API.", "format": "google-datetime", "type": "string" }, "endTime": { "description": "The time at which execution was completed.", "format": "google-datetime", "type": "string" }, "apiMethodName": { "description": "The name of the API method that initiated the operation.", "type": "string" } }, "id": "OperationMetadata" }, "StreamConfig": { "description": "This structure contains configuration for streaming FHIR export.", "type": "object", "properties": { "bigqueryDestination": { "$ref": "GoogleCloudHealthcareV1alpha2FhirBigQueryDestination", "description": "The destination BigQuery structure that contains both the dataset\nlocation and corresponding schema config.\nThe output will be organized in one table per resource type.\nThe server will inspect and potentially create new tables (if they\ndon't exist) in the given BigQuery dataset.\nResults will be appended to the corresponding BigQuery tables.\nThe views of the latest snapshot will also be automatically created in\nthe dataset." }, "resourceTypes": { "description": "Supply a FHIR resource type (such as \"Patient\" or \"Observation\").\nSee https://www.hl7.org/fhir/valueset-resource-types.html for a list of\nall FHIR resource types.\nThe server will treat an empty list as an intent to stream all the\nsupported resource types in this FHIR store.", "type": "array", "items": { "type": "string" } } }, "id": "StreamConfig" }, "Message": { "description": "A complete HL7v2 message.\nSee http://www.hl7.org/implement/standards/index.cfm?ref=common for details\non the standard.", "type": "object", "properties": { "createTime": { "description": "Output only. The datetime when the message was created. Set by the server.", "format": "google-datetime", "type": "string" }, "labels": { "additionalProperties": { "type": "string" }, "description": "User-supplied key-value pairs used to organize HL7v2 stores.\n\nLabel keys must be between 1 and 63 characters long, have a UTF-8 encoding\nof maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression:\n\\p{Ll}\\p{Lo}{0,62}\n\nLabel values are optional, must be between 1 and 63 characters long, have\na UTF-8 encoding of maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression: [\\p{Ll}\\p{Lo}\\p{N}_-]{0,63}\n\nNo more than 64 labels can be associated with a given store.", "type": "object" }, "parsedData": { "$ref": "ParsedData", "description": "Output only. The parsed version of the raw message data." }, "name": { "description": "Resource name of the Message, of the form\n`projects/{project_id}/datasets/{dataset_id}/hl7V2Stores/{hl7_v2_store_id}/messages/{message_id}`.\nAssigned by the server.", "type": "string" }, "sendTime": { "description": "The datetime the sending application sent this message. MSH-7.", "format": "google-datetime", "type": "string" }, "sendFacility": { "description": "The hospital that this message came from. MSH-4.", "type": "string" }, "messageType": { "description": "The message type and trigger event for this message. MSH-9.", "type": "string" }, "data": { "description": "Raw message bytes.", "format": "byte", "type": "string" }, "patientIds": { "description": "All patient IDs listed in the PID-2, PID-3, and PID-4 segments of this\nmessage.", "type": "array", "items": { "$ref": "PatientId" } } }, "id": "Message" }, "AnnotationStore": { "type": "object", "properties": { "labels": { "additionalProperties": { "type": "string" }, "description": "User-supplied key-value pairs used to organize Annotation stores.\n\nLabel keys must be between 1 and 63 characters long, have a UTF-8 encoding\nof maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression:\n\\p{Ll}\\p{Lo}{0,62}\n\nLabel values are optional, must be between 1 and 63 characters long, have\na UTF-8 encoding of maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression: [\\p{Ll}\\p{Lo}\\p{N}_-]{0,63}\n\nNo more than 64 labels can be associated with a given store.", "type": "object" }, "name": { "type": "string", "description": "Output only. Resource name of the Annotation store, of the form\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/annotationStores/{annotation_store_id}`." } }, "id": "AnnotationStore", "description": "An Annotation store that can store annotation resources such as\nlabels and tags for text, image and audio." }, "NotificationConfig": { "description": "Specifies where notifications should be sent upon changes to a data store.", "type": "object", "properties": { "pubsubTopic": { "description": "The [Cloud Pub/Sub](https://cloud.google.com/pubsub/docs/) topic that\nnotifications of changes are published on. Supplied by the client.\nPubsubMessage.Data will contain the resource name.\nPubsubMessage.MessageId is the ID of this message. It is guaranteed to be\nunique within the topic.\nPubsubMessage.PublishTime is the time at which the message was published.\nNotifications are only sent if the topic is\nnon-empty. [Topic\nnames](https://cloud.google.com/pubsub/docs/overview#names) must be scoped\nto a project. cloud-healthcare@system.gserviceaccount.com must have\npublisher permissions on the given Cloud Pub/Sub topic. Not having adequate\npermissions will cause the calls that send notifications to fail.", "type": "string" } }, "id": "NotificationConfig" }, "InfoTypeTransformation": { "properties": { "dateShiftConfig": { "$ref": "DateShiftConfig", "description": "Config for date shift." }, "characterMaskConfig": { "$ref": "CharacterMaskConfig", "description": "Config for character mask." }, "redactConfig": { "$ref": "RedactConfig", "description": "Config for text redaction." }, "infoTypes": { "description": "InfoTypes to apply this transformation to. If this is not specified, the\ntransformation applies to any info_type.", "type": "array", "items": { "type": "string" } }, "replaceWithInfoTypeConfig": { "$ref": "ReplaceWithInfoTypeConfig", "description": "Config for replace with InfoType." }, "cryptoHashConfig": { "$ref": "CryptoHashConfig", "description": "Config for crypto hash." } }, "id": "InfoTypeTransformation", "description": "A transformation to apply to text that is identified as a specific\ninfo_type.", "type": "object" }, "Vertex": { "description": "A 2D coordinate in an image. The origin is the top-left.", "type": "object", "properties": { "x": { "description": "X coordinate.", "format": "float", "type": "number" }, "y": { "description": "Y coordinate.", "format": "float", "type": "number" } }, "id": "Vertex" }, "GoogleCloudHealthcareV1alpha2DicomBigQueryDestination": { "description": "The BigQuery table where the output should be written.", "type": "object", "properties": { "tableUri": { "type": "string", "description": "BigQuery URI to a table, up to 2000 characters long, in the format\n`bq://projectId.bqDatasetId.tableId`" }, "force": { "description": "If the destination table already exists and this flag is `TRUE`, the table\nwill be overwritten by the contents of the DICOM store. If the flag is not\nset and the destination table already exists, the export call returns an\nerror.", "type": "boolean" } }, "id": "GoogleCloudHealthcareV1alpha2DicomBigQueryDestination" }, "BoundingPoly": { "description": "A bounding polygon for the detected image annotation.", "type": "object", "properties": { "vertices": { "type": "array", "items": { "$ref": "Vertex" } }, "label": { "type": "string" } }, "id": "BoundingPoly" }, "DicomStore": { "type": "object", "properties": { "labels": { "additionalProperties": { "type": "string" }, "description": "User-supplied key-value pairs used to organize DICOM stores.\n\nLabel keys must be between 1 and 63 characters long, have a UTF-8 encoding\nof maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression:\n\\p{Ll}\\p{Lo}{0,62}\n\nLabel values are optional, must be between 1 and 63 characters long, have\na UTF-8 encoding of maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression: [\\p{Ll}\\p{Lo}\\p{N}_-]{0,63}\n\nNo more than 64 labels can be associated with a given store.", "type": "object" }, "notificationConfig": { "description": "Notification destination for new DICOM instances.\nSupplied by the client.", "$ref": "NotificationConfig" }, "name": { "description": "Output only. Resource name of the DICOM store, of the form\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`.", "type": "string" } }, "id": "DicomStore", "description": "Represents a DICOM store." }, "AnnotationSource": { "description": "AnnotationSource holds the source information of the annotation.", "type": "object", "properties": { "cloudHealthcareSource": { "$ref": "CloudHealthcareSource", "description": "Cloud Healthcare API resource." } }, "id": "AnnotationSource" }, "SetIamPolicyRequest": { "id": "SetIamPolicyRequest", "description": "Request message for `SetIamPolicy` method.", "type": "object", "properties": { "updateMask": { "description": "OPTIONAL: A FieldMask specifying which fields of the policy to modify. Only\nthe fields in the mask will be modified. If no mask is provided, the\nfollowing default mask is used:\npaths: \"bindings, etag\"\nThis field is only used by Cloud IAM.", "format": "google-fieldmask", "type": "string" }, "policy": { "$ref": "Policy", "description": "REQUIRED: The complete policy to be applied to the `resource`. The size of\nthe policy is limited to a few 10s of KB. An empty policy is a\nvalid policy but certain Cloud Platform services (such as Projects)\nmight reject them." } } }, "SchemaConfig": { "description": "Configuration for the FHIR BigQuery and Cloud Storage schema. Determines\nhow the server generates the schema.", "type": "object", "properties": { "schemaType": { "enumDescriptions": ["No schema type specified. Same as `LOSSLESS`.", "A data-driven schema generated from the fields present in the FHIR data\nbeing exported, with no additional simplification.", "Analytics schema defined by the FHIR community.\nSee https://github.com/FHIR/sql-on-fhir/blob/master/sql-on-fhir.md."], "enum": ["SCHEMA_TYPE_UNSPECIFIED", "LOSSLESS", "ANALYTICS"], "description": "Specifies the output schema type. If unspecified, the default is\n`LOSSLESS`.", "type": "string" }, "recursiveStructureDepth": { "description": "The depth for all recursive structures in the output analytics\nschema. For example, `concept` in the CodeSystem resource is a recursive\nstructure; when the depth is 2, the CodeSystem table will have a column\ncalled `concept.concept` but not `concept.concept.concept`. If not\nspecified or set to 0, the server will use the default value 2.", "format": "int64", "type": "string" } }, "id": "SchemaConfig" }, "ListHl7V2StoresResponse": { "description": "Lists the HL7v2 stores in the given dataset.", "type": "object", "properties": { "hl7V2Stores": { "description": "The returned HL7v2 stores. Won't be more HL7v2 stores than the value of\npage_size in the request.", "type": "array", "items": { "$ref": "Hl7V2Store" } }, "nextPageToken": { "description": "Token to retrieve the next page of results or empty if there are no more\nresults in the list.", "type": "string" } }, "id": "ListHl7V2StoresResponse" }, "Location": { "type": "object", "properties": { "locationId": { "description": "The canonical id for this location. For example: `\"us-east1\"`.", "type": "string" }, "displayName": { "description": "The friendly name for this location, typically a nearby city name.\nFor example, \"Tokyo\".", "type": "string" }, "metadata": { "additionalProperties": { "description": "Properties of the object. Contains field @type with type URL.", "type": "any" }, "description": "Service-specific metadata. For example the available capacity at the given\nlocation.", "type": "object" }, "labels": { "additionalProperties": { "type": "string" }, "description": "Cross-service attributes for the location. For example\n\n    {\"cloud.googleapis.com/region\": \"us-east1\"}", "type": "object" }, "name": { "description": "Resource name for the location, which may vary between implementations.\nFor example: `\"projects/example-project/locations/us-east1\"`", "type": "string" } }, "id": "Location", "description": "A resource that represents Google Cloud Platform location." }, "Hl7V2Store": { "properties": { "name": { "description": "Output only. Resource name of the HL7v2 store, of the form\n`projects/{project_id}/datasets/{dataset_id}/hl7V2Stores/{hl7v2_store_id}`.", "type": "string" }, "labels": { "additionalProperties": { "type": "string" }, "description": "User-supplied key-value pairs used to organize HL7v2 stores.\n\nLabel keys must be between 1 and 63 characters long, have a UTF-8 encoding\nof maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression:\n\\p{Ll}\\p{Lo}{0,62}\n\nLabel values are optional, must be between 1 and 63 characters long, have\na UTF-8 encoding of maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression: [\\p{Ll}\\p{Lo}\\p{N}_-]{0,63}\n\nNo more than 64 labels can be associated with a given store.", "type": "object" }, "notificationConfig": { "$ref": "NotificationConfig", "description": "The notification destination all messages (both Ingest & Create) are\npublished on. Only the message name is sent as part of the notification. If\nthis is unset, no notifications will be sent. Supplied by the client." }, "parserConfig": { "$ref": "ParserConfig", "description": "The configuration for the parser. It determines how the server parses the\nmessages." } }, "id": "Hl7V2Store", "description": "Represents an HL7v2 store.", "type": "object" }, "Finding": { "type": "object", "properties": { "start": { "description": "Zero-based starting index of the found text, inclusively.", "format": "int64", "type": "string" }, "infoType": { "description": "The type of information stored in this text range (e.g. HumanName,\nBirthDate, Address, etc.)", "type": "string" }, "end": { "description": "Zero-based ending index of the found text, exclusively.", "format": "int64", "type": "string" } }, "id": "Finding" }, "CryptoHashConfig": { "description": "Pseudonymization method that generates surrogates via cryptographic hashing.\nUses SHA-256.\nOutputs a base64-encoded representation of the hashed output\n(for example, `L7k0BHmF1ha5U3NfGykjro4xWi1MPVQPjhMAZbSV9mM=`).", "type": "object", "properties": { "cryptoKey": { "type": "string", "description": "An AES 128/192/256 bit key. Causes the hash to be computed based on this\nkey. A default key is generated for each DeidentifyDataset operation and is\nused wherever crypto_key is not specified.", "format": "byte" } }, "id": "CryptoHashConfig" }, "Segment": { "id": "Segment", "description": "A segment in a structured format.", "type": "object", "properties": { "setId": { "description": "Set ID for segments that can be in a set. This can be empty if it is\nmissing or it is not applicable.", "type": "string" }, "fields": { "type": "object", "additionalProperties": { "type": "string" }, "description": "A mapping from the positional location to the value.\nThe key string uses zero-based indexes separated by dots to identify\nFields, components and sub-components. A bracket notation is also used to\nidentify different instances of a repeated field.\nRegex for key: (\\d+)(\\[\\d+\\])?(.\\d+)?(.\\d+)?\n\nExamples of (key, value) pairs:\n- (0.1, \"foo\"): Component 1 of Field 0 has the value \"foo\".\n- (1.1.2, \"bar\"): Sub-component 2 of Component 1 of field 1 has the value\n\"bar\".\n- (1[2].1, \"baz\"): Component 1 of Instance 2 of Field 1, which is repeated,\nhas the value \"baz\"." }, "segmentId": { "description": "A string that indicates the type of segment, e.g., EVN, PID.", "type": "string" } } }, "ListDatasetsResponse": { "description": "Lists the available datasets.", "type": "object", "properties": { "datasets": { "description": "The first page of datasets.", "type": "array", "items": { "$ref": "Dataset" } }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" } }, "id": "ListDatasetsResponse" }, "CreateMessageRequest": { "description": "Creates a new message.", "type": "object", "properties": { "message": { "description": "HL7v2 message.", "$ref": "Message" } }, "id": "CreateMessageRequest" }, "TestIamPermissionsRequest": { "type": "object", "properties": { "permissions": { "description": "The set of permissions to check for the `resource`. Permissions with\nwildcards (such as '*' or 'storage.*') are not allowed. For more\ninformation see\n[IAM Overview](https://cloud.google.com/iam/docs/overview#permissions).", "type": "array", "items": { "type": "string" } } }, "id": "TestIamPermissionsRequest", "description": "Request message for `TestIamPermissions` method." }, "CharacterMaskConfig": { "description": "Mask a string by replacing its characters with a fixed character.", "type": "object", "properties": { "maskingCharacter": { "description": "Character to mask the sensitive values. If not supplied, defaults to \"*\".", "type": "string" } }, "id": "CharacterMaskConfig" }, "GoogleCloudHealthcareV1alpha2FhirRestExportResourcesResponse": { "description": "Final response of exporting resources.\nThis structure will be included in the\nresponse to describe the detailed\noutcome. It will only be included when the operation finishes.", "type": "object", "properties": { "resourceCount": { "type": "string", "description": "The total number of resources exported from the requested FHIR store.", "format": "int64" }, "fhirStore": { "description": "The name of the FHIR store where resources have been exported, in the\nformat\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}`.", "type": "string" } }, "id": "GoogleCloudHealthcareV1alpha2FhirRestExportResourcesResponse" } }, "protocol": "rest", "icons": { "x32": "http://www.google.com/images/icons/product/search-32.gif", "x16": "http://www.google.com/images/icons/product/search-16.gif" }, "canonicalName": "Cloud Healthcare", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloud-platform": { "description": "View and manage your data across Google Cloud Platform services" } } } }, "rootUrl": "https://healthcare.googleapis.com/", "ownerDomain": "google.com", "name": "healthcare", "batchPath": "batch" };
//# sourceMappingURL=healthcare-v1alpha2.js.map