"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "title": "Web Security Scanner API", "ownerName": "Google", "resources": { "projects": { "resources": { "scanConfigs": { "methods": { "get": { "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}", "path": "v1alpha/{+name}", "id": "websecurityscanner.projects.scanConfigs.get", "description": "Gets a ScanConfig.", "response": { "$ref": "ScanConfig" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "description": "Required.\nThe resource name of the ScanConfig to be returned. The name follows the\nformat of 'projects/{projectId}/scanConfigs/{scanConfigId}'.", "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+$", "location": "path" } } }, "patch": { "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}", "id": "websecurityscanner.projects.scanConfigs.patch", "path": "v1alpha/{+name}", "request": { "$ref": "ScanConfig" }, "description": "Updates a ScanConfig. This method support partial update of a ScanConfig.", "httpMethod": "PATCH", "parameterOrder": ["name"], "response": { "$ref": "ScanConfig" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "location": "path", "description": "The resource name of the ScanConfig. The name follows the format of\n'projects/{projectId}/scanConfigs/{scanConfigId}'. The ScanConfig IDs are\ngenerated by the system.", "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+$" }, "updateMask": { "type": "string", "location": "query", "description": "Required.\nThe update mask applies to the resource. For the `FieldMask` definition,\nsee\nhttps://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask", "format": "google-fieldmask" } } }, "start": { "description": "Start a ScanRun according to the given ScanConfig.", "request": { "$ref": "StartScanRunRequest" }, "response": { "$ref": "ScanRun" }, "parameterOrder": ["name"], "httpMethod": "POST", "parameters": { "name": { "description": "Required.\nThe resource name of the ScanConfig to be used. The name follows the\nformat of 'projects/{projectId}/scanConfigs/{scanConfigId}'.", "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}:start", "path": "v1alpha/{+name}:start", "id": "websecurityscanner.projects.scanConfigs.start" }, "delete": { "description": "Deletes an existing ScanConfig and its child resources.", "response": { "$ref": "Empty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "description": "Required.\nThe resource name of the ScanConfig to be deleted. The name follows the\nformat of 'projects/{projectId}/scanConfigs/{scanConfigId}'.", "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+$", "location": "path" } }, "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}", "path": "v1alpha/{+name}", "id": "websecurityscanner.projects.scanConfigs.delete" }, "list": { "httpMethod": "GET", "response": { "$ref": "ListScanConfigsResponse" }, "parameterOrder": ["parent"], "parameters": { "pageToken": { "location": "query", "description": "A token identifying a page of results to be returned. This should be a\n`next_page_token` value returned from a previous List request.\nIf unspecified, the first page of results is returned.", "type": "string" }, "pageSize": { "location": "query", "description": "The maximum number of ScanConfigs to return, can be limited by server.\nIf not specified or not positive, the implementation will select a\nreasonable value.", "format": "int32", "type": "integer" }, "parent": { "location": "path", "description": "Required.\nThe parent resource name, which should be a project resource name in the\nformat 'projects/{projectId}'.", "required": true, "type": "string", "pattern": "^projects/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha/projects/{projectsId}/scanConfigs", "id": "websecurityscanner.projects.scanConfigs.list", "path": "v1alpha/{+parent}/scanConfigs", "description": "Lists ScanConfigs under a given project." }, "create": { "response": { "$ref": "ScanConfig" }, "parameterOrder": ["parent"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "pattern": "^projects/[^/]+$", "location": "path", "description": "Required.\nThe parent resource name where the scan is created, which should be a\nproject resource name in the format 'projects/{projectId}'.", "required": true, "type": "string" } }, "flatPath": "v1alpha/projects/{projectsId}/scanConfigs", "path": "v1alpha/{+parent}/scanConfigs", "id": "websecurityscanner.projects.scanConfigs.create", "request": { "$ref": "ScanConfig" }, "description": "Creates a new ScanConfig." } }, "resources": { "scanRuns": { "methods": { "get": { "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}", "path": "v1alpha/{+name}", "id": "websecurityscanner.projects.scanConfigs.scanRuns.get", "description": "Gets a ScanRun.", "response": { "$ref": "ScanRun" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "location": "path", "description": "Required.\nThe resource name of the ScanRun to be returned. The name follows the\nformat of\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.", "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$" } } }, "list": { "description": "Lists ScanRuns under a given ScanConfig, in descending order of ScanRun\nstop time.", "response": { "$ref": "ListScanRunsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+$", "location": "path", "description": "Required.\nThe parent resource name, which should be a scan resource name in the\nformat 'projects/{projectId}/scanConfigs/{scanConfigId}'." }, "pageToken": { "location": "query", "description": "A token identifying a page of results to be returned. This should be a\n`next_page_token` value returned from a previous List request.\nIf unspecified, the first page of results is returned.", "type": "string" }, "pageSize": { "location": "query", "description": "The maximum number of ScanRuns to return, can be limited by server.\nIf not specified or not positive, the implementation will select a\nreasonable value.", "format": "int32", "type": "integer" } }, "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns", "path": "v1alpha/{+parent}/scanRuns", "id": "websecurityscanner.projects.scanConfigs.scanRuns.list" }, "stop": { "response": { "$ref": "ScanRun" }, "parameterOrder": ["name"], "httpMethod": "POST", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "description": "Required.\nThe resource name of the ScanRun to be stopped. The name follows the\nformat of\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.", "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$", "location": "path" } }, "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}:stop", "path": "v1alpha/{+name}:stop", "id": "websecurityscanner.projects.scanConfigs.scanRuns.stop", "request": { "$ref": "StopScanRunRequest" }, "description": "Stops a ScanRun. The stopped ScanRun is returned." } }, "resources": { "findingTypeStats": { "methods": { "list": { "path": "v1alpha/{+parent}/findingTypeStats", "id": "websecurityscanner.projects.scanConfigs.scanRuns.findingTypeStats.list", "description": "List all FindingTypeStats under a given ScanRun.", "response": { "$ref": "ListFindingTypeStatsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$", "location": "path", "description": "Required.\nThe parent resource name, which should be a scan run resource name in the\nformat\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}/findingTypeStats" } } }, "findings": { "methods": { "get": { "description": "Gets a Finding.", "response": { "$ref": "Finding" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "location": "path", "description": "Required.\nThe resource name of the Finding to be returned. The name follows the\nformat of\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}/findings/{findingId}'.", "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+/findings/[^/]+$" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}/findings/{findingsId}", "path": "v1alpha/{+name}", "id": "websecurityscanner.projects.scanConfigs.scanRuns.findings.get" }, "list": { "httpMethod": "GET", "response": { "$ref": "ListFindingsResponse" }, "parameterOrder": ["parent"], "parameters": { "pageToken": { "type": "string", "location": "query", "description": "A token identifying a page of results to be returned. This should be a\n`next_page_token` value returned from a previous List request.\nIf unspecified, the first page of results is returned." }, "pageSize": { "description": "The maximum number of Findings to return, can be limited by server.\nIf not specified or not positive, the implementation will select a\nreasonable value.", "format": "int32", "type": "integer", "location": "query" }, "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$", "location": "path", "description": "Required.\nThe parent resource name, which should be a scan run resource name in the\nformat\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'." }, "filter": { "description": "The filter expression. The expression must be in the format: <field>\n<operator> <value>.\nSupported field: 'finding_type'.\nSupported operator: '='.", "type": "string", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}/findings", "id": "websecurityscanner.projects.scanConfigs.scanRuns.findings.list", "path": "v1alpha/{+parent}/findings", "description": "List Findings under a given ScanRun." } } }, "crawledUrls": { "methods": { "list": { "response": { "$ref": "ListCrawledUrlsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "pageToken": { "type": "string", "location": "query", "description": "A token identifying a page of results to be returned. This should be a\n`next_page_token` value returned from a previous List request.\nIf unspecified, the first page of results is returned." }, "pageSize": { "type": "integer", "location": "query", "description": "The maximum number of CrawledUrls to return, can be limited by server.\nIf not specified or not positive, the implementation will select a\nreasonable value.", "format": "int32" }, "parent": { "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$", "location": "path", "description": "Required.\nThe parent resource name, which should be a scan run resource name in the\nformat\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.", "required": true, "type": "string" } }, "flatPath": "v1alpha/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}/crawledUrls", "path": "v1alpha/{+parent}/crawledUrls", "id": "websecurityscanner.projects.scanConfigs.scanRuns.crawledUrls.list", "description": "List CrawledUrls under a given ScanRun." } } } } } } } } } }, "parameters": { "access_token": { "location": "query", "description": "OAuth access token.", "type": "string" }, "key": { "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.", "type": "string" }, "upload_protocol": { "location": "query", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string" }, "quotaUser": { "type": "string", "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters." }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" }, "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" }, "uploadType": { "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string", "location": "query" }, "callback": { "location": "query", "description": "JSONP", "type": "string" }, "oauth_token": { "location": "query", "description": "OAuth 2.0 token for the current user.", "type": "string" }, "$.xgafv": { "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query", "enum": ["1", "2"], "description": "V1 error format." }, "alt": { "default": "json", "enum": ["json", "media", "proto"], "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response." } }, "version": "v1alpha", "baseUrl": "https://websecurityscanner.googleapis.com/", "servicePath": "", "kind": "discovery#restDescription", "description": "Scans your Compute and App Engine apps for common web vulnerabilities.", "basePath": "", "id": "websecurityscanner:v1alpha", "documentationLink": "https://cloud.google.com/security-scanner/", "revision": "20190622", "discoveryVersion": "v1", "version_module": true, "schemas": { "Schedule": { "description": "Scan schedule configuration.", "type": "object", "properties": { "scheduleTime": { "description": "A timestamp indicates when the next run will be scheduled. The value is\nrefreshed by the server after each run. If unspecified, it will default\nto current server time, which means the scan will be scheduled to start\nimmediately.", "format": "google-datetime", "type": "string" }, "intervalDurationDays": { "description": "Required.\nThe duration of time between executions in days.", "format": "int32", "type": "integer" } }, "id": "Schedule" }, "Xss": { "id": "Xss", "description": "Information reported for an XSS.", "type": "object", "properties": { "stackTraces": { "description": "Stack traces leading to the point where the XSS occurred.", "type": "array", "items": { "type": "string" } }, "errorMessage": { "description": "An error message generated by a javascript breakage.", "type": "string" } } }, "Authentication": { "description": "Scan authentication configuration.", "type": "object", "properties": { "googleAccount": { "$ref": "GoogleAccount", "description": "Authentication using a Google account." }, "customAccount": { "$ref": "CustomAccount", "description": "Authentication using a custom account." } }, "id": "Authentication" }, "ListFindingTypeStatsResponse": { "id": "ListFindingTypeStatsResponse", "description": "Response for the `ListFindingTypeStats` method.", "type": "object", "properties": { "findingTypeStats": { "description": "The list of FindingTypeStats returned.", "type": "array", "items": { "$ref": "FindingTypeStats" } } } }, "GoogleAccount": { "type": "object", "properties": { "password": { "description": "Input only.\nRequired.\nThe password of the Google account. The credential is stored encrypted\nand not returned in any response nor included in audit logs.", "type": "string" }, "username": { "description": "Required.\nThe user name of the Google account.", "type": "string" } }, "id": "GoogleAccount", "description": "Describes authentication configuration that uses a Google account." }, "VulnerableParameters": { "description": "Information about vulnerable request parameters.", "type": "object", "properties": { "parameterNames": { "description": "The vulnerable parameter names.", "type": "array", "items": { "type": "string" } } }, "id": "VulnerableParameters" }, "VulnerableHeaders": { "description": "Information about vulnerable or missing HTTP Headers.", "type": "object", "properties": { "missingHeaders": { "description": "List of missing headers.", "type": "array", "items": { "$ref": "Header" } }, "headers": { "type": "array", "items": { "$ref": "Header" }, "description": "List of vulnerable headers." } }, "id": "VulnerableHeaders" }, "ListCrawledUrlsResponse": { "type": "object", "properties": { "crawledUrls": { "description": "The list of CrawledUrls returned.", "type": "array", "items": { "$ref": "CrawledUrl" } }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" } }, "id": "ListCrawledUrlsResponse", "description": "Response for the `ListCrawledUrls` method." }, "ListFindingsResponse": { "type": "object", "properties": { "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" }, "findings": { "type": "array", "items": { "$ref": "Finding" }, "description": "The list of Findings returned." } }, "id": "ListFindingsResponse", "description": "Response for the `ListFindings` method." }, "OutdatedLibrary": { "description": "Information reported for an outdated library.", "type": "object", "properties": { "libraryName": { "description": "The name of the outdated library.", "type": "string" }, "learnMoreUrls": { "type": "array", "items": { "type": "string" }, "description": "URLs to learn more information about the vulnerabilities in the library." }, "version": { "description": "The version number.", "type": "string" } }, "id": "OutdatedLibrary" }, "CustomAccount": { "type": "object", "properties": { "loginUrl": { "description": "Required.\nThe login form URL of the website.", "type": "string" }, "password": { "type": "string", "description": "Input only.\nRequired.\nThe password of the custom account. The credential is stored encrypted\nand not returned in any response nor included in audit logs." }, "username": { "description": "Required.\nThe user name of the custom account.", "type": "string" } }, "id": "CustomAccount", "description": "Describes authentication configuration that uses a custom account." }, "Empty": { "id": "Empty", "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object", "properties": {} }, "StartScanRunRequest": { "description": "Request for the `StartScanRun` method.", "type": "object", "properties": {}, "id": "StartScanRunRequest" }, "Finding": { "description": "A Finding resource represents a vulnerability instance identified during a\nScanRun.", "type": "object", "properties": { "fuzzedUrl": { "type": "string", "description": "Output only.\nThe URL produced by the server-side fuzzer and used in the request that\ntriggered the vulnerability." }, "description": { "description": "Output only.\nThe description of the vulnerability.", "type": "string" }, "trackingId": { "description": "Output only.\nThe tracking ID uniquely identifies a vulnerability instance across\nmultiple ScanRuns.", "type": "string" }, "httpMethod": { "description": "Output only.\nThe http method of the request that triggered the vulnerability, in\nuppercase.", "type": "string" }, "vulnerableParameters": { "$ref": "VulnerableParameters", "description": "Output only.\nAn addon containing information about request parameters which were found\nto be vulnerable." }, "name": { "description": "Output only.\nThe resource name of the Finding. The name follows the format of\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanruns/{scanRunId}/findings/{findingId}'.\nThe finding IDs are generated by the system.", "type": "string" }, "vulnerableHeaders": { "$ref": "VulnerableHeaders", "description": "Output only.\nAn addon containing information about vulnerable or missing HTTP headers." }, "findingType": { "enumDescriptions": ["The invalid finding type.", "A page that was served over HTTPS also resources over HTTP. A\nman-in-the-middle attacker could tamper with the HTTP resource and gain\nfull access to the website that loads the resource or to monitor the\nactions taken by the user.", "The version of an included library is known to contain a security issue.\nThe scanner checks the version of library in use against a known list of\nvulnerable libraries. False positives are possible if the version\ndetection fails or if the library has been manually patched.", "This type of vulnerability occurs when the value of a request parameter\nis reflected at the beginning of the response, for example, in requests\nusing JSONP. Under certain circumstances, an attacker may be able to\nsupply an alphanumeric-only Flash file in the vulnerable parameter\ncausing the browser to execute the Flash file as if it originated on the\nvulnerable server.", "A cross-site scripting (XSS) bug is found via JavaScript callback. For\ndetailed explanations on XSS, see\nhttps://www.google.com/about/appsecurity/learning/xss/.", "A potential cross-site scripting (XSS) bug due to JavaScript breakage.\nIn some circumstances, the application under test might modify the test\nstring before it is parsed by the browser. When the browser attempts to\nruns this modified test string, it will likely break and throw a\nJavaScript execution error, thus an injection issue is occurring.\nHowever, it may not be exploitable. Manual verification is needed to see\nif the test string modifications can be evaded and confirm that the issue\nis in fact an XSS vulnerability. For detailed explanations on XSS, see\nhttps://www.google.com/about/appsecurity/learning/xss/.", "An application appears to be transmitting a password field in clear text.\nAn attacker can eavesdrop network traffic and sniff the password field.", "An application returns sensitive content with an invalid content type,\nor without an 'X-Content-Type-Options: nosniff' header.", "A cross-site scripting (XSS) vulnerability in AngularJS module that\noccurs when a user-provided string is interpolated by Angular.", "A malformed or invalid valued header.", "Misspelled security header name.", "Mismatching values in a duplicate security header."], "enum": ["FINDING_TYPE_UNSPECIFIED", "MIXED_CONTENT", "OUTDATED_LIBRARY", "ROSETTA_FLASH", "XSS_CALLBACK", "XSS_ERROR", "CLEAR_TEXT_PASSWORD", "INVALID_CONTENT_TYPE", "XSS_ANGULAR_CALLBACK", "INVALID_HEADER", "MISSPELLED_SECURITY_HEADER_NAME", "MISMATCHING_SECURITY_HEADER_VALUES"], "description": "Output only.\nThe type of the Finding.", "type": "string" }, "outdatedLibrary": { "$ref": "OutdatedLibrary", "description": "Output only.\nAn addon containing information about outdated libraries." }, "violatingResource": { "$ref": "ViolatingResource", "description": "Output only.\nAn addon containing detailed information regarding any resource causing the\nvulnerability such as JavaScript sources, image, audio files, etc." }, "xss": { "description": "Output only.\nAn addon containing information reported for an XSS, if any.", "$ref": "Xss" }, "finalUrl": { "type": "string", "description": "Output only.\nThe URL where the browser lands when the vulnerability is detected." }, "reproductionUrl": { "description": "Output only.\nThe URL containing human-readable payload that user can leverage to\nreproduce the vulnerability.", "type": "string" }, "body": { "description": "Output only.\nThe body of the request that triggered the vulnerability.", "type": "string" }, "frameUrl": { "type": "string", "description": "Output only.\nIf the vulnerability was originated from nested IFrame, the immediate\nparent IFrame is reported." } }, "id": "Finding" }, "Header": { "type": "object", "properties": { "name": { "description": "Header name.", "type": "string" }, "value": { "description": "Header value.", "type": "string" } }, "id": "Header", "description": "Describes a HTTP Header." }, "ListScanRunsResponse": { "description": "Response for the `ListScanRuns` method.", "type": "object", "properties": { "nextPageToken": { "type": "string", "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list." }, "scanRuns": { "description": "The list of ScanRuns returned.", "type": "array", "items": { "$ref": "ScanRun" } } }, "id": "ListScanRunsResponse" }, "ViolatingResource": { "id": "ViolatingResource", "description": "Information regarding any resource causing the vulnerability such\nas JavaScript sources, image, audio files, etc.", "type": "object", "properties": { "contentType": { "description": "The MIME type of this resource.", "type": "string" }, "resourceUrl": { "description": "URL of this violating resource.", "type": "string" } } }, "ScanRun": { "description": "A ScanRun is a output-only resource representing an actual run of the scan.", "type": "object", "properties": { "progressPercent": { "type": "integer", "description": "Output only.\nThe percentage of total completion ranging from 0 to 100.\nIf the scan is in queue, the value is 0.\nIf the scan is running, the value ranges from 0 to 100.\nIf the scan is finished, the value is 100.", "format": "int32" }, "executionState": { "description": "Output only.\nThe execution state of the ScanRun.", "type": "string", "enumDescriptions": ["Represents an invalid state caused by internal server error. This value\nshould never be returned.", "The scan is waiting in the queue.", "The scan is in progress.", "The scan is either finished or stopped by user."], "enum": ["EXECUTION_STATE_UNSPECIFIED", "QUEUED", "SCANNING", "FINISHED"] }, "endTime": { "description": "Output only.\nThe time at which the ScanRun reached termination state - that the ScanRun\nis either finished or stopped by user.", "format": "google-datetime", "type": "string" }, "startTime": { "description": "Output only.\nThe time at which the ScanRun started.", "format": "google-datetime", "type": "string" }, "urlsCrawledCount": { "description": "Output only.\nThe number of URLs crawled during this ScanRun. If the scan is in progress,\nthe value represents the number of URLs crawled up to now.", "format": "int64", "type": "string" }, "hasVulnerabilities": { "description": "Output only.\nWhether the scan run has found any vulnerabilities.", "type": "boolean" }, "urlsTestedCount": { "type": "string", "description": "Output only.\nThe number of URLs tested during this ScanRun. If the scan is in progress,\nthe value represents the number of URLs tested up to now. The number of\nURLs tested is usually larger than the number URLS crawled because\ntypically a crawled URL is tested with multiple test payloads.", "format": "int64" }, "resultState": { "description": "Output only.\nThe result state of the ScanRun. This field is only available after the\nexecution state reaches \"FINISHED\".", "type": "string", "enumDescriptions": ["Default value. This value is returned when the ScanRun is not yet\nfinished.", "The scan finished without errors.", "The scan finished with errors.", "The scan was terminated by user."], "enum": ["RESULT_STATE_UNSPECIFIED", "SUCCESS", "ERROR", "KILLED"] }, "name": { "description": "Output only.\nThe resource name of the ScanRun. The name follows the format of\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.\nThe ScanRun IDs are generated by the system.", "type": "string" } }, "id": "ScanRun" }, "ScanConfig": { "id": "ScanConfig", "description": "A ScanConfig resource contains the configurations to launch a scan.\nnext id: 12", "type": "object", "properties": { "targetPlatforms": { "description": "Set of Cloud Platforms targeted by the scan. If empty, APP_ENGINE will be\nused as a default.", "type": "array", "items": { "type": "string", "enum": ["TARGET_PLATFORM_UNSPECIFIED", "APP_ENGINE", "COMPUTE"] }, "enumDescriptions": ["The target platform is unknown. Requests with this enum value will be\nrejected with INVALID_ARGUMENT error.", "Google App Engine service.", "Google Compute Engine service."] }, "schedule": { "description": "The schedule of the ScanConfig.", "$ref": "Schedule" }, "name": { "type": "string", "description": "The resource name of the ScanConfig. The name follows the format of\n'projects/{projectId}/scanConfigs/{scanConfigId}'. The ScanConfig IDs are\ngenerated by the system." }, "maxQps": { "description": "The maximum QPS during scanning. A valid value ranges from 5 to 20\ninclusively. If the field is unspecified or its value is set 0, server will\ndefault to 15. Other values outside of [5, 20] range will be rejected with\nINVALID_ARGUMENT error.", "format": "int32", "type": "integer" }, "authentication": { "$ref": "Authentication", "description": "The authentication configuration. If specified, service will use the\nauthentication configuration during scanning." }, "blacklistPatterns": { "description": "The blacklist URL patterns as described in\nhttps://cloud.google.com/security-scanner/docs/excluded-urls", "type": "array", "items": { "type": "string" } }, "latestRun": { "$ref": "ScanRun", "description": "Latest ScanRun if available." }, "displayName": { "type": "string", "description": "Required.\nThe user provided display name of the ScanConfig." }, "startingUrls": { "description": "Required.\nThe starting URLs from which the scanner finds site pages.", "type": "array", "items": { "type": "string" } }, "userAgent": { "description": "The user agent used during scanning.", "type": "string", "enumDescriptions": ["The user agent is unknown. Service will default to CHROME_LINUX.", "Chrome on Linux. This is the service default if unspecified.", "Chrome on Android.", "Safari on IPhone."], "enum": ["USER_AGENT_UNSPECIFIED", "CHROME_LINUX", "CHROME_ANDROID", "SAFARI_IPHONE"] } } }, "CrawledUrl": { "description": "A CrawledUrl resource represents a URL that was crawled during a ScanRun. Web\nSecurity Scanner Service crawls the web applications, following all links\nwithin the scope of sites, to find the URLs to test against.", "type": "object", "properties": { "httpMethod": { "description": "Output only.\nThe http method of the request that was used to visit the URL, in\nuppercase.", "type": "string" }, "body": { "description": "Output only.\nThe body of the request that was used to visit the URL.", "type": "string" }, "url": { "type": "string", "description": "Output only.\nThe URL that was crawled." } }, "id": "CrawledUrl" }, "StopScanRunRequest": { "description": "Request for the `StopScanRun` method.", "type": "object", "properties": {}, "id": "StopScanRunRequest" }, "ListScanConfigsResponse": { "description": "Response for the `ListScanConfigs` method.", "type": "object", "properties": { "scanConfigs": { "description": "The list of ScanConfigs returned.", "type": "array", "items": { "$ref": "ScanConfig" } }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" } }, "id": "ListScanConfigsResponse" }, "FindingTypeStats": { "id": "FindingTypeStats", "description": "A FindingTypeStats resource represents stats regarding a specific FindingType\nof Findings under a given ScanRun.", "type": "object", "properties": { "findingType": { "enum": ["FINDING_TYPE_UNSPECIFIED", "MIXED_CONTENT", "OUTDATED_LIBRARY", "ROSETTA_FLASH", "XSS_CALLBACK", "XSS_ERROR", "CLEAR_TEXT_PASSWORD", "INVALID_CONTENT_TYPE", "XSS_ANGULAR_CALLBACK", "INVALID_HEADER", "MISSPELLED_SECURITY_HEADER_NAME", "MISMATCHING_SECURITY_HEADER_VALUES"], "description": "Output only.\nThe finding type associated with the stats.", "type": "string", "enumDescriptions": ["The invalid finding type.", "A page that was served over HTTPS also resources over HTTP. A\nman-in-the-middle attacker could tamper with the HTTP resource and gain\nfull access to the website that loads the resource or to monitor the\nactions taken by the user.", "The version of an included library is known to contain a security issue.\nThe scanner checks the version of library in use against a known list of\nvulnerable libraries. False positives are possible if the version\ndetection fails or if the library has been manually patched.", "This type of vulnerability occurs when the value of a request parameter\nis reflected at the beginning of the response, for example, in requests\nusing JSONP. Under certain circumstances, an attacker may be able to\nsupply an alphanumeric-only Flash file in the vulnerable parameter\ncausing the browser to execute the Flash file as if it originated on the\nvulnerable server.", "A cross-site scripting (XSS) bug is found via JavaScript callback. For\ndetailed explanations on XSS, see\nhttps://www.google.com/about/appsecurity/learning/xss/.", "A potential cross-site scripting (XSS) bug due to JavaScript breakage.\nIn some circumstances, the application under test might modify the test\nstring before it is parsed by the browser. When the browser attempts to\nruns this modified test string, it will likely break and throw a\nJavaScript execution error, thus an injection issue is occurring.\nHowever, it may not be exploitable. Manual verification is needed to see\nif the test string modifications can be evaded and confirm that the issue\nis in fact an XSS vulnerability. For detailed explanations on XSS, see\nhttps://www.google.com/about/appsecurity/learning/xss/.", "An application appears to be transmitting a password field in clear text.\nAn attacker can eavesdrop network traffic and sniff the password field.", "An application returns sensitive content with an invalid content type,\nor without an 'X-Content-Type-Options: nosniff' header.", "A cross-site scripting (XSS) vulnerability in AngularJS module that\noccurs when a user-provided string is interpolated by Angular.", "A malformed or invalid valued header.", "Misspelled security header name.", "Mismatching values in a duplicate security header."] }, "findingCount": { "description": "Output only.\nThe count of findings belonging to this finding type.", "format": "int32", "type": "integer" } } } }, "icons": { "x32": "http://www.google.com/images/icons/product/search-32.gif", "x16": "http://www.google.com/images/icons/product/search-16.gif" }, "protocol": "rest", "canonicalName": "WebSecurityScanner", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloud-platform": { "description": "View and manage your data across Google Cloud Platform services" } } } }, "rootUrl": "https://websecurityscanner.googleapis.com/", "ownerDomain": "google.com", "name": "websecurityscanner", "batchPath": "batch", "fullyEncodeReservedExpansion": true };
//# sourceMappingURL=websecurityscanner-v1alpha.js.map