"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.default = { "basePath": "", "id": "websecurityscanner:v1beta", "documentationLink": "https://cloud.google.com/security-scanner/", "revision": "20190622", "discoveryVersion": "v1", "version_module": true, "schemas": { "ScanConfig": { "description": "A ScanConfig resource contains the configurations to launch a scan.", "type": "object", "properties": { "blacklistPatterns": { "description": "The blacklist URL patterns as described in\nhttps://cloud.google.com/security-scanner/docs/excluded-urls", "type": "array", "items": { "type": "string" } }, "startingUrls": { "description": "Required.\nThe starting URLs from which the scanner finds site pages.", "type": "array", "items": { "type": "string" } }, "targetPlatforms": { "enumDescriptions": ["The target platform is unknown. Requests with this enum value will be\nrejected with INVALID_ARGUMENT error.", "Google App Engine service.", "Google Compute Engine service."], "description": "Set of Cloud Platforms targeted by the scan. If empty, APP_ENGINE will be\nused as a default.", "type": "array", "items": { "enum": ["TARGET_PLATFORM_UNSPECIFIED", "APP_ENGINE", "COMPUTE"], "type": "string" } }, "name": { "description": "The resource name of the ScanConfig. The name follows the format of\n'projects/{projectId}/scanConfigs/{scanConfigId}'. The ScanConfig IDs are\ngenerated by the system.", "type": "string" }, "exportToSecurityCommandCenter": { "enum": ["EXPORT_TO_SECURITY_COMMAND_CENTER_UNSPECIFIED", "ENABLED", "DISABLED"], "description": "Controls export of scan configurations and results to Cloud Security\nCommand Center.", "type": "string", "enumDescriptions": ["Use default, which is ENABLED.", "Export results of this scan to Cloud Security Command Center.", "Do not export results of this scan to Cloud Security Command Center."] }, "latestRun": { "$ref": "ScanRun", "description": "Latest ScanRun if available." }, "displayName": { "description": "Required.\nThe user provided display name of the ScanConfig.", "type": "string" }, "userAgent": { "enum": ["USER_AGENT_UNSPECIFIED", "CHROME_LINUX", "CHROME_ANDROID", "SAFARI_IPHONE"], "description": "The user agent used during scanning.", "type": "string", "enumDescriptions": ["The user agent is unknown. Service will default to CHROME_LINUX.", "Chrome on Linux. This is the service default if unspecified.", "Chrome on Android.", "Safari on IPhone."] }, "schedule": { "$ref": "Schedule", "description": "The schedule of the ScanConfig." }, "riskLevel": { "type": "string", "enumDescriptions": ["Use default, which is NORMAL.", "Normal scanning (Recommended)", "Lower impact scanning"], "enum": ["RISK_LEVEL_UNSPECIFIED", "NORMAL", "LOW"], "description": "The risk level selected for the scan" }, "authentication": { "$ref": "Authentication", "description": "The authentication configuration. If specified, service will use the\nauthentication configuration during scanning." }, "maxQps": { "type": "integer", "description": "The maximum QPS during scanning. A valid value ranges from 5 to 20\ninclusively. If the field is unspecified or its value is set 0, server will\ndefault to 15. Other values outside of [5, 20] range will be rejected with\nINVALID_ARGUMENT error.", "format": "int32" } }, "id": "ScanConfig" }, "CrawledUrl": { "id": "CrawledUrl", "description": "A CrawledUrl resource represents a URL that was crawled during a ScanRun. Web\nSecurity Scanner Service crawls the web applications, following all links\nwithin the scope of sites, to find the URLs to test against.", "type": "object", "properties": { "httpMethod": { "description": "Output only.\nThe http method of the request that was used to visit the URL, in\nuppercase.", "type": "string" }, "body": { "description": "Output only.\nThe body of the request that was used to visit the URL.", "type": "string" }, "url": { "description": "Output only.\nThe URL that was crawled.", "type": "string" } } }, "Form": { "id": "Form", "description": "! Information about a vulnerability with an HTML.", "type": "object", "properties": { "actionUri": { "description": "! The URI where to send the form when it's submitted.", "type": "string" }, "fields": { "description": "! The names of form fields related to the vulnerability.", "type": "array", "items": { "type": "string" } } } }, "ListScanConfigsResponse": { "type": "object", "properties": { "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" }, "scanConfigs": { "description": "The list of ScanConfigs returned.", "type": "array", "items": { "$ref": "ScanConfig" } } }, "id": "ListScanConfigsResponse", "description": "Response for the `ListScanConfigs` method." }, "Schedule": { "id": "Schedule", "description": "Scan schedule configuration.", "type": "object", "properties": { "scheduleTime": { "type": "string", "description": "A timestamp indicates when the next run will be scheduled. The value is\nrefreshed by the server after each run. If unspecified, it will default\nto current server time, which means the scan will be scheduled to start\nimmediately.", "format": "google-datetime" }, "intervalDurationDays": { "description": "Required.\nThe duration of time between executions in days.", "format": "int32", "type": "integer" } } }, "ListFindingTypeStatsResponse": { "description": "Response for the `ListFindingTypeStats` method.", "type": "object", "properties": { "findingTypeStats": { "description": "The list of FindingTypeStats returned.", "type": "array", "items": { "$ref": "FindingTypeStats" } } }, "id": "ListFindingTypeStatsResponse" }, "ListFindingsResponse": { "type": "object", "properties": { "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" }, "findings": { "type": "array", "items": { "$ref": "Finding" }, "description": "The list of Findings returned." } }, "id": "ListFindingsResponse", "description": "Response for the `ListFindings` method." }, "OutdatedLibrary": { "id": "OutdatedLibrary", "description": "Information reported for an outdated library.", "type": "object", "properties": { "version": { "description": "The version number.", "type": "string" }, "libraryName": { "type": "string", "description": "The name of the outdated library." }, "learnMoreUrls": { "type": "array", "items": { "type": "string" }, "description": "URLs to learn more information about the vulnerabilities in the library." } } }, "CustomAccount": { "description": "Describes authentication configuration that uses a custom account.", "type": "object", "properties": { "password": { "type": "string", "description": "Input only.\nRequired.\nThe password of the custom account. The credential is stored encrypted\nand not returned in any response nor included in audit logs." }, "username": { "type": "string", "description": "Required.\nThe user name of the custom account." }, "loginUrl": { "type": "string", "description": "Required.\nThe login form URL of the website." } }, "id": "CustomAccount" }, "Empty": { "id": "Empty", "description": "A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.", "type": "object", "properties": {} }, "StartScanRunRequest": { "description": "Request for the `StartScanRun` method.", "type": "object", "properties": {}, "id": "StartScanRunRequest" }, "Finding": { "id": "Finding", "description": "A Finding resource represents a vulnerability instance identified during a\nScanRun.", "type": "object", "properties": { "httpMethod": { "description": "Output only.\nThe http method of the request that triggered the vulnerability, in\nuppercase.", "type": "string" }, "vulnerableParameters": { "$ref": "VulnerableParameters", "description": "Output only.\nAn addon containing information about request parameters which were found\nto be vulnerable." }, "name": { "description": "Output only.\nThe resource name of the Finding. The name follows the format of\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanruns/{scanRunId}/findings/{findingId}'.\nThe finding IDs are generated by the system.", "type": "string" }, "vulnerableHeaders": { "$ref": "VulnerableHeaders", "description": "Output only.\nAn addon containing information about vulnerable or missing HTTP headers." }, "outdatedLibrary": { "$ref": "OutdatedLibrary", "description": "Output only.\nAn addon containing information about outdated libraries." }, "findingType": { "description": "Output only.\nThe type of the Finding.\nDetailed and up-to-date information on findings can be found here:\nhttps://cloud.google.com/security-scanner/docs/scan-result-details", "type": "string" }, "violatingResource": { "$ref": "ViolatingResource", "description": "Output only.\nAn addon containing detailed information regarding any resource causing the\nvulnerability such as JavaScript sources, image, audio files, etc." }, "xss": { "description": "Output only.\nAn addon containing information reported for an XSS, if any.", "$ref": "Xss" }, "finalUrl": { "type": "string", "description": "Output only.\nThe URL where the browser lands when the vulnerability is detected." }, "reproductionUrl": { "type": "string", "description": "Output only.\nThe URL containing human-readable payload that user can leverage to\nreproduce the vulnerability." }, "body": { "description": "Output only.\nThe body of the request that triggered the vulnerability.", "type": "string" }, "form": { "$ref": "Form", "description": "Output only.\nAn addon containing information reported for a vulnerability with an HTML\nform, if any." }, "frameUrl": { "type": "string", "description": "Output only.\nIf the vulnerability was originated from nested IFrame, the immediate\nparent IFrame is reported." }, "fuzzedUrl": { "description": "Output only.\nThe URL produced by the server-side fuzzer and used in the request that\ntriggered the vulnerability.", "type": "string" }, "description": { "description": "Output only.\nThe description of the vulnerability.", "type": "string" }, "trackingId": { "type": "string", "description": "Output only.\nThe tracking ID uniquely identifies a vulnerability instance across\nmultiple ScanRuns." } } }, "Header": { "description": "Describes a HTTP Header.", "type": "object", "properties": { "value": { "type": "string", "description": "Header value." }, "name": { "description": "Header name.", "type": "string" } }, "id": "Header" }, "ListScanRunsResponse": { "description": "Response for the `ListScanRuns` method.", "type": "object", "properties": { "scanRuns": { "description": "The list of ScanRuns returned.", "type": "array", "items": { "$ref": "ScanRun" } }, "nextPageToken": { "type": "string", "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list." } }, "id": "ListScanRunsResponse" }, "ViolatingResource": { "type": "object", "properties": { "resourceUrl": { "description": "URL of this violating resource.", "type": "string" }, "contentType": { "description": "The MIME type of this resource.", "type": "string" } }, "id": "ViolatingResource", "description": "Information regarding any resource causing the vulnerability such\nas JavaScript sources, image, audio files, etc." }, "ScanRunWarningTrace": { "description": "Output only.\nDefines a warning trace message for ScanRun. Warning traces provide customers\nwith useful information that helps make the scanning process more effective.", "type": "object", "properties": { "code": { "description": "Output only.\nIndicates the warning code.", "type": "string", "enumDescriptions": ["Default value is never used.", "Indicates that a scan discovered an unexpectedly low number of URLs. This\nis sometimes caused by complex navigation features or by using a single\nURL for numerous pages.", "Indicates that a scan discovered too many URLs to test, or excessive\nredundant URLs.", "Indicates that too many tests have been generated for the scan. Customer\nshould try reducing the number of starting URLs, increasing the QPS rate,\nor narrowing down the scope of the scan using the excluded patterns.", "Indicates that a scan is blocked by IAP."], "enum": ["CODE_UNSPECIFIED", "INSUFFICIENT_CRAWL_RESULTS", "TOO_MANY_CRAWL_RESULTS", "TOO_MANY_FUZZ_TASKS", "BLOCKED_BY_IAP"] } }, "id": "ScanRunWarningTrace" }, "ScanRun": { "type": "object", "properties": { "executionState": { "type": "string", "enumDescriptions": ["Represents an invalid state caused by internal server error. This value\nshould never be returned.", "The scan is waiting in the queue.", "The scan is in progress.", "The scan is either finished or stopped by user."], "enum": ["EXECUTION_STATE_UNSPECIFIED", "QUEUED", "SCANNING", "FINISHED"], "description": "Output only.\nThe execution state of the ScanRun." }, "endTime": { "description": "Output only.\nThe time at which the ScanRun reached termination state - that the ScanRun\nis either finished or stopped by user.", "format": "google-datetime", "type": "string" }, "startTime": { "description": "Output only.\nThe time at which the ScanRun started.", "format": "google-datetime", "type": "string" }, "urlsCrawledCount": { "description": "Output only.\nThe number of URLs crawled during this ScanRun. If the scan is in progress,\nthe value represents the number of URLs crawled up to now.", "format": "int64", "type": "string" }, "hasVulnerabilities": { "description": "Output only.\nWhether the scan run has found any vulnerabilities.", "type": "boolean" }, "urlsTestedCount": { "description": "Output only.\nThe number of URLs tested during this ScanRun. If the scan is in progress,\nthe value represents the number of URLs tested up to now. The number of\nURLs tested is usually larger than the number URLS crawled because\ntypically a crawled URL is tested with multiple test payloads.", "format": "int64", "type": "string" }, "warningTraces": { "description": "Output only.\nA list of warnings, if such are encountered during this scan run.", "type": "array", "items": { "$ref": "ScanRunWarningTrace" } }, "resultState": { "description": "Output only.\nThe result state of the ScanRun. This field is only available after the\nexecution state reaches \"FINISHED\".", "type": "string", "enumDescriptions": ["Default value. This value is returned when the ScanRun is not yet\nfinished.", "The scan finished without errors.", "The scan finished with errors.", "The scan was terminated by user."], "enum": ["RESULT_STATE_UNSPECIFIED", "SUCCESS", "ERROR", "KILLED"] }, "name": { "description": "Output only.\nThe resource name of the ScanRun. The name follows the format of\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.\nThe ScanRun IDs are generated by the system.", "type": "string" }, "errorTrace": { "$ref": "ScanRunErrorTrace", "description": "Output only.\nIf result_state is an ERROR, this field provides the primary reason for\nscan's termination and more details, if such are available." }, "progressPercent": { "description": "Output only.\nThe percentage of total completion ranging from 0 to 100.\nIf the scan is in queue, the value is 0.\nIf the scan is running, the value ranges from 0 to 100.\nIf the scan is finished, the value is 100.", "format": "int32", "type": "integer" } }, "id": "ScanRun", "description": "A ScanRun is a output-only resource representing an actual run of the scan.\nNext id: 12" }, "StopScanRunRequest": { "description": "Request for the `StopScanRun` method.", "type": "object", "properties": {}, "id": "StopScanRunRequest" }, "ScanRunErrorTrace": { "type": "object", "properties": { "scanConfigError": { "$ref": "ScanConfigError", "description": "Output only.\nIf the scan encounters SCAN_CONFIG_ISSUE error, this field has the error\nmessage encountered during scan configuration validation that is performed\nbefore each scan run." }, "mostCommonHttpErrorCode": { "description": "Output only.\nIf the scan encounters TOO_MANY_HTTP_ERRORS, this field indicates the most\ncommon HTTP error code, if such is available. For example, if this code is\n404, the scan has encountered too many NOT_FOUND responses.", "format": "int32", "type": "integer" }, "code": { "enumDescriptions": ["Default value is never used.", "Indicates that the scan run failed due to an internal server error.", "Indicates a scan configuration error, usually due to outdated ScanConfig\nsettings, such as starting_urls or the DNS configuration.", "Indicates an authentication error, usually due to outdated ScanConfig\nauthentication settings.", "Indicates a scan operation timeout, usually caused by a very large site.", "Indicates that a scan encountered excessive redirects, either to\nauthentication or some other page outside of the scan scope.", "Indicates that a scan encountered numerous errors from the web site\npages. When available, most_common_http_error_code field indicates the\nthe most common HTTP error code encountered during the scan."], "enum": ["CODE_UNSPECIFIED", "INTERNAL_ERROR", "SCAN_CONFIG_ISSUE", "AUTHENTICATION_CONFIG_ISSUE", "TIMED_OUT_WHILE_SCANNING", "TOO_MANY_REDIRECTS", "TOO_MANY_HTTP_ERRORS"], "description": "Output only.\nIndicates the error reason code.", "type": "string" } }, "id": "ScanRunErrorTrace", "description": "Output only.\nDefines an error trace message for a ScanRun." }, "FindingTypeStats": { "description": "A FindingTypeStats resource represents stats regarding a specific FindingType\nof Findings under a given ScanRun.", "type": "object", "properties": { "findingType": { "description": "Output only.\nThe finding type associated with the stats.", "type": "string" }, "findingCount": { "description": "Output only.\nThe count of findings belonging to this finding type.", "format": "int32", "type": "integer" } }, "id": "FindingTypeStats" }, "Xss": { "description": "Information reported for an XSS.", "type": "object", "properties": { "errorMessage": { "description": "An error message generated by a javascript breakage.", "type": "string" }, "stackTraces": { "description": "Stack traces leading to the point where the XSS occurred.", "type": "array", "items": { "type": "string" } } }, "id": "Xss" }, "Authentication": { "description": "Scan authentication configuration.", "type": "object", "properties": { "googleAccount": { "$ref": "GoogleAccount", "description": "Authentication using a Google account." }, "customAccount": { "$ref": "CustomAccount", "description": "Authentication using a custom account." } }, "id": "Authentication" }, "VulnerableParameters": { "id": "VulnerableParameters", "description": "Information about vulnerable request parameters.", "type": "object", "properties": { "parameterNames": { "description": "The vulnerable parameter names.", "type": "array", "items": { "type": "string" } } } }, "GoogleAccount": { "description": "Describes authentication configuration that uses a Google account.", "type": "object", "properties": { "username": { "type": "string", "description": "Required.\nThe user name of the Google account." }, "password": { "description": "Input only.\nRequired.\nThe password of the Google account. The credential is stored encrypted\nand not returned in any response nor included in audit logs.", "type": "string" } }, "id": "GoogleAccount" }, "VulnerableHeaders": { "type": "object", "properties": { "headers": { "description": "List of vulnerable headers.", "type": "array", "items": { "$ref": "Header" } }, "missingHeaders": { "description": "List of missing headers.", "type": "array", "items": { "$ref": "Header" } } }, "id": "VulnerableHeaders", "description": "Information about vulnerable or missing HTTP Headers." }, "ListCrawledUrlsResponse": { "type": "object", "properties": { "crawledUrls": { "description": "The list of CrawledUrls returned.", "type": "array", "items": { "$ref": "CrawledUrl" } }, "nextPageToken": { "description": "Token to retrieve the next page of results, or empty if there are no\nmore results in the list.", "type": "string" } }, "id": "ListCrawledUrlsResponse", "description": "Response for the `ListCrawledUrls` method." }, "ScanConfigError": { "description": "Defines a custom error message used by CreateScanConfig and UpdateScanConfig\nAPIs when scan configuration validation fails. It is also reported as part of\na ScanRunErrorTrace message if scan validation fails due to a scan\nconfiguration error.", "type": "object", "properties": { "fieldName": { "description": "Output only.\nIndicates the full name of the ScanConfig field that triggers this error,\nfor example \"scan_config.max_qps\". This field is provided for\ntroubleshooting purposes only and its actual value can change in the\nfuture.", "type": "string" }, "code": { "enum": ["CODE_UNSPECIFIED", "OK", "INTERNAL_ERROR", "APPENGINE_API_BACKEND_ERROR", "APPENGINE_API_NOT_ACCESSIBLE", "APPENGINE_DEFAULT_HOST_MISSING", "CANNOT_USE_GOOGLE_COM_ACCOUNT", "CANNOT_USE_OWNER_ACCOUNT", "COMPUTE_API_BACKEND_ERROR", "COMPUTE_API_NOT_ACCESSIBLE", "CUSTOM_LOGIN_URL_DOES_NOT_BELONG_TO_CURRENT_PROJECT", "CUSTOM_LOGIN_URL_MALFORMED", "CUSTOM_LOGIN_URL_MAPPED_TO_NON_ROUTABLE_ADDRESS", "CUSTOM_LOGIN_URL_MAPPED_TO_UNRESERVED_ADDRESS", "CUSTOM_LOGIN_URL_HAS_NON_ROUTABLE_IP_ADDRESS", "CUSTOM_LOGIN_URL_HAS_UNRESERVED_IP_ADDRESS", "DUPLICATE_SCAN_NAME", "INVALID_FIELD_VALUE", "FAILED_TO_AUTHENTICATE_TO_TARGET", "FINDING_TYPE_UNSPECIFIED", "FORBIDDEN_TO_SCAN_COMPUTE", "MALFORMED_FILTER", "MALFORMED_RESOURCE_NAME", "PROJECT_INACTIVE", "REQUIRED_FIELD", "RESOURCE_NAME_INCONSISTENT", "SCAN_ALREADY_RUNNING", "SCAN_NOT_RUNNING", "SEED_URL_DOES_NOT_BELONG_TO_CURRENT_PROJECT", "SEED_URL_MALFORMED", "SEED_URL_MAPPED_TO_NON_ROUTABLE_ADDRESS", "SEED_URL_MAPPED_TO_UNRESERVED_ADDRESS", "SEED_URL_HAS_NON_ROUTABLE_IP_ADDRESS", "SEED_URL_HAS_UNRESERVED_IP_ADDRESS", "SERVICE_ACCOUNT_NOT_CONFIGURED", "TOO_MANY_SCANS", "UNABLE_TO_RESOLVE_PROJECT_INFO", "UNSUPPORTED_BLACKLIST_PATTERN_FORMAT", "UNSUPPORTED_FILTER", "UNSUPPORTED_FINDING_TYPE", "UNSUPPORTED_URL_SCHEME"], "description": "Output only.\nIndicates the reason code for a configuration failure.", "type": "string", "enumDescriptions": ["There is no error.", "There is no error.", "Indicates an internal server error.\nPlease DO NOT USE THIS ERROR CODE unless the root cause is truly unknown.", "One of the seed URLs is an App Engine URL but we cannot validate the scan\nsettings due to an App Engine API backend error.", "One of the seed URLs is an App Engine URL but we cannot access the\nApp Engine API to validate scan settings.", "One of the seed URLs is an App Engine URL but the Default Host of the\nApp Engine is not set.", "Google corporate accounts can not be used for scanning.", "The account of the scan creator can not be used for scanning.", "This scan targets Compute Engine, but we cannot validate scan settings\ndue to a Compute Engine API backend error.", "This scan targets Compute Engine, but we cannot access the Compute Engine\nAPI to validate the scan settings.", "The Custom Login URL does not belong to the current project.", "The Custom Login URL is malformed (can not be parsed).", "The Custom Login URL is mapped to a non-routable IP address in DNS.", "The Custom Login URL is mapped to an IP address which is not reserved for\nthe current project.", "The Custom Login URL has a non-routable IP address.", "The Custom Login URL has an IP address which is not reserved for the\ncurrent project.", "Another scan with the same name (case-sensitive) already exists.", "A field is set to an invalid value.", "There was an error trying to authenticate to the scan target.", "Finding type value is not specified in the list findings request.", "Scan targets Compute Engine, yet current project was not whitelisted for\nGoogle Compute Engine Scanning Alpha access.", "The supplied filter is malformed. For example, it can not be parsed, does\nnot have a filter type in expression, or the same filter type appears\nmore than once.", "The supplied resource name is malformed (can not be parsed).", "The current project is not in an active state.", "A required field is not set.", "Project id, scanconfig id, scanrun id, or finding id are not consistent\nwith each other in resource name.", "The scan being requested to start is already running.", "The scan that was requested to be stopped is not running.", "One of the seed URLs does not belong to the current project.", "One of the seed URLs is malformed (can not be parsed).", "One of the seed URLs is mapped to a non-routable IP address in DNS.", "One of the seed URLs is mapped to an IP address which is not reserved\nfor the current project.", "One of the seed URLs has on-routable IP address.", "One of the seed URLs has an IP address that is not reserved\nfor the current project.", "The Cloud Security Scanner service account is not configured under the\nproject.", "A project has reached the maximum number of scans.", "Resolving the details of the current project fails.", "One or more blacklist patterns were in the wrong format.", "The supplied filter is not supported.", "The supplied finding type is not supported. For example, we do not\nprovide findings of the given finding type.", "The URL scheme of one or more of the supplied URLs is not supported."] } }, "id": "ScanConfigError" } }, "protocol": "rest", "icons": { "x16": "http://www.google.com/images/icons/product/search-16.gif", "x32": "http://www.google.com/images/icons/product/search-32.gif" }, "canonicalName": "WebSecurityScanner", "auth": { "oauth2": { "scopes": { "https://www.googleapis.com/auth/cloud-platform": { "description": "View and manage your data across Google Cloud Platform services" } } } }, "rootUrl": "https://websecurityscanner.googleapis.com/", "ownerDomain": "google.com", "name": "websecurityscanner", "batchPath": "batch", "fullyEncodeReservedExpansion": true, "title": "Web Security Scanner API", "ownerName": "Google", "resources": { "projects": { "resources": { "scanConfigs": { "methods": { "delete": { "flatPath": "v1beta/projects/{projectsId}/scanConfigs/{scanConfigsId}", "path": "v1beta/{+name}", "id": "websecurityscanner.projects.scanConfigs.delete", "description": "Deletes an existing ScanConfig and its child resources.", "response": { "$ref": "Empty" }, "parameterOrder": ["name"], "httpMethod": "DELETE", "parameters": { "name": { "pattern": "^projects/[^/]+/scanConfigs/[^/]+$", "location": "path", "description": "Required.\nThe resource name of the ScanConfig to be deleted. The name follows the\nformat of 'projects/{projectId}/scanConfigs/{scanConfigId}'.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] }, "list": { "httpMethod": "GET", "parameterOrder": ["parent"], "response": { "$ref": "ListScanConfigsResponse" }, "parameters": { "pageToken": { "description": "A token identifying a page of results to be returned. This should be a\n`next_page_token` value returned from a previous List request.\nIf unspecified, the first page of results is returned.", "type": "string", "location": "query" }, "pageSize": { "location": "query", "description": "The maximum number of ScanConfigs to return, can be limited by server.\nIf not specified or not positive, the implementation will select a\nreasonable value.", "format": "int32", "type": "integer" }, "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path", "description": "Required.\nThe parent resource name, which should be a project resource name in the\nformat 'projects/{projectId}'." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta/projects/{projectsId}/scanConfigs", "id": "websecurityscanner.projects.scanConfigs.list", "path": "v1beta/{+parent}/scanConfigs", "description": "Lists ScanConfigs under a given project." }, "create": { "response": { "$ref": "ScanConfig" }, "parameterOrder": ["parent"], "httpMethod": "POST", "parameters": { "parent": { "required": true, "type": "string", "pattern": "^projects/[^/]+$", "location": "path", "description": "Required.\nThe parent resource name where the scan is created, which should be a\nproject resource name in the format 'projects/{projectId}'." } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta/projects/{projectsId}/scanConfigs", "path": "v1beta/{+parent}/scanConfigs", "id": "websecurityscanner.projects.scanConfigs.create", "description": "Creates a new ScanConfig.", "request": { "$ref": "ScanConfig" } }, "get": { "response": { "$ref": "ScanConfig" }, "parameterOrder": ["name"], "httpMethod": "GET", "parameters": { "name": { "pattern": "^projects/[^/]+/scanConfigs/[^/]+$", "location": "path", "description": "Required.\nThe resource name of the ScanConfig to be returned. The name follows the\nformat of 'projects/{projectId}/scanConfigs/{scanConfigId}'.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta/projects/{projectsId}/scanConfigs/{scanConfigsId}", "path": "v1beta/{+name}", "id": "websecurityscanner.projects.scanConfigs.get", "description": "Gets a ScanConfig." }, "patch": { "httpMethod": "PATCH", "parameterOrder": ["name"], "response": { "$ref": "ScanConfig" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "updateMask": { "location": "query", "description": "Required.\nThe update mask applies to the resource. For the `FieldMask` definition,\nsee\nhttps://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask", "format": "google-fieldmask", "type": "string" }, "name": { "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+$", "location": "path", "description": "The resource name of the ScanConfig. The name follows the format of\n'projects/{projectId}/scanConfigs/{scanConfigId}'. The ScanConfig IDs are\ngenerated by the system." } }, "flatPath": "v1beta/projects/{projectsId}/scanConfigs/{scanConfigsId}", "id": "websecurityscanner.projects.scanConfigs.patch", "path": "v1beta/{+name}", "request": { "$ref": "ScanConfig" }, "description": "Updates a ScanConfig. This method support partial update of a ScanConfig." }, "start": { "response": { "$ref": "ScanRun" }, "parameterOrder": ["name"], "httpMethod": "POST", "parameters": { "name": { "description": "Required.\nThe resource name of the ScanConfig to be used. The name follows the\nformat of 'projects/{projectId}/scanConfigs/{scanConfigId}'.", "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+$", "location": "path" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta/projects/{projectsId}/scanConfigs/{scanConfigsId}:start", "path": "v1beta/{+name}:start", "id": "websecurityscanner.projects.scanConfigs.start", "description": "Start a ScanRun according to the given ScanConfig.", "request": { "$ref": "StartScanRunRequest" } } }, "resources": { "scanRuns": { "methods": { "get": { "response": { "$ref": "ScanRun" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "location": "path", "description": "Required.\nThe resource name of the ScanRun to be returned. The name follows the\nformat of\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.", "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$" } }, "flatPath": "v1beta/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}", "path": "v1beta/{+name}", "id": "websecurityscanner.projects.scanConfigs.scanRuns.get", "description": "Gets a ScanRun." }, "list": { "id": "websecurityscanner.projects.scanConfigs.scanRuns.list", "path": "v1beta/{+parent}/scanRuns", "description": "Lists ScanRuns under a given ScanConfig, in descending order of ScanRun\nstop time.", "httpMethod": "GET", "parameterOrder": ["parent"], "response": { "$ref": "ListScanRunsResponse" }, "parameters": { "parent": { "location": "path", "description": "Required.\nThe parent resource name, which should be a scan resource name in the\nformat 'projects/{projectId}/scanConfigs/{scanConfigId}'.", "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+$" }, "pageToken": { "location": "query", "description": "A token identifying a page of results to be returned. This should be a\n`next_page_token` value returned from a previous List request.\nIf unspecified, the first page of results is returned.", "type": "string" }, "pageSize": { "description": "The maximum number of ScanRuns to return, can be limited by server.\nIf not specified or not positive, the implementation will select a\nreasonable value.", "format": "int32", "type": "integer", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns" }, "stop": { "httpMethod": "POST", "parameterOrder": ["name"], "response": { "$ref": "ScanRun" }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$", "location": "path", "description": "Required.\nThe resource name of the ScanRun to be stopped. The name follows the\nformat of\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'." } }, "flatPath": "v1beta/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}:stop", "id": "websecurityscanner.projects.scanConfigs.scanRuns.stop", "path": "v1beta/{+name}:stop", "request": { "$ref": "StopScanRunRequest" }, "description": "Stops a ScanRun. The stopped ScanRun is returned." } }, "resources": { "crawledUrls": { "methods": { "list": { "description": "List CrawledUrls under a given ScanRun.", "response": { "$ref": "ListCrawledUrlsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "parent": { "description": "Required.\nThe parent resource name, which should be a scan run resource name in the\nformat\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.", "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$", "location": "path" }, "pageToken": { "type": "string", "location": "query", "description": "A token identifying a page of results to be returned. This should be a\n`next_page_token` value returned from a previous List request.\nIf unspecified, the first page of results is returned." }, "pageSize": { "location": "query", "description": "The maximum number of CrawledUrls to return, can be limited by server.\nIf not specified or not positive, the implementation will select a\nreasonable value.", "format": "int32", "type": "integer" } }, "flatPath": "v1beta/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}/crawledUrls", "path": "v1beta/{+parent}/crawledUrls", "id": "websecurityscanner.projects.scanConfigs.scanRuns.crawledUrls.list" } } }, "findingTypeStats": { "methods": { "list": { "response": { "$ref": "ListFindingTypeStatsResponse" }, "parameterOrder": ["parent"], "httpMethod": "GET", "parameters": { "parent": { "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$", "location": "path", "description": "Required.\nThe parent resource name, which should be a scan run resource name in the\nformat\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.", "required": true, "type": "string" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "flatPath": "v1beta/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}/findingTypeStats", "path": "v1beta/{+parent}/findingTypeStats", "id": "websecurityscanner.projects.scanConfigs.scanRuns.findingTypeStats.list", "description": "List all FindingTypeStats under a given ScanRun." } } }, "findings": { "methods": { "get": { "flatPath": "v1beta/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}/findings/{findingsId}", "path": "v1beta/{+name}", "id": "websecurityscanner.projects.scanConfigs.scanRuns.findings.get", "description": "Gets a Finding.", "response": { "$ref": "Finding" }, "parameterOrder": ["name"], "httpMethod": "GET", "scopes": ["https://www.googleapis.com/auth/cloud-platform"], "parameters": { "name": { "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+/findings/[^/]+$", "location": "path", "description": "Required.\nThe resource name of the Finding to be returned. The name follows the\nformat of\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}/findings/{findingId}'." } } }, "list": { "flatPath": "v1beta/projects/{projectsId}/scanConfigs/{scanConfigsId}/scanRuns/{scanRunsId}/findings", "id": "websecurityscanner.projects.scanConfigs.scanRuns.findings.list", "path": "v1beta/{+parent}/findings", "description": "List Findings under a given ScanRun.", "httpMethod": "GET", "parameterOrder": ["parent"], "response": { "$ref": "ListFindingsResponse" }, "parameters": { "pageToken": { "type": "string", "location": "query", "description": "A token identifying a page of results to be returned. This should be a\n`next_page_token` value returned from a previous List request.\nIf unspecified, the first page of results is returned." }, "pageSize": { "description": "The maximum number of Findings to return, can be limited by server.\nIf not specified or not positive, the implementation will select a\nreasonable value.", "format": "int32", "type": "integer", "location": "query" }, "parent": { "location": "path", "description": "Required.\nThe parent resource name, which should be a scan run resource name in the\nformat\n'projects/{projectId}/scanConfigs/{scanConfigId}/scanRuns/{scanRunId}'.", "required": true, "type": "string", "pattern": "^projects/[^/]+/scanConfigs/[^/]+/scanRuns/[^/]+$" }, "filter": { "description": "The filter expression. The expression must be in the format: <field>\n<operator> <value>.\nSupported field: 'finding_type'.\nSupported operator: '='.", "type": "string", "location": "query" } }, "scopes": ["https://www.googleapis.com/auth/cloud-platform"] } } } } } } } } } }, "parameters": { "fields": { "location": "query", "description": "Selector specifying which fields to include in a partial response.", "type": "string" }, "uploadType": { "location": "query", "description": "Legacy upload protocol for media (e.g. \"media\", \"multipart\").", "type": "string" }, "callback": { "location": "query", "description": "JSONP", "type": "string" }, "oauth_token": { "type": "string", "location": "query", "description": "OAuth 2.0 token for the current user." }, "$.xgafv": { "description": "V1 error format.", "type": "string", "enumDescriptions": ["v1 error format", "v2 error format"], "location": "query", "enum": ["1", "2"] }, "alt": { "type": "string", "enumDescriptions": ["Responses with Content-Type of application/json", "Media download with context-dependent Content-Type", "Responses with Content-Type of application/x-protobuf"], "location": "query", "description": "Data format for response.", "default": "json", "enum": ["json", "media", "proto"] }, "access_token": { "location": "query", "description": "OAuth access token.", "type": "string" }, "key": { "type": "string", "location": "query", "description": "API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token." }, "upload_protocol": { "location": "query", "description": "Upload protocol for media (e.g. \"raw\", \"multipart\").", "type": "string" }, "quotaUser": { "location": "query", "description": "Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.", "type": "string" }, "prettyPrint": { "location": "query", "description": "Returns response with indentations and line breaks.", "type": "boolean", "default": "true" } }, "version": "v1beta", "baseUrl": "https://websecurityscanner.googleapis.com/", "servicePath": "", "description": "Scans your Compute and App Engine apps for common web vulnerabilities.", "kind": "discovery#restDescription" };
//# sourceMappingURL=websecurityscanner-v1beta.js.map