export default {"discoveryVersion":"v1","version_module":true,"schemas":{"Pivot":{"description":"The Pivot describes the pivot section in the request.\nThe Pivot helps rearrange the information in the table for certain reports\nby pivoting your data on a second dimension.","type":"object","properties":{"dimensions":{"description":"A list of dimensions to show as pivot columns. A Pivot can have a maximum\nof 4 dimensions. Pivot dimensions are part of the restriction on the\ntotal number of dimensions allowed in the request.","type":"array","items":{"$ref":"Dimension"}},"dimensionFilterClauses":{"type":"array","items":{"$ref":"DimensionFilterClause"},"description":"DimensionFilterClauses are logically combined with an `AND` operator: only\ndata that is included by all these DimensionFilterClauses contributes to\nthe values in this pivot region. Dimension filters can be used to restrict\nthe columns shown in the pivot region. For example if you have\n`ga:browser` as the requested dimension in the pivot region, and you\nspecify key filters to restrict `ga:browser` to only \"IE\" or \"Firefox\",\nthen only those two browsers would show up as columns."},"maxGroupCount":{"description":"Specifies the maximum number of groups to return.\nThe default value is 10, also the maximum value is 1,000.","format":"int32","type":"integer"},"startGroup":{"type":"integer","description":"If k metrics were requested, then the response will contain some\ndata-dependent multiple of k columns in the report.  E.g., if you pivoted\non the dimension `ga:browser` then you'd get k columns for \"Firefox\", k\ncolumns for \"IE\", k columns for \"Chrome\", etc. The ordering of the groups\nof columns is determined by descending order of \"total\" for the first of\nthe k values.  Ties are broken by lexicographic ordering of the first\npivot dimension, then lexicographic ordering of the second pivot\ndimension, and so on.  E.g., if the totals for the first value for\nFirefox, IE, and Chrome were 8, 2, 8, respectively, the order of columns\nwould be Chrome, Firefox, IE.\n\nThe following let you choose which of the groups of k columns are\nincluded in the response.","format":"int32"},"metrics":{"description":"The pivot metrics. Pivot metrics are part of the\nrestriction on total number of metrics allowed in the request.","type":"array","items":{"$ref":"Metric"}}},"id":"Pivot"},"ProductData":{"properties":{"productName":{"description":"The product name, supplied by the e-commerce tracking application, for\nthe purchased items.","type":"string"},"productSku":{"description":"Unique code that represents the product.","type":"string"},"itemRevenue":{"description":"The total revenue from purchased product items.","format":"double","type":"number"},"productQuantity":{"description":"Total number of this product units in the transaction.","format":"int64","type":"string"}},"id":"ProductData","description":"Details of the products in an e-commerce transaction.","type":"object"},"PivotHeaderEntry":{"description":"The headers for the each of the metric column corresponding to the metrics\nrequested in the pivots section of the response.","type":"object","properties":{"dimensionNames":{"description":"The name of the dimensions in the pivot response.","type":"array","items":{"type":"string"}},"metric":{"$ref":"MetricHeaderEntry","description":"The metric header for the metric in the pivot."},"dimensionValues":{"description":"The values for the dimensions in the pivot.","type":"array","items":{"type":"string"}}},"id":"PivotHeaderEntry"},"SearchUserActivityResponse":{"type":"object","properties":{"sessions":{"description":"Each record represents a session (device details, duration, etc).","type":"array","items":{"$ref":"UserActivitySession"}},"totalRows":{"description":"Total rows returned by this query (across different pages).","format":"int32","type":"integer"},"sampleRate":{"description":"This field represents the\n[sampling rate](https://support.google.com/analytics/answer/2637192) for\nthe given request and is a number between 0.0 to 1.0. See\n[developer guide](/analytics/devguides/reporting/core/v4/basics#sampling)\nfor details.","format":"double","type":"number"},"nextPageToken":{"description":"This token should be passed to\n[SearchUserActivityRequest](#SearchUserActivityRequest) to retrieve the\nnext page.","type":"string"}},"id":"SearchUserActivityResponse","description":"The response from `userActivity:get` call."},"SegmentFilter":{"id":"SegmentFilter","description":"SegmentFilter defines the segment to be either a simple or a sequence\nsegment. A simple segment condition contains dimension and metric conditions\nto select the sessions or users. A sequence segment condition can be used to\nselect users or sessions based on sequential conditions.","type":"object","properties":{"not":{"description":"If true, match the complement of simple or sequence segment.\nFor example, to match all visits not from \"New York\", we can define the\nsegment as follows:\n\n      \"sessionSegment\": {\n        \"segmentFilters\": [{\n          \"simpleSegment\" :{\n            \"orFiltersForSegment\": [{\n              \"segmentFilterClauses\":[{\n                \"dimensionFilter\": {\n                  \"dimensionName\": \"ga:city\",\n                  \"expressions\": [\"New York\"]\n                }\n              }]\n            }]\n          },\n          \"not\": \"True\"\n        }]\n      },","type":"boolean"},"simpleSegment":{"description":"A Simple segment conditions consist of one or more dimension/metric\nconditions that can be combined","$ref":"SimpleSegment"},"sequenceSegment":{"$ref":"SequenceSegment","description":"Sequence conditions consist of one or more steps, where each step is\ndefined by one or more dimension/metric conditions. Multiple steps can\nbe combined with special sequence operators."}}},"SegmentDefinition":{"description":"SegmentDefinition defines the segment to be a set of SegmentFilters which\nare combined together with a logical `AND` operation.","type":"object","properties":{"segmentFilters":{"description":"A segment is defined by a set of segment filters which are combined\ntogether with a logical `AND` operation.","type":"array","items":{"$ref":"SegmentFilter"}}},"id":"SegmentDefinition"},"ResourceQuotasRemaining":{"description":"The resource quota tokens remaining for the property after the request is\ncompleted.","type":"object","properties":{"hourlyQuotaTokensRemaining":{"description":"Hourly resource quota tokens remaining.","format":"int32","type":"integer"},"dailyQuotaTokensRemaining":{"description":"Daily resource quota remaining remaining.","format":"int32","type":"integer"}},"id":"ResourceQuotasRemaining"},"ReportData":{"description":"The data part of the report.","type":"object","properties":{"dataLastRefreshed":{"description":"The last time the data in the report was refreshed. All the hits received\nbefore this timestamp are included in the calculation of the report.","format":"google-datetime","type":"string"},"maximums":{"description":"Minimum and maximum values seen over all matching rows. These are both\nempty when `hideValueRanges` in the request is false, or when\nrowCount is zero.","type":"array","items":{"$ref":"DateRangeValues"}},"samplingSpaceSizes":{"description":"If the results are\n[sampled](https://support.google.com/analytics/answer/2637192),\nthis returns the total number of\nsamples present, one entry per date range. If the results are not sampled\nthis field will not be defined. See\n[developer guide](/analytics/devguides/reporting/core/v4/basics#sampling)\nfor details.","type":"array","items":{"format":"int64","type":"string"}},"minimums":{"description":"Minimum and maximum values seen over all matching rows. These are both\nempty when `hideValueRanges` in the request is false, or when\nrowCount is zero.","type":"array","items":{"$ref":"DateRangeValues"}},"totals":{"description":"For each requested date range, for the set of all rows that match\nthe query, every requested value format gets a total. The total\nfor a value format is computed by first totaling the metrics\nmentioned in the value format and then evaluating the value\nformat as a scalar expression.  E.g., The \"totals\" for\n`3 / (ga:sessions + 2)` we compute\n`3 / ((sum of all relevant ga:sessions) + 2)`.\nTotals are computed before pagination.","type":"array","items":{"$ref":"DateRangeValues"}},"samplesReadCounts":{"description":"If the results are\n[sampled](https://support.google.com/analytics/answer/2637192),\nthis returns the total number of samples read, one entry per date range.\nIf the results are not sampled this field will not be defined. See\n[developer guide](/analytics/devguides/reporting/core/v4/basics#sampling)\nfor details.","type":"array","items":{"format":"int64","type":"string"}},"rowCount":{"description":"Total number of matching rows for this query.","format":"int32","type":"integer"},"rows":{"type":"array","items":{"$ref":"ReportRow"},"description":"There's one ReportRow for every unique combination of dimensions."},"isDataGolden":{"description":"Indicates if response to this request is golden or not. Data is\ngolden when the exact same request will not produce any new results if\nasked at a later point in time.","type":"boolean"}},"id":"ReportData"},"DimensionFilter":{"type":"object","properties":{"dimensionName":{"description":"The dimension to filter on. A DimensionFilter must contain a dimension.","type":"string"},"operator":{"description":"How to match the dimension to the expression. The default is REGEXP.","type":"string","enumDescriptions":["If the match type is unspecified, it is treated as a `REGEXP`.","The match expression is treated as a regular expression. All match types\nare not treated as regular expressions.","Matches the value which begin with the match expression provided.","Matches the values which end with the match expression provided.","Substring match.","The value should match the match expression entirely.","Integer comparison filters.\ncase sensitivity is ignored for these and the expression\nis assumed to be a string representing an integer.\nFailure conditions:\n\n- If expression is not a valid int64, the client should expect\n  an error.\n- Input dimensions that are not valid int64 values will never match the\n  filter.","Checks if the dimension is numerically greater than the match\nexpression. Read the description for `NUMERIC_EQUALS` for restrictions.","Checks if the dimension is numerically less than the match expression.\nRead the description for `NUMERIC_EQUALS` for restrictions.","This option is used to specify a dimension filter whose expression can\ntake any value from a selected list of values. This helps avoiding\nevaluating multiple exact match dimension filters which are OR'ed for\nevery single response row. For example:\n\n    expressions: [\"A\", \"B\", \"C\"]\n\nAny response row whose dimension has it is value as A, B or C, matches\nthis DimensionFilter."],"enum":["OPERATOR_UNSPECIFIED","REGEXP","BEGINS_WITH","ENDS_WITH","PARTIAL","EXACT","NUMERIC_EQUAL","NUMERIC_GREATER_THAN","NUMERIC_LESS_THAN","IN_LIST"]},"not":{"description":"Logical `NOT` operator. If this boolean is set to true, then the matching\ndimension values will be excluded in the report. The default is false.","type":"boolean"},"expressions":{"description":"Strings or regular expression to match against. Only the first value of\nthe list is used for comparison unless the operator is `IN_LIST`.\nIf `IN_LIST` operator, then the entire list is used to filter the\ndimensions as explained in the description of the `IN_LIST` operator.","type":"array","items":{"type":"string"}},"caseSensitive":{"description":"Should the match be case sensitive? Default is false.","type":"boolean"}},"id":"DimensionFilter","description":"Dimension filter specifies the filtering options on a dimension."},"PageviewData":{"type":"object","properties":{"pageTitle":{"type":"string","description":"The title of the page that the visitor viewed."},"pagePath":{"description":"The URL of the page that the visitor viewed.","type":"string"}},"id":"PageviewData","description":"Represents details collected when the visitor views a page."},"EventData":{"description":"Represents all the details pertaining to an event.","type":"object","properties":{"eventCategory":{"description":"The object on the page that was interacted with. Eg: 'Video'.","type":"string"},"eventCount":{"description":"Number of such events in this activity.","format":"int64","type":"string"},"eventLabel":{"description":"Label attached with the event.","type":"string"},"eventValue":{"description":"Numeric value associated with the event.","format":"int64","type":"string"},"eventAction":{"type":"string","description":"Type of interaction with the object. Eg: 'play'."}},"id":"EventData"},"OrderBy":{"description":"Specifies the sorting options.","type":"object","properties":{"fieldName":{"description":"The field which to sort by. The default sort order is ascending. Example:\n`ga:browser`.\nNote, that you can only specify one field for sort here. For example,\n`ga:browser, ga:city` is not valid.","type":"string"},"orderType":{"enumDescriptions":["Unspecified order type will be treated as sort based on value.","The sort order is based on the value of the chosen column; looks only at\nthe first date range.","The sort order is based on the difference of the values of the chosen\ncolumn between the first two date ranges.  Usable only if there are\nexactly two date ranges.","The sort order is based on weighted value of the chosen column.  If\ncolumn has n/d format, then weighted value of this ratio will\nbe `(n + totals.n)/(d + totals.d)` Usable only for metrics that\nrepresent ratios.","Histogram order type is applicable only to dimension columns with\nnon-empty histogram-buckets.","If the dimensions are fixed length numbers, ordinary sort would just\nwork fine. `DIMENSION_AS_INTEGER` can be used if the dimensions are\nvariable length numbers."],"enum":["ORDER_TYPE_UNSPECIFIED","VALUE","DELTA","SMART","HISTOGRAM_BUCKET","DIMENSION_AS_INTEGER"],"description":"The order type. The default orderType is `VALUE`.","type":"string"},"sortOrder":{"enumDescriptions":["If the sort order is unspecified, the default is ascending.","Ascending sort. The field will be sorted in an ascending manner.","Descending sort. The field will be sorted in a descending manner."],"enum":["SORT_ORDER_UNSPECIFIED","ASCENDING","DESCENDING"],"description":"The sorting order for the field.","type":"string"}},"id":"OrderBy"},"SegmentSequenceStep":{"id":"SegmentSequenceStep","description":"A segment sequence definition.","type":"object","properties":{"orFiltersForSegment":{"description":"A sequence is specified with a list of Or grouped filters which are\ncombined with `AND` operator.","type":"array","items":{"$ref":"OrFiltersForSegment"}},"matchType":{"enum":["UNSPECIFIED_MATCH_TYPE","PRECEDES","IMMEDIATELY_PRECEDES"],"description":"Specifies if the step immediately precedes or can be any time before the\nnext step.","type":"string","enumDescriptions":["Unspecified match type is treated as precedes.","Operator indicates that the previous step precedes the next step.","Operator indicates that the previous step immediately precedes the next\nstep."]}}},"Metric":{"description":"[Metrics](https://support.google.com/analytics/answer/1033861)\nare the quantitative measurements. For example, the metric `ga:users`\nindicates the total number of users for the requested time period.","type":"object","properties":{"formattingType":{"type":"string","enumDescriptions":["Metric type is unspecified.","Integer metric.","Float metric.","Currency metric.","Percentage metric.","Time metric in `HH:MM:SS` format."],"enum":["METRIC_TYPE_UNSPECIFIED","INTEGER","FLOAT","CURRENCY","PERCENT","TIME"],"description":"Specifies how the metric expression should be formatted, for example\n`INTEGER`."},"alias":{"type":"string","description":"An alias for the metric expression is an alternate name for the\nexpression. The alias can be used for filtering and sorting. This field\nis optional and is useful if the expression is not a single metric but\na complex expression which cannot be used in filtering and sorting.\nThe alias is also used in the response column header."},"expression":{"type":"string","description":"A metric expression in the request. An expression is constructed from one\nor more metrics and numbers. Accepted operators include: Plus (+), Minus\n(-), Negation (Unary -), Divided by (/), Multiplied by (*), Parenthesis,\nPositive cardinal numbers (0-9), can include decimals and is limited to\n1024 characters. Example `ga:totalRefunds/ga:users`, in most cases the\nmetric expression is just a single metric name like `ga:users`.\nAdding mixed `MetricType` (E.g., `CURRENCY` + `PERCENTAGE`) metrics\nwill result in unexpected results."}},"id":"Metric"},"DateRange":{"type":"object","properties":{"startDate":{"type":"string","description":"The start date for the query in the format `YYYY-MM-DD`."},"endDate":{"description":"The end date for the query in the format `YYYY-MM-DD`.","type":"string"}},"id":"DateRange","description":"A contiguous set of days: startDate, startDate + 1 day, ..., endDate.\nThe start and end dates are specified in\n[ISO8601](https://en.wikipedia.org/wiki/ISO_8601) date format `YYYY-MM-DD`."},"MetricFilter":{"description":"MetricFilter specifies the filter on a metric.","type":"object","properties":{"comparisonValue":{"type":"string","description":"The value to compare against."},"operator":{"description":"Is the metric `EQUAL`, `LESS_THAN` or `GREATER_THAN` the\ncomparisonValue, the default is `EQUAL`. If the operator is\n`IS_MISSING`, checks if the metric is missing and would ignore the\ncomparisonValue.","type":"string","enumDescriptions":["If the operator is not specified, it is treated as `EQUAL`.","Should the value of the metric be exactly equal to the comparison value.","Should the value of the metric be less than to the comparison value.","Should the value of the metric be greater than to the comparison value.","Validates if the metric is missing.\nDoesn't take comparisonValue into account."],"enum":["OPERATOR_UNSPECIFIED","EQUAL","LESS_THAN","GREATER_THAN","IS_MISSING"]},"not":{"description":"Logical `NOT` operator. If this boolean is set to true, then the matching\nmetric values will be excluded in the report. The default is false.","type":"boolean"},"metricName":{"description":"The metric that will be filtered on. A metricFilter must contain a metric\nname. A metric name can be an alias earlier defined as a metric or it can\nalso be a metric expression.","type":"string"}},"id":"MetricFilter"},"ReportRequest":{"description":"The main request class which specifies the Reporting API request.","type":"object","properties":{"pivots":{"description":"The pivot definitions. Requests can have a maximum of 2 pivots.","type":"array","items":{"$ref":"Pivot"}},"includeEmptyRows":{"description":"If set to false, the response does not include rows if all the retrieved\nmetrics are equal to zero. The default is false which will exclude these\nrows.","type":"boolean"},"metricFilterClauses":{"description":"The metric filter clauses. They are logically combined with the `AND`\noperator.  Metric filters look at only the first date range and not the\ncomparing date range. Note that filtering on metrics occurs after the\nmetrics are aggregated.","type":"array","items":{"$ref":"MetricFilterClause"}},"pageSize":{"description":"Page size is for paging and specifies the maximum number of returned rows.\nPage size should be >= 0. A query returns the default of 1,000 rows.\nThe Analytics Core Reporting API returns a maximum of 100,000 rows per\nrequest, no matter how many you ask for. It can also return fewer rows\nthan requested, if there aren't as many dimension segments as you expect.\nFor instance, there are fewer than 300 possible values for `ga:country`,\nso when segmenting only by country, you can't get more than 300 rows,\neven if you set `pageSize` to a higher value.","format":"int32","type":"integer"},"hideValueRanges":{"description":"If set to true, hides the minimum and maximum across all matching rows.\nThe default is false and the value ranges are returned.","type":"boolean"},"hideTotals":{"description":"If set to true, hides the total of all metrics for all the matching rows,\nfor every date range. The default false and will return the totals.","type":"boolean"},"filtersExpression":{"description":"Dimension or metric filters that restrict the data returned for your\nrequest. To use the `filtersExpression`, supply a dimension or metric on\nwhich to filter, followed by the filter expression. For example, the\nfollowing expression selects `ga:browser` dimension which starts with\nFirefox; `ga:browser=~^Firefox`. For more information on dimensions\nand metric filters, see\n[Filters reference](https://developers.google.com/analytics/devguides/reporting/core/v3/reference#filters).","type":"string"},"cohortGroup":{"$ref":"CohortGroup","description":"Cohort group associated with this request. If there is a cohort group\nin the request the `ga:cohort` dimension must be present.\nEvery [ReportRequest](#ReportRequest) within a `batchGet` method must\ncontain the same `cohortGroup` definition."},"viewId":{"description":"The Analytics\n[view ID](https://support.google.com/analytics/answer/1009618)\nfrom which to retrieve data. Every [ReportRequest](#ReportRequest)\nwithin a `batchGet` method must contain the same `viewId`.","type":"string"},"metrics":{"description":"The metrics requested.\nRequests must specify at least one metric. Requests can have a\ntotal of 10 metrics.","type":"array","items":{"$ref":"Metric"}},"dimensionFilterClauses":{"description":"The dimension filter clauses for filtering Dimension Values. They are\nlogically combined with the `AND` operator. Note that filtering occurs\nbefore any dimensions are aggregated, so that the returned metrics\nrepresent the total for only the relevant dimensions.","type":"array","items":{"$ref":"DimensionFilterClause"}},"orderBys":{"description":"Sort order on output rows. To compare two rows, the elements of the\nfollowing are applied in order until a difference is found.  All date\nranges in the output get the same row order.","type":"array","items":{"$ref":"OrderBy"}},"segments":{"description":"Segment the data returned for the request. A segment definition helps look\nat a subset of the segment request. A request can contain up to four\nsegments. Every [ReportRequest](#ReportRequest) within a\n`batchGet` method must contain the same `segments` definition. Requests\nwith segments must have the `ga:segment` dimension.","type":"array","items":{"$ref":"Segment"}},"samplingLevel":{"description":"The desired report\n[sample](https://support.google.com/analytics/answer/2637192) size.\nIf the the `samplingLevel` field is unspecified the `DEFAULT` sampling\nlevel is used. Every [ReportRequest](#ReportRequest) within a\n`batchGet` method must contain the same `samplingLevel` definition. See\n[developer guide](/analytics/devguides/reporting/core/v4/basics#sampling)\n for details.","type":"string","enumDescriptions":["If the `samplingLevel` field is unspecified the `DEFAULT` sampling level\nis used.","Returns response with a sample size that balances speed and\naccuracy.","It returns a fast response with a smaller sampling size.","Returns a more accurate response using a large sampling size. But this\nmay result in response being slower."],"enum":["SAMPLING_UNSPECIFIED","DEFAULT","SMALL","LARGE"]},"dimensions":{"description":"The dimensions requested.\nRequests can have a total of 7 dimensions.","type":"array","items":{"$ref":"Dimension"}},"dateRanges":{"type":"array","items":{"$ref":"DateRange"},"description":"Date ranges in the request. The request can have a maximum of 2 date\nranges. The response will contain a set of metric values for each\ncombination of the dimensions for each date range in the request. So, if\nthere are two date ranges, there will be two set of metric values, one for\nthe original date range and one for the second date range.\nThe `reportRequest.dateRanges` field should not be specified for cohorts\nor Lifetime value requests.\nIf a date range is not provided, the default date range is (startDate:\ncurrent date - 7 days, endDate: current date - 1 day). Every\n[ReportRequest](#ReportRequest) within a `batchGet` method must\ncontain the same `dateRanges` definition."},"pageToken":{"description":"A continuation token to get the next page of the results. Adding this to\nthe request will return the rows after the pageToken. The pageToken should\nbe the value returned in the nextPageToken parameter in the response to\nthe GetReports request.","type":"string"}},"id":"ReportRequest"},"DynamicSegment":{"description":"Dynamic segment definition for defining the segment within the request.\nA segment can select users, sessions or both.","type":"object","properties":{"userSegment":{"description":"User Segment to select users to include in the segment.","$ref":"SegmentDefinition"},"sessionSegment":{"$ref":"SegmentDefinition","description":"Session Segment to select sessions to include in the segment."},"name":{"description":"The name of the dynamic segment.","type":"string"}},"id":"DynamicSegment"},"TransactionData":{"properties":{"transactionTax":{"description":"Total tax for the transaction.","format":"double","type":"number"},"transactionRevenue":{"description":"The total sale revenue (excluding shipping and tax) of the transaction.","format":"double","type":"number"},"transactionId":{"type":"string","description":"The transaction ID, supplied by the e-commerce tracking method, for the\npurchase in the shopping cart."},"transactionShipping":{"description":"Total cost of shipping.","format":"double","type":"number"}},"id":"TransactionData","description":"Represents details collected when the visitor performs a transaction on the\npage.","type":"object"},"Cohort":{"id":"Cohort","description":"Defines a cohort. A cohort is a group of users who share a common\ncharacteristic. For example, all users with the same acquisition date\nbelong to the same cohort.","type":"object","properties":{"type":{"enumDescriptions":["If unspecified it's treated as `FIRST_VISIT_DATE`.","Cohorts that are selected based on first visit date."],"enum":["UNSPECIFIED_COHORT_TYPE","FIRST_VISIT_DATE"],"description":"Type of the cohort. The only supported type as of now is\n`FIRST_VISIT_DATE`. If this field is unspecified the cohort is treated\nas `FIRST_VISIT_DATE` type cohort.","type":"string"},"name":{"description":"A unique name for the cohort. If not defined name will be auto-generated\nwith values cohort_[1234...].","type":"string"},"dateRange":{"description":"This is used for `FIRST_VISIT_DATE` cohort, the cohort selects users\nwhose first visit date is between start date and end date defined in the\nDateRange. The date ranges should be aligned for cohort requests. If the\nrequest contains `ga:cohortNthDay` it should be exactly one day long,\nif `ga:cohortNthWeek` it should be aligned to the week boundary (starting\nat Sunday and ending Saturday), and for `ga:cohortNthMonth` the date range\nshould be aligned to the month (starting at the first and ending on the\nlast day of the month).\nFor LTV requests there are no such restrictions.\nYou do not need to supply a date range for the\n`reportsRequest.dateRanges` field.","$ref":"DateRange"}}},"Activity":{"description":"An Activity represents data for an activity of a user. Note that an\nActivity is different from a hit.\nA hit might result in multiple Activity's. For example, if a hit\nincludes a transaction and a goal completion, there will be two\nActivity protos for this hit, one for ECOMMERCE and one for GOAL.\nConversely, multiple hits can also construct one Activity. In classic\ne-commerce, data for one transaction might be sent through multiple hits.\nThese hits will be merged into one ECOMMERCE Activity.","type":"object","properties":{"activityType":{"description":"Type of this activity.","type":"string","enumDescriptions":["ActivityType will never have this value in the response. Using this type in\nthe request will result in an error.","Used when the activity resulted out of a visitor viewing a page.","Used when the activity resulted out of a visitor using an application on a\nmobile device.","Used to denote that a goal type activity.","An e-commerce transaction was performed by the visitor on the page.","Used when the activity is an event."],"enum":["ACTIVITY_TYPE_UNSPECIFIED","PAGEVIEW","SCREENVIEW","GOAL","ECOMMERCE","EVENT"]},"event":{"$ref":"EventData","description":"This field contains all the details pertaining to an event and will be\nset if `activity_type` equals `EVENT`."},"appview":{"description":"This will be set if `activity_type` equals `SCREEN_VIEW`.","$ref":"ScreenviewData"},"activityTime":{"description":"Timestamp of the activity.","format":"google-datetime","type":"string"},"channelGrouping":{"description":"The Channel Group associated with an end user's session for this View\n(defined by the View's Channel Groupings).","type":"string"},"customDimension":{"description":"A list of all custom dimensions associated with this activity.","type":"array","items":{"$ref":"CustomDimension"}},"goals":{"description":"This field contains a list of all the goals that were reached in this\nactivity when `activity_type` equals `GOAL`.","$ref":"GoalSetData"},"pageview":{"description":"This will be set if `activity_type` equals `PAGEVIEW`. This field\ncontains all the details about the visitor and the page that was visited.","$ref":"PageviewData"},"medium":{"description":"The type of referrals. For manual campaign tracking, it is the value of the\nutm_medium campaign tracking parameter. For AdWords autotagging, it is cpc.\nIf users came from a search engine detected by Google Analytics, it is\norganic. If the referrer is not a search engine, it is referral. If users\ncame directly to the property and document.referrer is empty, its value is\n(none).","type":"string"},"campaign":{"description":"For manual campaign tracking, it is the value of the utm_campaign campaign\ntracking parameter. For AdWords autotagging, it is the name(s) of the\nonline ad campaign(s) you use for the property. If you use neither, its\nvalue is (not set).","type":"string"},"keyword":{"description":"For manual campaign tracking, it is the value of the utm_term campaign\ntracking parameter. For AdWords traffic, it contains the best matching\ntargeting criteria. For the display network, where multiple targeting\ncriteria could have caused the ad to show up, it returns the best matching\ntargeting criteria as selected by Ads. This could be display_keyword, site\nplacement, boomuserlist, user_interest, age, or gender. Otherwise its value\nis (not set).","type":"string"},"ecommerce":{"$ref":"EcommerceData","description":"This will be set if `activity_type` equals `ECOMMERCE`."},"source":{"description":"The source of referrals. For manual campaign tracking, it is the value of\nthe utm_source campaign tracking parameter. For AdWords autotagging, it is\ngoogle. If you use neither, it is the domain of the source\n(e.g., document.referrer) referring the users. It may also contain a port\naddress. If users arrived without a referrer, its value is (direct).","type":"string"},"landingPagePath":{"type":"string","description":"The first page in users' sessions, or the landing page."},"hostname":{"description":"The hostname from which the tracking request was made.","type":"string"}},"id":"Activity"},"DimensionFilterClause":{"description":"A group of dimension filters. Set the operator value to specify how\nthe filters are logically combined.","type":"object","properties":{"operator":{"enumDescriptions":["Unspecified operator. It is treated as an `OR`.","The logical `OR` operator.","The logical `AND` operator."],"enum":["OPERATOR_UNSPECIFIED","OR","AND"],"description":"The operator for combining multiple dimension filters. If unspecified, it\nis treated as an `OR`.","type":"string"},"filters":{"description":"The repeated set of filters. They are logically combined based on the\noperator specified.","type":"array","items":{"$ref":"DimensionFilter"}}},"id":"DimensionFilterClause"},"GetReportsResponse":{"description":"The main response class which holds the reports from the Reporting API\n`batchGet` call.","type":"object","properties":{"reports":{"description":"Responses corresponding to each of the request.","type":"array","items":{"$ref":"Report"}},"queryCost":{"description":"The amount of resource quota tokens deducted to execute the query. Includes\nall responses.","format":"int32","type":"integer"},"resourceQuotasRemaining":{"$ref":"ResourceQuotasRemaining","description":"The amount of resource quota remaining for the property."}},"id":"GetReportsResponse"},"SequenceSegment":{"id":"SequenceSegment","description":"Sequence conditions consist of one or more steps, where each step is defined\nby one or more dimension/metric conditions. Multiple steps can be combined\nwith special sequence operators.","type":"object","properties":{"segmentSequenceSteps":{"description":"The list of steps in the sequence.","type":"array","items":{"$ref":"SegmentSequenceStep"}},"firstStepShouldMatchFirstHit":{"description":"If set, first step condition must match the first hit of the visitor (in\nthe date range).","type":"boolean"}}},"User":{"type":"object","properties":{"userId":{"description":"Unique Id of the user for which the data is being requested.","type":"string"},"type":{"description":"Type of the user in the request. The field `userId` is associated with this\ntype.","type":"string","enumDescriptions":["When the User Id Type is not specified, the default type used will be\nCLIENT_ID.","A single user, like a signed-in user account, that may interact with\ncontent across one or more devices and / or browser instances.","Analytics assigned client_id."],"enum":["USER_ID_TYPE_UNSPECIFIED","USER_ID","CLIENT_ID"]}},"id":"User","description":"Contains information to identify a particular user uniquely."},"CohortGroup":{"description":"Defines a cohort group.\nFor example:\n\n    \"cohortGroup\": {\n      \"cohorts\": [{\n        \"name\": \"cohort 1\",\n        \"type\": \"FIRST_VISIT_DATE\",\n        \"dateRange\": { \"startDate\": \"2015-08-01\", \"endDate\": \"2015-08-01\" }\n      },{\n        \"name\": \"cohort 2\"\n         \"type\": \"FIRST_VISIT_DATE\"\n         \"dateRange\": { \"startDate\": \"2015-07-01\", \"endDate\": \"2015-07-01\" }\n      }]\n    }","type":"object","properties":{"cohorts":{"description":"The definition for the cohort.","type":"array","items":{"$ref":"Cohort"}},"lifetimeValue":{"description":"Enable Life Time Value (LTV).  LTV measures lifetime value for users\nacquired through different channels.\nPlease see:\n[Cohort Analysis](https://support.google.com/analytics/answer/6074676) and\n[Lifetime Value](https://support.google.com/analytics/answer/6182550)\nIf the value of lifetimeValue is false:\n\n- The metric values are similar to the values in the web interface cohort\n  report.\n- The cohort definition date ranges must be aligned to the calendar week\n  and month. i.e. while requesting `ga:cohortNthWeek` the `startDate` in\n  the cohort definition should be a Sunday and the `endDate` should be the\n  following Saturday, and for `ga:cohortNthMonth`, the `startDate`\n  should be the 1st of the month and `endDate` should be the last day\n  of the month.\n\nWhen the lifetimeValue is true:\n\n- The metric values will correspond to the values in the web interface\n  LifeTime value report.\n- The Lifetime Value report shows you how user value (Revenue) and\n  engagement (Appviews, Goal Completions, Sessions, and Session Duration)\n  grow during the 90 days after a user is acquired.\n- The metrics are calculated as a cumulative average per user per the time\n  increment.\n- The cohort definition date ranges need not be aligned to the calendar\n  week and month boundaries.\n- The `viewId` must be an\n  [app view ID](https://support.google.com/analytics/answer/2649553#WebVersusAppViews)","type":"boolean"}},"id":"CohortGroup"},"CustomDimension":{"description":"Custom dimension.","type":"object","properties":{"index":{"description":"Slot number of custom dimension.","format":"int32","type":"integer"},"value":{"description":"Value of the custom dimension. Default value (i.e. empty string) indicates\nclearing sesion/visitor scope custom dimension value.","type":"string"}},"id":"CustomDimension"},"MetricHeaderEntry":{"type":"object","properties":{"name":{"description":"The name of the header.","type":"string"},"type":{"enumDescriptions":["Metric type is unspecified.","Integer metric.","Float metric.","Currency metric.","Percentage metric.","Time metric in `HH:MM:SS` format."],"enum":["METRIC_TYPE_UNSPECIFIED","INTEGER","FLOAT","CURRENCY","PERCENT","TIME"],"description":"The type of the metric, for example `INTEGER`.","type":"string"}},"id":"MetricHeaderEntry","description":"Header for the metrics."},"SearchUserActivityRequest":{"description":"The request to fetch User Report from Reporting API `userActivity:get` call.","type":"object","properties":{"viewId":{"description":"Required. The Analytics\n[view ID](https://support.google.com/analytics/answer/1009618)\nfrom which to retrieve data. Every\n[SearchUserActivityRequest](#SearchUserActivityRequest) must contain the\n`viewId`.","type":"string"},"user":{"description":"Required. Unique user Id to query for. Every\n[SearchUserActivityRequest](#SearchUserActivityRequest) must contain this\nfield.","$ref":"User"},"activityTypes":{"description":"Set of all activity types being requested. Only acvities matching these\ntypes will be returned in the response. If empty, all activies will be\nreturned.","type":"array","items":{"type":"string","enum":["ACTIVITY_TYPE_UNSPECIFIED","PAGEVIEW","SCREENVIEW","GOAL","ECOMMERCE","EVENT"]},"enumDescriptions":["ActivityType will never have this value in the response. Using this type in\nthe request will result in an error.","Used when the activity resulted out of a visitor viewing a page.","Used when the activity resulted out of a visitor using an application on a\nmobile device.","Used to denote that a goal type activity.","An e-commerce transaction was performed by the visitor on the page.","Used when the activity is an event."]},"pageToken":{"type":"string","description":"A continuation token to get the next page of the results. Adding this to\nthe request will return the rows after the pageToken. The pageToken should\nbe the value returned in the nextPageToken parameter in the response to\nthe [SearchUserActivityRequest](#SearchUserActivityRequest) request."},"dateRange":{"description":"Date range for which to retrieve the user activity. If a date range is not\nprovided, the default date range is (startDate: current date - 7 days,\nendDate: current date - 1 day).","$ref":"DateRange"},"pageSize":{"description":"Page size is for paging and specifies the maximum number of returned rows.\nPage size should be > 0. If the value is 0 or if the field isn't specified,\nthe request returns the default of 1000 rows per page.","format":"int32","type":"integer"}},"id":"SearchUserActivityRequest"},"Segment":{"description":"The segment definition, if the report needs to be segmented.\nA Segment is a subset of the Analytics data. For example, of the entire\nset of users, one Segment might be users from a particular country or city.","type":"object","properties":{"dynamicSegment":{"description":"A dynamic segment definition in the request.","$ref":"DynamicSegment"},"segmentId":{"type":"string","description":"The segment ID of a built-in or custom segment, for example `gaid::-3`."}},"id":"Segment"},"SegmentDimensionFilter":{"properties":{"maxComparisonValue":{"description":"Maximum comparison values for `BETWEEN` match type.","type":"string"},"dimensionName":{"type":"string","description":"Name of the dimension for which the filter is being applied."},"operator":{"type":"string","enumDescriptions":["If the match type is unspecified, it is treated as a REGEXP.","The match expression is treated as a regular expression. All other match\ntypes are not treated as regular expressions.","Matches the values which begin with the match expression provided.","Matches the values which end with the match expression provided.","Substring match.","The value should match the match expression entirely.","This option is used to specify a dimension filter whose expression can\ntake any value from a selected list of values. This helps avoiding\nevaluating multiple exact match dimension filters which are OR'ed for\nevery single response row. For example:\n\n    expressions: [\"A\", \"B\", \"C\"]\n\nAny response row whose dimension has it is value as A, B or C, matches\nthis DimensionFilter.","Integer comparison filters.\ncase sensitivity is ignored for these and the expression\nis assumed to be a string representing an integer.\nFailure conditions:\n\n- if expression is not a valid int64, the client should expect\n  an error.\n- input dimensions that are not valid int64 values will never match the\n  filter.\n\nChecks if the dimension is numerically less than the match expression.","Checks if the dimension is numerically greater than the match\nexpression.","Checks if the dimension is numerically between the minimum and maximum\nof the match expression, boundaries excluded."],"enum":["OPERATOR_UNSPECIFIED","REGEXP","BEGINS_WITH","ENDS_WITH","PARTIAL","EXACT","IN_LIST","NUMERIC_LESS_THAN","NUMERIC_GREATER_THAN","NUMERIC_BETWEEN"],"description":"The operator to use to match the dimension with the expressions."},"expressions":{"description":"The list of expressions, only the first element is used for all operators","type":"array","items":{"type":"string"}},"caseSensitive":{"type":"boolean","description":"Should the match be case sensitive, ignored for `IN_LIST` operator."},"minComparisonValue":{"description":"Minimum comparison values for `BETWEEN` match type.","type":"string"}},"id":"SegmentDimensionFilter","description":"Dimension filter specifies the filtering options on a dimension.","type":"object"},"PivotValueRegion":{"description":"The metric values in the pivot region.","type":"object","properties":{"values":{"description":"The values of the metrics in each of the pivot regions.","type":"array","items":{"type":"string"}}},"id":"PivotValueRegion"},"ScreenviewData":{"type":"object","properties":{"mobileDeviceBranding":{"description":"Mobile manufacturer or branded name. Eg: \"Google\", \"Apple\" etc.","type":"string"},"appName":{"type":"string","description":"The application name."},"mobileDeviceModel":{"description":"Mobile device model. Eg: \"Pixel\", \"iPhone\" etc.","type":"string"},"screenName":{"description":"The name of the screen.","type":"string"}},"id":"ScreenviewData"},"Report":{"description":"The data response corresponding to the request.","type":"object","properties":{"data":{"$ref":"ReportData","description":"Response data."},"nextPageToken":{"description":"Page token to retrieve the next page of results in the list.","type":"string"},"columnHeader":{"$ref":"ColumnHeader","description":"The column headers."}},"id":"Report"},"GoalSetData":{"description":"Represents a set of goals that were reached in an activity.","type":"object","properties":{"goals":{"description":"All the goals that were reached in the current activity.","type":"array","items":{"$ref":"GoalData"}}},"id":"GoalSetData"},"EcommerceData":{"properties":{"products":{"description":"Details of the products in this transaction.","type":"array","items":{"$ref":"ProductData"}},"actionType":{"type":"string","enumDescriptions":["Action type is not known.","Click through of product lists.","Product detail views.","Add product(s) to cart.","Remove product(s) from cart.","Check out.","Completed purchase.","Refund of purchase.","Checkout options."],"enum":["UNKNOWN","CLICK","DETAILS_VIEW","ADD_TO_CART","REMOVE_FROM_CART","CHECKOUT","PAYMENT","REFUND","CHECKOUT_OPTION"],"description":"Action associated with this e-commerce action."},"transaction":{"description":"Transaction details of this e-commerce action.","$ref":"TransactionData"},"ecommerceType":{"enum":["ECOMMERCE_TYPE_UNSPECIFIED","CLASSIC","ENHANCED"],"description":"The type of this e-commerce activity.","type":"string","enumDescriptions":["Used when the e-commerce activity type is unspecified.","Used when activity has classic (non-enhanced) e-commerce information.","Used when activity has enhanced e-commerce information."]}},"id":"EcommerceData","description":"E-commerce details associated with the user activity.","type":"object"},"PivotHeader":{"description":"The headers for each of the pivot sections defined in the request.","type":"object","properties":{"pivotHeaderEntries":{"description":"A single pivot section header.","type":"array","items":{"$ref":"PivotHeaderEntry"}},"totalPivotGroupsCount":{"description":"The total number of groups for this pivot.","format":"int32","type":"integer"}},"id":"PivotHeader"},"GoalData":{"description":"Represents all the details pertaining to a goal.","type":"object","properties":{"goalCompletions":{"description":"Total number of goal completions in this activity.","format":"int64","type":"string"},"goalName":{"description":"Name of the goal.","type":"string"},"goalCompletionLocation":{"description":"URL of the page where this goal was completed.","type":"string"},"goalPreviousStep2":{"type":"string","description":"URL of the page two steps prior to the goal completion."},"goalPreviousStep3":{"description":"URL of the page three steps prior to the goal completion.","type":"string"},"goalIndex":{"description":"This identifies the goal as configured for the profile.","format":"int32","type":"integer"},"goalValue":{"description":"Value in this goal.","format":"double","type":"number"},"goalPreviousStep1":{"type":"string","description":"URL of the page one step prior to the goal completion."}},"id":"GoalData"},"Dimension":{"description":"[Dimensions](https://support.google.com/analytics/answer/1033861)\nare attributes of your data. For example, the dimension `ga:city`\nindicates the city, for example, \"Paris\" or \"New York\", from which\na session originates.","type":"object","properties":{"name":{"description":"Name of the dimension to fetch, for example `ga:browser`.","type":"string"},"histogramBuckets":{"description":"If non-empty, we place dimension values into buckets after string to\nint64. Dimension values that are not the string representation of an\nintegral value will be converted to zero.  The bucket values have to be in\nincreasing order.  Each bucket is closed on the lower end, and open on the\nupper end. The \"first\" bucket includes all values less than the first\nboundary, the \"last\" bucket includes all values up to infinity. Dimension\nvalues that fall in a bucket get transformed to a new dimension value. For\nexample, if one gives a list of \"0, 1, 3, 4, 7\", then we return the\nfollowing buckets:\n\n- bucket #1: values < 0, dimension value \"<0\"\n- bucket #2: values in [0,1), dimension value \"0\"\n- bucket #3: values in [1,3), dimension value \"1-2\"\n- bucket #4: values in [3,4), dimension value \"3\"\n- bucket #5: values in [4,7), dimension value \"4-6\"\n- bucket #6: values >= 7, dimension value \"7+\"\n\nNOTE: If you are applying histogram mutation on any dimension, and using\nthat dimension in sort, you will want to use the sort type\n`HISTOGRAM_BUCKET` for that purpose. Without that the dimension values\nwill be sorted according to dictionary\n(lexicographic) order. For example the ascending dictionary order is:\n\n   \"<50\", \"1001+\", \"121-1000\", \"50-120\"\n\nAnd the ascending `HISTOGRAM_BUCKET` order is:\n\n   \"<50\", \"50-120\", \"121-1000\", \"1001+\"\n\nThe client has to explicitly request `\"orderType\": \"HISTOGRAM_BUCKET\"`\nfor a histogram-mutated dimension.","type":"array","items":{"format":"int64","type":"string"}}},"id":"Dimension"},"SimpleSegment":{"description":"A Simple segment conditions consist of one or more dimension/metric\nconditions that can be combined.","type":"object","properties":{"orFiltersForSegment":{"description":"A list of segment filters groups which are combined with logical `AND`\noperator.","type":"array","items":{"$ref":"OrFiltersForSegment"}}},"id":"SimpleSegment"},"ColumnHeader":{"type":"object","properties":{"metricHeader":{"description":"Metric headers for the metrics in the response.","$ref":"MetricHeader"},"dimensions":{"description":"The dimension names in the response.","type":"array","items":{"type":"string"}}},"id":"ColumnHeader","description":"Column headers."},"SegmentFilterClause":{"description":"Filter Clause to be used in a segment definition, can be wither a metric or\na dimension filter.","type":"object","properties":{"metricFilter":{"$ref":"SegmentMetricFilter","description":"Metric Filter for the segment definition."},"not":{"description":"Matches the complement (`!`) of the filter.","type":"boolean"},"dimensionFilter":{"$ref":"SegmentDimensionFilter","description":"Dimension Filter for the segment definition."}},"id":"SegmentFilterClause"},"MetricFilterClause":{"description":"Represents a group of metric filters.\nSet the operator value to specify how the filters are logically combined.","type":"object","properties":{"operator":{"enumDescriptions":["Unspecified operator. It is treated as an `OR`.","The logical `OR` operator.","The logical `AND` operator."],"enum":["OPERATOR_UNSPECIFIED","OR","AND"],"description":"The operator for combining multiple metric filters. If unspecified, it is\ntreated as an `OR`.","type":"string"},"filters":{"type":"array","items":{"$ref":"MetricFilter"},"description":"The repeated set of filters. They are logically combined based on the\noperator specified."}},"id":"MetricFilterClause"},"ReportRow":{"description":"A row in the report.","type":"object","properties":{"dimensions":{"description":"List of requested dimensions.","type":"array","items":{"type":"string"}},"metrics":{"description":"List of metrics for each requested DateRange.","type":"array","items":{"$ref":"DateRangeValues"}}},"id":"ReportRow"},"OrFiltersForSegment":{"type":"object","properties":{"segmentFilterClauses":{"type":"array","items":{"$ref":"SegmentFilterClause"},"description":"List of segment filters to be combined with a `OR` operator."}},"id":"OrFiltersForSegment","description":"A list of segment filters in the `OR` group are combined with the logical OR\noperator."},"MetricHeader":{"id":"MetricHeader","description":"The headers for the metrics.","type":"object","properties":{"metricHeaderEntries":{"description":"Headers for the metrics in the response.","type":"array","items":{"$ref":"MetricHeaderEntry"}},"pivotHeaders":{"type":"array","items":{"$ref":"PivotHeader"},"description":"Headers for the pivots in the response."}}},"SegmentMetricFilter":{"type":"object","properties":{"metricName":{"description":"The metric that will be filtered on. A `metricFilter` must contain a\nmetric name.","type":"string"},"scope":{"type":"string","enumDescriptions":["If the scope is unspecified, it defaults to the condition scope,\n`USER` or `SESSION` depending on if the segment is trying to choose\nusers or sessions.","Product scope.","Hit scope.","Session scope.","User scope."],"enum":["UNSPECIFIED_SCOPE","PRODUCT","HIT","SESSION","USER"],"description":"Scope for a metric defines the level at which that metric is defined.  The\nspecified metric scope must be equal to or greater than its primary scope\nas defined in the data model. The primary scope is defined by if the\nsegment is selecting users or sessions."},"maxComparisonValue":{"description":"Max comparison value is only used for `BETWEEN` operator.","type":"string"},"comparisonValue":{"description":"The value to compare against. If the operator is `BETWEEN`, this value is\ntreated as minimum comparison value.","type":"string"},"operator":{"enumDescriptions":["Unspecified operator is treated as `LESS_THAN` operator.","Checks if the metric value is less than comparison value.","Checks if the metric value is greater than comparison value.","Equals operator.","For between operator, both the minimum and maximum are exclusive.\nWe will use `LT` and `GT` for comparison."],"enum":["UNSPECIFIED_OPERATOR","LESS_THAN","GREATER_THAN","EQUAL","BETWEEN"],"description":"Specifies is the operation to perform to compare the metric. The default\nis `EQUAL`.","type":"string"}},"id":"SegmentMetricFilter","description":"Metric filter to be used in a segment filter clause."},"DateRangeValues":{"id":"DateRangeValues","description":"Used to return a list of metrics for a single DateRange / dimension\ncombination","type":"object","properties":{"values":{"description":"Each value corresponds to each Metric in the request.","type":"array","items":{"type":"string"}},"pivotValueRegions":{"description":"The values of each pivot region.","type":"array","items":{"$ref":"PivotValueRegion"}}}},"GetReportsRequest":{"description":"The batch request containing multiple report request.","type":"object","properties":{"useResourceQuotas":{"description":"Enables\n[resource based quotas](/analytics/devguides/reporting/core/v4/limits-quotas#analytics_reporting_api_v4),\n(defaults to `False`). If this field is set to `True` the\nper view (profile) quotas are governed by the computational\ncost of the request. Note that using cost based quotas will\nhigher enable sampling rates. (10 Million for `SMALL`,\n100M for `LARGE`. See the\n[limits and quotas documentation](/analytics/devguides/reporting/core/v4/limits-quotas#analytics_reporting_api_v4) for details.","type":"boolean"},"reportRequests":{"description":"Requests, each request will have a separate response.\nThere can be a maximum of 5 requests. All requests should have the same\n`dateRanges`, `viewId`, `segments`, `samplingLevel`, and `cohortGroup`.","type":"array","items":{"$ref":"ReportRequest"}}},"id":"GetReportsRequest"},"UserActivitySession":{"type":"object","properties":{"deviceCategory":{"description":"The type of device used: \"mobile\", \"tablet\" etc.","type":"string"},"sessionDate":{"description":"Date of this session in ISO-8601 format.","type":"string"},"platform":{"description":"Platform on which the activity happened: \"android\", \"ios\" etc.","type":"string"},"dataSource":{"description":"The data source of a hit. By default, hits sent from analytics.js are\nreported as \"web\" and hits sent from the mobile SDKs are reported as \"app\".\nThese values can be overridden in the Measurement Protocol.","type":"string"},"sessionId":{"description":"Unique ID of the session.","type":"string"},"activities":{"description":"Represents a detailed view into each of the activity in this session.","type":"array","items":{"$ref":"Activity"}}},"id":"UserActivitySession","description":"This represents a user session performed on a specific device at a certain\ntime over a period of time."}},"protocol":"rest","icons":{"x16":"http://www.google.com/images/icons/product/search-16.gif","x32":"http://www.google.com/images/icons/product/search-32.gif"},"canonicalName":"AnalyticsReporting","auth":{"oauth2":{"scopes":{"https://www.googleapis.com/auth/analytics.readonly":{"description":"View your Google Analytics data"},"https://www.googleapis.com/auth/analytics":{"description":"View and manage your Google Analytics data"}}}},"rootUrl":"https://analyticsreporting.googleapis.com/","ownerDomain":"google.com","name":"analyticsreporting","batchPath":"batch","fullyEncodeReservedExpansion":true,"title":"Analytics Reporting API","ownerName":"Google","resources":{"reports":{"methods":{"batchGet":{"request":{"$ref":"GetReportsRequest"},"description":"Returns the Analytics data.","httpMethod":"POST","parameterOrder":[],"response":{"$ref":"GetReportsResponse"},"scopes":["https://www.googleapis.com/auth/analytics","https://www.googleapis.com/auth/analytics.readonly"],"parameters":{},"flatPath":"v4/reports:batchGet","id":"analyticsreporting.reports.batchGet","path":"v4/reports:batchGet"}}},"userActivity":{"methods":{"search":{"response":{"$ref":"SearchUserActivityResponse"},"parameterOrder":[],"httpMethod":"POST","parameters":{},"scopes":["https://www.googleapis.com/auth/analytics","https://www.googleapis.com/auth/analytics.readonly"],"flatPath":"v4/userActivity:search","path":"v4/userActivity:search","id":"analyticsreporting.userActivity.search","description":"Returns User Activity data.","request":{"$ref":"SearchUserActivityRequest"}}}}},"parameters":{"uploadType":{"description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\").","type":"string","location":"query"},"fields":{"location":"query","description":"Selector specifying which fields to include in a partial response.","type":"string"},"callback":{"location":"query","description":"JSONP","type":"string"},"oauth_token":{"type":"string","location":"query","description":"OAuth 2.0 token for the current user."},"$.xgafv":{"location":"query","enum":["1","2"],"description":"V1 error format.","type":"string","enumDescriptions":["v1 error format","v2 error format"]},"alt":{"enum":["json","media","proto"],"type":"string","enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"],"location":"query","description":"Data format for response.","default":"json"},"key":{"type":"string","location":"query","description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token."},"access_token":{"location":"query","description":"OAuth access token.","type":"string"},"upload_protocol":{"description":"Upload protocol for media (e.g. \"raw\", \"multipart\").","type":"string","location":"query"},"quotaUser":{"description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.","type":"string","location":"query"},"prettyPrint":{"type":"boolean","default":"true","location":"query","description":"Returns response with indentations and line breaks."}},"version":"v4","baseUrl":"https://analyticsreporting.googleapis.com/","servicePath":"","description":"Accesses Analytics report data.","kind":"discovery#restDescription","basePath":"","id":"analyticsreporting:v4","documentationLink":"https://developers.google.com/analytics/devguides/reporting/core/v4/","revision":"20190625"};