export default {"id":"cloudasset:v1beta1","documentationLink":"https://cloud.google.com/resource-manager/docs/cloud-asset-inventory/quickstart-cloud-asset-inventory","revision":"20190615","discoveryVersion":"v1","version_module":true,"schemas":{"Policy":{"properties":{"etag":{"description":"`etag` is used for optimistic concurrency control as a way to help\nprevent simultaneous updates of a policy from overwriting each other.\nIt is strongly suggested that systems make use of the `etag` in the\nread-modify-write cycle to perform policy updates in order to avoid race\nconditions: An `etag` is returned in the response to `getIamPolicy`, and\nsystems are expected to put that etag in the request to `setIamPolicy` to\nensure that their change will be applied to the same version of the policy.\n\nIf no `etag` is provided in the call to `setIamPolicy`, then the existing\npolicy is overwritten blindly.","format":"byte","type":"string"},"version":{"description":"Deprecated.","format":"int32","type":"integer"},"auditConfigs":{"description":"Specifies cloud audit logging configuration for this policy.","type":"array","items":{"$ref":"AuditConfig"}},"bindings":{"description":"Associates a list of `members` to a `role`.\n`bindings` with no members will result in an error.","type":"array","items":{"$ref":"Binding"}}},"id":"Policy","description":"Defines an Identity and Access Management (IAM) policy. It is used to\nspecify access control policies for Cloud Platform resources.\n\n\nA `Policy` consists of a list of `bindings`. A `binding` binds a list of\n`members` to a `role`, where the members can be user accounts, Google groups,\nGoogle domains, and service accounts. A `role` is a named list of permissions\ndefined by IAM.\n\n**JSON Example**\n\n    {\n      \"bindings\": [\n        {\n          \"role\": \"roles/owner\",\n          \"members\": [\n            \"user:mike@example.com\",\n            \"group:admins@example.com\",\n            \"domain:google.com\",\n            \"serviceAccount:my-other-app@appspot.gserviceaccount.com\"\n          ]\n        },\n        {\n          \"role\": \"roles/viewer\",\n          \"members\": [\"user:sean@example.com\"]\n        }\n      ]\n    }\n\n**YAML Example**\n\n    bindings:\n    - members:\n      - user:mike@example.com\n      - group:admins@example.com\n      - domain:google.com\n      - serviceAccount:my-other-app@appspot.gserviceaccount.com\n      role: roles/owner\n    - members:\n      - user:sean@example.com\n      role: roles/viewer\n\n\nFor a description of IAM and its features, see the\n[IAM developer's guide](https://cloud.google.com/iam/docs).","type":"object"},"TimeWindow":{"description":"A time window of (start_time, end_time].","type":"object","properties":{"startTime":{"description":"Start time of the time window (exclusive).","format":"google-datetime","type":"string"},"endTime":{"description":"End time of the time window (inclusive).\nCurrent timestamp if not specified.","format":"google-datetime","type":"string"}},"id":"TimeWindow"},"Operation":{"properties":{"response":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"description":"The normal response of the operation in case of success.  If the original\nmethod returns no data on success, such as `Delete`, the response is\n`google.protobuf.Empty`.  If the original method is standard\n`Get`/`Create`/`Update`, the response should be the resource.  For other\nmethods, the response should have the type `XxxResponse`, where `Xxx`\nis the original method name.  For example, if the original method name\nis `TakeSnapshot()`, the inferred response type is\n`TakeSnapshotResponse`.","type":"object"},"name":{"description":"The server-assigned name, which is only unique within the same service that\noriginally returns it. If you use the default HTTP mapping, the\n`name` should be a resource name ending with `operations/{unique_id}`.","type":"string"},"error":{"$ref":"Status","description":"The error result of the operation in case of failure or cancellation."},"metadata":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"description":"Service-specific metadata associated with the operation.  It typically\ncontains progress information and common metadata such as create time.\nSome services might not provide such metadata.  Any method that returns a\nlong-running operation should document the metadata type, if any.","type":"object"},"done":{"description":"If the value is `false`, it means the operation is still in progress.\nIf `true`, the operation is completed, and either `error` or `response` is\navailable.","type":"boolean"}},"id":"Operation","description":"This resource represents a long-running operation that is the result of a\nnetwork API call.","type":"object"},"AuditConfig":{"properties":{"service":{"description":"Specifies a service that will be enabled for audit logging.\nFor example, `storage.googleapis.com`, `cloudsql.googleapis.com`.\n`allServices` is a special value that covers all services.","type":"string"},"auditLogConfigs":{"description":"The configuration for logging of each type of permission.","type":"array","items":{"$ref":"AuditLogConfig"}}},"id":"AuditConfig","description":"Specifies the audit configuration for a service.\nThe configuration determines which permission types are logged, and what\nidentities, if any, are exempted from logging.\nAn AuditConfig must have one or more AuditLogConfigs.\n\nIf there are AuditConfigs for both `allServices` and a specific service,\nthe union of the two AuditConfigs is used for that service: the log_types\nspecified in each AuditConfig are enabled, and the exempted_members in each\nAuditLogConfig are exempted.\n\nExample Policy with multiple AuditConfigs:\n\n    {\n      \"audit_configs\": [\n        {\n          \"service\": \"allServices\"\n          \"audit_log_configs\": [\n            {\n              \"log_type\": \"DATA_READ\",\n              \"exempted_members\": [\n                \"user:foo@gmail.com\"\n              ]\n            },\n            {\n              \"log_type\": \"DATA_WRITE\",\n            },\n            {\n              \"log_type\": \"ADMIN_READ\",\n            }\n          ]\n        },\n        {\n          \"service\": \"fooservice.googleapis.com\"\n          \"audit_log_configs\": [\n            {\n              \"log_type\": \"DATA_READ\",\n            },\n            {\n              \"log_type\": \"DATA_WRITE\",\n              \"exempted_members\": [\n                \"user:bar@gmail.com\"\n              ]\n            }\n          ]\n        }\n      ]\n    }\n\nFor fooservice, this policy enables DATA_READ, DATA_WRITE and ADMIN_READ\nlogging. It also exempts foo@gmail.com from DATA_READ logging, and\nbar@gmail.com from DATA_WRITE logging.","type":"object"},"Asset":{"properties":{"assetType":{"description":"Type of the asset. Example: \"google.compute.Disk\".","type":"string"},"name":{"description":"The full name of the asset. For example:\n`//compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1`.\nSee [Resource\nNames](https://cloud.google.com/apis/design/resource_names#full_resource_name)\nfor more information.","type":"string"},"iamPolicy":{"description":"Representation of the actual Cloud IAM policy set on a cloud resource. For\neach resource, there must be at most one Cloud IAM policy set on it.","$ref":"Policy"},"resource":{"description":"Representation of the resource.","$ref":"Resource"}},"id":"Asset","description":"Cloud asset. This includes all Google Cloud Platform resources,\nCloud IAM policies, and other non-GCP assets.","type":"object"},"TemporalAsset":{"description":"Temporal asset. In addition to the asset, the temporal asset includes the\nstatus of the asset and valid from and to time of it.","type":"object","properties":{"window":{"$ref":"TimeWindow","description":"The time window when the asset data and state was observed."},"asset":{"$ref":"Asset","description":"Asset."},"deleted":{"description":"If the asset is deleted or not.","type":"boolean"}},"id":"TemporalAsset"},"OutputConfig":{"properties":{"gcsDestination":{"$ref":"GcsDestination","description":"Destination on Cloud Storage."}},"id":"OutputConfig","description":"Output configuration for export assets destination.","type":"object"},"BatchGetAssetsHistoryResponse":{"description":"Batch get assets history response.","type":"object","properties":{"assets":{"description":"A list of assets with valid time windows.","type":"array","items":{"$ref":"TemporalAsset"}}},"id":"BatchGetAssetsHistoryResponse"},"Status":{"description":"The `Status` type defines a logical error model that is suitable for\ndifferent programming environments, including REST APIs and RPC APIs. It is\nused by [gRPC](https://github.com/grpc). Each `Status` message contains\nthree pieces of data: error code, error message, and error details.\n\nYou can find out more about this error model and how to work with it in the\n[API Design Guide](https://cloud.google.com/apis/design/errors).","type":"object","properties":{"message":{"description":"A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.","type":"string"},"details":{"description":"A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.","type":"array","items":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"type":"object"}},"code":{"description":"The status code, which should be an enum value of google.rpc.Code.","format":"int32","type":"integer"}},"id":"Status"},"Binding":{"description":"Associates `members` with a `role`.","type":"object","properties":{"condition":{"description":"The condition that is associated with this binding.\nNOTE: An unsatisfied condition will not allow user access via current\nbinding. Different bindings, including their conditions, are examined\nindependently.","$ref":"Expr"},"members":{"description":"Specifies the identities requesting access for a Cloud Platform resource.\n`members` can have the following values:\n\n* `allUsers`: A special identifier that represents anyone who is\n   on the internet; with or without a Google account.\n\n* `allAuthenticatedUsers`: A special identifier that represents anyone\n   who is authenticated with a Google account or a service account.\n\n* `user:{emailid}`: An email address that represents a specific Google\n   account. For example, `alice@gmail.com` .\n\n\n* `serviceAccount:{emailid}`: An email address that represents a service\n   account. For example, `my-other-app@appspot.gserviceaccount.com`.\n\n* `group:{emailid}`: An email address that represents a Google group.\n   For example, `admins@example.com`.\n\n\n* `domain:{domain}`: The G Suite domain (primary) that represents all the\n   users of that domain. For example, `google.com` or `example.com`.\n\n","type":"array","items":{"type":"string"}},"role":{"description":"Role that is assigned to `members`.\nFor example, `roles/viewer`, `roles/editor`, or `roles/owner`.","type":"string"}},"id":"Binding"},"Expr":{"description":"Represents an expression text. Example:\n\n    title: \"User account presence\"\n    description: \"Determines whether the request has a user account\"\n    expression: \"size(request.user) > 0\"","type":"object","properties":{"title":{"description":"An optional title for the expression, i.e. a short string describing\nits purpose. This can be used e.g. in UIs which allow to enter the\nexpression.","type":"string"},"location":{"description":"An optional string indicating the location of the expression for error\nreporting, e.g. a file name and a position in the file.","type":"string"},"description":{"description":"An optional description of the expression. This is a longer text which\ndescribes the expression, e.g. when hovered over it in a UI.","type":"string"},"expression":{"description":"Textual representation of an expression in\nCommon Expression Language syntax.\n\nThe application context of the containing message determines which\nwell-known feature set of CEL is supported.","type":"string"}},"id":"Expr"},"AuditLogConfig":{"properties":{"exemptedMembers":{"description":"Specifies the identities that do not cause logging for this type of\npermission.\nFollows the same format of Binding.members.","type":"array","items":{"type":"string"}},"logType":{"enum":["LOG_TYPE_UNSPECIFIED","ADMIN_READ","DATA_WRITE","DATA_READ"],"description":"The log type that this config enables.","type":"string","enumDescriptions":["Default case. Should never be this.","Admin reads. Example: CloudIAM getIamPolicy","Data writes. Example: CloudSQL Users create","Data reads. Example: CloudSQL Users list"]}},"id":"AuditLogConfig","description":"Provides the configuration for logging a type of permissions.\nExample:\n\n    {\n      \"audit_log_configs\": [\n        {\n          \"log_type\": \"DATA_READ\",\n          \"exempted_members\": [\n            \"user:foo@gmail.com\"\n          ]\n        },\n        {\n          \"log_type\": \"DATA_WRITE\",\n        }\n      ]\n    }\n\nThis enables 'DATA_READ' and 'DATA_WRITE' logging, while exempting\nfoo@gmail.com from DATA_READ logging.","type":"object"},"GcsDestination":{"properties":{"uriPrefix":{"description":"The uri prefix of all generated Cloud Storage objects. For example:\n\"gs://bucket_name/object_name_prefix\". Each object uri is in format:\n\"gs://bucket_name/object_name_prefix/<asset type>/<shard number> and only\ncontains assets for that type. <shard number> starts from 0. For example:\n\"gs://bucket_name/object_name_prefix/google.compute.disk/0\" is the first\nshard of output objects containing all google.compute.disk assets.\nAn INVALID_ARGUMENT error will be returned if file with the same name\n\"gs://bucket_name/object_name_prefix\" already exists.","type":"string"},"uri":{"description":"The uri of the Cloud Storage object. It's the same uri that is used by\ngsutil. For example: \"gs://bucket_name/object_name\". See [Viewing and\nEditing Object\nMetadata](https://cloud.google.com/storage/docs/viewing-editing-metadata)\nfor more information.","type":"string"}},"id":"GcsDestination","description":"A Cloud Storage location.","type":"object"},"Resource":{"properties":{"data":{"additionalProperties":{"description":"Properties of the object.","type":"any"},"description":"The content of the resource, in which some sensitive fields are scrubbed\naway and may not be present.","type":"object"},"discoveryDocumentUri":{"description":"The URL of the discovery document containing the resource's JSON schema.\nFor example:\n`\"https://www.googleapis.com/discovery/v1/apis/compute/v1/rest\"`.\nIt will be left unspecified for resources without a discovery-based API,\nsuch as Cloud Bigtable.","type":"string"},"parent":{"description":"The full name of the immediate parent of this resource. See\n[Resource\nNames](https://cloud.google.com/apis/design/resource_names#full_resource_name)\nfor more information.\n\nFor GCP assets, it is the parent resource defined in the [Cloud IAM policy\nhierarchy](https://cloud.google.com/iam/docs/overview#policy_hierarchy).\nFor example:\n`\"//cloudresourcemanager.googleapis.com/projects/my_project_123\"`.\n\nFor third-party assets, it is up to the users to define.","type":"string"},"resourceUrl":{"description":"The REST URL for accessing the resource. An HTTP GET operation using this\nURL returns the resource itself.\nExample:\n`https://cloudresourcemanager.googleapis.com/v1/projects/my-project-123`.\nIt will be left unspecified for resources without a REST API.","type":"string"},"discoveryName":{"description":"The JSON schema name listed in the discovery document.\nExample: \"Project\". It will be left unspecified for resources (such as\nCloud Bigtable) without a discovery-based API.","type":"string"},"version":{"description":"The API version. Example: \"v1\".","type":"string"}},"id":"Resource","description":"Representation of a cloud resource.","type":"object"},"ExportAssetsRequest":{"properties":{"assetTypes":{"description":"A list of asset types of which to take a snapshot for. For example:\n\"google.compute.Disk\". If specified, only matching assets will be returned.\nSee [Introduction to Cloud Asset\nInventory](https://cloud.google.com/resource-manager/docs/cloud-asset-inventory/overview)\nfor all supported asset types.","type":"array","items":{"type":"string"}},"readTime":{"description":"Timestamp to take an asset snapshot. This can only be set to a timestamp\nbetween 2018-10-02 UTC (inclusive) and the current time. If not specified,\nthe current time will be used. Due to delays in resource data collection\nand indexing, there is a volatile window during which running the same\nquery may get different results.","format":"google-datetime","type":"string"},"contentType":{"enumDescriptions":["Unspecified content type.","Resource metadata.","The actual IAM policy set on a resource."],"enum":["CONTENT_TYPE_UNSPECIFIED","RESOURCE","IAM_POLICY"],"description":"Asset content type. If not specified, no content but the asset name will be\nreturned.","type":"string"},"outputConfig":{"description":"Required. Output configuration indicating where the results will be output\nto. All results will be in newline delimited JSON format.","$ref":"OutputConfig"}},"id":"ExportAssetsRequest","description":"Export asset request.","type":"object"}},"icons":{"x32":"http://www.google.com/images/icons/product/search-32.gif","x16":"http://www.google.com/images/icons/product/search-16.gif"},"protocol":"rest","canonicalName":"Cloud Asset","auth":{"oauth2":{"scopes":{"https://www.googleapis.com/auth/cloud-platform":{"description":"View and manage your data across Google Cloud Platform services"}}}},"rootUrl":"https://cloudasset.googleapis.com/","ownerDomain":"google.com","name":"cloudasset","batchPath":"batch","fullyEncodeReservedExpansion":true,"title":"Cloud Asset API","ownerName":"Google","resources":{"organizations":{"resources":{"operations":{"methods":{"get":{"response":{"$ref":"Operation"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"description":"The name of the operation resource.","required":true,"type":"string","pattern":"^organizations/[^/]+/operations/[^/]+/.+$","location":"path"}},"flatPath":"v1beta1/organizations/{organizationsId}/operations/{operationsId}/{operationsId1}","path":"v1beta1/{+name}","id":"cloudasset.organizations.operations.get","description":"Gets the latest state of a long-running operation.  Clients can use this\nmethod to poll the operation result at intervals as recommended by the API\nservice."}}}},"methods":{"exportAssets":{"response":{"$ref":"Operation"},"parameterOrder":["parent"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"parent":{"pattern":"^organizations/[^/]+$","location":"path","description":"Required. The relative name of the root asset. This can only be an\norganization number (such as \"organizations/123\"), a project ID (such as\n\"projects/my-project-id\"), a project number (such as \"projects/12345\"), or\na folder number (such as \"folders/123\").","required":true,"type":"string"}},"flatPath":"v1beta1/organizations/{organizationsId}:exportAssets","path":"v1beta1/{+parent}:exportAssets","id":"cloudasset.organizations.exportAssets","request":{"$ref":"ExportAssetsRequest"},"description":"Exports assets with time and resource types to a given Cloud Storage\nlocation. The output format is newline-delimited JSON.\nThis API implements the google.longrunning.Operation API allowing you\nto keep track of the export."},"batchGetAssetsHistory":{"description":"Batch gets the update history of assets that overlap a time window.\nFor RESOURCE content, this API outputs history with asset in both\nnon-delete or deleted status.\nFor IAM_POLICY content, this API outputs history when the asset and its\nattached IAM POLICY both exist. This can create gaps in the output history.\nIf a specified asset does not exist, this API returns an INVALID_ARGUMENT\nerror.","response":{"$ref":"BatchGetAssetsHistoryResponse"},"parameterOrder":["parent"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"contentType":{"location":"query","enum":["CONTENT_TYPE_UNSPECIFIED","RESOURCE","IAM_POLICY"],"description":"Required. The content type.","type":"string"},"readTimeWindow.endTime":{"description":"End time of the time window (inclusive).\nCurrent timestamp if not specified.","format":"google-datetime","type":"string","location":"query"},"readTimeWindow.startTime":{"location":"query","description":"Start time of the time window (exclusive).","format":"google-datetime","type":"string"},"parent":{"pattern":"^organizations/[^/]+$","location":"path","description":"Required. The relative name of the root asset. It can only be an\norganization number (such as \"organizations/123\"), a project ID (such as\n\"projects/my-project-id\")\", or a project number (such as \"projects/12345\").","required":true,"type":"string"},"assetNames":{"repeated":true,"location":"query","description":"A list of the full names of the assets. For example:\n`//compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1`.\nSee [Resource\nNames](https://cloud.google.com/apis/design/resource_names#full_resource_name)\nfor more info.\n\nThe request becomes a no-op if the asset name list is empty, and the max\nsize of the asset name list is 100 in one request.","type":"string"}},"flatPath":"v1beta1/organizations/{organizationsId}:batchGetAssetsHistory","path":"v1beta1/{+parent}:batchGetAssetsHistory","id":"cloudasset.organizations.batchGetAssetsHistory"}}},"folders":{"methods":{"exportAssets":{"response":{"$ref":"Operation"},"parameterOrder":["parent"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"parent":{"pattern":"^folders/[^/]+$","location":"path","description":"Required. The relative name of the root asset. This can only be an\norganization number (such as \"organizations/123\"), a project ID (such as\n\"projects/my-project-id\"), a project number (such as \"projects/12345\"), or\na folder number (such as \"folders/123\").","required":true,"type":"string"}},"flatPath":"v1beta1/folders/{foldersId}:exportAssets","path":"v1beta1/{+parent}:exportAssets","id":"cloudasset.folders.exportAssets","request":{"$ref":"ExportAssetsRequest"},"description":"Exports assets with time and resource types to a given Cloud Storage\nlocation. The output format is newline-delimited JSON.\nThis API implements the google.longrunning.Operation API allowing you\nto keep track of the export."}},"resources":{"operations":{"methods":{"get":{"response":{"$ref":"Operation"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"pattern":"^folders/[^/]+/operations/[^/]+/.+$","location":"path","description":"The name of the operation resource.","required":true,"type":"string"}},"flatPath":"v1beta1/folders/{foldersId}/operations/{operationsId}/{operationsId1}","path":"v1beta1/{+name}","id":"cloudasset.folders.operations.get","description":"Gets the latest state of a long-running operation.  Clients can use this\nmethod to poll the operation result at intervals as recommended by the API\nservice."}}}}},"projects":{"resources":{"operations":{"methods":{"get":{"response":{"$ref":"Operation"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"pattern":"^projects/[^/]+/operations/[^/]+/.+$","location":"path","description":"The name of the operation resource.","required":true,"type":"string"}},"flatPath":"v1beta1/projects/{projectsId}/operations/{operationsId}/{operationsId1}","path":"v1beta1/{+name}","id":"cloudasset.projects.operations.get","description":"Gets the latest state of a long-running operation.  Clients can use this\nmethod to poll the operation result at intervals as recommended by the API\nservice."}}}},"methods":{"batchGetAssetsHistory":{"path":"v1beta1/{+parent}:batchGetAssetsHistory","id":"cloudasset.projects.batchGetAssetsHistory","description":"Batch gets the update history of assets that overlap a time window.\nFor RESOURCE content, this API outputs history with asset in both\nnon-delete or deleted status.\nFor IAM_POLICY content, this API outputs history when the asset and its\nattached IAM POLICY both exist. This can create gaps in the output history.\nIf a specified asset does not exist, this API returns an INVALID_ARGUMENT\nerror.","response":{"$ref":"BatchGetAssetsHistoryResponse"},"parameterOrder":["parent"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"contentType":{"enum":["CONTENT_TYPE_UNSPECIFIED","RESOURCE","IAM_POLICY"],"description":"Required. The content type.","type":"string","location":"query"},"readTimeWindow.endTime":{"description":"End time of the time window (inclusive).\nCurrent timestamp if not specified.","format":"google-datetime","type":"string","location":"query"},"readTimeWindow.startTime":{"description":"Start time of the time window (exclusive).","format":"google-datetime","type":"string","location":"query"},"parent":{"pattern":"^projects/[^/]+$","location":"path","description":"Required. The relative name of the root asset. It can only be an\norganization number (such as \"organizations/123\"), a project ID (such as\n\"projects/my-project-id\")\", or a project number (such as \"projects/12345\").","required":true,"type":"string"},"assetNames":{"description":"A list of the full names of the assets. For example:\n`//compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1`.\nSee [Resource\nNames](https://cloud.google.com/apis/design/resource_names#full_resource_name)\nfor more info.\n\nThe request becomes a no-op if the asset name list is empty, and the max\nsize of the asset name list is 100 in one request.","type":"string","repeated":true,"location":"query"}},"flatPath":"v1beta1/projects/{projectsId}:batchGetAssetsHistory"},"exportAssets":{"httpMethod":"POST","parameterOrder":["parent"],"response":{"$ref":"Operation"},"parameters":{"parent":{"pattern":"^projects/[^/]+$","location":"path","description":"Required. The relative name of the root asset. This can only be an\norganization number (such as \"organizations/123\"), a project ID (such as\n\"projects/my-project-id\"), a project number (such as \"projects/12345\"), or\na folder number (such as \"folders/123\").","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}:exportAssets","id":"cloudasset.projects.exportAssets","path":"v1beta1/{+parent}:exportAssets","description":"Exports assets with time and resource types to a given Cloud Storage\nlocation. The output format is newline-delimited JSON.\nThis API implements the google.longrunning.Operation API allowing you\nto keep track of the export.","request":{"$ref":"ExportAssetsRequest"}}}}},"parameters":{"fields":{"description":"Selector specifying which fields to include in a partial response.","type":"string","location":"query"},"uploadType":{"description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\").","type":"string","location":"query"},"callback":{"location":"query","description":"JSONP","type":"string"},"oauth_token":{"location":"query","description":"OAuth 2.0 token for the current user.","type":"string"},"$.xgafv":{"enum":["1","2"],"description":"V1 error format.","type":"string","enumDescriptions":["v1 error format","v2 error format"],"location":"query"},"alt":{"description":"Data format for response.","default":"json","enum":["json","media","proto"],"type":"string","enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"],"location":"query"},"access_token":{"location":"query","description":"OAuth access token.","type":"string"},"key":{"description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.","type":"string","location":"query"},"upload_protocol":{"location":"query","description":"Upload protocol for media (e.g. \"raw\", \"multipart\").","type":"string"},"prettyPrint":{"location":"query","description":"Returns response with indentations and line breaks.","type":"boolean","default":"true"},"quotaUser":{"description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.","type":"string","location":"query"}},"version":"v1beta1","baseUrl":"https://cloudasset.googleapis.com/","servicePath":"","description":"The cloud asset API manages the history and inventory of cloud resources.","kind":"discovery#restDescription","basePath":""};