export default {"schemas":{"Profile":{"description":"Profile resource.","type":"object","properties":{"name":{"type":"string","description":"Output only. Opaque, server-assigned, unique ID for this profile."},"duration":{"description":"Duration of the profiling session.\nInput (for the offline mode) or output (for the online mode).\nThe field represents requested profiling duration. It may slightly differ\nfrom the effective profiling duration, which is recorded in the profile\ndata, in case the profiling can't be stopped immediately (e.g. in case\nstopping the profiling is handled asynchronously).","format":"google-duration","type":"string"},"profileType":{"description":"Type of profile.\nFor offline mode, this must be specified when creating the profile. For\nonline mode it is assigned and returned by the server.","type":"string","enumDescriptions":["Unspecified profile type.","Thread CPU time sampling.","Wallclock time sampling. More expensive as stops all threads.","In-use heap profile. Represents a snapshot of the allocations that are\nlive at the time of the profiling.","Single-shot collection of all thread stacks.","Synchronization contention profile.","Peak heap profile.","Heap allocation profile. It represents the aggregation of all allocations\nmade over the duration of the profile. All allocations are included,\nincluding those that might have been freed by the end of the profiling\ninterval. The profile is in particular useful for garbage collecting\nlanguages to understand which parts of the code create most of the garbage\ncollection pressure to see if those can be optimized."],"enum":["PROFILE_TYPE_UNSPECIFIED","CPU","WALL","HEAP","THREADS","CONTENTION","PEAK_HEAP","HEAP_ALLOC"]},"deployment":{"description":"Deployment this profile corresponds to.","$ref":"Deployment"},"labels":{"type":"object","additionalProperties":{"type":"string"},"description":"Input only. Labels associated to this specific profile. These labels will\nget merged with the deployment labels for the final data set.  See\ndocumentation on deployment labels for validation rules and limits."},"profileBytes":{"description":"Input only. Profile bytes, as a gzip compressed serialized proto, the\nformat is https://github.com/google/pprof/blob/master/proto/profile.proto.","format":"byte","type":"string"}},"id":"Profile"},"CreateProfileRequest":{"type":"object","properties":{"profileType":{"enumDescriptions":["Unspecified profile type.","Thread CPU time sampling.","Wallclock time sampling. More expensive as stops all threads.","In-use heap profile. Represents a snapshot of the allocations that are\nlive at the time of the profiling.","Single-shot collection of all thread stacks.","Synchronization contention profile.","Peak heap profile.","Heap allocation profile. It represents the aggregation of all allocations\nmade over the duration of the profile. All allocations are included,\nincluding those that might have been freed by the end of the profiling\ninterval. The profile is in particular useful for garbage collecting\nlanguages to understand which parts of the code create most of the garbage\ncollection pressure to see if those can be optimized."],"description":"One or more profile types that the agent is capable of providing.","type":"array","items":{"type":"string","enum":["PROFILE_TYPE_UNSPECIFIED","CPU","WALL","HEAP","THREADS","CONTENTION","PEAK_HEAP","HEAP_ALLOC"]}},"deployment":{"description":"Deployment details.","$ref":"Deployment"}},"id":"CreateProfileRequest","description":"CreateProfileRequest describes a profile resource online creation request.\nThe deployment field must be populated. The profile_type specifies the list\nof profile types supported by the agent. The creation call will hang until a\nprofile of one of these types needs to be collected."},"Deployment":{"description":"Deployment contains the deployment identification information.","type":"object","properties":{"target":{"type":"string","description":"Target is the service name used to group related deployments:\n* Service name for GAE Flex / Standard.\n* Cluster and container name for GKE.\n* User-specified string for direct GCE profiling (e.g. Java).\n* Job name for Dataflow.\nValidation regex: `^[a-z]([-a-z0-9_.]{0,253}[a-z0-9])?$`."},"projectId":{"type":"string","description":"Project ID is the ID of a cloud project.\nValidation regex: `^a-z{4,61}[a-z0-9]$`."},"labels":{"type":"object","additionalProperties":{"type":"string"},"description":"Labels identify the deployment within the user universe and same target.\nValidation regex for label names: `^[a-z0-9]([a-z0-9-]{0,61}[a-z0-9])?$`.\nValue for an individual label must be <= 512 bytes, the total\nsize of all label names and values must be <= 1024 bytes.\n\nLabel named \"language\" can be used to record the programming language of\nthe profiled deployment. The standard choices for the value include \"java\",\n\"go\", \"python\", \"ruby\", \"nodejs\", \"php\", \"dotnet\".\n\nFor deployments running on Google Cloud Platform, \"zone\" or \"region\" label\nshould be present describing the deployment location. An example of a zone\nis \"us-central1-a\", an example of a region is \"us-central1\" or\n\"us-central\"."}},"id":"Deployment"}},"icons":{"x16":"http://www.google.com/images/icons/product/search-16.gif","x32":"http://www.google.com/images/icons/product/search-32.gif"},"protocol":"rest","canonicalName":"Cloud Profiler","auth":{"oauth2":{"scopes":{"https://www.googleapis.com/auth/monitoring.write":{"description":"Publish metric data to your Google Cloud projects"},"https://www.googleapis.com/auth/cloud-platform":{"description":"View and manage your data across Google Cloud Platform services"},"https://www.googleapis.com/auth/monitoring":{"description":"View and write monitoring data for all of your Google and third-party Cloud and API projects"}}}},"rootUrl":"https://cloudprofiler.googleapis.com/","ownerDomain":"google.com","name":"cloudprofiler","batchPath":"batch","fullyEncodeReservedExpansion":true,"title":"Stackdriver Profiler API","ownerName":"Google","resources":{"projects":{"resources":{"profiles":{"methods":{"createOffline":{"id":"cloudprofiler.projects.profiles.createOffline","path":"v2/{+parent}/profiles:createOffline","request":{"$ref":"Profile"},"description":"CreateOfflineProfile creates a new profile resource in the offline mode.\nThe client provides the profile to create along with the profile bytes, the\nserver records it.","httpMethod":"POST","parameterOrder":["parent"],"response":{"$ref":"Profile"},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/monitoring","https://www.googleapis.com/auth/monitoring.write"],"parameters":{"parent":{"location":"path","description":"Parent project to create the profile in.","required":true,"type":"string","pattern":"^projects/[^/]+$"}},"flatPath":"v2/projects/{projectsId}/profiles:createOffline"},"patch":{"httpMethod":"PATCH","parameterOrder":["name"],"response":{"$ref":"Profile"},"parameters":{"updateMask":{"location":"query","description":"Field mask used to specify the fields to be overwritten. Currently only\nprofile_bytes and labels fields are supported by UpdateProfile, so only\nthose fields can be specified in the mask. When no mask is provided, all\nfields are overwritten.","format":"google-fieldmask","type":"string"},"name":{"required":true,"type":"string","pattern":"^projects/[^/]+/profiles/[^/]+$","location":"path","description":"Output only. Opaque, server-assigned, unique ID for this profile."}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/monitoring","https://www.googleapis.com/auth/monitoring.write"],"flatPath":"v2/projects/{projectsId}/profiles/{profilesId}","id":"cloudprofiler.projects.profiles.patch","path":"v2/{+name}","description":"UpdateProfile updates the profile bytes and labels on the profile resource\ncreated in the online mode. Updating the bytes for profiles created in the\noffline mode is currently not supported: the profile content must be\nprovided at the time of the profile creation.","request":{"$ref":"Profile"}},"create":{"flatPath":"v2/projects/{projectsId}/profiles","id":"cloudprofiler.projects.profiles.create","path":"v2/{+parent}/profiles","description":"CreateProfile creates a new profile resource in the online mode.\n\nThe server ensures that the new profiles are created at a constant rate per\ndeployment, so the creation request may hang for some time until the next\nprofile session is available.\n\nThe request may fail with ABORTED error if the creation is not available\nwithin ~1m, the response will indicate the duration of the backoff the\nclient should take before attempting creating a profile again. The backoff\nduration is returned in google.rpc.RetryInfo extension on the response\nstatus. To a gRPC client, the extension will be return as a\nbinary-serialized proto in the trailing metadata item named\n\"google.rpc.retryinfo-bin\".","request":{"$ref":"CreateProfileRequest"},"httpMethod":"POST","parameterOrder":["parent"],"response":{"$ref":"Profile"},"parameters":{"parent":{"pattern":"^projects/[^/]+$","location":"path","description":"Parent project to create the profile in.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/monitoring","https://www.googleapis.com/auth/monitoring.write"]}}}}}},"parameters":{"quotaUser":{"location":"query","description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.","type":"string"},"prettyPrint":{"location":"query","description":"Returns response with indentations and line breaks.","type":"boolean","default":"true"},"fields":{"description":"Selector specifying which fields to include in a partial response.","type":"string","location":"query"},"uploadType":{"type":"string","location":"query","description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\")."},"callback":{"location":"query","description":"JSONP","type":"string"},"oauth_token":{"location":"query","description":"OAuth 2.0 token for the current user.","type":"string"},"$.xgafv":{"enumDescriptions":["v1 error format","v2 error format"],"location":"query","enum":["1","2"],"description":"V1 error format.","type":"string"},"alt":{"enum":["json","media","proto"],"type":"string","enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"],"location":"query","description":"Data format for response.","default":"json"},"access_token":{"location":"query","description":"OAuth access token.","type":"string"},"key":{"type":"string","location":"query","description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token."},"upload_protocol":{"description":"Upload protocol for media (e.g. \"raw\", \"multipart\").","type":"string","location":"query"}},"version":"v2","baseUrl":"https://cloudprofiler.googleapis.com/","servicePath":"","kind":"discovery#restDescription","description":"Manages continuous profiling information.","basePath":"","id":"cloudprofiler:v2","documentationLink":"https://cloud.google.com/profiler/","revision":"20190614","discoveryVersion":"v1","version_module":true};