export default {"name":"firebasedynamiclinks","batchPath":"batch","title":"Firebase Dynamic Links API","ownerName":"Google","resources":{"shortLinks":{"methods":{"create":{"path":"v1/shortLinks","id":"firebasedynamiclinks.shortLinks.create","request":{"$ref":"CreateShortDynamicLinkRequest"},"description":"Creates a short Dynamic Link given either a valid long Dynamic Link or\ndetails such as Dynamic Link domain, Android and iOS app information.\nThe created short Dynamic Link will not expire.\n\nRepeated calls with the same long Dynamic Link or Dynamic Link information\nwill produce the same short Dynamic Link.\n\nThe Dynamic Link domain in the request must be owned by requester's\nFirebase project.","response":{"$ref":"CreateShortDynamicLinkResponse"},"parameterOrder":[],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/firebase"],"parameters":{},"flatPath":"v1/shortLinks"}}},"managedShortLinks":{"methods":{"create":{"httpMethod":"POST","parameterOrder":[],"response":{"$ref":"CreateManagedShortLinkResponse"},"parameters":{},"scopes":["https://www.googleapis.com/auth/firebase"],"flatPath":"v1/managedShortLinks:create","id":"firebasedynamiclinks.managedShortLinks.create","path":"v1/managedShortLinks:create","description":"Creates a managed short Dynamic Link given either a valid long Dynamic Link\nor details such as Dynamic Link domain, Android and iOS app information.\nThe created short Dynamic Link will not expire.\n\nThis differs from CreateShortDynamicLink in the following ways:\n  - The request will also contain a name for the link (non unique name\n    for the front end).\n  - The response must be authenticated with an auth token (generated with\n    the admin service account).\n  - The link will appear in the FDL list of links in the console front end.\n\nThe Dynamic Link domain in the request must be owned by requester's\nFirebase project.","request":{"$ref":"CreateManagedShortLinkRequest"}}}},"v1":{"methods":{"reopenAttribution":{"response":{"$ref":"GetIosReopenAttributionResponse"},"parameterOrder":[],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/firebase"],"parameters":{},"flatPath":"v1/reopenAttribution","path":"v1/reopenAttribution","id":"firebasedynamiclinks.reopenAttribution","request":{"$ref":"GetIosReopenAttributionRequest"},"description":"Get iOS reopen attribution for app universal link open deeplinking."},"getLinkStats":{"response":{"$ref":"DynamicLinkStats"},"parameterOrder":["dynamicLink"],"httpMethod":"GET","parameters":{"durationDays":{"type":"string","location":"query","description":"The span of time requested in days.","format":"int64"},"dynamicLink":{"description":"Dynamic Link URL. e.g. https://abcd.app.goo.gl/wxyz","required":true,"type":"string","location":"path"},"sdkVersion":{"type":"string","location":"query","description":"Google SDK version. Version takes the form \"$major.$minor.$patch\""}},"scopes":["https://www.googleapis.com/auth/firebase"],"flatPath":"v1/{dynamicLink}/linkStats","path":"v1/{dynamicLink}/linkStats","id":"firebasedynamiclinks.getLinkStats","description":"Fetches analytics stats of a short Dynamic Link for a given\nduration. Metrics include number of clicks, redirects, installs,\napp first opens, and app reopens."},"installAttribution":{"flatPath":"v1/installAttribution","id":"firebasedynamiclinks.installAttribution","path":"v1/installAttribution","description":"Get iOS strong/weak-match info for post-install attribution.","request":{"$ref":"GetIosPostInstallAttributionRequest"},"httpMethod":"POST","parameterOrder":[],"response":{"$ref":"GetIosPostInstallAttributionResponse"},"parameters":{},"scopes":["https://www.googleapis.com/auth/firebase"]}}}},"parameters":{"access_token":{"location":"query","description":"OAuth access token.","type":"string"},"key":{"description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.","type":"string","location":"query"},"upload_protocol":{"location":"query","description":"Upload protocol for media (e.g. \"raw\", \"multipart\").","type":"string"},"prettyPrint":{"location":"query","description":"Returns response with indentations and line breaks.","type":"boolean","default":"true"},"quotaUser":{"type":"string","location":"query","description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters."},"fields":{"location":"query","description":"Selector specifying which fields to include in a partial response.","type":"string"},"uploadType":{"location":"query","description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\").","type":"string"},"callback":{"description":"JSONP","type":"string","location":"query"},"oauth_token":{"description":"OAuth 2.0 token for the current user.","type":"string","location":"query"},"$.xgafv":{"location":"query","enum":["1","2"],"description":"V1 error format.","type":"string","enumDescriptions":["v1 error format","v2 error format"]},"alt":{"enum":["json","media","proto"],"type":"string","enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"],"location":"query","description":"Data format for response.","default":"json"}},"version":"v1","baseUrl":"https://firebasedynamiclinks.googleapis.com/","servicePath":"","description":"Programmatically creates and manages Firebase Dynamic Links.","kind":"discovery#restDescription","basePath":"","revision":"20190626","documentationLink":"https://firebase.google.com/docs/dynamic-links/","id":"firebasedynamiclinks:v1","discoveryVersion":"v1","version_module":true,"schemas":{"DeviceInfo":{"description":"Signals associated with the device making the request.","type":"object","properties":{"deviceModelName":{"description":"Device model name.","type":"string"},"languageCodeFromWebview":{"type":"string","description":"Device language code setting obtained by executing JavaScript code in\nWebView."},"languageCodeRaw":{"description":"Device language code raw setting.\niOS does returns language code in different format than iOS WebView.\nFor example WebView returns en_US, but iOS returns en-US.\nField below will return raw value returned by iOS.","type":"string"},"screenResolutionWidth":{"type":"string","description":"Device display resolution width.","format":"int64"},"screenResolutionHeight":{"description":"Device display resolution height.","format":"int64","type":"string"},"languageCode":{"description":"Device language code setting.","type":"string"},"timezone":{"description":"Device timezone setting.","type":"string"}},"id":"DeviceInfo"},"ITunesConnectAnalytics":{"id":"ITunesConnectAnalytics","description":"Parameters for iTunes Connect App Analytics.","type":"object","properties":{"pt":{"type":"string","description":"Provider token that enables analytics for Dynamic Links from within iTunes\nConnect."},"at":{"description":"Affiliate token used to create affiliate-coded links.","type":"string"},"ct":{"type":"string","description":"Campaign text that developers can optionally add to any link in order to\ntrack sales from a specific marketing campaign."},"mt":{"description":"iTune media types, including music, podcasts, audiobooks and so on.","type":"string"}}},"GetIosPostInstallAttributionResponse":{"id":"GetIosPostInstallAttributionResponse","description":"Response for iSDK to execute strong match flow for post-install attribution.","type":"object","properties":{"utmMedium":{"description":"Scion medium value to be propagated by iSDK to Scion at post-install.","type":"string"},"utmSource":{"description":"Scion source value to be propagated by iSDK to Scion at post-install.","type":"string"},"isStrongMatchExecutable":{"description":"Instruction for iSDK to attemmpt to perform strong match. For instance,\nif browser does not support/allow cookie or outside of support browsers,\nthis will be false.","type":"boolean"},"appMinimumVersion":{"description":"The minimum version for app, specified by dev through ?imv= parameter.\nReturn to iSDK to allow app to evaluate if current version meets this.","type":"string"},"invitationId":{"description":"Invitation ID attributed post-install via one of several techniques\n(fingerprint, copy unique).","type":"string"},"deepLink":{"description":"The deep-link attributed post-install via one of several techniques\n(fingerprint, copy unique).","type":"string"},"externalBrowserDestinationLink":{"description":"User-agent specific custom-scheme URIs for iSDK to open. This will be set\naccording to the user-agent tha the click was originally made in. There is\nno Safari-equivalent custom-scheme open URLs.\nie: googlechrome://www.example.com\nie: firefox://open-url?url=http://www.example.com\nie: opera-http://example.com","type":"string"},"attributionConfidence":{"description":"The confidence of the returned attribution.","type":"string","enumDescriptions":["Unset.","Weak confidence, more than one matching link found or link suspected to\nbe false positive","Default confidence, match based on fingerprint","Unique confidence, match based on \"unique match link to check\" or other\nmeans"],"enum":["UNKNOWN_ATTRIBUTION_CONFIDENCE","WEAK","DEFAULT","UNIQUE"]},"matchMessage":{"description":"Describes why match failed, ie: \"discarded due to low confidence\".\nThis message will be publicly visible.","type":"string"},"utmTerm":{"type":"string","description":"Scion term value to be propagated by iSDK to Scion at app-reopen."},"resolvedLink":{"description":"The entire FDL, expanded from a short link. It is the same as the\nrequested_link, if it is long. Parameters from this should not be\nused directly (ie: server can default utm_[campaign|medium|source]\nto a value when requested_link lack them, server determine the best\nfallback_link when requested_link specifies >1 fallback links).","type":"string"},"utmCampaign":{"type":"string","description":"Scion campaign value to be propagated by iSDK to Scion at post-install."},"requestIpVersion":{"enum":["UNKNOWN_IP_VERSION","IP_V4","IP_V6"],"description":"Which IP version the request was made from.","type":"string","enumDescriptions":["Unset.","Request made from an IPv4 IP address.","Request made from an IPv6 IP address."]},"utmContent":{"description":"Scion content value to be propagated by iSDK to Scion at app-reopen.","type":"string"},"fallbackLink":{"description":"The link to navigate to update the app if min version is not met.\nThis is either (in order): 1) fallback link (from ?ifl= parameter, if\nspecified by developer) or 2) AppStore URL (from ?isi= parameter, if\nspecified), or 3) the payload link (from required link= parameter).","type":"string"},"requestedLink":{"type":"string","description":"Entire FDL (short or long) attributed post-install via one of several\ntechniques (fingerprint, copy unique)."}}},"CreateManagedShortLinkResponse":{"type":"object","properties":{"previewLink":{"description":"Preview link to show the link flow chart. (debug info.)","type":"string"},"managedShortLink":{"$ref":"ManagedShortLink","description":"Short Dynamic Link value. e.g. https://abcd.app.goo.gl/wxyz"},"warning":{"description":"Information about potential warnings on link creation.","type":"array","items":{"$ref":"DynamicLinkWarning"}}},"id":"CreateManagedShortLinkResponse","description":"Response to create a short Dynamic Link."},"GetIosReopenAttributionResponse":{"type":"object","properties":{"utmContent":{"description":"Scion content value to be propagated by iSDK to Scion at app-reopen.","type":"string"},"deepLink":{"description":"The deep-link attributed the app universal link open. For both regular\nFDL links and invite FDL links.","type":"string"},"invitationId":{"description":"Optional invitation ID, for only invite typed requested FDL links.","type":"string"},"iosMinAppVersion":{"description":"FDL input value of the \"&imv=\" parameter, minimum app version to be\nreturned to Google Firebase SDK running on iOS-9.","type":"string"},"utmMedium":{"description":"Scion medium value to be propagated by iSDK to Scion at app-reopen.","type":"string"},"utmTerm":{"description":"Scion term value to be propagated by iSDK to Scion at app-reopen.","type":"string"},"resolvedLink":{"description":"The entire FDL, expanded from a short link. It is the same as the\nrequested_link, if it is long.","type":"string"},"utmSource":{"type":"string","description":"Scion source value to be propagated by iSDK to Scion at app-reopen."},"utmCampaign":{"type":"string","description":"Scion campaign value to be propagated by iSDK to Scion at app-reopen."}},"id":"GetIosReopenAttributionResponse","description":"Response for iSDK to get reopen attribution for app universal link open\ndeeplinking. This endpoint is meant for only iOS requests."},"SocialMetaTagInfo":{"description":"Parameters for social meta tag params.\nUsed to set meta tag data for link previews on social sites.","type":"object","properties":{"socialDescription":{"type":"string","description":"A short description of the link. Optional."},"socialTitle":{"description":"Title to be displayed. Optional.","type":"string"},"socialImageLink":{"description":"An image url string. Optional.","type":"string"}},"id":"SocialMetaTagInfo"},"AndroidInfo":{"type":"object","properties":{"androidPackageName":{"type":"string","description":"Android package name of the app."},"androidMinPackageVersionCode":{"description":"Minimum version code for the Android app. If the installed app’s version\ncode is lower, then the user is taken to the Play Store.","type":"string"},"androidLink":{"description":"If specified, this overrides the ‘link’ parameter on Android.","type":"string"},"androidFallbackLink":{"description":"Link to open on Android if the app is not installed.","type":"string"}},"id":"AndroidInfo","description":"Android related attributes to the Dynamic Link."},"DynamicLinkWarning":{"description":"Dynamic Links warning messages.","type":"object","properties":{"warningCode":{"enum":["CODE_UNSPECIFIED","NOT_IN_PROJECT_ANDROID_PACKAGE_NAME","NOT_INTEGER_ANDROID_PACKAGE_MIN_VERSION","UNNECESSARY_ANDROID_PACKAGE_MIN_VERSION","NOT_URI_ANDROID_LINK","UNNECESSARY_ANDROID_LINK","NOT_URI_ANDROID_FALLBACK_LINK","BAD_URI_SCHEME_ANDROID_FALLBACK_LINK","NOT_IN_PROJECT_IOS_BUNDLE_ID","NOT_IN_PROJECT_IPAD_BUNDLE_ID","UNNECESSARY_IOS_URL_SCHEME","NOT_NUMERIC_IOS_APP_STORE_ID","UNNECESSARY_IOS_APP_STORE_ID","NOT_URI_IOS_FALLBACK_LINK","BAD_URI_SCHEME_IOS_FALLBACK_LINK","NOT_URI_IPAD_FALLBACK_LINK","BAD_URI_SCHEME_IPAD_FALLBACK_LINK","BAD_DEBUG_PARAM","BAD_AD_PARAM","DEPRECATED_PARAM","UNRECOGNIZED_PARAM","TOO_LONG_PARAM","NOT_URI_SOCIAL_IMAGE_LINK","BAD_URI_SCHEME_SOCIAL_IMAGE_LINK","NOT_URI_SOCIAL_URL","BAD_URI_SCHEME_SOCIAL_URL","LINK_LENGTH_TOO_LONG","LINK_WITH_FRAGMENTS","NOT_MATCHING_IOS_BUNDLE_ID_AND_STORE_ID"],"description":"The warning code.","type":"string","enumDescriptions":["Unknown code.","The Android package does not match any in developer's DevConsole project.","The Android minimum version code has to be a valid integer.","Android package min version param is not needed, e.g. when\n'apn' is missing.","Android link is not a valid URI.","Android link param is not needed, e.g. when param 'al' and 'link' have\nthe same value..","Android fallback link is not a valid URI.","Android fallback link has an invalid (non http/https) URI scheme.","The iOS bundle ID does not match any in developer's DevConsole project.","The iPad bundle ID does not match any in developer's DevConsole project.","iOS URL scheme is not needed, e.g. when 'ibi' are 'ipbi' are all missing.","iOS app store ID format is incorrect, e.g. not numeric.","iOS app store ID is not needed.","iOS fallback link is not a valid URI.","iOS fallback link has an invalid (non http/https) URI scheme.","iPad fallback link is not a valid URI.","iPad fallback link has an invalid (non http/https) URI scheme.","Debug param format is incorrect.","isAd param format is incorrect.","Indicates a certain param is deprecated.","Indicates certain paramater is not recognized.","Indicates certain paramater is too long.","Social meta tag image link is not a valid URI.","Social meta tag image link has an invalid (non http/https) URI scheme.","","","Dynamic Link URL length is too long.","Dynamic Link URL contains fragments.","The iOS bundle ID does not match with the given iOS store ID."]},"warningMessage":{"type":"string","description":"The warning message to help developers improve their requests."},"warningDocumentLink":{"description":"The document describing the warning, and helps resolve.","type":"string"}},"id":"DynamicLinkWarning"},"DynamicLinkStats":{"description":"Analytics stats of a Dynamic Link for a given timeframe.","type":"object","properties":{"linkEventStats":{"description":"Dynamic Link event stats.","type":"array","items":{"$ref":"DynamicLinkEventStat"}}},"id":"DynamicLinkStats"},"GetIosReopenAttributionRequest":{"description":"Request for iSDK to get reopen attribution for app universal link open\ndeeplinking. This endpoint is meant for only iOS requests.","type":"object","properties":{"bundleId":{"type":"string","description":"APP bundle ID."},"requestedLink":{"type":"string","description":"FDL link to be verified from an app universal link open.\nThe FDL link can be one of:\n1) short FDL.\ne.g. <app_code>.page.link/<ddl_id>, or\n2) long FDL.\ne.g. <app_code>.page.link/?{query params}, or\n3) Invite FDL.\ne.g. <app_code>.page.link/i/<invite_id_or_alias>"},"sdkVersion":{"description":"Google SDK version. Version takes the form \"$major.$minor.$patch\"","type":"string"}},"id":"GetIosReopenAttributionRequest"},"NavigationInfo":{"id":"NavigationInfo","description":"Information of navigation behavior.","type":"object","properties":{"enableForcedRedirect":{"description":"If this option is on, FDL click will be forced to redirect rather than\nshow an interstitial page.","type":"boolean"}}},"IosInfo":{"type":"object","properties":{"iosIpadBundleId":{"description":"iPad bundle ID of the app.","type":"string"},"iosCustomScheme":{"type":"string","description":"Custom (destination) scheme to use for iOS. By default, we’ll use the\nbundle ID as the custom scheme. Developer can override this behavior using\nthis param."},"iosBundleId":{"type":"string","description":"iOS bundle ID of the app."},"iosFallbackLink":{"description":"Link to open on iOS if the app is not installed.","type":"string"},"iosAppStoreId":{"description":"iOS App Store ID.","type":"string"},"iosIpadFallbackLink":{"description":"If specified, this overrides the ios_fallback_link value on iPads.","type":"string"},"iosMinimumVersion":{"description":"iOS minimum version.","type":"string"}},"id":"IosInfo","description":"iOS related attributes to the Dynamic Link.."},"AnalyticsInfo":{"description":"Tracking parameters supported by Dynamic Link.","type":"object","properties":{"itunesConnectAnalytics":{"$ref":"ITunesConnectAnalytics","description":"iTunes Connect App Analytics."},"googlePlayAnalytics":{"$ref":"GooglePlayAnalytics","description":"Google Play Campaign Measurements."}},"id":"AnalyticsInfo"},"CreateShortDynamicLinkRequest":{"id":"CreateShortDynamicLinkRequest","description":"Request to create a short Dynamic Link.","type":"object","properties":{"dynamicLinkInfo":{"$ref":"DynamicLinkInfo","description":"Information about the Dynamic Link to be shortened.\n[Learn\nmore](https://firebase.google.com/docs/reference/dynamic-links/link-shortener)."},"sdkVersion":{"description":"Google SDK version. Version takes the form \"$major.$minor.$patch\"","type":"string"},"longDynamicLink":{"description":"Full long Dynamic Link URL with desired query parameters specified.\nFor example,\n\"https://sample.app.goo.gl/?link=http://www.google.com&apn=com.sample\",\n[Learn\nmore](https://firebase.google.com/docs/reference/dynamic-links/link-shortener).","type":"string"},"suffix":{"description":"Short Dynamic Link suffix. Optional.","$ref":"Suffix"}}},"ManagedShortLink":{"type":"object","properties":{"link":{"type":"string","description":"Short durable link url, for example, \"https://sample.app.goo.gl/xyz123\".\n\nRequired."},"creationTime":{"description":"Creation timestamp of the short link.","format":"google-datetime","type":"string"},"visibility":{"enumDescriptions":["Visibility of the link is not specified.","Link created in console and should be shown in console.","Link created in console and should not be shown in console (but can\nbe shown in the console again if it is unarchived).","Link created outside of console and should never be shown in console."],"enum":["UNSPECIFIED_VISIBILITY","UNARCHIVED","ARCHIVED","NEVER_SHOWN"],"description":"Visibility status of link.","type":"string"},"linkName":{"description":"Link name defined by the creator.\n\nRequired.","type":"string"},"flaggedAttribute":{"description":"Attributes that have been flagged about this short url.","type":"array","items":{"enum":["UNSPECIFIED_ATTRIBUTE","SPAM"],"type":"string"},"enumDescriptions":["Indicates that no attributes were found for this short url.","Indicates that short url has been flagged by AbuseIAm team as spam."]},"info":{"$ref":"DynamicLinkInfo","description":"Full Dyamic Link info"}},"id":"ManagedShortLink","description":"Managed Short Link."},"DesktopInfo":{"description":"Desktop related attributes to the Dynamic Link.","type":"object","properties":{"desktopFallbackLink":{"description":"Link to open on desktop.","type":"string"}},"id":"DesktopInfo"},"DynamicLinkEventStat":{"id":"DynamicLinkEventStat","description":"Dynamic Link event stat.","type":"object","properties":{"count":{"description":"The number of times this event occurred.","format":"int64","type":"string"},"event":{"enum":["DYNAMIC_LINK_EVENT_UNSPECIFIED","CLICK","REDIRECT","APP_INSTALL","APP_FIRST_OPEN","APP_RE_OPEN"],"description":"Link event.","type":"string","enumDescriptions":["Unspecified type.","Indicates that an FDL is clicked by users.","Indicates that an FDL redirects users to fallback link.","Indicates that an FDL triggers an app install from Play store, currently\nit's impossible to get stats from App store.","Indicates that the app is opened for the first time after an install\ntriggered by FDLs","Indicates that the app is opened via an FDL for non-first time."]},"platform":{"description":"Requested platform.","type":"string","enumDescriptions":["Unspecified platform.","Represents Android platform.\nAll apps and browsers on Android are classfied in this category.","Represents iOS platform.\nAll apps and browsers on iOS are classfied in this category.","Represents desktop.","Platforms are not categorized as Android/iOS/Destop fall into here."],"enum":["DYNAMIC_LINK_PLATFORM_UNSPECIFIED","ANDROID","IOS","DESKTOP","OTHER"]}}},"GetIosPostInstallAttributionRequest":{"description":"Request for iSDK to execute strong match flow for post-install attribution.\nThis is meant for iOS requests only. Requests from other platforms will\nnot be honored.","type":"object","properties":{"bundleId":{"description":"APP bundle ID.","type":"string"},"device":{"$ref":"DeviceInfo","description":"Device information."},"uniqueMatchLinkToCheck":{"description":"Possible unique matched link that server need to check before performing\nfingerprint match. If passed link is short server need to expand the link.\nIf link is long server need to vslidate the link.","type":"string"},"appInstallationTime":{"type":"string","description":"App installation epoch time (https://en.wikipedia.org/wiki/Unix_time).\nThis is a client signal for a more accurate weak match.","format":"int64"},"iosVersion":{"description":"iOS version, ie: 9.3.5.\nConsider adding \"build\".","type":"string"},"retrievalMethod":{"description":"App post install attribution retrieval information. Disambiguates\nmechanism (iSDK or developer invoked) to retrieve payload from\nclicked link.","type":"string","enumDescriptions":["Unknown method.","iSDK performs a server lookup by device fingerprint in the background\nwhen app is first-opened; no API called by developer.","iSDK performs a server lookup by device fingerprint upon a dev API call.","iSDK performs a strong match only if weak match is found upon a dev\nAPI call."],"enum":["UNKNOWN_PAYLOAD_RETRIEVAL_METHOD","IMPLICIT_WEAK_MATCH","EXPLICIT_WEAK_MATCH","EXPLICIT_STRONG_AFTER_WEAK_MATCH"]},"visualStyle":{"description":"Strong match page information. Disambiguates between default UI and\ncustom page to present when strong match succeeds/fails to find cookie.","type":"string","enumDescriptions":["Unknown style.","Default style.","Custom style."],"enum":["UNKNOWN_VISUAL_STYLE","DEFAULT_STYLE","CUSTOM_STYLE"]},"sdkVersion":{"description":"Google SDK version. Version takes the form \"$major.$minor.$patch\"","type":"string"}},"id":"GetIosPostInstallAttributionRequest"},"CreateManagedShortLinkRequest":{"description":"Request to create a managed Short Dynamic Link.","type":"object","properties":{"dynamicLinkInfo":{"$ref":"DynamicLinkInfo","description":"Information about the Dynamic Link to be shortened.\n[Learn\nmore](https://firebase.google.com/docs/reference/dynamic-links/link-shortener)."},"sdkVersion":{"description":"Google SDK version. Version takes the form \"$major.$minor.$patch\"","type":"string"},"longDynamicLink":{"description":"Full long Dynamic Link URL with desired query parameters specified.\nFor example,\n\"https://sample.app.goo.gl/?link=http://www.google.com&apn=com.sample\",\n[Learn\nmore](https://firebase.google.com/docs/reference/dynamic-links/link-shortener).","type":"string"},"name":{"description":"Link name to associate with the link. It's used for marketer to identify\nmanually-created links in the Firebase console\n(https://console.firebase.google.com/).\nLinks must be named to be tracked.","type":"string"},"suffix":{"description":"Short Dynamic Link suffix. Optional.","$ref":"Suffix"}},"id":"CreateManagedShortLinkRequest"},"CreateShortDynamicLinkResponse":{"description":"Response to create a short Dynamic Link.","type":"object","properties":{"warning":{"description":"Information about potential warnings on link creation.","type":"array","items":{"$ref":"DynamicLinkWarning"}},"shortLink":{"description":"Short Dynamic Link value. e.g. https://abcd.app.goo.gl/wxyz","type":"string"},"previewLink":{"description":"Preview link to show the link flow chart. (debug info.)","type":"string"}},"id":"CreateShortDynamicLinkResponse"},"Suffix":{"id":"Suffix","description":"Short Dynamic Link suffix.","type":"object","properties":{"customSuffix":{"type":"string","description":"Only applies to Option.CUSTOM."},"option":{"description":"Suffix option.","type":"string","enumDescriptions":["The suffix option is not specified, performs as UNGUESSABLE .","Short Dynamic Link suffix is a base62 [0-9A-Za-z] encoded string of\na random generated 96 bit random number, which has a length of 17 chars.\nFor example, \"nlAR8U4SlKRZw1cb2\".\nIt prevents other people from guessing and crawling short Dynamic Links\nthat contain personal identifiable information.","Short Dynamic Link suffix is a base62 [0-9A-Za-z] string starting with a\nlength of 4 chars. the length will increase when all the space is\noccupied.","Custom DDL suffix is a client specified string, for example,\n\"buy2get1free\".\nNOTE: custom suffix should only be available to managed short link\ncreation"],"enum":["OPTION_UNSPECIFIED","UNGUESSABLE","SHORT","CUSTOM"]}}},"GooglePlayAnalytics":{"description":"Parameters for Google Play Campaign Measurements.\n[Learn\nmore](https://developers.google.com/analytics/devguides/collection/android/v4/campaigns#campaign-params)","type":"object","properties":{"utmTerm":{"type":"string","description":"Campaign term; used with paid search to supply the keywords for ads."},"utmSource":{"description":"Campaign source; used to identify a search engine, newsletter, or other\nsource.","type":"string"},"gclid":{"type":"string","description":"[AdWords autotagging\nparameter](https://support.google.com/analytics/answer/1033981?hl=en); used\nto measure Google AdWords ads. This value is generated dynamically and\nshould never be modified."},"utmCampaign":{"type":"string","description":"Campaign name; used for keyword analysis to identify a specific product\npromotion or strategic campaign."},"utmContent":{"description":"Campaign content; used for A/B testing and content-targeted ads to\ndifferentiate ads or links that point to the same URL.","type":"string"},"utmMedium":{"description":"Campaign medium; used to identify a medium such as email or cost-per-click.","type":"string"}},"id":"GooglePlayAnalytics"},"DynamicLinkInfo":{"type":"object","properties":{"androidInfo":{"$ref":"AndroidInfo","description":"Android related information. See Android related parameters in the\n[documentation](https://firebase.google.com/docs/dynamic-links/create-manually)."},"navigationInfo":{"$ref":"NavigationInfo","description":"Information of navigation behavior of a Firebase Dynamic Links."},"analyticsInfo":{"$ref":"AnalyticsInfo","description":"Parameters used for tracking. See all tracking parameters in the\n[documentation](https://firebase.google.com/docs/dynamic-links/create-manually)."},"dynamicLinkDomain":{"description":"Dynamic Links domain that the project owns, e.g. abcd.app.goo.gl\n[Learn\nmore](https://firebase.google.com/docs/dynamic-links/android/receive) on\nhow to set up Dynamic Link domain associated with your Firebase project.\n\nRequired if missing domain_uri_prefix.","type":"string"},"desktopInfo":{"description":"Desktop related information. See desktop related parameters in the\n[documentation](https://firebase.google.com/docs/dynamic-links/create-manually).","$ref":"DesktopInfo"},"link":{"description":"The link your app will open, You can specify any URL your app can handle.\nThis link must be a well-formatted URL, be properly URL-encoded, and use\nthe HTTP or HTTPS scheme. See 'link' parameters in the\n[documentation](https://firebase.google.com/docs/dynamic-links/create-manually).\n\nRequired.","type":"string"},"iosInfo":{"$ref":"IosInfo","description":"iOS related information. See iOS related parameters in the\n[documentation](https://firebase.google.com/docs/dynamic-links/create-manually)."},"socialMetaTagInfo":{"$ref":"SocialMetaTagInfo","description":"Parameters for social meta tag params.\nUsed to set meta tag data for link previews on social sites."},"domainUriPrefix":{"description":"E.g. https://maps.app.goo.gl, https://maps.page.link, https://g.co/maps\nMore examples can be found in description of getNormalizedUriPrefix in\nj/c/g/firebase/dynamiclinks/uri/DdlDomain.java\n\nWill fallback to dynamic_link_domain is this field is missing","type":"string"}},"id":"DynamicLinkInfo","description":"Information about a Dynamic Link."}},"icons":{"x16":"http://www.google.com/images/icons/product/search-16.gif","x32":"http://www.google.com/images/icons/product/search-32.gif"},"protocol":"rest","canonicalName":"Firebase Dynamic Links","auth":{"oauth2":{"scopes":{"https://www.googleapis.com/auth/firebase":{"description":"View and administer all your Firebase data and settings"}}}},"rootUrl":"https://firebasedynamiclinks.googleapis.com/","ownerDomain":"google.com"};