export default {"schemas":{"InfoTypeTransformation":{"description":"A transformation to apply to text that is identified as a specific\ninfo_type.","type":"object","properties":{"cryptoHashConfig":{"description":"Config for crypto hash.","$ref":"CryptoHashConfig"},"dateShiftConfig":{"$ref":"DateShiftConfig","description":"Config for date shift."},"characterMaskConfig":{"$ref":"CharacterMaskConfig","description":"Config for character mask."},"redactConfig":{"$ref":"RedactConfig","description":"Config for text redaction."},"infoTypes":{"description":"InfoTypes to apply this transformation to. If this is not specified, the\ntransformation applies to any info_type.","type":"array","items":{"type":"string"}},"replaceWithInfoTypeConfig":{"description":"Config for replace with InfoType.","$ref":"ReplaceWithInfoTypeConfig"}},"id":"InfoTypeTransformation"},"GoogleCloudHealthcareV1beta1DicomGcsDestination":{"description":"The Cloud Storage location where the output should be written, and the export\nconfiguration.","type":"object","properties":{"mimeType":{"type":"string","description":"MIME types supported by DICOM spec.\nEach file will be written in the following format:\n`.../{study_id}/{series_id}/{instance_id}[/{frame_number}].{extension}`\nThe frame_number component will exist only for multi-frame instances.\n\nRefer to the DICOM conformance statement for permissible MIME types:\nhttps://cloud.google.com/healthcare/docs/dicom#wado-rs\n\nThe following extensions will be used for output files:\n  application/dicom -> .dcm\n  image/jpeg -> .jpg\n  image/png -> .png\n\nIf unspecified, the instances will be exported in their original\nDICOM format."},"uriPrefix":{"type":"string","description":"The Cloud Storage destination to export to.\n\nURI for a Cloud Storage directory where result files should be written (in\nthe format `gs://{bucket-id}/{path/to/destination/dir}`). If there is no\ntrailing slash, the service will append one when composing the object path.\nThe user is responsible for creating the Cloud Storage bucket referenced in\n`uri_prefix`."}},"id":"GoogleCloudHealthcareV1beta1DicomGcsDestination"},"DicomStore":{"id":"DicomStore","description":"Represents a DICOM store.","type":"object","properties":{"labels":{"additionalProperties":{"type":"string"},"description":"User-supplied key-value pairs used to organize DICOM stores.\n\nLabel keys must be between 1 and 63 characters long, have a UTF-8 encoding\nof maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression:\n\\p{Ll}\\p{Lo}{0,62}\n\nLabel values are optional, must be between 1 and 63 characters long, have\na UTF-8 encoding of maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression: [\\p{Ll}\\p{Lo}\\p{N}_-]{0,63}\n\nNo more than 64 labels can be associated with a given store.","type":"object"},"notificationConfig":{"description":"Notification destination for new DICOM instances.\nSupplied by the client.","$ref":"NotificationConfig"},"name":{"description":"Output only. Resource name of the DICOM store, of the form\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`.","type":"string"}}},"SetIamPolicyRequest":{"description":"Request message for `SetIamPolicy` method.","type":"object","properties":{"updateMask":{"description":"OPTIONAL: A FieldMask specifying which fields of the policy to modify. Only\nthe fields in the mask will be modified. If no mask is provided, the\nfollowing default mask is used:\npaths: \"bindings, etag\"\nThis field is only used by Cloud IAM.","format":"google-fieldmask","type":"string"},"policy":{"description":"REQUIRED: The complete policy to be applied to the `resource`. The size of\nthe policy is limited to a few 10s of KB. An empty policy is a\nvalid policy but certain Cloud Platform services (such as Projects)\nmight reject them.","$ref":"Policy"}},"id":"SetIamPolicyRequest"},"ListHl7V2StoresResponse":{"description":"Lists the HL7v2 stores in the given dataset.","type":"object","properties":{"hl7V2Stores":{"type":"array","items":{"$ref":"Hl7V2Store"},"description":"The returned HL7v2 stores. Won't be more HL7v2 stores than the value of\npage_size in the request."},"nextPageToken":{"description":"Token to retrieve the next page of results or empty if there are no more\nresults in the list.","type":"string"}},"id":"ListHl7V2StoresResponse"},"SchemaConfig":{"properties":{"schemaType":{"enumDescriptions":["No schema type specified. Same as `LOSSLESS`.","A data-driven schema generated from the fields present in the FHIR data\nbeing exported, with no additional simplification.","Analytics schema defined by the FHIR community.\nSee https://github.com/FHIR/sql-on-fhir/blob/master/sql-on-fhir.md."],"enum":["SCHEMA_TYPE_UNSPECIFIED","LOSSLESS","ANALYTICS"],"description":"Specifies the output schema type. If unspecified, the default is\n`LOSSLESS`.","type":"string"},"recursiveStructureDepth":{"description":"The depth for all recursive structures in the output analytics\nschema. For example, `concept` in the CodeSystem resource is a recursive\nstructure; when the depth is 2, the CodeSystem table will have a column\ncalled `concept.concept` but not `concept.concept.concept`. If not\nspecified or set to 0, the server will use the default value 2.","format":"int64","type":"string"}},"id":"SchemaConfig","description":"Configuration for the FHIR BigQuery schema. Determines how the server\ngenerates the schema.","type":"object"},"Location":{"description":"A resource that represents Google Cloud Platform location.","type":"object","properties":{"labels":{"description":"Cross-service attributes for the location. For example\n\n    {\"cloud.googleapis.com/region\": \"us-east1\"}","type":"object","additionalProperties":{"type":"string"}},"name":{"description":"Resource name for the location, which may vary between implementations.\nFor example: `\"projects/example-project/locations/us-east1\"`","type":"string"},"locationId":{"description":"The canonical id for this location. For example: `\"us-east1\"`.","type":"string"},"displayName":{"description":"The friendly name for this location, typically a nearby city name.\nFor example, \"Tokyo\".","type":"string"},"metadata":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"description":"Service-specific metadata. For example the available capacity at the given\nlocation.","type":"object"}},"id":"Location"},"GoogleCloudHealthcareV1beta1FhirRestGcsDestination":{"description":"The configuration for exporting to Cloud Storage.","type":"object","properties":{"uriPrefix":{"description":"URI for a Cloud Storage directory where result files should be written (in\nthe format `gs://{bucket-id}/{path/to/destination/dir}`). If there is no\ntrailing slash, the service will append one when composing the object path.\nThe user is responsible for creating the Cloud Storage bucket referenced in\n`uri_prefix`.","type":"string"}},"id":"GoogleCloudHealthcareV1beta1FhirRestGcsDestination"},"Hl7V2Store":{"id":"Hl7V2Store","description":"Represents an HL7v2 store.","type":"object","properties":{"labels":{"description":"User-supplied key-value pairs used to organize HL7v2 stores.\n\nLabel keys must be between 1 and 63 characters long, have a UTF-8 encoding\nof maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression:\n\\p{Ll}\\p{Lo}{0,62}\n\nLabel values are optional, must be between 1 and 63 characters long, have\na UTF-8 encoding of maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression: [\\p{Ll}\\p{Lo}\\p{N}_-]{0,63}\n\nNo more than 64 labels can be associated with a given store.","type":"object","additionalProperties":{"type":"string"}},"notificationConfig":{"description":"The notification destination all messages (both Ingest & Create) are\npublished on. Only the message name is sent as part of the notification. If\nthis is unset, no notifications will be sent. Supplied by the client.","$ref":"NotificationConfig"},"parserConfig":{"$ref":"ParserConfig","description":"The configuration for the parser. It determines how the server parses the\nmessages."},"name":{"description":"Output only. Resource name of the HL7v2 store, of the form\n`projects/{project_id}/datasets/{dataset_id}/hl7V2Stores/{hl7v2_store_id}`.","type":"string"}}},"CryptoHashConfig":{"id":"CryptoHashConfig","description":"Pseudonymization method that generates surrogates via cryptographic hashing.\nUses SHA-256.\nOutputs a base64-encoded representation of the hashed output\n(for example, `L7k0BHmF1ha5U3NfGykjro4xWi1MPVQPjhMAZbSV9mM=`).","type":"object","properties":{"cryptoKey":{"description":"An AES 128/192/256 bit key. Causes the hash to be computed based on this\nkey. A default key is generated for each DeidentifyDataset operation and is\nused wherever crypto_key is not specified.","format":"byte","type":"string"}}},"Segment":{"description":"A segment in a structured format.","type":"object","properties":{"setId":{"description":"Set ID for segments that can be in a set. This can be empty if it is\nmissing or it is not applicable.","type":"string"},"fields":{"description":"A mapping from the positional location to the value.\nThe key string uses zero-based indexes separated by dots to identify\nFields, components and sub-components. A bracket notation is also used to\nidentify different instances of a repeated field.\nRegex for key: (\\d+)(\\[\\d+\\])?(.\\d+)?(.\\d+)?\n\nExamples of (key, value) pairs:\n- (0.1, \"foo\"): Component 1 of Field 0 has the value \"foo\".\n- (1.1.2, \"bar\"): Sub-component 2 of Component 1 of field 1 has the value\n\"bar\".\n- (1[2].1, \"baz\"): Component 1 of Instance 2 of Field 1, which is repeated,\nhas the value \"baz\".","type":"object","additionalProperties":{"type":"string"}},"segmentId":{"description":"A string that indicates the type of segment, e.g., EVN, PID.","type":"string"}},"id":"Segment"},"ListDatasetsResponse":{"description":"Lists the available datasets.","type":"object","properties":{"datasets":{"description":"The first page of datasets.","type":"array","items":{"$ref":"Dataset"}},"nextPageToken":{"description":"Token to retrieve the next page of results, or empty if there are no\nmore results in the list.","type":"string"}},"id":"ListDatasetsResponse"},"CreateMessageRequest":{"description":"Creates a new message.","type":"object","properties":{"message":{"description":"HL7v2 message.","$ref":"Message"}},"id":"CreateMessageRequest"},"TestIamPermissionsRequest":{"type":"object","properties":{"permissions":{"type":"array","items":{"type":"string"},"description":"The set of permissions to check for the `resource`. Permissions with\nwildcards (such as '*' or 'storage.*') are not allowed. For more\ninformation see\n[IAM Overview](https://cloud.google.com/iam/docs/overview#permissions)."}},"id":"TestIamPermissionsRequest","description":"Request message for `TestIamPermissions` method."},"CharacterMaskConfig":{"description":"Mask a string by replacing its characters with a fixed character.","type":"object","properties":{"maskingCharacter":{"description":"Character to mask the sensitive values. If not supplied, defaults to \"*\".","type":"string"}},"id":"CharacterMaskConfig"},"FhirConfig":{"description":"Specifies how de-identification of a FHIR store should be handled.","type":"object","properties":{"fieldMetadataList":{"description":"Specifies FHIR paths to match and how to transform them. Any field that\nis not matched by a FieldMetadata will be passed through to the output\ndataset unmodified. All extensions are removed in the output.","type":"array","items":{"$ref":"FieldMetadata"}}},"id":"FhirConfig"},"AuditConfig":{"type":"object","properties":{"service":{"description":"Specifies a service that will be enabled for audit logging.\nFor example, `storage.googleapis.com`, `cloudsql.googleapis.com`.\n`allServices` is a special value that covers all services.","type":"string"},"auditLogConfigs":{"description":"The configuration for logging of each type of permission.","type":"array","items":{"$ref":"AuditLogConfig"}}},"id":"AuditConfig","description":"Specifies the audit configuration for a service.\nThe configuration determines which permission types are logged, and what\nidentities, if any, are exempted from logging.\nAn AuditConfig must have one or more AuditLogConfigs.\n\nIf there are AuditConfigs for both `allServices` and a specific service,\nthe union of the two AuditConfigs is used for that service: the log_types\nspecified in each AuditConfig are enabled, and the exempted_members in each\nAuditLogConfig are exempted.\n\nExample Policy with multiple AuditConfigs:\n\n    {\n      \"audit_configs\": [\n        {\n          \"service\": \"allServices\"\n          \"audit_log_configs\": [\n            {\n              \"log_type\": \"DATA_READ\",\n              \"exempted_members\": [\n                \"user:foo@gmail.com\"\n              ]\n            },\n            {\n              \"log_type\": \"DATA_WRITE\",\n            },\n            {\n              \"log_type\": \"ADMIN_READ\",\n            }\n          ]\n        },\n        {\n          \"service\": \"fooservice.googleapis.com\"\n          \"audit_log_configs\": [\n            {\n              \"log_type\": \"DATA_READ\",\n            },\n            {\n              \"log_type\": \"DATA_WRITE\",\n              \"exempted_members\": [\n                \"user:bar@gmail.com\"\n              ]\n            }\n          ]\n        }\n      ]\n    }\n\nFor fooservice, this policy enables DATA_READ, DATA_WRITE and ADMIN_READ\nlogging. It also exempts foo@gmail.com from DATA_READ logging, and\nbar@gmail.com from DATA_WRITE logging."},"DeidentifyDatasetRequest":{"description":"Redacts identifying information from the specified dataset.","type":"object","properties":{"destinationDataset":{"type":"string","description":"The name of the dataset resource to create and write the redacted data to\n(e.g.,\n\n * The destination dataset must not exist.\n * The destination dataset must be in the same project as the source\n   dataset. De-identifying data across multiple projects is not supported."},"config":{"$ref":"DeidentifyConfig","description":"Deidentify configuration."}},"id":"DeidentifyDatasetRequest"},"ListFhirStoresResponse":{"properties":{"nextPageToken":{"description":"Token to retrieve the next page of results or empty if there are no more\nresults in the list.","type":"string"},"fhirStores":{"description":"The returned FHIR stores. Won't be more FHIR stores than the value of\npage_size in the request.","type":"array","items":{"$ref":"FhirStore"}}},"id":"ListFhirStoresResponse","description":"Lists the FHIR stores in the given dataset.","type":"object"},"GoogleCloudHealthcareV1beta1DicomGcsSource":{"id":"GoogleCloudHealthcareV1beta1DicomGcsSource","description":"Specifies the configuration for importing data from Cloud Storage.","type":"object","properties":{"uri":{"description":"Points to a Cloud Storage URI containing file(s) with\ncontent only. The URI must be in the following format:\n`gs://{bucket_id}/{object_id}`. The URI can include wildcards in\n`object_id` and thus identify multiple files. Supported wildcards:\n '*' to match 0 or more non-separator characters\n '**' to match 0 or more characters (including separators). Must be used at\n      the end of a path and with no other wildcards in the\n      path. Can also be used with a file extension (such as .dcm), which\n      imports all files with the extension in the specified directory and\n      its sub-directories. For example,\n      `gs://my-bucket/my-directory/**.dcm` imports all files with .dcm\n      extensions in `my-directory/` and its sub-directories.\n '?' to match 1 character\nAll other URI formats are invalid.\nFiles matching the wildcard are expected to contain content only, no\nmetadata.","type":"string"}}},"SearchResourcesRequest":{"type":"object","properties":{"resourceType":{"description":"The FHIR resource type to search, such as Patient or Observation. For a\ncomplete list, see the [FHIR Resource\nIndex](http://hl7.org/implement/standards/fhir/STU3/resourcelist.html).","type":"string"}},"id":"SearchResourcesRequest","description":"Request to search the resources in the specified FHIR store."},"ParserConfig":{"description":"The configuration for the parser. It determines how the server parses the\nmessages.","type":"object","properties":{"allowNullHeader":{"description":"Determines whether messages with no header are allowed.","type":"boolean"},"segmentTerminator":{"description":"Byte(s) to be used as the segment terminator. If this is unset, '\\r' will\nbe used as segment terminator.","format":"byte","type":"string"}},"id":"ParserConfig"},"Expr":{"description":"Represents an expression text. Example:\n\n    title: \"User account presence\"\n    description: \"Determines whether the request has a user account\"\n    expression: \"size(request.user) > 0\"","type":"object","properties":{"description":{"description":"An optional description of the expression. This is a longer text which\ndescribes the expression, e.g. when hovered over it in a UI.","type":"string"},"expression":{"description":"Textual representation of an expression in\nCommon Expression Language syntax.\n\nThe application context of the containing message determines which\nwell-known feature set of CEL is supported.","type":"string"},"title":{"description":"An optional title for the expression, i.e. a short string describing\nits purpose. This can be used e.g. in UIs which allow to enter the\nexpression.","type":"string"},"location":{"description":"An optional string indicating the location of the expression for error\nreporting, e.g. a file name and a position in the file.","type":"string"}},"id":"Expr"},"PatientId":{"properties":{"value":{"description":"The patient's unique identifier.","type":"string"},"type":{"description":"ID type, e.g. MRN or NHS.","type":"string"}},"id":"PatientId","description":"A patient identifier and associated type.","type":"object"},"IngestMessageRequest":{"type":"object","properties":{"message":{"description":"HL7v2 message to ingest.","$ref":"Message"}},"id":"IngestMessageRequest","description":"Ingests a message into the specified HL7v2 store."},"TestIamPermissionsResponse":{"description":"Response message for `TestIamPermissions` method.","type":"object","properties":{"permissions":{"description":"A subset of `TestPermissionsRequest.permissions` that the caller is\nallowed.","type":"array","items":{"type":"string"}}},"id":"TestIamPermissionsResponse"},"ImportDicomDataErrorDetails":{"description":"Returns the errors encountered during DICOM store import.","type":"object","properties":{"sampleErrors":{"description":"Deprecated. Use only for debugging purposes.\n\nContains sample errors encountered in imports of individual resources\n(for example, a Cloud Storage object).","type":"array","items":{"$ref":"ErrorDetail"}}},"id":"ImportDicomDataErrorDetails"},"DeidentifySummary":{"type":"object","properties":{"successStoreCount":{"description":"Number of stores successfully processed.","format":"int64","type":"string"},"successResourceCount":{"description":"Number of resources successfully processed.","format":"int64","type":"string"}},"id":"DeidentifySummary","description":"Contains a detailed summary of the Deidentify operation."},"FhirStore":{"id":"FhirStore","description":"Represents a FHIR store.","type":"object","properties":{"labels":{"additionalProperties":{"type":"string"},"description":"User-supplied key-value pairs used to organize FHIR stores.\n\nLabel keys must be between 1 and 63 characters long, have a UTF-8 encoding\nof maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression:\n\\p{Ll}\\p{Lo}{0,62}\n\nLabel values are optional, must be between 1 and 63 characters long, have\na UTF-8 encoding of maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression: [\\p{Ll}\\p{Lo}\\p{N}_-]{0,63}\n\nNo more than 64 labels can be associated with a given store.","type":"object"},"notificationConfig":{"$ref":"NotificationConfig","description":"If non-empty, publish all resource modifications of this FHIR store to\nthis destination. The Cloud Pub/Sub message attributes will contain a map\nwith a string describing the action that has triggered the notification,\ne.g. \"action\":\"CreateResource\"."},"name":{"description":"Output only. Resource name of the FHIR store, of the form\n`projects/{project_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}`.","type":"string"},"disableReferentialIntegrity":{"type":"boolean","description":"Whether to disable referential integrity in this FHIR store. This field is\nimmutable after FHIR store creation.\nThe default value is false, meaning that the API will enforce referential\nintegrity and fail the requests that will result in inconsistent state in\nthe FHIR store.\nWhen this field is set to true, the API will skip referential integrity\ncheck. Consequently, operations that rely on references, such as\nGetPatientEverything, will not return all the results if broken references\nexist."},"disableResourceVersioning":{"description":"Whether to disable resource versioning for this FHIR store. This field can\nnot be changed after the creation of FHIR store.\nIf set to false, which is the default behavior, all write operations will\ncause historical versions to be recorded automatically. The historical\nversions can be fetched through the history APIs, but cannot be updated.\nIf set to true, no historical versions will be kept. The server will send\nback errors for attempts to read the historical versions.","type":"boolean"},"enableHistoryImport":{"description":"Whether to allow the bulk import API to accept history bundles and directly\ninsert historical resource versions into the FHIR store. Importing resource\nhistories creates resource interactions that appear to have occurred in the\npast, which clients may not want to allow. If set to false, history bundles\nwithin an import will fail with an error.","type":"boolean"},"enableUpdateCreate":{"description":"Whether this FHIR store has the [updateCreate\ncapability](https://www.hl7.org/fhir/capabilitystatement-definitions.html#CapabilityStatement.rest.resource.updateCreate).\nThis determines if the client can use an Update operation to create a new\nresource with a client-specified ID. If false, all IDs are server-assigned\nthrough the Create operation and attempts to Update a non-existent resource\nwill return errors. Please treat the audit logs with appropriate levels of\ncare if client-specified resource IDs contain sensitive data such as\npatient identifiers, those IDs will be part of the FHIR resource path\nrecorded in Cloud audit logs and Cloud Pub/Sub notifications.","type":"boolean"}}},"ImageConfig":{"id":"ImageConfig","description":"Specifies how de-identification of image pixel should be handled.","type":"object","properties":{"textRedactionMode":{"description":"Determines how to redact text from image.","type":"string","enumDescriptions":["No text redaction specified. Same as REDACT_NO_TEXT.","Redact all text.","Redact sensitive text.","Do not redact text."],"enum":["TEXT_REDACTION_MODE_UNSPECIFIED","REDACT_ALL_TEXT","REDACT_SENSITIVE_TEXT","REDACT_NO_TEXT"]}}},"ProgressCounter":{"description":"ProgressCounter provides counters to describe an operation's progress.","type":"object","properties":{"pending":{"description":"The number of units that are pending in the operation.","format":"int64","type":"string"},"failure":{"description":"The number of units that failed in the operation.","format":"int64","type":"string"},"success":{"type":"string","description":"The number of units that succeeded in the operation.","format":"int64"}},"id":"ProgressCounter"},"Dataset":{"description":"A message representing a health dataset.\n\nA health dataset represents a collection of healthcare data pertaining to one\nor more patients. This may include multiple modalities of healthcare data,\nsuch as electronic medical records or medical imaging data.","type":"object","properties":{"timeZone":{"description":"The default timezone used by this dataset. Must be a either a valid IANA\ntime zone name such as \"America/New_York\" or empty, which defaults to UTC.\nThis is used for parsing times in resources (e.g., HL7 messages) where no\nexplicit timezone is specified.","type":"string"},"name":{"description":"Output only. Resource name of the dataset, of the form\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}`.","type":"string"}},"id":"Dataset"},"TagFilterList":{"id":"TagFilterList","description":"List of tags to be filtered.","type":"object","properties":{"tags":{"description":"Tags to be filtered. Tags must be DICOM Data Elements, File Meta\nElements, or Directory Structuring Elements, as defined at:\nhttp://dicom.nema.org/medical/dicom/current/output/html/part06.html#table_6-1,.\nThey may be provided by \"Keyword\" or \"Tag\". For example \"PatientID\",\n\"00100010\".","type":"array","items":{"type":"string"}}}},"ParsedData":{"description":"The content of a HL7v2 message in a structured format.","type":"object","properties":{"segments":{"type":"array","items":{"$ref":"Segment"}}},"id":"ParsedData"},"ReplaceWithInfoTypeConfig":{"id":"ReplaceWithInfoTypeConfig","description":"When using the INSPECT_AND_TRANSFORM action, each match is replaced with\nthe name of the info_type. For example, \"My name is Jake\" becomes \"My name is\n[PERSON_NAME].\" The TRANSFORM action is equivalent to redacting.","type":"object","properties":{}},"DicomConfig":{"description":"Specifies the parameters needed for de-identification of DICOM stores.","type":"object","properties":{"filterProfile":{"enum":["TAG_FILTER_PROFILE_UNSPECIFIED","MINIMAL_KEEP_LIST_PROFILE","ATTRIBUTE_CONFIDENTIALITY_BASIC_PROFILE","KEEP_ALL_PROFILE","DEIDENTIFY_TAG_CONTENTS"],"description":"Tag filtering profile that determines which tags to keep/remove.","type":"string","enumDescriptions":["No tag filtration profile provided. Same as KEEP_ALL_PROFILE.","Keep only tags required to produce valid DICOM.","Remove tags based on DICOM Standard's Attribute Confidentiality Basic\nProfile (DICOM Standard Edition 2018e)\nhttp://dicom.nema.org/medical/dicom/2018e/output/chtml/part15/chapter_E.html.","Keep all tags.","Inspects within tag contents and replaces sensitive text. The process\ncan be configured using the TextConfig.\nApplies to all tags with the following Value Representation names:\nAE, LO, LT, PN, SH, ST, UC, UT, DA, DT, AS"]},"keepList":{"description":"List of tags to keep. Remove all other tags.","$ref":"TagFilterList"},"removeList":{"description":"List of tags to remove. Keep all other tags.","$ref":"TagFilterList"}},"id":"DicomConfig"},"ErrorDetail":{"id":"ErrorDetail","description":"Structure to describe the error encountered during batch operation on one\nresource. This is used both for sample errors in operation response, and\nfor format of errors in error reports.","type":"object","properties":{"error":{"$ref":"Status","description":"The status of the error."},"resource":{"description":"The identifier of the resource.","type":"string"}}},"Empty":{"description":"A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.","type":"object","properties":{},"id":"Empty"},"ListMessagesResponse":{"description":"Lists the messages in the specified HL7v2 store.","type":"object","properties":{"nextPageToken":{"description":"Token to retrieve the next page of results or empty if there are no more\nresults in the list.","type":"string"},"messages":{"description":"The returned message names. Won't be more values than the value of\npage_size in the request.","type":"array","items":{"type":"string"}}},"id":"ListMessagesResponse"},"GoogleCloudHealthcareV1beta1FhirBigQueryDestination":{"properties":{"datasetUri":{"description":"BigQuery URI to a dataset, up to 2000 characters long, in the format\n`bq://projectId.bqDatasetId`","type":"string"},"schemaConfig":{"$ref":"SchemaConfig","description":"The configuration for the exported BigQuery schema."}},"id":"GoogleCloudHealthcareV1beta1FhirBigQueryDestination","description":"The configuration for exporting to BigQuery.","type":"object"},"FieldMetadata":{"type":"object","properties":{"paths":{"description":"List of paths to FHIR fields to be redacted. Each path is a\nperiod-separated list where each component is either a field name or\nFHIR type name, for example: Patient, HumanName.\nFor \"choice\" types (those defined in the FHIR spec with the form:\nfield[x]) we use two separate components. e.g. \"deceasedAge.unit\" is\nmatched by \"Deceased.Age.unit\".\nSupported types are: AdministrativeGenderCode, Code, Date, DateTime,\nDecimal, HumanName, Id, LanguageCode, Markdown, MimeTypeCode, Oid,\nString, Uri, Uuid, Xhtml.","type":"array","items":{"type":"string"}},"action":{"description":"Deidentify action for one field.","type":"string","enumDescriptions":["No action specified.","Transform the entire field.","Inspect and transform any found PHI.","Do not transform."],"enum":["ACTION_UNSPECIFIED","TRANSFORM","INSPECT_AND_TRANSFORM","DO_NOT_TRANSFORM"]}},"id":"FieldMetadata","description":"Specifies FHIR paths to match, and how to handle de-identification of\nmatching fields."},"AuditLogConfig":{"properties":{"exemptedMembers":{"description":"Specifies the identities that do not cause logging for this type of\npermission.\nFollows the same format of Binding.members.","type":"array","items":{"type":"string"}},"logType":{"enum":["LOG_TYPE_UNSPECIFIED","ADMIN_READ","DATA_WRITE","DATA_READ"],"description":"The log type that this config enables.","type":"string","enumDescriptions":["Default case. Should never be this.","Admin reads. Example: CloudIAM getIamPolicy","Data writes. Example: CloudSQL Users create","Data reads. Example: CloudSQL Users list"]}},"id":"AuditLogConfig","description":"Provides the configuration for logging a type of permissions.\nExample:\n\n    {\n      \"audit_log_configs\": [\n        {\n          \"log_type\": \"DATA_READ\",\n          \"exempted_members\": [\n            \"user:foo@gmail.com\"\n          ]\n        },\n        {\n          \"log_type\": \"DATA_WRITE\",\n        }\n      ]\n    }\n\nThis enables 'DATA_READ' and 'DATA_WRITE' logging, while exempting\nfoo@gmail.com from DATA_READ logging.","type":"object"},"ImportDicomDataRequest":{"description":"Imports data into the specified DICOM store.\nReturns an error if any of the files to import are not DICOM files. This\nAPI will accept duplicate DICOM instances, by simply ignoring the newly\npushed instance (it will not overwrite).","type":"object","properties":{"gcsSource":{"$ref":"GoogleCloudHealthcareV1beta1DicomGcsSource","description":"Cloud Storage source data location and import configuration.\n\nThe Cloud Storage location requires the `roles/storage.objectViewer`\nCloud IAM role."}},"id":"ImportDicomDataRequest"},"ListDicomStoresResponse":{"description":"Lists the DICOM stores in the given dataset.","type":"object","properties":{"nextPageToken":{"description":"Token to retrieve the next page of results or empty if there are no more\nresults in the list.","type":"string"},"dicomStores":{"description":"The returned DICOM stores. Won't be more DICOM stores than the value of\npage_size in the request.","type":"array","items":{"$ref":"DicomStore"}}},"id":"ListDicomStoresResponse"},"DeidentifyErrorDetails":{"id":"DeidentifyErrorDetails","description":"Contains the status of the Deidentify operation.","type":"object","properties":{"failureResourceCount":{"description":"Number of resources failed to process.","format":"int64","type":"string"},"successStoreCount":{"description":"Number of stores successfully processed.","format":"int64","type":"string"},"successResourceCount":{"description":"Number of resources successfully processed.","format":"int64","type":"string"},"failureStoreCount":{"description":"Number of stores failed to process.","format":"int64","type":"string"}}},"Policy":{"description":"Defines an Identity and Access Management (IAM) policy. It is used to\nspecify access control policies for Cloud Platform resources.\n\n\nA `Policy` consists of a list of `bindings`. A `binding` binds a list of\n`members` to a `role`, where the members can be user accounts, Google groups,\nGoogle domains, and service accounts. A `role` is a named list of permissions\ndefined by IAM.\n\n**JSON Example**\n\n    {\n      \"bindings\": [\n        {\n          \"role\": \"roles/owner\",\n          \"members\": [\n            \"user:mike@example.com\",\n            \"group:admins@example.com\",\n            \"domain:google.com\",\n            \"serviceAccount:my-other-app@appspot.gserviceaccount.com\"\n          ]\n        },\n        {\n          \"role\": \"roles/viewer\",\n          \"members\": [\"user:sean@example.com\"]\n        }\n      ]\n    }\n\n**YAML Example**\n\n    bindings:\n    - members:\n      - user:mike@example.com\n      - group:admins@example.com\n      - domain:google.com\n      - serviceAccount:my-other-app@appspot.gserviceaccount.com\n      role: roles/owner\n    - members:\n      - user:sean@example.com\n      role: roles/viewer\n\n\nFor a description of IAM and its features, see the\n[IAM developer's guide](https://cloud.google.com/iam/docs).","type":"object","properties":{"etag":{"description":"`etag` is used for optimistic concurrency control as a way to help\nprevent simultaneous updates of a policy from overwriting each other.\nIt is strongly suggested that systems make use of the `etag` in the\nread-modify-write cycle to perform policy updates in order to avoid race\nconditions: An `etag` is returned in the response to `getIamPolicy`, and\nsystems are expected to put that etag in the request to `setIamPolicy` to\nensure that their change will be applied to the same version of the policy.\n\nIf no `etag` is provided in the call to `setIamPolicy`, then the existing\npolicy is overwritten blindly.","format":"byte","type":"string"},"version":{"type":"integer","description":"Deprecated.","format":"int32"},"auditConfigs":{"description":"Specifies cloud audit logging configuration for this policy.","type":"array","items":{"$ref":"AuditConfig"}},"bindings":{"description":"Associates a list of `members` to a `role`.\n`bindings` with no members will result in an error.","type":"array","items":{"$ref":"Binding"}}},"id":"Policy"},"ListLocationsResponse":{"description":"The response message for Locations.ListLocations.","type":"object","properties":{"locations":{"description":"A list of locations that matches the specified filter in the request.","type":"array","items":{"$ref":"Location"}},"nextPageToken":{"type":"string","description":"The standard List next-page token."}},"id":"ListLocationsResponse"},"DateShiftConfig":{"description":"Shift a date forward or backward in time by a random amount which is\nconsistent for a given patient and crypto key combination.","type":"object","properties":{"cryptoKey":{"description":"An AES 128/192/256 bit key. Causes the shift to be computed based on this\nkey and the patient ID. A default key is generated for each\nDeidentifyDataset operation and is used wherever crypto_key is not\nspecified.","format":"byte","type":"string"}},"id":"DateShiftConfig"},"IngestMessageResponse":{"description":"Acknowledges that a message has been ingested into the specified\nHL7v2 store.","type":"object","properties":{"message":{"$ref":"Message","description":"Created message resource."},"hl7Ack":{"type":"string","description":"HL7v2 ACK message.","format":"byte"}},"id":"IngestMessageResponse"},"RedactConfig":{"description":"Define how to redact sensitive values. Default behaviour is erase,\ne.g. \"My name is Jake.\" becomes \"My name is .\"","type":"object","properties":{},"id":"RedactConfig"},"ImportResourcesRequest":{"description":"Request to import resources.","type":"object","properties":{"gcsSource":{"$ref":"GoogleCloudHealthcareV1beta1FhirRestGcsSource","description":"Cloud Storage source data location and import configuration.\n\nThe Cloud Storage location requires the `roles/storage.objectViewer`\nCloud IAM role.\n\nEach Cloud Storage object should be a text file that contains the format\nspecified in ContentStructure."},"contentStructure":{"enum":["CONTENT_STRUCTURE_UNSPECIFIED","BUNDLE","RESOURCE"],"description":"The content structure in the source location. If not specified, the server\ntreats the input source files as BUNDLE.","type":"string","enumDescriptions":["","The source file contains one or more lines of newline-delimited JSON\n(ndjson). Each line is a bundle, which contains one or more resources.\nSet the bundle type to `history` to import resource versions.","The source file contains one or more lines of newline-delimited JSON\n(ndjson). Each line is a single resource."]}},"id":"ImportResourcesRequest"},"ExportResourcesRequest":{"description":"Request to export resources.","type":"object","properties":{"gcsDestination":{"description":"The Cloud Storage output destination.\n\nThe Cloud Storage location requires the `roles/storage.objectAdmin` Cloud\nIAM role.\n\nThe exported outputs are\norganized by FHIR resource types. The server will create one object per\nresource type. Each object contains newline delimited JSON, and each line\nis a FHIR resource.","$ref":"GoogleCloudHealthcareV1beta1FhirRestGcsDestination"},"bigqueryDestination":{"$ref":"GoogleCloudHealthcareV1beta1FhirBigQueryDestination","description":"The BigQuery output destination.\n\nThe BigQuery location requires two IAM roles:\n`roles/bigquery.dataEditor` and `roles/bigquery.jobUser`.\n\nThe output will be one BigQuery table per resource type."}},"id":"ExportResourcesRequest"},"Operation":{"properties":{"done":{"description":"If the value is `false`, it means the operation is still in progress.\nIf `true`, the operation is completed, and either `error` or `response` is\navailable.","type":"boolean"},"response":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"description":"The normal response of the operation in case of success.  If the original\nmethod returns no data on success, such as `Delete`, the response is\n`google.protobuf.Empty`.  If the original method is standard\n`Get`/`Create`/`Update`, the response should be the resource.  For other\nmethods, the response should have the type `XxxResponse`, where `Xxx`\nis the original method name.  For example, if the original method name\nis `TakeSnapshot()`, the inferred response type is\n`TakeSnapshotResponse`.","type":"object"},"name":{"description":"The server-assigned name, which is only unique within the same service that\noriginally returns it. If you use the default HTTP mapping, the\n`name` should be a resource name ending with `operations/{unique_id}`.","type":"string"},"error":{"description":"The error result of the operation in case of failure or cancellation.","$ref":"Status"},"metadata":{"description":"Service-specific metadata associated with the operation.  It typically\ncontains progress information and common metadata such as create time.\nSome services might not provide such metadata.  Any method that returns a\nlong-running operation should document the metadata type, if any.","type":"object","additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"}}},"id":"Operation","description":"This resource represents a long-running operation that is the result of a\nnetwork API call.","type":"object"},"GoogleCloudHealthcareV1beta1FhirRestImportResourcesResponse":{"description":"Final response of importing resources.\nThis structure will be included in the\nresponse to describe the detailed\noutcome. It will only be included when the operation finishes successfully.","type":"object","properties":{"fhirStore":{"description":"The name of the FHIR store where the resources have been imported, in the\nformat\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}`.","type":"string"},"inputSize":{"description":"The total number of resources included in the source data.","format":"int64","type":"string"}},"id":"GoogleCloudHealthcareV1beta1FhirRestImportResourcesResponse"},"Status":{"description":"The `Status` type defines a logical error model that is suitable for\ndifferent programming environments, including REST APIs and RPC APIs. It is\nused by [gRPC](https://github.com/grpc). Each `Status` message contains\nthree pieces of data: error code, error message, and error details.\n\nYou can find out more about this error model and how to work with it in the\n[API Design Guide](https://cloud.google.com/apis/design/errors).","type":"object","properties":{"code":{"description":"The status code, which should be an enum value of google.rpc.Code.","format":"int32","type":"integer"},"message":{"description":"A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.","type":"string"},"details":{"type":"array","items":{"additionalProperties":{"type":"any","description":"Properties of the object. Contains field @type with type URL."},"type":"object"},"description":"A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use."}},"id":"Status"},"Binding":{"description":"Associates `members` with a `role`.","type":"object","properties":{"condition":{"$ref":"Expr","description":"The condition that is associated with this binding.\nNOTE: An unsatisfied condition will not allow user access via current\nbinding. Different bindings, including their conditions, are examined\nindependently."},"members":{"description":"Specifies the identities requesting access for a Cloud Platform resource.\n`members` can have the following values:\n\n* `allUsers`: A special identifier that represents anyone who is\n   on the internet; with or without a Google account.\n\n* `allAuthenticatedUsers`: A special identifier that represents anyone\n   who is authenticated with a Google account or a service account.\n\n* `user:{emailid}`: An email address that represents a specific Google\n   account. For example, `alice@gmail.com` .\n\n\n* `serviceAccount:{emailid}`: An email address that represents a service\n   account. For example, `my-other-app@appspot.gserviceaccount.com`.\n\n* `group:{emailid}`: An email address that represents a Google group.\n   For example, `admins@example.com`.\n\n\n* `domain:{domain}`: The G Suite domain (primary) that represents all the\n   users of that domain. For example, `google.com` or `example.com`.\n\n","type":"array","items":{"type":"string"}},"role":{"description":"Role that is assigned to `members`.\nFor example, `roles/viewer`, `roles/editor`, or `roles/owner`.","type":"string"}},"id":"Binding"},"ExportDicomDataRequest":{"id":"ExportDicomDataRequest","description":"Exports data from the specified DICOM store.\nIf a given resource (e.g., a DICOM object with the same SOPInstance UID)\nalready exists in the output, it is overwritten with the version\nin the source dataset.\nExported DICOM data will persist when the DICOM store from which it was\nexported is deleted.","type":"object","properties":{"gcsDestination":{"description":"The Cloud Storage output destination.\n\nThe Cloud Storage location requires the `roles/storage.objectAdmin` Cloud\nIAM role.","$ref":"GoogleCloudHealthcareV1beta1DicomGcsDestination"},"bigqueryDestination":{"$ref":"GoogleCloudHealthcareV1beta1DicomBigQueryDestination","description":"The BigQuery output destination.\n\nYou can only export to a BigQuery dataset that's in the same project as\nthe DICOM store you're exporting from.\n\nThe BigQuery location requires two IAM roles:\n`roles/bigquery.dataEditor` and `roles/bigquery.jobUser`."}}},"DeidentifyConfig":{"description":"Configures de-id options specific to different types of content.\nEach submessage customizes the handling of an\nhttps://tools.ietf.org/html/rfc6838 media type or subtype. Configs are\napplied in a nested manner at runtime.","type":"object","properties":{"dicom":{"description":"Configures de-id of application/DICOM content.","$ref":"DicomConfig"},"fhir":{"description":"Configures de-id of application/FHIR content.","$ref":"FhirConfig"},"image":{"$ref":"ImageConfig","description":"Configures de-identification of image pixels wherever they are found in the\nsource_dataset."},"text":{"description":"Configures de-identification of text wherever it is found in the\nsource_dataset.","$ref":"TextConfig"}},"id":"DeidentifyConfig"},"GoogleCloudHealthcareV1beta1FhirRestImportResourcesErrorDetails":{"description":"Error response of importing resources.\nThis structure will be included in the\nerror details to describe the\ndetailed error. It will only be included when the operation finishes with\nsome failure.","type":"object","properties":{"errorCount":{"description":"The number of resources that had errors.","format":"int64","type":"string"},"fhirStore":{"description":"The name of the FHIR store where resources have been imported, in the\nformat\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}`.","type":"string"},"inputSize":{"description":"The total number of resources included in the source data. This is the sum\nof the success and error counts.","format":"int64","type":"string"},"successCount":{"type":"string","description":"The number of resources that have been imported.","format":"int64"}},"id":"GoogleCloudHealthcareV1beta1FhirRestImportResourcesErrorDetails"},"TextConfig":{"type":"object","properties":{"transformations":{"type":"array","items":{"$ref":"InfoTypeTransformation"},"description":"The transformations to apply to the detected data."}},"id":"TextConfig"},"HttpBody":{"description":"Message that represents an arbitrary HTTP body. It should only be used for\npayload formats that can't be represented as JSON, such as raw binary or\nan HTML page.\n\n\nThis message can be used both in streaming and non-streaming API methods in\nthe request as well as the response.\n\nIt can be used as a top-level request field, which is convenient if one\nwants to extract parameters from either the URL or HTTP template into the\nrequest fields and also want access to the raw HTTP body.\n\nExample:\n\n    message GetResourceRequest {\n      // A unique request id.\n      string request_id = 1;\n\n      // The raw HTTP body is bound to this field.\n      google.api.HttpBody http_body = 2;\n    }\n\n    service ResourceService {\n      rpc GetResource(GetResourceRequest) returns (google.api.HttpBody);\n      rpc UpdateResource(google.api.HttpBody) returns\n      (google.protobuf.Empty);\n    }\n\nExample with streaming methods:\n\n    service CaldavService {\n      rpc GetCalendar(stream google.api.HttpBody)\n        returns (stream google.api.HttpBody);\n      rpc UpdateCalendar(stream google.api.HttpBody)\n        returns (stream google.api.HttpBody);\n    }\n\nUse of this type only changes how the request and response bodies are\nhandled, all other features will continue to work unchanged.","type":"object","properties":{"extensions":{"description":"Application specific response metadata. Must be set in the first response\nfor streaming APIs.","type":"array","items":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"type":"object"}},"data":{"description":"The HTTP request/response body as raw binary.","format":"byte","type":"string"},"contentType":{"description":"The HTTP Content-Type header value specifying the content type of the body.","type":"string"}},"id":"HttpBody"},"ListOperationsResponse":{"description":"The response message for Operations.ListOperations.","type":"object","properties":{"nextPageToken":{"description":"The standard List next-page token.","type":"string"},"operations":{"description":"A list of operations that matches the specified filter in the request.","type":"array","items":{"$ref":"Operation"}}},"id":"ListOperationsResponse"},"OperationMetadata":{"description":"OperationMetadata provides information about the operation execution.\nReturned in the long-running operation's metadata field.","type":"object","properties":{"apiMethodName":{"description":"The name of the API method that initiated the operation.","type":"string"},"counter":{"$ref":"ProgressCounter"},"createTime":{"description":"The time at which the operation was created by the API.","format":"google-datetime","type":"string"},"endTime":{"description":"The time at which execution was completed.","format":"google-datetime","type":"string"}},"id":"OperationMetadata"},"Message":{"description":"A complete HL7v2 message.\nSee http://www.hl7.org/implement/standards/index.cfm?ref=common for details\non the standard.","type":"object","properties":{"sendTime":{"description":"The datetime the sending application sent this message. MSH-7.","format":"google-datetime","type":"string"},"sendFacility":{"description":"The hospital that this message came from. MSH-4.","type":"string"},"data":{"description":"Raw message bytes.","format":"byte","type":"string"},"messageType":{"description":"The message type and trigger event for this message. MSH-9.","type":"string"},"patientIds":{"description":"All patient IDs listed in the PID-2, PID-3, and PID-4 segments of this\nmessage.","type":"array","items":{"$ref":"PatientId"}},"labels":{"additionalProperties":{"type":"string"},"description":"User-supplied key-value pairs used to organize HL7v2 stores.\n\nLabel keys must be between 1 and 63 characters long, have a UTF-8 encoding\nof maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression:\n\\p{Ll}\\p{Lo}{0,62}\n\nLabel values are optional, must be between 1 and 63 characters long, have\na UTF-8 encoding of maximum 128 bytes, and must conform to the\nfollowing PCRE regular expression: [\\p{Ll}\\p{Lo}\\p{N}_-]{0,63}\n\nNo more than 64 labels can be associated with a given store.","type":"object"},"createTime":{"description":"Output only. The datetime when the message was created. Set by the server.","format":"google-datetime","type":"string"},"parsedData":{"$ref":"ParsedData","description":"Output only. The parsed version of the raw message data."},"name":{"description":"Resource name of the Message, of the form\n`projects/{project_id}/datasets/{dataset_id}/hl7V2Stores/{hl7_v2_store_id}/messages/{message_id}`.\nAssigned by the server.","type":"string"}},"id":"Message"},"GoogleCloudHealthcareV1beta1DicomBigQueryDestination":{"description":"The BigQuery table where the output should be written.","type":"object","properties":{"force":{"description":"If the destination table already exists and this flag is `TRUE`, the table\nwill be overwritten by the contents of the DICOM store. If the flag is not\nset and the destination table already exists, the export call returns an\nerror.","type":"boolean"},"tableUri":{"description":"BigQuery URI to a table, up to 2000 characters long, in the format\n`bq://projectId.bqDatasetId.tableId`","type":"string"}},"id":"GoogleCloudHealthcareV1beta1DicomBigQueryDestination"},"GoogleCloudHealthcareV1beta1FhirRestExportResourcesResponse":{"description":"Final response of exporting resources.\nThis structure will be included in the\nresponse to describe the detailed\noutcome. It will only be included when the operation finishes.","type":"object","properties":{"resourceCount":{"description":"The total number of resources exported from the requested FHIR store.","format":"int64","type":"string"},"fhirStore":{"description":"The name of the FHIR store where resources have been exported, in the\nformat\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}`.","type":"string"}},"id":"GoogleCloudHealthcareV1beta1FhirRestExportResourcesResponse"},"GoogleCloudHealthcareV1beta1FhirRestGcsSource":{"description":"Specifies the configuration for importing data from Cloud Storage.","type":"object","properties":{"uri":{"description":"Points to a Cloud Storage URI containing file(s) to import.\n\nThe URI must be in the following format: `gs://{bucket_id}/{object_id}`.\nThe URI can include wildcards in `object_id` and thus identify multiple\nfiles. Supported wildcards:\n\n*  `*` to match 0 or more non-separator characters\n*  `**` to match 0 or more characters (including separators). Must be used\nat the end of a path and with no other wildcards in the\npath. Can also be used with a file extension (such as .ndjson), which\nimports all files with the extension in the specified directory and\nits sub-directories. For example, `gs://my-bucket/my-directory/**.ndjson`\nimports all files with `.ndjson` extensions in `my-directory/` and its\nsub-directories.\n*  `?` to match 1 character\n\nFiles matching the wildcard are expected to contain content only, no\nmetadata.","type":"string"}},"id":"GoogleCloudHealthcareV1beta1FhirRestGcsSource"},"NotificationConfig":{"type":"object","properties":{"pubsubTopic":{"description":"The [Cloud Pub/Sub](https://cloud.google.com/pubsub/docs/) topic that\nnotifications of changes are published on. Supplied by the client.\nPubsubMessage.Data will contain the resource name.\nPubsubMessage.MessageId is the ID of this message. It is guaranteed to be\nunique within the topic.\nPubsubMessage.PublishTime is the time at which the message was published.\nNotifications are only sent if the topic is\nnon-empty. [Topic\nnames](https://cloud.google.com/pubsub/docs/overview#names) must be scoped\nto a project. cloud-healthcare@system.gserviceaccount.com must have\npublisher permissions on the given Cloud Pub/Sub topic. Not having adequate\npermissions will cause the calls that send notifications to fail.","type":"string"}},"id":"NotificationConfig","description":"Specifies where notifications should be sent upon changes to a data store."}},"protocol":"rest","icons":{"x16":"http://www.google.com/images/icons/product/search-16.gif","x32":"http://www.google.com/images/icons/product/search-32.gif"},"canonicalName":"Cloud Healthcare","auth":{"oauth2":{"scopes":{"https://www.googleapis.com/auth/cloud-platform":{"description":"View and manage your data across Google Cloud Platform services"}}}},"rootUrl":"https://healthcare.googleapis.com/","ownerDomain":"google.com","name":"healthcare","batchPath":"batch","fullyEncodeReservedExpansion":true,"title":"Cloud Healthcare API","ownerName":"Google","resources":{"projects":{"resources":{"locations":{"methods":{"list":{"flatPath":"v1beta1/projects/{projectsId}/locations","path":"v1beta1/{+name}/locations","id":"healthcare.projects.locations.list","description":"Lists information about the supported locations for this service.","response":{"$ref":"ListLocationsResponse"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"filter":{"type":"string","location":"query","description":"The standard list filter."},"name":{"required":true,"type":"string","pattern":"^projects/[^/]+$","location":"path","description":"The resource that owns the locations collection, if applicable."},"pageToken":{"location":"query","description":"The standard list page token.","type":"string"},"pageSize":{"location":"query","description":"The standard list page size.","format":"int32","type":"integer"}}},"get":{"description":"Gets information about a location.","response":{"$ref":"Location"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"description":"Resource name for the location.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+$","location":"path"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.get"}},"resources":{"datasets":{"methods":{"list":{"response":{"$ref":"ListDatasetsResponse"},"parameterOrder":["parent"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"pageToken":{"description":"The next_page_token value returned from a previous List request, if any.","type":"string","location":"query"},"pageSize":{"type":"integer","location":"query","description":"The maximum number of items to return. Capped to 100 if not specified.\nMay not be larger than 1000.","format":"int32"},"parent":{"description":"The name of the project whose datasets should be listed (e.g.,\n`projects/{project_id}/locations/{location_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+$","location":"path"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets","path":"v1beta1/{+parent}/datasets","id":"healthcare.projects.locations.datasets.list","description":"Lists the health datasets in the current project."},"create":{"path":"v1beta1/{+parent}/datasets","id":"healthcare.projects.locations.datasets.create","request":{"$ref":"Dataset"},"description":"Creates a new health dataset. Results are returned through the\nOperation interface which returns either an\n`Operation.response` which contains a Dataset or\n`Operation.error`. The metadata\nfield type is OperationMetadata.\nA Google Cloud Platform project can contain up to 500 datasets across all\nregions.","response":{"$ref":"Operation"},"parameterOrder":["parent"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"parent":{"description":"The name of the project in which the dataset should be created (e.g.,\n`projects/{project_id}/locations/{location_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+$","location":"path"},"datasetId":{"type":"string","location":"query","description":"The ID of the dataset that is being created.\nThe string must match the following regex: `[\\p{L}\\p{N}_\\-\\.]{1,256}`."}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets"},"setIamPolicy":{"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}:setIamPolicy","id":"healthcare.projects.locations.datasets.setIamPolicy","path":"v1beta1/{+resource}:setIamPolicy","request":{"$ref":"SetIamPolicyRequest"},"description":"Sets the access control policy on the specified resource. Replaces any\nexisting policy.","httpMethod":"POST","parameterOrder":["resource"],"response":{"$ref":"Policy"},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"resource":{"required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+$","location":"path","description":"REQUIRED: The resource for which the policy is being specified.\nSee the operation documentation for the appropriate value for this field."}}},"getIamPolicy":{"description":"Gets the access control policy for a resource.\nReturns an empty policy if the resource exists and does not have a policy\nset.","response":{"$ref":"Policy"},"parameterOrder":["resource"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"options.requestedPolicyVersion":{"location":"query","description":"Optional. The policy format version to be returned.\nAcceptable values are 0 and 1.\nIf the value is 0, or the field is omitted, policy format version 1 will be\nreturned.","format":"int32","type":"integer"},"resource":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+$","location":"path","description":"REQUIRED: The resource for which the policy is being requested.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}:getIamPolicy","path":"v1beta1/{+resource}:getIamPolicy","id":"healthcare.projects.locations.datasets.getIamPolicy"},"patch":{"description":"Updates dataset metadata.","request":{"$ref":"Dataset"},"httpMethod":"PATCH","parameterOrder":["name"],"response":{"$ref":"Dataset"},"parameters":{"updateMask":{"type":"string","location":"query","description":"The update mask applies to the resource. For the `FieldMask` definition,\nsee\nhttps://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask","format":"google-fieldmask"},"name":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+$","location":"path","description":"Output only. Resource name of the dataset, of the form\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}`.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}","id":"healthcare.projects.locations.datasets.patch","path":"v1beta1/{+name}"},"get":{"description":"Gets any metadata associated with a dataset.","httpMethod":"GET","parameterOrder":["name"],"response":{"$ref":"Dataset"},"parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+$","location":"path","description":"The name of the dataset to read (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}`).","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}","id":"healthcare.projects.locations.datasets.get","path":"v1beta1/{+name}"},"testIamPermissions":{"response":{"$ref":"TestIamPermissionsResponse"},"parameterOrder":["resource"],"httpMethod":"POST","parameters":{"resource":{"description":"REQUIRED: The resource for which the policy detail is being requested.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}:testIamPermissions","path":"v1beta1/{+resource}:testIamPermissions","id":"healthcare.projects.locations.datasets.testIamPermissions","description":"Returns permissions that a caller has on the specified resource.\nIf the resource does not exist, this will return an empty set of\npermissions, not a NOT_FOUND error.\n\nNote: This operation is designed to be used for building permission-aware\nUIs and command-line tools, not for authorization checking. This operation\nmay \"fail open\" without warning.","request":{"$ref":"TestIamPermissionsRequest"}},"deidentify":{"description":"Creates a new dataset containing de-identified data from the source\ndataset. The metadata field type\nis OperationMetadata.\nIf the request is successful, the\nresponse field type is\nDeidentifySummary.\nIf errors occur,\ndetails field type is\nDeidentifyErrorDetails.","request":{"$ref":"DeidentifyDatasetRequest"},"response":{"$ref":"Operation"},"parameterOrder":["sourceDataset"],"httpMethod":"POST","parameters":{"sourceDataset":{"location":"path","description":"Source dataset resource name. (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}:deidentify","path":"v1beta1/{+sourceDataset}:deidentify","id":"healthcare.projects.locations.datasets.deidentify"},"delete":{"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.delete","description":"Deletes the specified health dataset and all data contained in the dataset.\nDeleting a dataset does not affect the sources from which the dataset was\nimported (if any).","response":{"$ref":"Empty"},"parameterOrder":["name"],"httpMethod":"DELETE","parameters":{"name":{"description":"The name of the dataset to delete (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"]}},"resources":{"fhirStores":{"methods":{"export":{"response":{"$ref":"Operation"},"parameterOrder":["name"],"httpMethod":"POST","parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$","location":"path","description":"The name of the FHIR store to export resource from. The name should be in\nthe format of\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}`.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}:export","path":"v1beta1/{+name}:export","id":"healthcare.projects.locations.datasets.fhirStores.export","description":"Export resources from the FHIR store to the specified destination.\n\nThis method returns an Operation that can\nbe used to track the status of the export by calling\nGetOperation.\n\nImmediate fatal errors appear in the\nerror field.\nOtherwise, when the operation finishes, a detailed response of type\nExportResourcesResponse is returned in the\nresponse field.\nThe metadata field type for this\noperation is OperationMetadata.","request":{"$ref":"ExportResourcesRequest"}},"getIamPolicy":{"path":"v1beta1/{+resource}:getIamPolicy","id":"healthcare.projects.locations.datasets.fhirStores.getIamPolicy","description":"Gets the access control policy for a resource.\nReturns an empty policy if the resource exists and does not have a policy\nset.","response":{"$ref":"Policy"},"parameterOrder":["resource"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"options.requestedPolicyVersion":{"location":"query","description":"Optional. The policy format version to be returned.\nAcceptable values are 0 and 1.\nIf the value is 0, or the field is omitted, policy format version 1 will be\nreturned.","format":"int32","type":"integer"},"resource":{"required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$","location":"path","description":"REQUIRED: The resource for which the policy is being requested.\nSee the operation documentation for the appropriate value for this field."}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}:getIamPolicy"},"get":{"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.fhirStores.get","description":"Gets the configuration of the specified FHIR store.","response":{"$ref":"FhirStore"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$","location":"path","description":"The resource name of the FHIR store to get.","required":true,"type":"string"}}},"patch":{"description":"Updates the configuration of the specified FHIR store.","request":{"$ref":"FhirStore"},"httpMethod":"PATCH","parameterOrder":["name"],"response":{"$ref":"FhirStore"},"parameters":{"name":{"location":"path","description":"Output only. Resource name of the FHIR store, of the form\n`projects/{project_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$"},"updateMask":{"location":"query","description":"The update mask applies to the resource. For the `FieldMask` definition,\nsee\nhttps://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask","format":"google-fieldmask","type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}","id":"healthcare.projects.locations.datasets.fhirStores.patch","path":"v1beta1/{+name}"},"testIamPermissions":{"path":"v1beta1/{+resource}:testIamPermissions","id":"healthcare.projects.locations.datasets.fhirStores.testIamPermissions","request":{"$ref":"TestIamPermissionsRequest"},"description":"Returns permissions that a caller has on the specified resource.\nIf the resource does not exist, this will return an empty set of\npermissions, not a NOT_FOUND error.\n\nNote: This operation is designed to be used for building permission-aware\nUIs and command-line tools, not for authorization checking. This operation\nmay \"fail open\" without warning.","response":{"$ref":"TestIamPermissionsResponse"},"parameterOrder":["resource"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"resource":{"required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$","location":"path","description":"REQUIRED: The resource for which the policy detail is being requested.\nSee the operation documentation for the appropriate value for this field."}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}:testIamPermissions"},"delete":{"path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.fhirStores.delete","description":"Deletes the specified FHIR store and removes all resources within it.","response":{"$ref":"Empty"},"parameterOrder":["name"],"httpMethod":"DELETE","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"location":"path","description":"The resource name of the FHIR store to delete.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}"},"import":{"request":{"$ref":"ImportResourcesRequest"},"description":"Import resources to the FHIR store by loading data from the specified\nsources. Each resource must have a client-supplied ID, which is retained\nby the server.\n\nThe import operation is idempotent. Upon retry, the most recent data\n(matching the client-supplied ID) is overwritten, without creating a new\nresource version. If partial failures occur during the import, successful\nchanges are not rolled back.\n\nIf history imports are enabled\n(enable_history_import is set in the\nFHIR store's configuration), you can import historical versions of a\nresource by supplying a bundle of type `history`. The historical versions\nin the bundle must have `lastUpdated` timestamps. If a current or\nhistorical version with the supplied resource ID already exists, the\nbundle is rejected.\n\nThis method returns an Operation that can\nbe used to track the status of the import by calling\nGetOperation.\n\nImmediate fatal errors appear in the\nerror field.\nOtherwise, when the operation finishes, a detailed response of type\nImportResourcesResponse is returned in the\nresponse field.\nThe metadata field type for this\noperation is OperationMetadata.","response":{"$ref":"Operation"},"parameterOrder":["name"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$","location":"path","description":"The name of the FHIR store to import FHIR resources to. The name should be\nin the format of\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/fhirStores/{fhir_store_id}`."}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}:import","path":"v1beta1/{+name}:import","id":"healthcare.projects.locations.datasets.fhirStores.import"},"list":{"description":"Lists the FHIR stores in the given dataset.","response":{"$ref":"ListFhirStoresResponse"},"parameterOrder":["parent"],"httpMethod":"GET","parameters":{"filter":{"location":"query","description":"Restricts stores returned to those matching a filter. Syntax:\nhttps://cloud.google.com/appengine/docs/standard/python/search/query_strings\nOnly filtering on labels is supported, for example `labels.key=value`.","type":"string"},"pageToken":{"location":"query","description":"The next_page_token value returned from the previous List request, if any.","type":"string"},"pageSize":{"location":"query","description":"Limit on the number of FHIR stores to return in a single response.  If zero\nthe default page size of 100 is used.","format":"int32","type":"integer"},"parent":{"description":"Name of the dataset.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores","path":"v1beta1/{+parent}/fhirStores","id":"healthcare.projects.locations.datasets.fhirStores.list"},"setIamPolicy":{"parameters":{"resource":{"description":"REQUIRED: The resource for which the policy is being specified.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}:setIamPolicy","path":"v1beta1/{+resource}:setIamPolicy","id":"healthcare.projects.locations.datasets.fhirStores.setIamPolicy","description":"Sets the access control policy on the specified resource. Replaces any\nexisting policy.","request":{"$ref":"SetIamPolicyRequest"},"response":{"$ref":"Policy"},"parameterOrder":["resource"],"httpMethod":"POST"},"create":{"description":"Creates a new FHIR store within the parent dataset.","request":{"$ref":"FhirStore"},"httpMethod":"POST","parameterOrder":["parent"],"response":{"$ref":"FhirStore"},"parameters":{"parent":{"description":"The name of the dataset this FHIR store belongs to.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+$","location":"path"},"fhirStoreId":{"location":"query","description":"The ID of the FHIR store that is being created.\nThe string must match the following regex: `[\\p{L}\\p{N}_\\-\\.]{1,256}`.","type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores","id":"healthcare.projects.locations.datasets.fhirStores.create","path":"v1beta1/{+parent}/fhirStores"}},"resources":{"fhir":{"methods":{"vread":{"description":"Gets the contents of a version (current or historical) of a FHIR resource\nby version ID.\n\nImplements the FHIR standard [vread\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#vread).\n\nOn success, the response body will contain a JSON-encoded representation\nof the resource.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.","response":{"$ref":"HttpBody"},"parameterOrder":["name"],"httpMethod":"GET","parameters":{"name":{"location":"path","description":"The name of the resource version to retrieve.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/[^/]+/[^/]+/_history/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}/{fhirId1}/_history/{_historyId}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.fhirStores.fhir.vread"},"Resource-purge":{"response":{"$ref":"Empty"},"parameterOrder":["name"],"httpMethod":"DELETE","parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/[^/]+/[^/]+$","location":"path","description":"The name of the resource to purge.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}/{fhirId1}/$purge","path":"v1beta1/{+name}/$purge","id":"healthcare.projects.locations.datasets.fhirStores.fhir.Resource-purge","description":"Deletes all the historical versions of a resource (excluding the current\nversion) from the FHIR store. To remove all versions of a resource, first\ndelete the current version and then call this method.\n\nThis is not a FHIR standard operation."},"update":{"response":{"$ref":"HttpBody"},"parameterOrder":["name"],"httpMethod":"PUT","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"description":"The name of the resource to update.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/[^/]+/[^/]+$","location":"path"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}/{fhirId1}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.fhirStores.fhir.update","request":{"$ref":"HttpBody"},"description":"Updates the entire contents of a resource.\n\nImplements the FHIR standard [update\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#update).\n\nIf the specified resource does\nnot exist and the FHIR store has\nenable_update_create set, creates the\nresource with the client-specified ID.\n\nThe request body must contain a JSON-encoded FHIR resource, and the request\nheaders must contain `Content-Type: application/fhir+json`. The resource\nmust contain an `id` element having an identical value to the ID in the\nREST path of the request.\n\nOn success, the response body will contain a JSON-encoded representation\nof the updated resource, including the server-assigned version ID.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead."},"conditionalUpdate":{"scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"type":{"location":"path","description":"The FHIR resource type to update, such as Patient or Observation. For a\ncomplete list, see the [FHIR Resource\nIndex](http://hl7.org/implement/standards/fhir/STU3/resourcelist.html).\nMust match the resource type in the provided content.","required":true,"type":"string","pattern":"^[^/]+$"},"parent":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$","location":"path","description":"The name of the FHIR store this resource belongs to.","required":true,"type":"string"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}","path":"v1beta1/{+parent}/fhir/{+type}","id":"healthcare.projects.locations.datasets.fhirStores.fhir.conditionalUpdate","request":{"$ref":"HttpBody"},"description":"If a resource is found based on the search criteria specified in the query\nparameters, updates the entire contents of that resource.\n\nImplements the FHIR standard [conditional update\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#cond-update).\n\nSearch terms are provided as query parameters following the same pattern as\nthe search method.\n\nIf the search criteria identify more than one match, the request will\nreturn a `412 Precondition Failed` error.\nIf the search criteria identify zero matches, and the supplied resource\nbody contains an `id`, and the FHIR store has\nenable_update_create set, creates the\nresource with the client-specified ID. If the search criteria identify zero\nmatches, and the supplied resource body does not contain an `id`, the\nresource will be created with a server-assigned ID as per the\ncreate method.\n\nThe request body must contain a JSON-encoded FHIR resource, and the request\nheaders must contain `Content-Type: application/fhir+json`.\n\nOn success, the response body will contain a JSON-encoded representation\nof the updated resource, including the server-assigned version ID.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.","response":{"$ref":"HttpBody"},"parameterOrder":["parent","type"],"httpMethod":"PUT"},"conditionalDelete":{"scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"type":{"location":"path","description":"The FHIR resource type to delete, such as Patient or Observation. For a\ncomplete list, see the [FHIR Resource\nIndex](http://hl7.org/implement/standards/fhir/STU3/resourcelist.html).","required":true,"type":"string","pattern":"^[^/]+$"},"parent":{"location":"path","description":"The name of the FHIR store this resource belongs to.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}","path":"v1beta1/{+parent}/fhir/{+type}","id":"healthcare.projects.locations.datasets.fhirStores.fhir.conditionalDelete","description":"Deletes FHIR resources that match a search query.\n\nImplements the FHIR standard [conditional delete\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#2.21.0.13.1).\nIf multiple resources match, all of them will be deleted.\n\nSearch terms are provided as query parameters following the same pattern as\nthe search method.\n\nNote: Unless resource versioning is disabled by setting the\ndisable_resource_versioning flag\non the FHIR store, the deleted resources will be moved to a history\nrepository that can still be retrieved through vread\nand related methods, unless they are removed by the\npurge method.","response":{"$ref":"Empty"},"parameterOrder":["parent","type"],"httpMethod":"DELETE"},"create":{"request":{"$ref":"HttpBody"},"description":"Creates a FHIR resource.\n\nImplements the FHIR standard [create\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#create),\nwhich creates a new resource with a server-assigned resource ID.\n\nAlso supports the FHIR standard [conditional create\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#ccreate),\nspecified by supplying an `If-None-Exist` header containing a FHIR search\nquery. If no resources match this search query, the server processes the\ncreate operation as normal.\n\nThe request body must contain a JSON-encoded FHIR resource, and the request\nheaders must contain `Content-Type: application/fhir+json`.\n\nOn success, the response body will contain a JSON-encoded representation\nof the resource as it was created on the server, including the\nserver-assigned resource ID and version ID.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.","response":{"$ref":"HttpBody"},"parameterOrder":["parent","type"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"parent":{"location":"path","description":"The name of the FHIR store this resource belongs to.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$"},"type":{"location":"path","description":"The FHIR resource type to create, such as Patient or Observation. For a\ncomplete list, see the [FHIR Resource\nIndex](http://hl7.org/implement/standards/fhir/STU3/resourcelist.html).\nMust match the resource type in the provided content.","required":true,"type":"string","pattern":"^[^/]+$"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}","path":"v1beta1/{+parent}/fhir/{+type}","id":"healthcare.projects.locations.datasets.fhirStores.fhir.create"},"Observation-lastn":{"description":"Retrieves the N most recent `Observation` resources for a subject matching\nsearch criteria specified as query parameters, grouped by\n`Observation.code`, sorted from most recent to oldest.\n\nImplements the FHIR extended operation\n[Observation-lastn](http://hl7.org/implement/standards/fhir/STU3/observation-operations.html#lastn).\n\nSearch terms are provided as query parameters following the same pattern as\nthe search method. This operation accepts an additional\nquery parameter `max`, which specifies N, the maximum number of\nObservations to return from each group, with a default of 1.\n\nOn success, the response body will contain a JSON-encoded representation\nof a `Bundle` resource of type `searchset`, containing the results of the\noperation.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.","response":{"$ref":"HttpBody"},"parameterOrder":["parent"],"httpMethod":"GET","parameters":{"parent":{"description":"Name of the FHIR store to retrieve resources from.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/Observation/$lastn","path":"v1beta1/{+parent}/fhir/Observation/$lastn","id":"healthcare.projects.locations.datasets.fhirStores.fhir.Observation-lastn"},"Patient-everything":{"path":"v1beta1/{+name}/$everything","id":"healthcare.projects.locations.datasets.fhirStores.fhir.Patient-everything","description":"Retrieves all the resources in the patient compartment for a `Patient`\nresource.\n\nImplements the FHIR extended operation\n[Patient-everything](http://hl7.org/implement/standards/fhir/STU3/patient-operations.html#everything).\n\nOn success, the response body will contain a JSON-encoded representation\nof a `Bundle` resource of type `searchset`, containing the results of the\noperation.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.","response":{"$ref":"HttpBody"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"description":"Name of the `Patient` resource for which the information is required.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/Patient/[^/]+$","location":"path"},"start":{"description":"The response includes records subsequent to the start date. If no start\ndate is provided, all records prior to the end date are in scope.","type":"string","location":"query"},"end":{"location":"query","description":"The response includes records prior to the end date. If no end date is\nprovided, all records subsequent to the start date are in scope.","type":"string"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/Patient/{PatientId}/$everything"},"read":{"httpMethod":"GET","parameterOrder":["name"],"response":{"$ref":"HttpBody"},"parameters":{"name":{"description":"The name of the resource to retrieve.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/[^/]+/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}/{fhirId1}","id":"healthcare.projects.locations.datasets.fhirStores.fhir.read","path":"v1beta1/{+name}","description":"Gets the contents of a FHIR resource.\n\nImplements the FHIR standard [read\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#read).\n\nAlso supports the FHIR standard [conditional read\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#cread)\nspecified by supplying an `If-Modified-Since` header with a date/time value\nor an `If-None-Match` header with an ETag value.\n\nOn success, the response body will contain a JSON-encoded representation\nof the resource.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead."},"search":{"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/_search","path":"v1beta1/{+parent}/fhir/_search","id":"healthcare.projects.locations.datasets.fhirStores.fhir.search","request":{"$ref":"SearchResourcesRequest"},"description":"Searches for resources in the given FHIR store according to criteria\nspecified as query parameters.\n\nImplements the FHIR standard [search\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#search)\nusing the search semantics described in the [FHIR Search\nspecification](http://hl7.org/implement/standards/fhir/STU3/search.html).\n\nSupports three methods of search defined by the specification:\n\n*  `GET [base]?[parameters]` to search across all resources.\n*  `GET [base]/[type]?[parameters]` to search resources of a specified\ntype.\n*  `POST [base]/[type]/_search?[parameters]` as an alternate form having\nthe same semantics as the `GET` method.\n\nThe `GET` methods do not support compartment searches. The `POST` method\ndoes not support `application/x-www-form-urlencoded` search parameters.\n\nOn success, the response body will contain a JSON-encoded representation\nof a `Bundle` resource of type `searchset`, containing the results of the\nsearch.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.\n\nThe server's capability statement, retrieved through\ncapabilities, indicates what search parameters\nare supported on each FHIR resource. A list of all search parameters\ndefined by the specification can be found in the [FHIR Search Parameter\nRegistry](http://hl7.org/implement/standards/fhir/STU3/searchparameter-registry.html).\n\nSupported search modifiers: `:missing`, `:exact`, `:contains`, `:text`,\n`:in`, `:not-in`, `:above`, `:below`, `:[type]`, `:not`, and `:recurse`.\n\nSupported search result parameters: `_sort`, `_count`, `_include`,\n`_revinclude`, `_summary=text`, `_summary=data`, and `_elements`.\n\nThe maximum number of search results returned defaults to 100, which can\nbe overridden by the `_count` parameter up to a maximum limit of 1000. If\nthere are additional results, the returned `Bundle` will contain\npagination links.","response":{"$ref":"HttpBody"},"parameterOrder":["parent"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"parent":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$","location":"path","description":"Name of the FHIR store to retrieve resources from.","required":true,"type":"string"}}},"patch":{"request":{"$ref":"HttpBody"},"description":"Updates part of an existing resource by applying the operations specified\nin a [JSON Patch](http://jsonpatch.com/) document.\n\nImplements the FHIR standard [patch\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#patch).\n\nThe request body must contain a JSON Patch document, and the request\nheaders must contain `Content-Type: application/json-patch+json`.\n\nOn success, the response body will contain a JSON-encoded representation\nof the updated resource, including the server-assigned version ID.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.","response":{"$ref":"HttpBody"},"parameterOrder":["name"],"httpMethod":"PATCH","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"location":"path","description":"The name of the resource to update.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/[^/]+/[^/]+$"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}/{fhirId1}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.fhirStores.fhir.patch"},"executeBundle":{"response":{"$ref":"HttpBody"},"parameterOrder":["parent"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"parent":{"location":"path","description":"Name of the FHIR store in which this bundle will be executed.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir","path":"v1beta1/{+parent}/fhir","id":"healthcare.projects.locations.datasets.fhirStores.fhir.executeBundle","request":{"$ref":"HttpBody"},"description":"Executes all the requests in the given Bundle.\n\nImplements the FHIR standard [batch/transaction\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#transaction).\n\nSupports all interactions within a bundle, except search. This method\naccepts Bundles of type `batch` and `transaction`, processing them\naccording to the [batch processing\nrules](http://hl7.org/implement/standards/fhir/STU3/http.html#2.21.0.17.1)\nand [transaction processing\nrules](http://hl7.org/implement/standards/fhir/STU3/http.html#2.21.0.17.2).\n\nThe request body must contain a JSON-encoded FHIR `Bundle` resource, and\nthe request headers must contain `Content-Type: application/fhir+json`.\n\nFor a batch bundle or a successful transaction the response body will\ncontain a JSON-encoded representation of a `Bundle` resource of type\n`batch-response` or `transaction-response` containing one entry for each\nentry in the request, with the outcome of processing the entry. In the\ncase of an error for a transaction bundle, the response body will contain\na JSON-encoded `OperationOutcome` resource describing the reason for the\nerror. If the request cannot be mapped to a valid API method on a FHIR\nstore, a generic GCP error might be returned instead."},"capabilities":{"description":"Gets the FHIR [capability\nstatement](http://hl7.org/implement/standards/fhir/STU3/capabilitystatement.html)\nfor the store, which contains a description of functionality supported by\nthe server.\n\nImplements the FHIR standard [capabilities\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#capabilities).\n\nOn success, the response body will contain a JSON-encoded representation\nof a `CapabilityStatement` resource.","response":{"$ref":"HttpBody"},"parameterOrder":["name"],"httpMethod":"GET","parameters":{"name":{"location":"path","description":"Name of the FHIR store to retrieve the capabilities for.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/metadata","path":"v1beta1/{+name}/fhir/metadata","id":"healthcare.projects.locations.datasets.fhirStores.fhir.capabilities"},"conditionalPatch":{"description":"If a resource is found based on the search criteria specified in the query\nparameters, updates part of that resource by applying the operations\nspecified in a [JSON Patch](http://jsonpatch.com/) document.\n\nImplements the FHIR standard [conditional patch\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#patch).\n\nSearch terms are provided as query parameters following the same pattern as\nthe search method.\n\nIf the search criteria identify more than one match, the request will\nreturn a `412 Precondition Failed` error.\n\nThe request body must contain a JSON Patch document, and the request\nheaders must contain `Content-Type: application/json-patch+json`.\n\nOn success, the response body will contain a JSON-encoded representation\nof the updated resource, including the server-assigned version ID.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.","request":{"$ref":"HttpBody"},"response":{"$ref":"HttpBody"},"parameterOrder":["parent","type"],"httpMethod":"PATCH","parameters":{"type":{"required":true,"type":"string","pattern":"^[^/]+$","location":"path","description":"The FHIR resource type to update, such as Patient or Observation. For a\ncomplete list, see the [FHIR Resource\nIndex](http://hl7.org/implement/standards/fhir/STU3/resourcelist.html)."},"parent":{"required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+$","location":"path","description":"The name of the FHIR store this resource belongs to."}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}","path":"v1beta1/{+parent}/fhir/{+type}","id":"healthcare.projects.locations.datasets.fhirStores.fhir.conditionalPatch"},"history":{"path":"v1beta1/{+name}/_history","id":"healthcare.projects.locations.datasets.fhirStores.fhir.history","description":"Lists all the versions of a resource (including the current version and\ndeleted versions) from the FHIR store.\n\nImplements the per-resource form of the FHIR standard [history\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#history).\n\nOn success, the response body will contain a JSON-encoded representation\nof a `Bundle` resource of type `history`, containing the version history\nsorted from most recent to oldest versions.\nErrors generated by the FHIR store will contain a JSON-encoded\n`OperationOutcome` resource describing the reason for the error. If the\nrequest cannot be mapped to a valid API method on a FHIR store, a generic\nGCP error might be returned instead.","response":{"$ref":"HttpBody"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"description":"The name of the resource to retrieve.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/[^/]+/[^/]+$","location":"path"},"count":{"description":"The maximum number of search results on a page. Defaults to 1000.","format":"int32","type":"integer","location":"query"},"since":{"description":"Only include resource versions that were created at or after the given\ninstant in time. The instant in time uses the format\nYYYY-MM-DDThh:mm:ss.sss+zz:zz (for example 2015-02-07T13:28:17.239+02:00 or\n2017-01-01T00:00:00Z). The time must be specified to the second and\ninclude a time zone.","type":"string","location":"query"},"page":{"type":"string","location":"query","description":"Used to retrieve the first, previous, next, or last page of resource\nversions when using pagination. Value should be set to the value of the\n`link.url` field returned in the response to the previous request, where\n`link.relation` is \"first\", \"previous\", \"next\" or \"last\".\n\nOmit `page` if no previous request has been made."},"at":{"type":"string","location":"query","description":"Only include resource versions that were current at some point during the\ntime period specified in the date time value. The date parameter format is\nyyyy-mm-ddThh:mm:ss[Z|(+|-)hh:mm]\n\nClients may specify any of the following:\n\n*  An entire year: `_at=2019`\n*  An entire month: `_at=2019-01`\n*  A specific day: `_at=2019-01-20`\n*  A specific second: `_at=2018-12-31T23:59:58Z`"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}/{fhirId1}/_history"},"delete":{"description":"Deletes a FHIR resource.\n\nImplements the FHIR standard [delete\ninteraction](http://hl7.org/implement/standards/fhir/STU3/http.html#delete).\n\nNote: Unless resource versioning is disabled by setting the\ndisable_resource_versioning flag\non the FHIR store, the deleted resources will be moved to a history\nrepository that can still be retrieved through vread\nand related methods, unless they are removed by the\npurge method.","response":{"$ref":"HttpBody"},"parameterOrder":["name"],"httpMethod":"DELETE","parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/fhirStores/[^/]+/fhir/[^/]+/[^/]+$","location":"path","description":"The name of the resource to delete.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/fhirStores/{fhirStoresId}/fhir/{fhirId}/{fhirId1}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.fhirStores.fhir.delete"}}}}},"operations":{"methods":{"list":{"description":"Lists operations that match the specified filter in the request. If the\nserver doesn't support this method, it returns `UNIMPLEMENTED`.\n\nNOTE: the `name` binding allows API services to override the binding\nto use different resource name schemes, such as `users/*/operations`. To\noverride the binding, API services can add a binding such as\n`\"/v1/{name=users/*}/operations\"` to their service configuration.\nFor backwards compatibility, the default name includes the operations\ncollection id, however overriding users must ensure the name binding\nis the parent resource, without the operations collection id.","response":{"$ref":"ListOperationsResponse"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"description":"The name of the operation's parent resource.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+$","location":"path"},"pageToken":{"location":"query","description":"The standard list page token.","type":"string"},"pageSize":{"location":"query","description":"The standard list page size.","format":"int32","type":"integer"},"filter":{"description":"The standard list filter.","type":"string","location":"query"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/operations","path":"v1beta1/{+name}/operations","id":"healthcare.projects.locations.datasets.operations.list"},"get":{"response":{"$ref":"Operation"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"description":"The name of the operation resource.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/operations/[^/]+$","location":"path"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/operations/{operationsId}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.operations.get","description":"Gets the latest state of a long-running operation.  Clients can use this\nmethod to poll the operation result at intervals as recommended by the API\nservice."}}},"dicomStores":{"methods":{"storeInstances":{"id":"healthcare.projects.locations.datasets.dicomStores.storeInstances","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","description":"StoreInstances stores DICOM instances associated with study instance unique\nidentifiers (SUID). See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.5.","request":{"$ref":"HttpBody"},"httpMethod":"POST","parameterOrder":["parent","dicomWebPath"],"response":{"$ref":"HttpBody"},"parameters":{"parent":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path","description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string"},"dicomWebPath":{"pattern":"^studies$","location":"path","description":"The path of the StoreInstances DICOMweb request (e.g.,\n`studies/[{study_id}]`). Note that the `study_uid` is optional.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies"},"searchForSeries":{"description":"SearchForSeries returns a list of matching series. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.6.","httpMethod":"GET","parameterOrder":["parent","dicomWebPath"],"response":{"$ref":"HttpBody"},"parameters":{"parent":{"required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path","description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`)."},"dicomWebPath":{"pattern":"^series$","location":"path","description":"The path of the SearchForSeries DICOMweb request(e.g., `series` or\n`studies/{study_uid}/series`).","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/series","id":"healthcare.projects.locations.datasets.dicomStores.searchForSeries","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}"},"list":{"description":"Lists the DICOM stores in the given dataset.","response":{"$ref":"ListDicomStoresResponse"},"parameterOrder":["parent"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"pageToken":{"location":"query","description":"The next_page_token value returned from the previous List request, if any.","type":"string"},"pageSize":{"location":"query","description":"Limit on the number of DICOM stores to return in a single response.\nIf zero the default page size of 100 is used.","format":"int32","type":"integer"},"parent":{"description":"Name of the dataset.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+$","location":"path"},"filter":{"location":"query","description":"Restricts stores returned to those matching a filter. Syntax:\nhttps://cloud.google.com/appengine/docs/standard/python/search/query_strings\nOnly filtering on labels is supported, for example `labels.key=value`.","type":"string"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores","path":"v1beta1/{+parent}/dicomStores","id":"healthcare.projects.locations.datasets.dicomStores.list"},"create":{"httpMethod":"POST","parameterOrder":["parent"],"response":{"$ref":"DicomStore"},"parameters":{"parent":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+$","location":"path","description":"The name of the dataset this DICOM store belongs to.","required":true,"type":"string"},"dicomStoreId":{"type":"string","location":"query","description":"The ID of the DICOM store that is being created.\nAny string value up to 256 characters in length."}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores","id":"healthcare.projects.locations.datasets.dicomStores.create","path":"v1beta1/{+parent}/dicomStores","description":"Creates a new DICOM store within the parent dataset.","request":{"$ref":"DicomStore"}},"patch":{"description":"Updates the specified DICOM store.","request":{"$ref":"DicomStore"},"response":{"$ref":"DicomStore"},"parameterOrder":["name"],"httpMethod":"PATCH","parameters":{"updateMask":{"type":"string","location":"query","description":"The update mask applies to the resource. For the `FieldMask` definition,\nsee\nhttps://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask","format":"google-fieldmask"},"name":{"description":"Output only. Resource name of the DICOM store, of the form\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.dicomStores.patch"},"get":{"description":"Gets the specified DICOM store.","response":{"$ref":"DicomStore"},"parameterOrder":["name"],"httpMethod":"GET","parameters":{"name":{"required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path","description":"The resource name of the DICOM store to get."}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.dicomStores.get"},"testIamPermissions":{"httpMethod":"POST","parameterOrder":["resource"],"response":{"$ref":"TestIamPermissionsResponse"},"parameters":{"resource":{"required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path","description":"REQUIRED: The resource for which the policy detail is being requested.\nSee the operation documentation for the appropriate value for this field."}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}:testIamPermissions","id":"healthcare.projects.locations.datasets.dicomStores.testIamPermissions","path":"v1beta1/{+resource}:testIamPermissions","description":"Returns permissions that a caller has on the specified resource.\nIf the resource does not exist, this will return an empty set of\npermissions, not a NOT_FOUND error.\n\nNote: This operation is designed to be used for building permission-aware\nUIs and command-line tools, not for authorization checking. This operation\nmay \"fail open\" without warning.","request":{"$ref":"TestIamPermissionsRequest"}},"delete":{"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.dicomStores.delete","description":"Deletes the specified DICOM store and removes all images that are contained\nwithin it.","response":{"$ref":"Empty"},"parameterOrder":["name"],"httpMethod":"DELETE","parameters":{"name":{"location":"path","description":"The resource name of the DICOM store to delete.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"]},"searchForInstances":{"path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","id":"healthcare.projects.locations.datasets.dicomStores.searchForInstances","description":"SearchForInstances returns a list of matching instances. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.6.","response":{"$ref":"HttpBody"},"parameterOrder":["parent","dicomWebPath"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"dicomWebPath":{"pattern":"^instances$","location":"path","description":"The path of the SearchForInstancesRequest DICOMweb request (e.g.,\n`instances` or `series/{series_uid}/instances` or\n`studies/{study_uid}/instances`).","required":true,"type":"string"},"parent":{"description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/instances"},"import":{"path":"v1beta1/{+name}:import","id":"healthcare.projects.locations.datasets.dicomStores.import","description":"Imports data into the DICOM store by copying it from the specified source.\nFor errors, the Operation will be populated with error details (in the form\nof ImportDicomDataErrorDetails in error.details), which will hold\nfiner-grained error information.\nThe metadata field type is\nOperationMetadata.","request":{"$ref":"ImportDicomDataRequest"},"response":{"$ref":"Operation"},"parameterOrder":["name"],"httpMethod":"POST","parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path","description":"The name of the DICOM store resource into which the data is imported (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}:import"},"searchForStudies":{"id":"healthcare.projects.locations.datasets.dicomStores.searchForStudies","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","description":"SearchForStudies returns a list of matching studies. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.6.","httpMethod":"GET","response":{"$ref":"HttpBody"},"parameterOrder":["parent","dicomWebPath"],"parameters":{"parent":{"location":"path","description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$"},"dicomWebPath":{"description":"The path of the SearchForStudies DICOMweb request (e.g., `studies`).","required":true,"type":"string","pattern":"^studies$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies"},"setIamPolicy":{"scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"resource":{"required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path","description":"REQUIRED: The resource for which the policy is being specified.\nSee the operation documentation for the appropriate value for this field."}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}:setIamPolicy","path":"v1beta1/{+resource}:setIamPolicy","id":"healthcare.projects.locations.datasets.dicomStores.setIamPolicy","request":{"$ref":"SetIamPolicyRequest"},"description":"Sets the access control policy on the specified resource. Replaces any\nexisting policy.","response":{"$ref":"Policy"},"parameterOrder":["resource"],"httpMethod":"POST"},"export":{"response":{"$ref":"Operation"},"parameterOrder":["name"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path","description":"The DICOM store resource name from which the data should be exported (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}:export","path":"v1beta1/{+name}:export","id":"healthcare.projects.locations.datasets.dicomStores.export","request":{"$ref":"ExportDicomDataRequest"},"description":"Exports data to the specified destination by copying it from the DICOM\nstore.\nThe metadata field type is\nOperationMetadata."},"getIamPolicy":{"response":{"$ref":"Policy"},"parameterOrder":["resource"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"options.requestedPolicyVersion":{"location":"query","description":"Optional. The policy format version to be returned.\nAcceptable values are 0 and 1.\nIf the value is 0, or the field is omitted, policy format version 1 will be\nreturned.","format":"int32","type":"integer"},"resource":{"required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path","description":"REQUIRED: The resource for which the policy is being requested.\nSee the operation documentation for the appropriate value for this field."}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}:getIamPolicy","path":"v1beta1/{+resource}:getIamPolicy","id":"healthcare.projects.locations.datasets.dicomStores.getIamPolicy","description":"Gets the access control policy for a resource.\nReturns an empty policy if the resource exists and does not have a policy\nset."}},"resources":{"studies":{"methods":{"retrieveMetadata":{"id":"healthcare.projects.locations.datasets.dicomStores.studies.retrieveMetadata","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","description":"RetrieveStudyMetadata returns instance associated with the given study\npresented as metadata with the bulk data removed. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4.","httpMethod":"GET","response":{"$ref":"HttpBody"},"parameterOrder":["parent","dicomWebPath"],"parameters":{"parent":{"location":"path","description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$"},"dicomWebPath":{"required":true,"type":"string","pattern":"^studies/[^/]+/metadata$","location":"path","description":"The path of the RetrieveStudyMetadata DICOMweb request (e.g.,\n`studies/{study_id}/metadata`)."}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/metadata"},"storeInstances":{"request":{"$ref":"HttpBody"},"description":"StoreInstances stores DICOM instances associated with study instance unique\nidentifiers (SUID). See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.5.","response":{"$ref":"HttpBody"},"parameterOrder":["parent","dicomWebPath"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"parent":{"location":"path","description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$"},"dicomWebPath":{"location":"path","description":"The path of the StoreInstances DICOMweb request (e.g.,\n`studies/[{study_id}]`). Note that the `study_uid` is optional.","required":true,"type":"string","pattern":"^studies/[^/]+$"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","id":"healthcare.projects.locations.datasets.dicomStores.studies.storeInstances"},"delete":{"response":{"$ref":"Empty"},"parameterOrder":["parent","dicomWebPath"],"httpMethod":"DELETE","parameters":{"parent":{"description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path"},"dicomWebPath":{"pattern":"^studies/[^/]+$","location":"path","description":"The path of the DeleteStudy request (e.g., `studies/{study_id}`).","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","id":"healthcare.projects.locations.datasets.dicomStores.studies.delete","description":"DeleteStudy deletes all instances within the given study. Delete requests\nare equivalent to the GET requests specified in the WADO-RS standard."},"retrieveStudy":{"description":"RetrieveStudy returns all instances within the given study. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4.","response":{"$ref":"HttpBody"},"parameterOrder":["parent","dicomWebPath"],"httpMethod":"GET","parameters":{"parent":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path","description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string"},"dicomWebPath":{"location":"path","description":"The path of the RetrieveStudy DICOMweb request (e.g.,\n`studies/{study_id}`).","required":true,"type":"string","pattern":"^studies/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","id":"healthcare.projects.locations.datasets.dicomStores.studies.retrieveStudy"},"searchForSeries":{"parameters":{"parent":{"description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path"},"dicomWebPath":{"location":"path","description":"The path of the SearchForSeries DICOMweb request(e.g., `series` or\n`studies/{study_uid}/series`).","required":true,"type":"string","pattern":"^studies/[^/]+/series$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series","id":"healthcare.projects.locations.datasets.dicomStores.studies.searchForSeries","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","description":"SearchForSeries returns a list of matching series. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.6.","httpMethod":"GET","parameterOrder":["parent","dicomWebPath"],"response":{"$ref":"HttpBody"}},"searchForInstances":{"httpMethod":"GET","response":{"$ref":"HttpBody"},"parameterOrder":["parent","dicomWebPath"],"parameters":{"dicomWebPath":{"description":"The path of the SearchForInstancesRequest DICOMweb request (e.g.,\n`instances` or `series/{series_uid}/instances` or\n`studies/{study_uid}/instances`).","required":true,"type":"string","pattern":"^studies/[^/]+/instances$","location":"path"},"parent":{"location":"path","description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/instances","id":"healthcare.projects.locations.datasets.dicomStores.studies.searchForInstances","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","description":"SearchForInstances returns a list of matching instances. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.6."}},"resources":{"series":{"methods":{"retrieveSeries":{"parameters":{"parent":{"description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path"},"dicomWebPath":{"description":"The path of the RetrieveSeries DICOMweb request (e.g.,\n`studies/{study_id}/series/{series_id}`).","required":true,"type":"string","pattern":"^studies/[^/]+/series/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}","id":"healthcare.projects.locations.datasets.dicomStores.studies.series.retrieveSeries","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","description":"RetrieveSeries returns all instances within the given study and series. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4.","httpMethod":"GET","parameterOrder":["parent","dicomWebPath"],"response":{"$ref":"HttpBody"}},"searchForInstances":{"description":"SearchForInstances returns a list of matching instances. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.6.","httpMethod":"GET","parameterOrder":["parent","dicomWebPath"],"response":{"$ref":"HttpBody"},"parameters":{"parent":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path","description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string"},"dicomWebPath":{"pattern":"^studies/[^/]+/series/[^/]+/instances$","location":"path","description":"The path of the SearchForInstancesRequest DICOMweb request (e.g.,\n`instances` or `series/{series_uid}/instances` or\n`studies/{study_uid}/instances`).","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/instances","id":"healthcare.projects.locations.datasets.dicomStores.studies.series.searchForInstances","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}"},"delete":{"httpMethod":"DELETE","parameterOrder":["parent","dicomWebPath"],"response":{"$ref":"Empty"},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"parent":{"description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path"},"dicomWebPath":{"required":true,"type":"string","pattern":"^studies/[^/]+/series/[^/]+$","location":"path","description":"The path of the DeleteSeries request (e.g.,\n`studies/{study_id}/series/{series_id}`)."}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}","id":"healthcare.projects.locations.datasets.dicomStores.studies.series.delete","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","description":"DeleteSeries deletes all instances within the given study and series.\nDelete requests are equivalent to the GET requests specified in the WADO-RS\nstandard."},"retrieveMetadata":{"description":"RetrieveSeriesMetadata returns instance associated with the given study and\nseries, presented as metadata with the bulk data removed. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4.","response":{"$ref":"HttpBody"},"parameterOrder":["parent","dicomWebPath"],"httpMethod":"GET","parameters":{"parent":{"location":"path","description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$"},"dicomWebPath":{"description":"The path of the RetrieveSeriesMetadata DICOMweb request (e.g.,\n`studies/{study_id}/series/{series_id}/metadata`).","required":true,"type":"string","pattern":"^studies/[^/]+/series/[^/]+/metadata$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/metadata","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","id":"healthcare.projects.locations.datasets.dicomStores.studies.series.retrieveMetadata"}},"resources":{"instances":{"methods":{"retrieveInstance":{"response":{"$ref":"HttpBody"},"parameterOrder":["parent","dicomWebPath"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"dicomWebPath":{"description":"The path of the RetrieveInstance DICOMweb request (e.g.,\n`studies/{study_id}/series/{series_id}/instances/{instance_id}`).","required":true,"type":"string","pattern":"^studies/[^/]+/series/[^/]+/instances/[^/]+$","location":"path"},"parent":{"location":"path","description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/instances/{instancesId}","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","id":"healthcare.projects.locations.datasets.dicomStores.studies.series.instances.retrieveInstance","description":"RetrieveInstance returns instance associated with the given study, series,\nand SOP Instance UID. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4."},"retrieveMetadata":{"httpMethod":"GET","response":{"$ref":"HttpBody"},"parameterOrder":["parent","dicomWebPath"],"parameters":{"parent":{"description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$","location":"path"},"dicomWebPath":{"description":"The path of the RetrieveInstanceMetadata DICOMweb request (e.g.,\n`studies/{study_id}/series/{series_id}/instances/{instance_id}/metadata`).","required":true,"type":"string","pattern":"^studies/[^/]+/series/[^/]+/instances/[^/]+/metadata$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/instances/{instancesId}/metadata","id":"healthcare.projects.locations.datasets.dicomStores.studies.series.instances.retrieveMetadata","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","description":"RetrieveInstanceMetadata returns instance associated with the given study,\nseries, and SOP Instance UID presented as metadata with the bulk data\nremoved. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4."},"delete":{"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/instances/{instancesId}","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","id":"healthcare.projects.locations.datasets.dicomStores.studies.series.instances.delete","description":"DeleteInstance deletes an instance associated with the given study, series,\nand SOP Instance UID. Delete requests are equivalent to the GET requests\nspecified in the WADO-RS standard.","response":{"$ref":"Empty"},"parameterOrder":["parent","dicomWebPath"],"httpMethod":"DELETE","parameters":{"parent":{"location":"path","description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$"},"dicomWebPath":{"location":"path","description":"The path of the DeleteInstance request (e.g.,\n`studies/{study_id}/series/{series_id}/instances/{instance_id}`).","required":true,"type":"string","pattern":"^studies/[^/]+/series/[^/]+/instances/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"]},"retrieveRendered":{"description":"RetrieveRenderedInstance returns instance associated with the given study,\nseries, and SOP Instance UID in an acceptable Rendered Media Type. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4.","httpMethod":"GET","response":{"$ref":"HttpBody"},"parameterOrder":["parent","dicomWebPath"],"parameters":{"parent":{"location":"path","description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$"},"dicomWebPath":{"description":"The path of the RetrieveRenderedInstance DICOMweb request (e.g.,\n`studies/{study_id}/series/{series_id}/instances/{instance_id}/rendered`).","required":true,"type":"string","pattern":"^studies/[^/]+/series/[^/]+/instances/[^/]+/rendered$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/instances/{instancesId}/rendered","id":"healthcare.projects.locations.datasets.dicomStores.studies.series.instances.retrieveRendered","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}"}},"resources":{"frames":{"methods":{"retrieveRendered":{"parameters":{"dicomWebPath":{"required":true,"type":"string","pattern":"^studies/[^/]+/series/[^/]+/instances/[^/]+/frames/[^/]+/rendered$","location":"path","description":"The path of the RetrieveRenderedFrames DICOMweb request (e.g.,\n`studies/{study_id}/series/{series_id}/instances/{instance_id}/frames/{frame_list}/rendered`)."},"parent":{"location":"path","description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/instances/{instancesId}/frames/{framesId}/rendered","id":"healthcare.projects.locations.datasets.dicomStores.studies.series.instances.frames.retrieveRendered","path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","description":"RetrieveRenderedFrames returns instances associated with the given study,\nseries, SOP Instance UID and frame numbers in an acceptable Rendered Media\nType. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4.","httpMethod":"GET","response":{"$ref":"HttpBody"},"parameterOrder":["parent","dicomWebPath"]},"retrieveFrames":{"path":"v1beta1/{+parent}/dicomWeb/{+dicomWebPath}","id":"healthcare.projects.locations.datasets.dicomStores.studies.series.instances.frames.retrieveFrames","description":"RetrieveFrames returns instances associated with the given study, series,\nSOP Instance UID and frame numbers. See\nhttp://dicom.nema.org/medical/dicom/current/output/html/part18.html#sect_10.4.","response":{"$ref":"HttpBody"},"parameterOrder":["parent","dicomWebPath"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"parent":{"location":"path","description":"The name of the DICOM store that is being accessed (e.g.,\n`projects/{project_id}/locations/{location_id}/datasets/{dataset_id}/dicomStores/{dicom_store_id}`).","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/dicomStores/[^/]+$"},"dicomWebPath":{"location":"path","description":"The path of the RetrieveFrames DICOMweb request (e.g.,\n`studies/{study_id}/series/{series_id}/instances/{instance_id}/frames/{frame_list}`).","required":true,"type":"string","pattern":"^studies/[^/]+/series/[^/]+/instances/[^/]+/frames/[^/]+$"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/dicomStores/{dicomStoresId}/dicomWeb/studies/{studiesId}/series/{seriesId}/instances/{instancesId}/frames/{framesId}"}}}}}}}}}}},"hl7V2Stores":{"methods":{"get":{"description":"Gets the specified HL7v2 store.","httpMethod":"GET","parameterOrder":["name"],"response":{"$ref":"Hl7V2Store"},"parameters":{"name":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$","location":"path","description":"The resource name of the HL7v2 store to get.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}","id":"healthcare.projects.locations.datasets.hl7V2Stores.get","path":"v1beta1/{+name}"},"patch":{"request":{"$ref":"Hl7V2Store"},"description":"Updates the HL7v2 store.","response":{"$ref":"Hl7V2Store"},"parameterOrder":["name"],"httpMethod":"PATCH","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"updateMask":{"location":"query","description":"The update mask applies to the resource. For the `FieldMask` definition,\nsee\nhttps://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask","format":"google-fieldmask","type":"string"},"name":{"description":"Output only. Resource name of the HL7v2 store, of the form\n`projects/{project_id}/datasets/{dataset_id}/hl7V2Stores/{hl7v2_store_id}`.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$","location":"path"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.hl7V2Stores.patch"},"testIamPermissions":{"httpMethod":"POST","parameterOrder":["resource"],"response":{"$ref":"TestIamPermissionsResponse"},"parameters":{"resource":{"description":"REQUIRED: The resource for which the policy detail is being requested.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}:testIamPermissions","id":"healthcare.projects.locations.datasets.hl7V2Stores.testIamPermissions","path":"v1beta1/{+resource}:testIamPermissions","description":"Returns permissions that a caller has on the specified resource.\nIf the resource does not exist, this will return an empty set of\npermissions, not a NOT_FOUND error.\n\nNote: This operation is designed to be used for building permission-aware\nUIs and command-line tools, not for authorization checking. This operation\nmay \"fail open\" without warning.","request":{"$ref":"TestIamPermissionsRequest"}},"delete":{"description":"Deletes the specified HL7v2 store and removes all messages that are\ncontained within it.","response":{"$ref":"Empty"},"parameterOrder":["name"],"httpMethod":"DELETE","parameters":{"name":{"description":"The resource name of the HL7v2 store to delete.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.hl7V2Stores.delete"},"list":{"response":{"$ref":"ListHl7V2StoresResponse"},"parameterOrder":["parent"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"parent":{"location":"path","description":"Name of the dataset.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+$"},"filter":{"type":"string","location":"query","description":"Restricts stores returned to those matching a filter. Syntax:\nhttps://cloud.google.com/appengine/docs/standard/python/search/query_strings\nOnly filtering on labels is supported, for example `labels.key=value`."},"pageToken":{"type":"string","location":"query","description":"The next_page_token value returned from the previous List request, if any."},"pageSize":{"location":"query","description":"Limit on the number of HL7v2 stores to return in a single response.\nIf zero the default page size of 100 is used.","format":"int32","type":"integer"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores","path":"v1beta1/{+parent}/hl7V2Stores","id":"healthcare.projects.locations.datasets.hl7V2Stores.list","description":"Lists the HL7v2 stores in the given dataset."},"setIamPolicy":{"response":{"$ref":"Policy"},"parameterOrder":["resource"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"resource":{"location":"path","description":"REQUIRED: The resource for which the policy is being specified.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}:setIamPolicy","path":"v1beta1/{+resource}:setIamPolicy","id":"healthcare.projects.locations.datasets.hl7V2Stores.setIamPolicy","request":{"$ref":"SetIamPolicyRequest"},"description":"Sets the access control policy on the specified resource. Replaces any\nexisting policy."},"create":{"response":{"$ref":"Hl7V2Store"},"parameterOrder":["parent"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"parent":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+$","location":"path","description":"The name of the dataset this HL7v2 store belongs to.","required":true,"type":"string"},"hl7V2StoreId":{"location":"query","description":"The ID of the HL7v2 store that is being created.\nThe string must match the following regex: `[\\p{L}\\p{N}_\\-\\.]{1,256}`.","type":"string"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores","path":"v1beta1/{+parent}/hl7V2Stores","id":"healthcare.projects.locations.datasets.hl7V2Stores.create","request":{"$ref":"Hl7V2Store"},"description":"Creates a new HL7v2 store within the parent dataset."},"getIamPolicy":{"httpMethod":"GET","parameterOrder":["resource"],"response":{"$ref":"Policy"},"parameters":{"options.requestedPolicyVersion":{"description":"Optional. The policy format version to be returned.\nAcceptable values are 0 and 1.\nIf the value is 0, or the field is omitted, policy format version 1 will be\nreturned.","format":"int32","type":"integer","location":"query"},"resource":{"description":"REQUIRED: The resource for which the policy is being requested.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}:getIamPolicy","id":"healthcare.projects.locations.datasets.hl7V2Stores.getIamPolicy","path":"v1beta1/{+resource}:getIamPolicy","description":"Gets the access control policy for a resource.\nReturns an empty policy if the resource exists and does not have a policy\nset."}},"resources":{"messages":{"methods":{"list":{"response":{"$ref":"ListMessagesResponse"},"parameterOrder":["parent"],"httpMethod":"GET","parameters":{"parent":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$","location":"path","description":"Name of the HL7v2 store to retrieve messages from.","required":true,"type":"string"},"filter":{"location":"query","description":"Restricts messages returned to those matching a filter. Syntax:\nhttps://cloud.google.com/appengine/docs/standard/python/search/query_strings\n\nFields/functions available for filtering are:\n\n*  `message_type`, from the MSH-9 segment; for example\n`NOT message_type = \"ADT\"`\n*  `send_date` or `sendDate`, the YYYY-MM-DD date the message was sent in\nthe dataset's time_zone, from the MSH-7 segment; for example\n`send_date < \"2017-01-02\"`\n*  `send_time`, the timestamp of when the message was sent, using the\nRFC3339 time format for comparisons, from the MSH-7 segment; for example\n`send_time < \"2017-01-02T00:00:00-05:00\"`\n*  `send_facility`, the care center that the message came from, from the\nMSH-4 segment; for example `send_facility = \"ABC\"`\n*  `HL7RegExp(expr)`, which does regular expression matching of `expr`\nagainst the message payload using re2 (http://code.google.com/p/re2/)\nsyntax; for example `HL7RegExp(\"^.*\\|.*\\|EMERG\")`\n*  `PatientId(value, type)`, which matches if the message lists a patient\nhaving an ID of the given value and type in the PID-2, PID-3, or PID-4\nsegments; for example `PatientId(\"123456\", \"MRN\")`\n*  `labels.x`, a string value of the label with key `x` as set using the\nMessage.labels\nmap, for example `labels.\"priority\"=\"high\"`. The operator `:*` can be used\nto assert the existence of a label, for example `labels.\"priority\":*`.\n\nLimitations on conjunctions:\n\n*  Negation on the patient ID function or the labels field is not\nsupported, for example these queries are invalid:\n`NOT PatientId(\"123456\", \"MRN\")`, `NOT labels.\"tag1\":*`,\n`NOT labels.\"tag2\"=\"val2\"`.\n*  Conjunction of multiple patient ID functions is not supported, for\nexample this query is invalid:\n`PatientId(\"123456\", \"MRN\") AND PatientId(\"456789\", \"MRN\")`.\n*  Conjunction of multiple labels fields is also not supported, for\nexample this query is invalid: `labels.\"tag1\":* AND labels.\"tag2\"=\"val2\"`.\n*  Conjunction of one patient ID function, one labels field and conditions\non other fields is supported, for example this query is valid:\n`PatientId(\"123456\", \"MRN\") AND labels.\"tag1\":* AND message_type = \"ADT\"`.","type":"string"},"pageToken":{"description":"The next_page_token value returned from the previous List request, if any.","type":"string","location":"query"},"orderBy":{"location":"query","description":"Orders messages returned by the specified order_by clause.\nSyntax: https://cloud.google.com/apis/design/design_patterns#sorting_order\n\nFields available for ordering are:\n\n*  `send_time`","type":"string"},"pageSize":{"location":"query","description":"Limit on the number of messages to return in a single response.\nIf zero the default page size of 100 is used.","format":"int32","type":"integer"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}/messages","path":"v1beta1/{+parent}/messages","id":"healthcare.projects.locations.datasets.hl7V2Stores.messages.list","description":"Lists all the messages in the given HL7v2 store with support for filtering."},"create":{"request":{"$ref":"CreateMessageRequest"},"description":"Creates a message and sends a notification to the Cloud Pub/Sub topic. If\nconfigured, the MLLP adapter listens to messages created by this method and\nsends those back to the hospital. A successful response indicates the\nmessage has been persisted to storage and a Cloud Pub/Sub notification has\nbeen sent. Sending to the hospital by the MLLP adapter happens\nasynchronously.","response":{"$ref":"Message"},"parameterOrder":["parent"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"parent":{"description":"The name of the dataset this message belongs to.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$","location":"path"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}/messages","path":"v1beta1/{+parent}/messages","id":"healthcare.projects.locations.datasets.hl7V2Stores.messages.create"},"ingest":{"httpMethod":"POST","parameterOrder":["parent"],"response":{"$ref":"IngestMessageResponse"},"parameters":{"parent":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+$","location":"path","description":"The name of the HL7v2 store this message belongs to.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}/messages:ingest","id":"healthcare.projects.locations.datasets.hl7V2Stores.messages.ingest","path":"v1beta1/{+parent}/messages:ingest","description":"Ingests a new HL7v2 message from the hospital and sends a notification to\nthe Cloud Pub/Sub topic. Return is an HL7v2 ACK message if the message was\nsuccessfully stored. Otherwise an error is returned.  If an identical\nHL7v2 message is created twice only one resource is created on the server\nand no error is reported.","request":{"$ref":"IngestMessageRequest"}},"patch":{"scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"updateMask":{"type":"string","location":"query","description":"The update mask applies to the resource. For the `FieldMask` definition,\nsee\nhttps://developers.google.com/protocol-buffers/docs/reference/google.protobuf#fieldmask\nOnly the `labels` field is allowed to be updated.\nThe labels in the request will be merged with the existing set of labels.\nExisting labels with the same keys will be updated.","format":"google-fieldmask"},"name":{"description":"Resource name of the Message, of the form\n`projects/{project_id}/datasets/{dataset_id}/hl7V2Stores/{hl7_v2_store_id}/messages/{message_id}`.\nAssigned by the server.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+/messages/[^/]+$","location":"path"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}/messages/{messagesId}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.hl7V2Stores.messages.patch","request":{"$ref":"Message"},"description":"Update the message.","response":{"$ref":"Message"},"parameterOrder":["name"],"httpMethod":"PATCH"},"get":{"response":{"$ref":"Message"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"view":{"location":"query","enum":["MESSAGE_VIEW_UNSPECIFIED","RAW_ONLY","PARSED_ONLY","FULL"],"description":"Specifies which parts of the Message resource should be returned\nin the response.","type":"string"},"name":{"pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+/messages/[^/]+$","location":"path","description":"The resource name of the HL7v2 message to retrieve.","required":true,"type":"string"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}/messages/{messagesId}","path":"v1beta1/{+name}","id":"healthcare.projects.locations.datasets.hl7V2Stores.messages.get","description":"Gets an HL7v2 message."},"delete":{"description":"Deletes an HL7v2 message.","httpMethod":"DELETE","parameterOrder":["name"],"response":{"$ref":"Empty"},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"description":"The resource name of the HL7v2 message to delete.","required":true,"type":"string","pattern":"^projects/[^/]+/locations/[^/]+/datasets/[^/]+/hl7V2Stores/[^/]+/messages/[^/]+$","location":"path"}},"flatPath":"v1beta1/projects/{projectsId}/locations/{locationsId}/datasets/{datasetsId}/hl7V2Stores/{hl7V2StoresId}/messages/{messagesId}","id":"healthcare.projects.locations.datasets.hl7V2Stores.messages.delete","path":"v1beta1/{+name}"}}}}}}}}}}}},"parameters":{"quotaUser":{"description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.","type":"string","location":"query"},"prettyPrint":{"description":"Returns response with indentations and line breaks.","type":"boolean","default":"true","location":"query"},"uploadType":{"description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\").","type":"string","location":"query"},"fields":{"location":"query","description":"Selector specifying which fields to include in a partial response.","type":"string"},"callback":{"description":"JSONP","type":"string","location":"query"},"oauth_token":{"location":"query","description":"OAuth 2.0 token for the current user.","type":"string"},"$.xgafv":{"type":"string","enumDescriptions":["v1 error format","v2 error format"],"location":"query","enum":["1","2"],"description":"V1 error format."},"alt":{"type":"string","enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"],"location":"query","description":"Data format for response.","default":"json","enum":["json","media","proto"]},"key":{"description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.","type":"string","location":"query"},"access_token":{"location":"query","description":"OAuth access token.","type":"string"},"upload_protocol":{"location":"query","description":"Upload protocol for media (e.g. \"raw\", \"multipart\").","type":"string"}},"version":"v1beta1","baseUrl":"https://healthcare.googleapis.com/","servicePath":"","description":"Manage, store, and access healthcare data in Google Cloud Platform.","kind":"discovery#restDescription","basePath":"","id":"healthcare:v1beta1","documentationLink":"https://cloud.google.com/healthcare","revision":"20190626","discoveryVersion":"v1","version_module":true};