export default {"documentationLink":"https://cloud.google.com/service-management/","revision":"20190621","id":"servicemanagement:v1","discoveryVersion":"v1","schemas":{"AuthenticationRule":{"id":"AuthenticationRule","description":"Authentication rules for the service.\n\nBy default, if a method has any authentication requirements, every request\nmust include a valid credential matching one of the requirements.\nIt's an error to include more than one kind of credential in a single\nrequest.\n\nIf a method doesn't have any auth requirements, request credentials will be\nignored.","type":"object","properties":{"selector":{"description":"Selects the methods to which this rule applies.\n\nRefer to selector for syntax details.","type":"string"},"allowWithoutCredential":{"description":"If true, the service accepts API keys without any other credential.","type":"boolean"},"oauth":{"$ref":"OAuthRequirements","description":"The requirements for OAuth credentials."},"requirements":{"description":"Requirements for additional authentication providers.","type":"array","items":{"$ref":"AuthRequirement"}}}},"BackendRule":{"description":"A backend rule provides configuration for an individual API element.","type":"object","properties":{"address":{"description":"The address of the API backend.","type":"string"},"pathTranslation":{"enumDescriptions":["","Use the backend address as-is, with no modification to the path. If the\nURL pattern contains variables, the variable names and values will be\nappended to the query string. If a query string parameter and a URL\npattern variable have the same name, this may result in duplicate keys in\nthe query string.\n\n# Examples\n\nGiven the following operation config:\n\n    Method path:        /api/company/{cid}/user/{uid}\n    Backend address:    https://example.cloudfunctions.net/getUser\n\nRequests to the following request paths will call the backend at the\ntranslated path:\n\n    Request path: /api/company/widgetworks/user/johndoe\n    Translated:\n    https://example.cloudfunctions.net/getUser?cid=widgetworks&uid=johndoe\n\n    Request path: /api/company/widgetworks/user/johndoe?timezone=EST\n    Translated:\n    https://example.cloudfunctions.net/getUser?timezone=EST&cid=widgetworks&uid=johndoe","The request path will be appended to the backend address.\n\n# Examples\n\nGiven the following operation config:\n\n    Method path:        /api/company/{cid}/user/{uid}\n    Backend address:    https://example.appspot.com\n\nRequests to the following request paths will call the backend at the\ntranslated path:\n\n    Request path: /api/company/widgetworks/user/johndoe\n    Translated:\n    https://example.appspot.com/api/company/widgetworks/user/johndoe\n\n    Request path: /api/company/widgetworks/user/johndoe?timezone=EST\n    Translated:\n    https://example.appspot.com/api/company/widgetworks/user/johndoe?timezone=EST"],"enum":["PATH_TRANSLATION_UNSPECIFIED","CONSTANT_ADDRESS","APPEND_PATH_TO_ADDRESS"],"type":"string"},"jwtAudience":{"description":"The JWT audience is used when generating a JWT id token for the backend.","type":"string"},"selector":{"description":"Selects the methods to which this rule applies.\n\nRefer to selector for syntax details.","type":"string"},"operationDeadline":{"type":"number","description":"The number of seconds to wait for the completion of a long running\noperation. The default is no deadline.","format":"double"},"deadline":{"type":"number","description":"The number of seconds to wait for a response from a request.  The default\ndeadline for gRPC is infinite (no deadline) and HTTP requests is 5 seconds.","format":"double"},"minDeadline":{"type":"number","description":"Minimum deadline in seconds needed for this method. Calls having deadline\nvalue lower than this will be rejected.","format":"double"}},"id":"BackendRule"},"Policy":{"type":"object","properties":{"etag":{"description":"`etag` is used for optimistic concurrency control as a way to help\nprevent simultaneous updates of a policy from overwriting each other.\nIt is strongly suggested that systems make use of the `etag` in the\nread-modify-write cycle to perform policy updates in order to avoid race\nconditions: An `etag` is returned in the response to `getIamPolicy`, and\nsystems are expected to put that etag in the request to `setIamPolicy` to\nensure that their change will be applied to the same version of the policy.\n\nIf no `etag` is provided in the call to `setIamPolicy`, then the existing\npolicy is overwritten blindly.","format":"byte","type":"string"},"version":{"description":"Deprecated.","format":"int32","type":"integer"},"auditConfigs":{"description":"Specifies cloud audit logging configuration for this policy.","type":"array","items":{"$ref":"AuditConfig"}},"bindings":{"description":"Associates a list of `members` to a `role`.\n`bindings` with no members will result in an error.","type":"array","items":{"$ref":"Binding"}}},"id":"Policy","description":"Defines an Identity and Access Management (IAM) policy. It is used to\nspecify access control policies for Cloud Platform resources.\n\n\nA `Policy` consists of a list of `bindings`. A `binding` binds a list of\n`members` to a `role`, where the members can be user accounts, Google groups,\nGoogle domains, and service accounts. A `role` is a named list of permissions\ndefined by IAM.\n\n**JSON Example**\n\n    {\n      \"bindings\": [\n        {\n          \"role\": \"roles/owner\",\n          \"members\": [\n            \"user:mike@example.com\",\n            \"group:admins@example.com\",\n            \"domain:google.com\",\n            \"serviceAccount:my-other-app@appspot.gserviceaccount.com\"\n          ]\n        },\n        {\n          \"role\": \"roles/viewer\",\n          \"members\": [\"user:sean@example.com\"]\n        }\n      ]\n    }\n\n**YAML Example**\n\n    bindings:\n    - members:\n      - user:mike@example.com\n      - group:admins@example.com\n      - domain:google.com\n      - serviceAccount:my-other-app@appspot.gserviceaccount.com\n      role: roles/owner\n    - members:\n      - user:sean@example.com\n      role: roles/viewer\n\n\nFor a description of IAM and its features, see the\n[IAM developer's guide](https://cloud.google.com/iam/docs)."},"UndeleteServiceResponse":{"id":"UndeleteServiceResponse","description":"Response message for UndeleteService method.","type":"object","properties":{"service":{"$ref":"ManagedService","description":"Revived service resource."}}},"Api":{"description":"Api is a light-weight descriptor for an API Interface.\n\nInterfaces are also described as \"protocol buffer services\" in some contexts,\nsuch as by the \"service\" keyword in a .proto file, but they are different\nfrom API Services, which represent a concrete implementation of an interface\nas opposed to simply a description of methods and bindings. They are also\nsometimes simply referred to as \"APIs\" in other contexts, such as the name of\nthis message itself. See https://cloud.google.com/apis/design/glossary for\ndetailed terminology.","type":"object","properties":{"version":{"description":"A version string for this interface. If specified, must have the form\n`major-version.minor-version`, as in `1.10`. If the minor version is\nomitted, it defaults to zero. If the entire version field is empty, the\nmajor version is derived from the package name, as outlined below. If the\nfield is not empty, the version in the package name will be verified to be\nconsistent with what is provided here.\n\nThe versioning schema uses [semantic\nversioning](http://semver.org) where the major version number\nindicates a breaking change and the minor version an additive,\nnon-breaking change. Both version numbers are signals to users\nwhat to expect from different versions, and should be carefully\nchosen based on the product plan.\n\nThe major version is also reflected in the package name of the\ninterface, which must end in `v<major-version>`, as in\n`google.feature.v1`. For major versions 0 and 1, the suffix can\nbe omitted. Zero major versions must only be used for\nexperimental, non-GA interfaces.\n","type":"string"},"mixins":{"description":"Included interfaces. See Mixin.","type":"array","items":{"$ref":"Mixin"}},"options":{"description":"Any metadata attached to the interface.","type":"array","items":{"$ref":"Option"}},"methods":{"description":"The methods of this interface, in unspecified order.","type":"array","items":{"$ref":"Method"}},"name":{"description":"The fully qualified name of this interface, including package name\nfollowed by the interface's simple name.","type":"string"},"syntax":{"type":"string","enumDescriptions":["Syntax `proto2`.","Syntax `proto3`."],"enum":["SYNTAX_PROTO2","SYNTAX_PROTO3"],"description":"The source syntax of the service."},"sourceContext":{"description":"Source context for the protocol buffer service represented by this\nmessage.","$ref":"SourceContext"}},"id":"Api"},"MetricRule":{"description":"Bind API methods to metrics. Binding a method to a metric causes that\nmetric's configured quota behaviors to apply to the method call.","type":"object","properties":{"selector":{"type":"string","description":"Selects the methods to which this rule applies.\n\nRefer to selector for syntax details."},"metricCosts":{"description":"Metrics to update when the selected methods are called, and the associated\ncost applied to each metric.\n\nThe key of the map is the metric name, and the values are the amount\nincreased for the metric against which the quota limits are defined.\nThe value must not be negative.","type":"object","additionalProperties":{"format":"int64","type":"string"}}},"id":"MetricRule"},"Authentication":{"description":"`Authentication` defines the authentication configuration for an API.\n\nExample for an API targeted for external use:\n\n    name: calendar.googleapis.com\n    authentication:\n      providers:\n      - id: google_calendar_auth\n        jwks_uri: https://www.googleapis.com/oauth2/v1/certs\n        issuer: https://securetoken.google.com\n      rules:\n      - selector: \"*\"\n        requirements:\n          provider_id: google_calendar_auth","type":"object","properties":{"rules":{"description":"A list of authentication rules that apply to individual API methods.\n\n**NOTE:** All service configuration rules follow \"last one wins\" order.","type":"array","items":{"$ref":"AuthenticationRule"}},"providers":{"description":"Defines a set of authentication providers that a service supports.","type":"array","items":{"$ref":"AuthProvider"}}},"id":"Authentication"},"Operation":{"description":"This resource represents a long-running operation that is the result of a\nnetwork API call.","type":"object","properties":{"metadata":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"description":"Service-specific metadata associated with the operation.  It typically\ncontains progress information and common metadata such as create time.\nSome services might not provide such metadata.  Any method that returns a\nlong-running operation should document the metadata type, if any.","type":"object"},"done":{"type":"boolean","description":"If the value is `false`, it means the operation is still in progress.\nIf `true`, the operation is completed, and either `error` or `response` is\navailable."},"response":{"type":"object","additionalProperties":{"type":"any","description":"Properties of the object. Contains field @type with type URL."},"description":"The normal response of the operation in case of success.  If the original\nmethod returns no data on success, such as `Delete`, the response is\n`google.protobuf.Empty`.  If the original method is standard\n`Get`/`Create`/`Update`, the response should be the resource.  For other\nmethods, the response should have the type `XxxResponse`, where `Xxx`\nis the original method name.  For example, if the original method name\nis `TakeSnapshot()`, the inferred response type is\n`TakeSnapshotResponse`."},"name":{"description":"The server-assigned name, which is only unique within the same service that\noriginally returns it. If you use the default HTTP mapping, the\n`name` should be a resource name ending with `operations/{unique_id}`.","type":"string"},"error":{"$ref":"Status","description":"The error result of the operation in case of failure or cancellation."}},"id":"Operation"},"Page":{"description":"Represents a documentation page. A page can contain subpages to represent\nnested documentation set structure.","type":"object","properties":{"subpages":{"description":"Subpages of this page. The order of subpages specified here will be\nhonored in the generated docset.","type":"array","items":{"$ref":"Page"}},"name":{"description":"The name of the page. It will be used as an identity of the page to\ngenerate URI of the page, text of the link to this page in navigation,\netc. The full page name (start from the root page name to this page\nconcatenated with `.`) can be used as reference to the page in your\ndocumentation. For example:\n<pre><code>pages:\n- name: Tutorial\n  content: &#40;== include tutorial.md ==&#41;\n  subpages:\n  - name: Java\n    content: &#40;== include tutorial_java.md ==&#41;\n</code></pre>\nYou can reference `Java` page using Markdown reference link syntax:\n`Java`.","type":"string"},"content":{"type":"string","description":"The Markdown content of the page. You can use <code>&#40;== include {path}\n==&#41;</code> to include content from a Markdown file."}},"id":"Page"},"Status":{"type":"object","properties":{"details":{"description":"A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.","type":"array","items":{"type":"object","additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"}}},"code":{"description":"The status code, which should be an enum value of google.rpc.Code.","format":"int32","type":"integer"},"message":{"description":"A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.","type":"string"}},"id":"Status","description":"The `Status` type defines a logical error model that is suitable for\ndifferent programming environments, including REST APIs and RPC APIs. It is\nused by [gRPC](https://github.com/grpc). Each `Status` message contains\nthree pieces of data: error code, error message, and error details.\n\nYou can find out more about this error model and how to work with it in the\n[API Design Guide](https://cloud.google.com/apis/design/errors)."},"Binding":{"type":"object","properties":{"members":{"type":"array","items":{"type":"string"},"description":"Specifies the identities requesting access for a Cloud Platform resource.\n`members` can have the following values:\n\n* `allUsers`: A special identifier that represents anyone who is\n   on the internet; with or without a Google account.\n\n* `allAuthenticatedUsers`: A special identifier that represents anyone\n   who is authenticated with a Google account or a service account.\n\n* `user:{emailid}`: An email address that represents a specific Google\n   account. For example, `alice@gmail.com` .\n\n\n* `serviceAccount:{emailid}`: An email address that represents a service\n   account. For example, `my-other-app@appspot.gserviceaccount.com`.\n\n* `group:{emailid}`: An email address that represents a Google group.\n   For example, `admins@example.com`.\n\n\n* `domain:{domain}`: The G Suite domain (primary) that represents all the\n   users of that domain. For example, `google.com` or `example.com`.\n\n"},"role":{"description":"Role that is assigned to `members`.\nFor example, `roles/viewer`, `roles/editor`, or `roles/owner`.","type":"string"},"condition":{"$ref":"Expr","description":"The condition that is associated with this binding.\nNOTE: An unsatisfied condition will not allow user access via current\nbinding. Different bindings, including their conditions, are examined\nindependently."}},"id":"Binding","description":"Associates `members` with a `role`."},"AuthProvider":{"description":"Configuration for an authentication provider, including support for\n[JSON Web Token\n(JWT)](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32).","type":"object","properties":{"jwksUri":{"description":"URL of the provider's public key set to validate signature of the JWT. See\n[OpenID\nDiscovery](https://openid.net/specs/openid-connect-discovery-1_0.html#ProviderMetadata).\nOptional if the key set document:\n - can be retrieved from\n   [OpenID\n   Discovery](https://openid.net/specs/openid-connect-discovery-1_0.html of\n   the issuer.\n - can be inferred from the email domain of the issuer (e.g. a Google\n service account).\n\nExample: https://www.googleapis.com/oauth2/v1/certs","type":"string"},"audiences":{"description":"The list of JWT\n[audiences](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.3).\nthat are allowed to access. A JWT containing any of these audiences will\nbe accepted. When this setting is absent, only JWTs with audience\n\"https://Service_name/API_name\"\nwill be accepted. For example, if no audiences are in the setting,\nLibraryService API will only accept JWTs with the following audience\n\"https://library-example.googleapis.com/google.example.library.v1.LibraryService\".\n\nExample:\n\n    audiences: bookstore_android.apps.googleusercontent.com,\n               bookstore_web.apps.googleusercontent.com","type":"string"},"id":{"type":"string","description":"The unique identifier of the auth provider. It will be referred to by\n`AuthRequirement.provider_id`.\n\nExample: \"bookstore_auth\"."},"issuer":{"description":"Identifies the principal that issued the JWT. See\nhttps://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.1\nUsually a URL or an email address.\n\nExample: https://securetoken.google.com\nExample: 1234567-compute@developer.gserviceaccount.com","type":"string"},"authorizationUrl":{"type":"string","description":"Redirect URL if JWT token is required but not present or is expired.\nImplement authorizationUrl of securityDefinitions in OpenAPI spec."}},"id":"AuthProvider"},"EnumValue":{"id":"EnumValue","description":"Enum value definition.","type":"object","properties":{"number":{"description":"Enum value number.","format":"int32","type":"integer"},"name":{"type":"string","description":"Enum value name."},"options":{"description":"Protocol buffer options.","type":"array","items":{"$ref":"Option"}}}},"Service":{"description":"`Service` is the root object of Google service configuration schema. It\ndescribes basic information about a service, such as the name and the\ntitle, and delegates other aspects to sub-sections. Each sub-section is\neither a proto message or a repeated proto message that configures a\nspecific aspect, such as auth. See each proto message definition for details.\n\nExample:\n\n    type: google.api.Service\n    config_version: 3\n    name: calendar.googleapis.com\n    title: Google Calendar API\n    apis:\n    - name: google.calendar.v3.Calendar\n    authentication:\n      providers:\n      - id: google_calendar_auth\n        jwks_uri: https://www.googleapis.com/oauth2/v1/certs\n        issuer: https://securetoken.google.com\n      rules:\n      - selector: \"*\"\n        requirements:\n          provider_id: google_calendar_auth","type":"object","properties":{"quota":{"$ref":"Quota","description":"Quota configuration."},"billing":{"$ref":"Billing","description":"Billing configuration."},"name":{"description":"The service name, which is a DNS-like logical identifier for the\nservice, such as `calendar.googleapis.com`. The service name\ntypically goes through DNS verification to make sure the owner\nof the service also owns the DNS name.","type":"string"},"customError":{"description":"Custom error configuration.","$ref":"CustomError"},"title":{"description":"The product title for this service.","type":"string"},"endpoints":{"description":"Configuration for network endpoints.  If this is empty, then an endpoint\nwith the same name as the service is automatically generated to service all\ndefined APIs.","type":"array","items":{"$ref":"Endpoint"}},"apis":{"type":"array","items":{"$ref":"Api"},"description":"A list of API interfaces exported by this service. Only the `name` field\nof the google.protobuf.Api needs to be provided by the configuration\nauthor, as the remaining fields will be derived from the IDL during the\nnormalization process. It is an error to specify an API interface here\nwhich cannot be resolved against the associated IDL files."},"logs":{"description":"Defines the logs used by this service.","type":"array","items":{"$ref":"LogDescriptor"}},"types":{"type":"array","items":{"$ref":"Type"},"description":"A list of all proto message types included in this API service.\nTypes referenced directly or indirectly by the `apis` are\nautomatically included.  Messages which are not referenced but\nshall be included, such as types used by the `google.protobuf.Any` type,\nshould be listed here by name. Example:\n\n    types:\n    - name: google.protobuf.Int32"},"sourceInfo":{"$ref":"SourceInfo","description":"Output only. The source information for this configuration if available."},"http":{"$ref":"Http","description":"HTTP configuration."},"backend":{"$ref":"Backend","description":"API backend configuration."},"systemParameters":{"$ref":"SystemParameters","description":"System parameter configuration."},"documentation":{"$ref":"Documentation","description":"Additional API documentation."},"monitoredResources":{"description":"Defines the monitored resources used by this service. This is required\nby the Service.monitoring and Service.logging configurations.","type":"array","items":{"$ref":"MonitoredResourceDescriptor"}},"logging":{"$ref":"Logging","description":"Logging configuration."},"enums":{"description":"A list of all enum types included in this API service.  Enums\nreferenced directly or indirectly by the `apis` are automatically\nincluded.  Enums which are not referenced but shall be included\nshould be listed here by name. Example:\n\n    enums:\n    - name: google.someapi.v1.SomeEnum","type":"array","items":{"$ref":"Enum"}},"context":{"$ref":"Context","description":"Context configuration."},"id":{"type":"string","description":"A unique ID for a specific instance of this message, typically assigned\nby the client for tracking purpose. If empty, the server may choose to\ngenerate one instead. Must be no longer than 60 characters."},"usage":{"$ref":"Usage","description":"Configuration controlling usage of this service."},"metrics":{"description":"Defines the metrics used by this service.","type":"array","items":{"$ref":"MetricDescriptor"}},"authentication":{"$ref":"Authentication","description":"Auth configuration."},"control":{"$ref":"Control","description":"Configuration for the service control plane."},"configVersion":{"description":"The semantic version of the service configuration. The config version\naffects the interpretation of the service configuration. For example,\ncertain features are enabled by default for certain config versions.\nThe latest config version is `3`.","format":"uint32","type":"integer"},"monitoring":{"$ref":"Monitoring","description":"Monitoring configuration."},"producerProjectId":{"description":"The Google project that owns this service.","type":"string"},"systemTypes":{"description":"A list of all proto message types included in this API service.\nIt serves similar purpose as [google.api.Service.types], except that\nthese types are not needed by user-defined APIs. Therefore, they will not\nshow up in the generated discovery doc. This field should only be used\nto define system APIs in ESF.","type":"array","items":{"$ref":"Type"}}},"id":"Service"},"ListOperationsResponse":{"type":"object","properties":{"operations":{"description":"A list of operations that matches the specified filter in the request.","type":"array","items":{"$ref":"Operation"}},"nextPageToken":{"description":"The standard List next-page token.","type":"string"}},"id":"ListOperationsResponse","description":"The response message for Operations.ListOperations."},"OperationMetadata":{"description":"The metadata associated with a long running operation resource.","type":"object","properties":{"startTime":{"description":"The start time of the operation.","format":"google-datetime","type":"string"},"resourceNames":{"description":"The full name of the resources that this operation is directly\nassociated with.","type":"array","items":{"type":"string"}},"steps":{"description":"Detailed status information for each step. The order is undetermined.","type":"array","items":{"$ref":"Step"}},"progressPercentage":{"type":"integer","description":"Percentage of completion of this operation, ranging from 0 to 100.","format":"int32"}},"id":"OperationMetadata"},"CustomHttpPattern":{"id":"CustomHttpPattern","description":"A custom pattern is used for defining custom HTTP verb.","type":"object","properties":{"kind":{"description":"The name of this custom HTTP verb.","type":"string"},"path":{"description":"The path matched by this custom verb.","type":"string"}}},"MetricDescriptorMetadata":{"type":"object","properties":{"ingestDelay":{"type":"string","description":"The delay of data points caused by ingestion. Data points older than this\nage are guaranteed to be ingested and available to be read, excluding\ndata loss due to errors.","format":"google-duration"},"launchStage":{"description":"Deprecated. Please use the MetricDescriptor.launch_stage instead.\nThe launch stage of the metric definition.","type":"string","enumDescriptions":["Do not use this default value.","Early Access features are limited to a closed group of testers. To use\nthese features, you must sign up in advance and sign a Trusted Tester\nagreement (which includes confidentiality provisions). These features may\nbe unstable, changed in backward-incompatible ways, and are not\nguaranteed to be released.","Alpha is a limited availability test for releases before they are cleared\nfor widespread use. By Alpha, all significant design issues are resolved\nand we are in the process of verifying functionality. Alpha customers\nneed to apply for access, agree to applicable terms, and have their\nprojects whitelisted. Alpha releases don’t have to be feature complete,\nno SLAs are provided, and there are no technical support obligations, but\nthey will be far enough along that customers can actually use them in\ntest environments or for limited-use tests -- just like they would in\nnormal production cases.","Beta is the point at which we are ready to open a release for any\ncustomer to use. There are no SLA or technical support obligations in a\nBeta release. Products will be complete from a feature perspective, but\nmay have some open outstanding issues. Beta releases are suitable for\nlimited production use cases.","GA features are open to all developers and are considered stable and\nfully qualified for production use.","Deprecated features are scheduled to be shut down and removed. For more\ninformation, see the “Deprecation Policy” section of our [Terms of\nService](https://cloud.google.com/terms/)\nand the [Google Cloud Platform Subject to the Deprecation\nPolicy](https://cloud.google.com/terms/deprecation) documentation."],"enum":["LAUNCH_STAGE_UNSPECIFIED","EARLY_ACCESS","ALPHA","BETA","GA","DEPRECATED"]},"samplePeriod":{"description":"The sampling period of metric data points. For metrics which are written\nperiodically, consecutive data points are stored at this time interval,\nexcluding data loss due to errors. Metrics with a higher granularity have\na smaller sampling period.","format":"google-duration","type":"string"}},"id":"MetricDescriptorMetadata","description":"Additional annotations that can be used to guide the usage of a metric."},"SystemParameterRule":{"type":"object","properties":{"selector":{"description":"Selects the methods to which this rule applies. Use '*' to indicate all\nmethods in all APIs.\n\nRefer to selector for syntax details.","type":"string"},"parameters":{"type":"array","items":{"$ref":"SystemParameter"},"description":"Define parameters. Multiple names may be defined for a parameter.\nFor a given method call, only one of them should be used. If multiple\nnames are used the behavior is implementation-dependent.\nIf none of the specified names are present the behavior is\nparameter-dependent."}},"id":"SystemParameterRule","description":"Define a system parameter rule mapping system parameter definitions to\nmethods."},"HttpRule":{"type":"object","properties":{"selector":{"description":"Selects a method to which this rule applies.\n\nRefer to selector for syntax details.","type":"string"},"post":{"type":"string","description":"Maps to HTTP POST. Used for creating a resource or performing an action."},"custom":{"$ref":"CustomHttpPattern","description":"The custom pattern is used for specifying an HTTP method that is not\nincluded in the `pattern` field, such as HEAD, or \"*\" to leave the\nHTTP method unspecified for this rule. The wild-card rule is useful\nfor services that provide content to Web (HTML) clients."},"get":{"description":"Maps to HTTP GET. Used for listing and getting information about\nresources.","type":"string"},"patch":{"description":"Maps to HTTP PATCH. Used for updating a resource.","type":"string"},"put":{"description":"Maps to HTTP PUT. Used for replacing a resource.","type":"string"},"additionalBindings":{"description":"Additional HTTP bindings for the selector. Nested bindings must\nnot contain an `additional_bindings` field themselves (that is,\nthe nesting may only be one level deep).","type":"array","items":{"$ref":"HttpRule"}},"delete":{"description":"Maps to HTTP DELETE. Used for deleting a resource.","type":"string"},"responseBody":{"description":"Optional. The name of the response field whose value is mapped to the HTTP\nresponse body. When omitted, the entire response message will be used\nas the HTTP response body.\n\nNOTE: The referred field must be present at the top-level of the response\nmessage type.","type":"string"},"body":{"type":"string","description":"The name of the request field whose value is mapped to the HTTP request\nbody, or `*` for mapping all request fields not captured by the path\npattern to the HTTP body, or omitted for not having any HTTP request body.\n\nNOTE: the referred field must be present at the top-level of the request\nmessage type."}},"id":"HttpRule","description":"# gRPC Transcoding\n\ngRPC Transcoding is a feature for mapping between a gRPC method and one or\nmore HTTP REST endpoints. It allows developers to build a single API service\nthat supports both gRPC APIs and REST APIs. Many systems, including [Google\nAPIs](https://github.com/googleapis/googleapis),\n[Cloud Endpoints](https://cloud.google.com/endpoints), [gRPC\nGateway](https://github.com/grpc-ecosystem/grpc-gateway),\nand [Envoy](https://github.com/envoyproxy/envoy) proxy support this feature\nand use it for large scale production services.\n\n`HttpRule` defines the schema of the gRPC/REST mapping. The mapping specifies\nhow different portions of the gRPC request message are mapped to the URL\npath, URL query parameters, and HTTP request body. It also controls how the\ngRPC response message is mapped to the HTTP response body. `HttpRule` is\ntypically specified as an `google.api.http` annotation on the gRPC method.\n\nEach mapping specifies a URL path template and an HTTP method. The path\ntemplate may refer to one or more fields in the gRPC request message, as long\nas each field is a non-repeated field with a primitive (non-message) type.\nThe path template controls how fields of the request message are mapped to\nthe URL path.\n\nExample:\n\n    service Messaging {\n      rpc GetMessage(GetMessageRequest) returns (Message) {\n        option (google.api.http) = {\n            get: \"/v1/{name=messages/*}\"\n        };\n      }\n    }\n    message GetMessageRequest {\n      string name = 1; // Mapped to URL path.\n    }\n    message Message {\n      string text = 1; // The resource content.\n    }\n\nThis enables an HTTP REST to gRPC mapping as below:\n\nHTTP | gRPC\n-----|-----\n`GET /v1/messages/123456`  | `GetMessage(name: \"messages/123456\")`\n\nAny fields in the request message which are not bound by the path template\nautomatically become HTTP query parameters if there is no HTTP request body.\nFor example:\n\n    service Messaging {\n      rpc GetMessage(GetMessageRequest) returns (Message) {\n        option (google.api.http) = {\n            get:\"/v1/messages/{message_id}\"\n        };\n      }\n    }\n    message GetMessageRequest {\n      message SubMessage {\n        string subfield = 1;\n      }\n      string message_id = 1; // Mapped to URL path.\n      int64 revision = 2;    // Mapped to URL query parameter `revision`.\n      SubMessage sub = 3;    // Mapped to URL query parameter `sub.subfield`.\n    }\n\nThis enables a HTTP JSON to RPC mapping as below:\n\nHTTP | gRPC\n-----|-----\n`GET /v1/messages/123456?revision=2&sub.subfield=foo` |\n`GetMessage(message_id: \"123456\" revision: 2 sub: SubMessage(subfield:\n\"foo\"))`\n\nNote that fields which are mapped to URL query parameters must have a\nprimitive type or a repeated primitive type or a non-repeated message type.\nIn the case of a repeated type, the parameter can be repeated in the URL\nas `...?param=A&param=B`. In the case of a message type, each field of the\nmessage is mapped to a separate parameter, such as\n`...?foo.a=A&foo.b=B&foo.c=C`.\n\nFor HTTP methods that allow a request body, the `body` field\nspecifies the mapping. Consider a REST update method on the\nmessage resource collection:\n\n    service Messaging {\n      rpc UpdateMessage(UpdateMessageRequest) returns (Message) {\n        option (google.api.http) = {\n          patch: \"/v1/messages/{message_id}\"\n          body: \"message\"\n        };\n      }\n    }\n    message UpdateMessageRequest {\n      string message_id = 1; // mapped to the URL\n      Message message = 2;   // mapped to the body\n    }\n\nThe following HTTP JSON to RPC mapping is enabled, where the\nrepresentation of the JSON in the request body is determined by\nprotos JSON encoding:\n\nHTTP | gRPC\n-----|-----\n`PATCH /v1/messages/123456 { \"text\": \"Hi!\" }` | `UpdateMessage(message_id:\n\"123456\" message { text: \"Hi!\" })`\n\nThe special name `*` can be used in the body mapping to define that\nevery field not bound by the path template should be mapped to the\nrequest body.  This enables the following alternative definition of\nthe update method:\n\n    service Messaging {\n      rpc UpdateMessage(Message) returns (Message) {\n        option (google.api.http) = {\n          patch: \"/v1/messages/{message_id}\"\n          body: \"*\"\n        };\n      }\n    }\n    message Message {\n      string message_id = 1;\n      string text = 2;\n    }\n\n\nThe following HTTP JSON to RPC mapping is enabled:\n\nHTTP | gRPC\n-----|-----\n`PATCH /v1/messages/123456 { \"text\": \"Hi!\" }` | `UpdateMessage(message_id:\n\"123456\" text: \"Hi!\")`\n\nNote that when using `*` in the body mapping, it is not possible to\nhave HTTP parameters, as all fields not bound by the path end in\nthe body. This makes this option more rarely used in practice when\ndefining REST APIs. The common usage of `*` is in custom methods\nwhich don't use the URL at all for transferring data.\n\nIt is possible to define multiple HTTP methods for one RPC by using\nthe `additional_bindings` option. Example:\n\n    service Messaging {\n      rpc GetMessage(GetMessageRequest) returns (Message) {\n        option (google.api.http) = {\n          get: \"/v1/messages/{message_id}\"\n          additional_bindings {\n            get: \"/v1/users/{user_id}/messages/{message_id}\"\n          }\n        };\n      }\n    }\n    message GetMessageRequest {\n      string message_id = 1;\n      string user_id = 2;\n    }\n\nThis enables the following two alternative HTTP JSON to RPC mappings:\n\nHTTP | gRPC\n-----|-----\n`GET /v1/messages/123456` | `GetMessage(message_id: \"123456\")`\n`GET /v1/users/me/messages/123456` | `GetMessage(user_id: \"me\" message_id:\n\"123456\")`\n\n## Rules for HTTP mapping\n\n1. Leaf request fields (recursive expansion nested messages in the request\n   message) are classified into three categories:\n   - Fields referred by the path template. They are passed via the URL path.\n   - Fields referred by the HttpRule.body. They are passed via the HTTP\n     request body.\n   - All other fields are passed via the URL query parameters, and the\n     parameter name is the field path in the request message. A repeated\n     field can be represented as multiple query parameters under the same\n     name.\n 2. If HttpRule.body is \"*\", there is no URL query parameter, all fields\n    are passed via URL path and HTTP request body.\n 3. If HttpRule.body is omitted, there is no HTTP request body, all\n    fields are passed via URL path and URL query parameters.\n\n### Path template syntax\n\n    Template = \"/\" Segments [ Verb ] ;\n    Segments = Segment { \"/\" Segment } ;\n    Segment  = \"*\" | \"**\" | LITERAL | Variable ;\n    Variable = \"{\" FieldPath [ \"=\" Segments ] \"}\" ;\n    FieldPath = IDENT { \".\" IDENT } ;\n    Verb     = \":\" LITERAL ;\n\nThe syntax `*` matches a single URL path segment. The syntax `**` matches\nzero or more URL path segments, which must be the last part of the URL path\nexcept the `Verb`.\n\nThe syntax `Variable` matches part of the URL path as specified by its\ntemplate. A variable template must not contain other variables. If a variable\nmatches a single path segment, its template may be omitted, e.g. `{var}`\nis equivalent to `{var=*}`.\n\nThe syntax `LITERAL` matches literal text in the URL path. If the `LITERAL`\ncontains any reserved character, such characters should be percent-encoded\nbefore the matching.\n\nIf a variable contains exactly one path segment, such as `\"{var}\"` or\n`\"{var=*}\"`, when such a variable is expanded into a URL path on the client\nside, all characters except `[-_.~0-9a-zA-Z]` are percent-encoded. The\nserver side does the reverse decoding. Such variables show up in the\n[Discovery\nDocument](https://developers.google.com/discovery/v1/reference/apis) as\n`{var}`.\n\nIf a variable contains multiple path segments, such as `\"{var=foo/*}\"`\nor `\"{var=**}\"`, when such a variable is expanded into a URL path on the\nclient side, all characters except `[-_.~/0-9a-zA-Z]` are percent-encoded.\nThe server side does the reverse decoding, except \"%2F\" and \"%2f\" are left\nunchanged. Such variables show up in the\n[Discovery\nDocument](https://developers.google.com/discovery/v1/reference/apis) as\n`{+var}`.\n\n## Using gRPC API Service Configuration\n\ngRPC API Service Configuration (service config) is a configuration language\nfor configuring a gRPC service to become a user-facing product. The\nservice config is simply the YAML representation of the `google.api.Service`\nproto message.\n\nAs an alternative to annotating your proto file, you can configure gRPC\ntranscoding in your service config YAML files. You do this by specifying a\n`HttpRule` that maps the gRPC method to a REST endpoint, achieving the same\neffect as the proto annotation. This can be particularly useful if you\nhave a proto that is reused in multiple services. Note that any transcoding\nspecified in the service config will override any matching transcoding\nconfiguration in the proto.\n\nExample:\n\n    http:\n      rules:\n        # Selects a gRPC method and applies HttpRule to it.\n        - selector: example.v1.Messaging.GetMessage\n          get: /v1/messages/{message_id}/{sub.subfield}\n\n## Special notes\n\nWhen gRPC Transcoding is used to map a gRPC to JSON REST endpoints, the\nproto to JSON conversion must follow the [proto3\nspecification](https://developers.google.com/protocol-buffers/docs/proto3#json).\n\nWhile the single segment variable follows the semantics of\n[RFC 6570](https://tools.ietf.org/html/rfc6570) Section 3.2.2 Simple String\nExpansion, the multi segment variable **does not** follow RFC 6570 Section\n3.2.3 Reserved Expansion. The reason is that the Reserved Expansion\ndoes not expand special characters like `?` and `#`, which would lead\nto invalid URLs. As the result, gRPC Transcoding uses a custom encoding\nfor multi segment variables.\n\nThe path variables **must not** refer to any repeated or mapped field,\nbecause client libraries are not capable of handling such variable expansion.\n\nThe path variables **must not** capture the leading \"/\" character. The reason\nis that the most common use case \"{var}\" does not capture the leading \"/\"\ncharacter. For consistency, all path variables must share the same behavior.\n\nRepeated message fields must not be mapped to URL query parameters, because\nno client library can support such complicated mapping.\n\nIf an API needs to use a JSON array for request or response body, it can map\nthe request or response body to a repeated field. However, some gRPC\nTranscoding implementations may not support this feature."},"MonitoringDestination":{"description":"Configuration of a specific monitoring destination (the producer project\nor the consumer project).","type":"object","properties":{"monitoredResource":{"description":"The monitored resource type. The type must be defined in\nService.monitored_resources section.","type":"string"},"metrics":{"type":"array","items":{"type":"string"},"description":"Types of the metrics to report to this monitoring destination.\nEach type must be defined in Service.metrics section."}},"id":"MonitoringDestination"},"SystemParameters":{"description":"### System parameter configuration\n\nA system parameter is a special kind of parameter defined by the API\nsystem, not by an individual API. It is typically mapped to an HTTP header\nand/or a URL query parameter. This configuration specifies which methods\nchange the names of the system parameters.","type":"object","properties":{"rules":{"description":"Define system parameters.\n\nThe parameters defined here will override the default parameters\nimplemented by the system. If this field is missing from the service\nconfig, default system parameters will be used. Default system parameters\nand names is implementation-dependent.\n\nExample: define api key for all methods\n\n    system_parameters\n      rules:\n        - selector: \"*\"\n          parameters:\n            - name: api_key\n              url_query_parameter: api_key\n\n\nExample: define 2 api key names for a specific method.\n\n    system_parameters\n      rules:\n        - selector: \"/ListShelves\"\n          parameters:\n            - name: api_key\n              http_header: Api-Key1\n            - name: api_key\n              http_header: Api-Key2\n\n**NOTE:** All service configuration rules follow \"last one wins\" order.","type":"array","items":{"$ref":"SystemParameterRule"}}},"id":"SystemParameters"},"ConfigChange":{"description":"Output generated from semantically comparing two versions of a service\nconfiguration.\n\nIncludes detailed information about a field that have changed with\napplicable advice about potential consequences for the change, such as\nbackwards-incompatibility.","type":"object","properties":{"newValue":{"type":"string","description":"Value of the changed object in the new Service configuration,\nin JSON format. This field will not be populated if ChangeType == REMOVED."},"changeType":{"type":"string","enumDescriptions":["No value was provided.","The changed object exists in the 'new' service configuration, but not\nin the 'old' service configuration.","The changed object exists in the 'old' service configuration, but not\nin the 'new' service configuration.","The changed object exists in both service configurations, but its value\nis different."],"enum":["CHANGE_TYPE_UNSPECIFIED","ADDED","REMOVED","MODIFIED"],"description":"The type for this change, either ADDED, REMOVED, or MODIFIED."},"element":{"description":"Object hierarchy path to the change, with levels separated by a '.'\ncharacter. For repeated fields, an applicable unique identifier field is\nused for the index (usually selector, name, or id). For maps, the term\n'key' is used. If the field has no unique identifier, the numeric index\nis used.\nExamples:\n- visibility.rules[selector==\"google.LibraryService.ListBooks\"].restriction\n- quota.metric_rules[selector==\"google\"].metric_costs[key==\"reads\"].value\n- logging.producer_destinations[0]","type":"string"},"oldValue":{"description":"Value of the changed object in the old Service configuration,\nin JSON format. This field will not be populated if ChangeType == ADDED.","type":"string"},"advices":{"description":"Collection of advice provided for this change, useful for determining the\npossible impact of this change.","type":"array","items":{"$ref":"Advice"}}},"id":"ConfigChange"},"Quota":{"description":"Quota configuration helps to achieve fairness and budgeting in service\nusage.\n\nThe metric based quota configuration works this way:\n- The service configuration defines a set of metrics.\n- For API calls, the quota.metric_rules maps methods to metrics with\n  corresponding costs.\n- The quota.limits defines limits on the metrics, which will be used for\n  quota checks at runtime.\n\nAn example quota configuration in yaml format:\n\n   quota:\n     limits:\n\n     - name: apiWriteQpsPerProject\n       metric: library.googleapis.com/write_calls\n       unit: \"1/min/{project}\"  # rate limit for consumer projects\n       values:\n         STANDARD: 10000\n\n\n     # The metric rules bind all methods to the read_calls metric,\n     # except for the UpdateBook and DeleteBook methods. These two methods\n     # are mapped to the write_calls metric, with the UpdateBook method\n     # consuming at twice rate as the DeleteBook method.\n     metric_rules:\n     - selector: \"*\"\n       metric_costs:\n         library.googleapis.com/read_calls: 1\n     - selector: google.example.library.v1.LibraryService.UpdateBook\n       metric_costs:\n         library.googleapis.com/write_calls: 2\n     - selector: google.example.library.v1.LibraryService.DeleteBook\n       metric_costs:\n         library.googleapis.com/write_calls: 1\n\n Corresponding Metric definition:\n\n     metrics:\n     - name: library.googleapis.com/read_calls\n       display_name: Read requests\n       metric_kind: DELTA\n       value_type: INT64\n\n     - name: library.googleapis.com/write_calls\n       display_name: Write requests\n       metric_kind: DELTA\n       value_type: INT64\n\n","type":"object","properties":{"limits":{"description":"List of `QuotaLimit` definitions for the service.","type":"array","items":{"$ref":"QuotaLimit"}},"metricRules":{"description":"List of `MetricRule` definitions, each one mapping a selected method to one\nor more metrics.","type":"array","items":{"$ref":"MetricRule"}}},"id":"Quota"},"Rollout":{"description":"A rollout resource that defines how service configuration versions are pushed\nto control plane systems. Typically, you create a new version of the\nservice config, and then create a Rollout to push the service config.","type":"object","properties":{"rolloutId":{"description":"Optional unique identifier of this Rollout. Only lower case letters, digits\n and '-' are allowed.\n\nIf not specified by client, the server will generate one. The generated id\nwill have the form of <date><revision number>, where \"date\" is the create\ndate in ISO 8601 format.  \"revision number\" is a monotonically increasing\npositive number that is reset every day for each service.\nAn example of the generated rollout_id is '2016-02-16r1'","type":"string"},"deleteServiceStrategy":{"$ref":"DeleteServiceStrategy","description":"The strategy associated with a rollout to delete a `ManagedService`.\nReadonly."},"createTime":{"description":"Creation time of the rollout. Readonly.","format":"google-datetime","type":"string"},"status":{"enumDescriptions":["No status specified.","The Rollout is in progress.","The Rollout has completed successfully.","The Rollout has been cancelled. This can happen if you have overlapping\nRollout pushes, and the previous ones will be cancelled.","The Rollout has failed and the rollback attempt has failed too.","The Rollout has not started yet and is pending for execution.","The Rollout has failed and rolled back to the previous successful\nRollout."],"enum":["ROLLOUT_STATUS_UNSPECIFIED","IN_PROGRESS","SUCCESS","CANCELLED","FAILED","PENDING","FAILED_ROLLED_BACK"],"description":"The status of this rollout. Readonly. In case of a failed rollout,\nthe system will automatically rollback to the current Rollout\nversion. Readonly.","type":"string"},"serviceName":{"description":"The name of the service associated with this Rollout.","type":"string"},"createdBy":{"type":"string","description":"The user who created the Rollout. Readonly."},"trafficPercentStrategy":{"$ref":"TrafficPercentStrategy","description":"Google Service Control selects service configurations based on\ntraffic percentage."}},"id":"Rollout"},"GenerateConfigReportRequest":{"type":"object","properties":{"oldConfig":{"description":"Service configuration against which the comparison will be done.\nFor this version of API, the supported types are\ngoogle.api.servicemanagement.v1.ConfigRef,\ngoogle.api.servicemanagement.v1.ConfigSource,\nand google.api.Service","type":"object","additionalProperties":{"type":"any","description":"Properties of the object. Contains field @type with type URL."}},"newConfig":{"description":"Service configuration for which we want to generate the report.\nFor this version of API, the supported types are\ngoogle.api.servicemanagement.v1.ConfigRef,\ngoogle.api.servicemanagement.v1.ConfigSource,\nand google.api.Service","type":"object","additionalProperties":{"type":"any","description":"Properties of the object. Contains field @type with type URL."}}},"id":"GenerateConfigReportRequest","description":"Request message for GenerateConfigReport method."},"SetIamPolicyRequest":{"description":"Request message for `SetIamPolicy` method.","type":"object","properties":{"policy":{"$ref":"Policy","description":"REQUIRED: The complete policy to be applied to the `resource`. The size of\nthe policy is limited to a few 10s of KB. An empty policy is a\nvalid policy but certain Cloud Platform services (such as Projects)\nmight reject them."},"updateMask":{"type":"string","description":"OPTIONAL: A FieldMask specifying which fields of the policy to modify. Only\nthe fields in the mask will be modified. If no mask is provided, the\nfollowing default mask is used:\npaths: \"bindings, etag\"\nThis field is only used by Cloud IAM.","format":"google-fieldmask"}},"id":"SetIamPolicyRequest"},"DeleteServiceStrategy":{"type":"object","properties":{},"id":"DeleteServiceStrategy","description":"Strategy used to delete a service. This strategy is a placeholder only\nused by the system generated rollout to delete a service."},"Step":{"description":"Represents the status of one operation step.","type":"object","properties":{"status":{"enum":["STATUS_UNSPECIFIED","DONE","NOT_STARTED","IN_PROGRESS","FAILED","CANCELLED"],"description":"The status code.","type":"string","enumDescriptions":["Unspecifed code.","The operation or step has completed without errors.","The operation or step has not started yet.","The operation or step is in progress.","The operation or step has completed with errors. If the operation is\nrollbackable, the rollback completed with errors too.","The operation or step has completed with cancellation."]},"description":{"description":"The short description of the step.","type":"string"}},"id":"Step"},"LoggingDestination":{"description":"Configuration of a specific logging destination (the producer project\nor the consumer project).","type":"object","properties":{"logs":{"type":"array","items":{"type":"string"},"description":"Names of the logs to be sent to this destination. Each name must\nbe defined in the Service.logs section. If the log name is\nnot a domain scoped name, it will be automatically prefixed with\nthe service name followed by \"/\"."},"monitoredResource":{"description":"The monitored resource type. The type must be defined in the\nService.monitored_resources section.","type":"string"}},"id":"LoggingDestination"},"Option":{"description":"A protocol buffer option, which can be attached to a message, field,\nenumeration, etc.","type":"object","properties":{"value":{"additionalProperties":{"type":"any","description":"Properties of the object. Contains field @type with type URL."},"description":"The option's value packed in an Any message. If the value is a primitive,\nthe corresponding wrapper type defined in google/protobuf/wrappers.proto\nshould be used. If the value is an enum, it should be stored as an int32\nvalue using the google.protobuf.Int32Value type.","type":"object"},"name":{"type":"string","description":"The option's name. For protobuf built-in options (options defined in\ndescriptor.proto), this is the short name. For example, `\"map_entry\"`.\nFor custom options, it should be the fully-qualified name. For example,\n`\"google.api.http\"`."}},"id":"Option"},"Logging":{"description":"Logging configuration of the service.\n\nThe following example shows how to configure logs to be sent to the\nproducer and consumer projects. In the example, the `activity_history`\nlog is sent to both the producer and consumer projects, whereas the\n`purchase_history` log is only sent to the producer project.\n\n    monitored_resources:\n    - type: library.googleapis.com/branch\n      labels:\n      - key: /city\n        description: The city where the library branch is located in.\n      - key: /name\n        description: The name of the branch.\n    logs:\n    - name: activity_history\n      labels:\n      - key: /customer_id\n    - name: purchase_history\n    logging:\n      producer_destinations:\n      - monitored_resource: library.googleapis.com/branch\n        logs:\n        - activity_history\n        - purchase_history\n      consumer_destinations:\n      - monitored_resource: library.googleapis.com/branch\n        logs:\n        - activity_history","type":"object","properties":{"consumerDestinations":{"description":"Logging configurations for sending logs to the consumer project.\nThere can be multiple consumer destinations, each one must have a\ndifferent monitored resource type. A log can be used in at most\none consumer destination.","type":"array","items":{"$ref":"LoggingDestination"}},"producerDestinations":{"description":"Logging configurations for sending logs to the producer project.\nThere can be multiple producer destinations, each one must have a\ndifferent monitored resource type. A log can be used in at most\none producer destination.","type":"array","items":{"$ref":"LoggingDestination"}}},"id":"Logging"},"Method":{"description":"Method represents a method of an API interface.","type":"object","properties":{"options":{"description":"Any metadata attached to the method.","type":"array","items":{"$ref":"Option"}},"responseStreaming":{"description":"If true, the response is streamed.","type":"boolean"},"name":{"description":"The simple name of this method.","type":"string"},"requestTypeUrl":{"description":"A URL of the input message type.","type":"string"},"requestStreaming":{"description":"If true, the request is streamed.","type":"boolean"},"syntax":{"enum":["SYNTAX_PROTO2","SYNTAX_PROTO3"],"description":"The source syntax of this method.","type":"string","enumDescriptions":["Syntax `proto2`.","Syntax `proto3`."]},"responseTypeUrl":{"description":"The URL of the output message type.","type":"string"}},"id":"Method"},"QuotaLimit":{"description":"`QuotaLimit` defines a specific limit that applies over a specified duration\nfor a limit type. There can be at most one limit for a duration and limit\ntype combination defined within a `QuotaGroup`.","type":"object","properties":{"name":{"description":"Name of the quota limit.\n\nThe name must be provided, and it must be unique within the service. The\nname can only include alphanumeric characters as well as '-'.\n\nThe maximum length of the limit name is 64 characters.","type":"string"},"duration":{"type":"string","description":"Duration of this limit in textual notation. Example: \"100s\", \"24h\", \"1d\".\nFor duration longer than a day, only multiple of days is supported. We\nsupport only \"100s\" and \"1d\" for now. Additional support will be added in\nthe future. \"0\" indicates indefinite duration.\n\nUsed by group-based quotas only."},"freeTier":{"description":"Free tier value displayed in the Developers Console for this limit.\nThe free tier is the number of tokens that will be subtracted from the\nbilled amount when billing is enabled.\nThis field can only be set on a limit with duration \"1d\", in a billable\ngroup; it is invalid on any other limit. If this field is not set, it\ndefaults to 0, indicating that there is no free tier for this service.\n\nUsed by group-based quotas only.","format":"int64","type":"string"},"defaultLimit":{"description":"Default number of tokens that can be consumed during the specified\nduration. This is the number of tokens assigned when a client\napplication developer activates the service for his/her project.\n\nSpecifying a value of 0 will block all requests. This can be used if you\nare provisioning quota to selected consumers and blocking others.\nSimilarly, a value of -1 will indicate an unlimited quota. No other\nnegative values are allowed.\n\nUsed by group-based quotas only.","format":"int64","type":"string"},"description":{"description":"Optional. User-visible, extended description for this quota limit.\nShould be used only when more context is needed to understand this limit\nthan provided by the limit's display name (see: `display_name`).","type":"string"},"displayName":{"description":"User-visible display name for this limit.\nOptional. If not set, the UI will provide a default display name based on\nthe quota configuration. This field can be used to override the default\ndisplay name generated from the configuration.","type":"string"},"metric":{"description":"The name of the metric this quota limit applies to. The quota limits with\nthe same metric will be checked together during runtime. The metric must be\ndefined within the service config.","type":"string"},"values":{"type":"object","additionalProperties":{"type":"string","format":"int64"},"description":"Tiered limit values. You must specify this as a key:value pair, with an\ninteger value that is the maximum number of requests allowed for the\nspecified unit. Currently only STANDARD is supported."},"unit":{"description":"Specify the unit of the quota limit. It uses the same syntax as\nMetric.unit. The supported unit kinds are determined by the quota\nbackend system.\n\nHere are some examples:\n* \"1/min/{project}\" for quota per minute per project.\n\nNote: the order of unit components is insignificant.\nThe \"1\" at the beginning is required to follow the metric unit syntax.","type":"string"},"maxLimit":{"description":"Maximum number of tokens that can be consumed during the specified\nduration. Client application developers can override the default limit up\nto this maximum. If specified, this value cannot be set to a value less\nthan the default limit. If not specified, it is set to the default limit.\n\nTo allow clients to apply overrides with no upper bound, set this to -1,\nindicating unlimited maximum quota.\n\nUsed by group-based quotas only.","format":"int64","type":"string"}},"id":"QuotaLimit"},"ConfigRef":{"description":"Represents a service configuration with its name and id.","type":"object","properties":{"name":{"description":"Resource name of a service config. It must have the following\nformat: \"services/{service name}/configs/{config id}\".","type":"string"}},"id":"ConfigRef"},"ListServiceRolloutsResponse":{"description":"Response message for ListServiceRollouts method.","type":"object","properties":{"nextPageToken":{"type":"string","description":"The token of the next page of results."},"rollouts":{"description":"The list of rollout resources.","type":"array","items":{"$ref":"Rollout"}}},"id":"ListServiceRolloutsResponse"},"Mixin":{"description":"Declares an API Interface to be included in this interface. The including\ninterface must redeclare all the methods from the included interface, but\ndocumentation and options are inherited as follows:\n\n- If after comment and whitespace stripping, the documentation\n  string of the redeclared method is empty, it will be inherited\n  from the original method.\n\n- Each annotation belonging to the service config (http,\n  visibility) which is not set in the redeclared method will be\n  inherited.\n\n- If an http annotation is inherited, the path pattern will be\n  modified as follows. Any version prefix will be replaced by the\n  version of the including interface plus the root path if\n  specified.\n\nExample of a simple mixin:\n\n    package google.acl.v1;\n    service AccessControl {\n      // Get the underlying ACL object.\n      rpc GetAcl(GetAclRequest) returns (Acl) {\n        option (google.api.http).get = \"/v1/{resource=**}:getAcl\";\n      }\n    }\n\n    package google.storage.v2;\n    service Storage {\n      //       rpc GetAcl(GetAclRequest) returns (Acl);\n\n      // Get a data record.\n      rpc GetData(GetDataRequest) returns (Data) {\n        option (google.api.http).get = \"/v2/{resource=**}\";\n      }\n    }\n\nExample of a mixin configuration:\n\n    apis:\n    - name: google.storage.v2.Storage\n      mixins:\n      - name: google.acl.v1.AccessControl\n\nThe mixin construct implies that all methods in `AccessControl` are\nalso declared with same name and request/response types in\n`Storage`. A documentation generator or annotation processor will\nsee the effective `Storage.GetAcl` method after inherting\ndocumentation and annotations as follows:\n\n    service Storage {\n      // Get the underlying ACL object.\n      rpc GetAcl(GetAclRequest) returns (Acl) {\n        option (google.api.http).get = \"/v2/{resource=**}:getAcl\";\n      }\n      ...\n    }\n\nNote how the version in the path pattern changed from `v1` to `v2`.\n\nIf the `root` field in the mixin is specified, it should be a\nrelative path under which inherited HTTP paths are placed. Example:\n\n    apis:\n    - name: google.storage.v2.Storage\n      mixins:\n      - name: google.acl.v1.AccessControl\n        root: acls\n\nThis implies the following inherited HTTP annotation:\n\n    service Storage {\n      // Get the underlying ACL object.\n      rpc GetAcl(GetAclRequest) returns (Acl) {\n        option (google.api.http).get = \"/v2/acls/{resource=**}:getAcl\";\n      }\n      ...\n    }","type":"object","properties":{"name":{"description":"The fully qualified name of the interface which is included.","type":"string"},"root":{"type":"string","description":"If non-empty specifies a path under which inherited HTTP paths\nare rooted."}},"id":"Mixin"},"CustomError":{"type":"object","properties":{"rules":{"description":"The list of custom error rules that apply to individual API messages.\n\n**NOTE:** All service configuration rules follow \"last one wins\" order.","type":"array","items":{"$ref":"CustomErrorRule"}},"types":{"description":"The list of custom error detail types, e.g. 'google.foo.v1.CustomError'.","type":"array","items":{"type":"string"}}},"id":"CustomError","description":"Customize service error responses.  For example, list any service\nspecific protobuf types that can appear in error detail lists of\nerror responses.\n\nExample:\n\n    custom_error:\n      types:\n      - google.foo.v1.CustomError\n      - google.foo.v1.AnotherError"},"Http":{"description":"Defines the HTTP configuration for an API service. It contains a list of\nHttpRule, each specifying the mapping of an RPC method\nto one or more HTTP REST API methods.","type":"object","properties":{"fullyDecodeReservedExpansion":{"description":"When set to true, URL path parameters will be fully URI-decoded except in\ncases of single segment matches in reserved expansion, where \"%2F\" will be\nleft encoded.\n\nThe default behavior is to not decode RFC 6570 reserved characters in multi\nsegment matches.","type":"boolean"},"rules":{"description":"A list of HTTP configuration rules that apply to individual API methods.\n\n**NOTE:** All service configuration rules follow \"last one wins\" order.","type":"array","items":{"$ref":"HttpRule"}}},"id":"Http"},"SourceInfo":{"id":"SourceInfo","description":"Source information used to create a Service Config","type":"object","properties":{"sourceFiles":{"type":"array","items":{"type":"object","additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"}},"description":"All files used during config generation."}}},"Control":{"id":"Control","description":"Selects and configures the service controller used by the service.  The\nservice controller handles features like abuse, quota, billing, logging,\nmonitoring, etc.","type":"object","properties":{"environment":{"description":"The service control environment to use. If empty, no control plane\nfeature (like quota and billing) will be enabled.","type":"string"}}},"SystemParameter":{"type":"object","properties":{"urlQueryParameter":{"description":"Define the URL query parameter name to use for the parameter. It is case\nsensitive.","type":"string"},"httpHeader":{"type":"string","description":"Define the HTTP header name to use for the parameter. It is case\ninsensitive."},"name":{"type":"string","description":"Define the name of the parameter, such as \"api_key\" . It is case sensitive."}},"id":"SystemParameter","description":"Define a parameter's name and location. The parameter may be passed as either\nan HTTP header or a URL query parameter, and if both are passed the behavior\nis implementation-dependent."},"Monitoring":{"description":"Monitoring configuration of the service.\n\nThe example below shows how to configure monitored resources and metrics\nfor monitoring. In the example, a monitored resource and two metrics are\ndefined. The `library.googleapis.com/book/returned_count` metric is sent\nto both producer and consumer projects, whereas the\n`library.googleapis.com/book/overdue_count` metric is only sent to the\nconsumer project.\n\n    monitored_resources:\n    - type: library.googleapis.com/branch\n      labels:\n      - key: /city\n        description: The city where the library branch is located in.\n      - key: /name\n        description: The name of the branch.\n    metrics:\n    - name: library.googleapis.com/book/returned_count\n      metric_kind: DELTA\n      value_type: INT64\n      labels:\n      - key: /customer_id\n    - name: library.googleapis.com/book/overdue_count\n      metric_kind: GAUGE\n      value_type: INT64\n      labels:\n      - key: /customer_id\n    monitoring:\n      producer_destinations:\n      - monitored_resource: library.googleapis.com/branch\n        metrics:\n        - library.googleapis.com/book/returned_count\n      consumer_destinations:\n      - monitored_resource: library.googleapis.com/branch\n        metrics:\n        - library.googleapis.com/book/returned_count\n        - library.googleapis.com/book/overdue_count","type":"object","properties":{"consumerDestinations":{"description":"Monitoring configurations for sending metrics to the consumer project.\nThere can be multiple consumer destinations. A monitored resouce type may\nappear in multiple monitoring destinations if different aggregations are\nneeded for different sets of metrics associated with that monitored\nresource type. A monitored resource and metric pair may only be used once\nin the Monitoring configuration.","type":"array","items":{"$ref":"MonitoringDestination"}},"producerDestinations":{"type":"array","items":{"$ref":"MonitoringDestination"},"description":"Monitoring configurations for sending metrics to the producer project.\nThere can be multiple producer destinations. A monitored resouce type may\nappear in multiple monitoring destinations if different aggregations are\nneeded for different sets of metrics associated with that monitored\nresource type. A monitored resource and metric pair may only be used once\nin the Monitoring configuration."}},"id":"Monitoring"},"Field":{"description":"A single field of a message type.","type":"object","properties":{"kind":{"type":"string","enumDescriptions":["Field type unknown.","Field type double.","Field type float.","Field type int64.","Field type uint64.","Field type int32.","Field type fixed64.","Field type fixed32.","Field type bool.","Field type string.","Field type group. Proto2 syntax only, and deprecated.","Field type message.","Field type bytes.","Field type uint32.","Field type enum.","Field type sfixed32.","Field type sfixed64.","Field type sint32.","Field type sint64."],"enum":["TYPE_UNKNOWN","TYPE_DOUBLE","TYPE_FLOAT","TYPE_INT64","TYPE_UINT64","TYPE_INT32","TYPE_FIXED64","TYPE_FIXED32","TYPE_BOOL","TYPE_STRING","TYPE_GROUP","TYPE_MESSAGE","TYPE_BYTES","TYPE_UINT32","TYPE_ENUM","TYPE_SFIXED32","TYPE_SFIXED64","TYPE_SINT32","TYPE_SINT64"],"description":"The field type."},"jsonName":{"description":"The field JSON name.","type":"string"},"options":{"description":"The protocol buffer options.","type":"array","items":{"$ref":"Option"}},"oneofIndex":{"description":"The index of the field type in `Type.oneofs`, for message or enumeration\ntypes. The first type has index 1; zero means the type is not in the list.","format":"int32","type":"integer"},"packed":{"description":"Whether to use alternative packed wire representation.","type":"boolean"},"cardinality":{"description":"The field cardinality.","type":"string","enumDescriptions":["For fields with unknown cardinality.","For optional fields.","For required fields. Proto2 syntax only.","For repeated fields."],"enum":["CARDINALITY_UNKNOWN","CARDINALITY_OPTIONAL","CARDINALITY_REQUIRED","CARDINALITY_REPEATED"]},"defaultValue":{"type":"string","description":"The string value of the default value of this field. Proto2 syntax only."},"name":{"description":"The field name.","type":"string"},"typeUrl":{"description":"The field type URL, without the scheme, for message or enumeration\ntypes. Example: `\"type.googleapis.com/google.protobuf.Timestamp\"`.","type":"string"},"number":{"description":"The field number.","format":"int32","type":"integer"}},"id":"Field"},"TestIamPermissionsRequest":{"description":"Request message for `TestIamPermissions` method.","type":"object","properties":{"permissions":{"description":"The set of permissions to check for the `resource`. Permissions with\nwildcards (such as '*' or 'storage.*') are not allowed. For more\ninformation see\n[IAM Overview](https://cloud.google.com/iam/docs/overview#permissions).","type":"array","items":{"type":"string"}}},"id":"TestIamPermissionsRequest"},"Enum":{"description":"Enum type definition.","type":"object","properties":{"options":{"description":"Protocol buffer options.","type":"array","items":{"$ref":"Option"}},"sourceContext":{"$ref":"SourceContext","description":"The source context."},"syntax":{"description":"The source syntax.","type":"string","enumDescriptions":["Syntax `proto2`.","Syntax `proto3`."],"enum":["SYNTAX_PROTO2","SYNTAX_PROTO3"]},"name":{"description":"Enum type name.","type":"string"},"enumvalue":{"description":"Enum value definitions.","type":"array","items":{"$ref":"EnumValue"}}},"id":"Enum"},"EnableServiceRequest":{"description":"Request message for EnableService method.","type":"object","properties":{"consumerId":{"description":"The identity of consumer resource which service enablement will be\napplied to.\n\nThe Google Service Management implementation accepts the following\nforms:\n- \"project:<project_id>\"\n\nNote: this is made compatible with\ngoogle.api.servicecontrol.v1.Operation.consumer_id.","type":"string"}},"id":"EnableServiceRequest"},"Diagnostic":{"id":"Diagnostic","description":"Represents a diagnostic message (error or warning)","type":"object","properties":{"message":{"description":"Message describing the error or warning.","type":"string"},"location":{"description":"File name and line number of the error or warning.","type":"string"},"kind":{"description":"The kind of diagnostic information provided.","type":"string","enumDescriptions":["Warnings and errors","Only errors"],"enum":["WARNING","ERROR"]}}},"LabelDescriptor":{"id":"LabelDescriptor","description":"A description of a label.","type":"object","properties":{"key":{"description":"The label key.","type":"string"},"description":{"description":"A human-readable description for the label.","type":"string"},"valueType":{"enumDescriptions":["A variable-length string. This is the default.","Boolean; true or false.","A 64-bit signed integer."],"enum":["STRING","BOOL","INT64"],"description":"The type of data that can be assigned to the label.","type":"string"}}},"GenerateConfigReportResponse":{"id":"GenerateConfigReportResponse","description":"Response message for GenerateConfigReport method.","type":"object","properties":{"id":{"description":"ID of the service configuration this report belongs to.","type":"string"},"diagnostics":{"description":"Errors / Linter warnings associated with the service definition this\nreport\nbelongs to.","type":"array","items":{"$ref":"Diagnostic"}},"serviceName":{"description":"Name of the service this report belongs to.","type":"string"},"changeReports":{"description":"list of ChangeReport, each corresponding to comparison between two\nservice configurations.","type":"array","items":{"$ref":"ChangeReport"}}}},"Type":{"type":"object","properties":{"options":{"description":"The protocol buffer options.","type":"array","items":{"$ref":"Option"}},"fields":{"description":"The list of fields.","type":"array","items":{"$ref":"Field"}},"name":{"type":"string","description":"The fully qualified message name."},"oneofs":{"description":"The list of types appearing in `oneof` definitions in this type.","type":"array","items":{"type":"string"}},"syntax":{"description":"The source syntax.","type":"string","enumDescriptions":["Syntax `proto2`.","Syntax `proto3`."],"enum":["SYNTAX_PROTO2","SYNTAX_PROTO3"]},"sourceContext":{"$ref":"SourceContext","description":"The source context."}},"id":"Type","description":"A protocol buffer message type."},"ListServiceConfigsResponse":{"id":"ListServiceConfigsResponse","description":"Response message for ListServiceConfigs method.","type":"object","properties":{"nextPageToken":{"description":"The token of the next page of results.","type":"string"},"serviceConfigs":{"type":"array","items":{"$ref":"Service"},"description":"The list of service configuration resources."}}},"AuditConfig":{"description":"Specifies the audit configuration for a service.\nThe configuration determines which permission types are logged, and what\nidentities, if any, are exempted from logging.\nAn AuditConfig must have one or more AuditLogConfigs.\n\nIf there are AuditConfigs for both `allServices` and a specific service,\nthe union of the two AuditConfigs is used for that service: the log_types\nspecified in each AuditConfig are enabled, and the exempted_members in each\nAuditLogConfig are exempted.\n\nExample Policy with multiple AuditConfigs:\n\n    {\n      \"audit_configs\": [\n        {\n          \"service\": \"allServices\"\n          \"audit_log_configs\": [\n            {\n              \"log_type\": \"DATA_READ\",\n              \"exempted_members\": [\n                \"user:foo@gmail.com\"\n              ]\n            },\n            {\n              \"log_type\": \"DATA_WRITE\",\n            },\n            {\n              \"log_type\": \"ADMIN_READ\",\n            }\n          ]\n        },\n        {\n          \"service\": \"fooservice.googleapis.com\"\n          \"audit_log_configs\": [\n            {\n              \"log_type\": \"DATA_READ\",\n            },\n            {\n              \"log_type\": \"DATA_WRITE\",\n              \"exempted_members\": [\n                \"user:bar@gmail.com\"\n              ]\n            }\n          ]\n        }\n      ]\n    }\n\nFor fooservice, this policy enables DATA_READ, DATA_WRITE and ADMIN_READ\nlogging. It also exempts foo@gmail.com from DATA_READ logging, and\nbar@gmail.com from DATA_WRITE logging.","type":"object","properties":{"service":{"type":"string","description":"Specifies a service that will be enabled for audit logging.\nFor example, `storage.googleapis.com`, `cloudsql.googleapis.com`.\n`allServices` is a special value that covers all services."},"auditLogConfigs":{"type":"array","items":{"$ref":"AuditLogConfig"},"description":"The configuration for logging of each type of permission."}},"id":"AuditConfig"},"Backend":{"description":"`Backend` defines the backend configuration for a service.","type":"object","properties":{"rules":{"description":"A list of API backend rules that apply to individual API methods.\n\n**NOTE:** All service configuration rules follow \"last one wins\" order.","type":"array","items":{"$ref":"BackendRule"}}},"id":"Backend"},"SubmitConfigSourceRequest":{"type":"object","properties":{"configSource":{"$ref":"ConfigSource","description":"The source configuration for the service."},"validateOnly":{"description":"Optional. If set, this will result in the generation of a\n`google.api.Service` configuration based on the `ConfigSource` provided,\nbut the generated config and the sources will NOT be persisted.","type":"boolean"}},"id":"SubmitConfigSourceRequest","description":"Request message for SubmitConfigSource method."},"DocumentationRule":{"type":"object","properties":{"deprecationDescription":{"description":"Deprecation description of the selected element(s). It can be provided if\nan element is marked as `deprecated`.","type":"string"},"selector":{"description":"The selector is a comma-separated list of patterns. Each pattern is a\nqualified name of the element which may end in \"*\", indicating a wildcard.\nWildcards are only allowed at the end and for a whole component of the\nqualified name, i.e. \"foo.*\" is ok, but not \"foo.b*\" or \"foo.*.bar\". A\nwildcard will match one or more components. To specify a default for all\napplicable elements, the whole pattern \"*\" is used.","type":"string"},"description":{"description":"Description of the selected API(s).","type":"string"}},"id":"DocumentationRule","description":"A documentation rule provides information about individual API elements."},"ContextRule":{"type":"object","properties":{"requested":{"description":"A list of full type names of requested contexts.","type":"array","items":{"type":"string"}},"allowedRequestExtensions":{"type":"array","items":{"type":"string"},"description":"A list of full type names or extension IDs of extensions allowed in grpc\nside channel from client to backend."},"allowedResponseExtensions":{"type":"array","items":{"type":"string"},"description":"A list of full type names or extension IDs of extensions allowed in grpc\nside channel from backend to client."},"selector":{"description":"Selects the methods to which this rule applies.\n\nRefer to selector for syntax details.","type":"string"},"provided":{"description":"A list of full type names of provided contexts.","type":"array","items":{"type":"string"}}},"id":"ContextRule","description":"A context rule provides information about the context for an individual API\nelement."},"Billing":{"description":"Billing related configuration of the service.\n\nThe following example shows how to configure monitored resources and metrics\nfor billing:\n\n    monitored_resources:\n    - type: library.googleapis.com/branch\n      labels:\n      - key: /city\n        description: The city where the library branch is located in.\n      - key: /name\n        description: The name of the branch.\n    metrics:\n    - name: library.googleapis.com/book/borrowed_count\n      metric_kind: DELTA\n      value_type: INT64\n    billing:\n      consumer_destinations:\n      - monitored_resource: library.googleapis.com/branch\n        metrics:\n        - library.googleapis.com/book/borrowed_count","type":"object","properties":{"consumerDestinations":{"description":"Billing configurations for sending metrics to the consumer project.\nThere can be multiple consumer destinations per service, each one must have\na different monitored resource type. A metric can be used in at most\none consumer destination.","type":"array","items":{"$ref":"BillingDestination"}}},"id":"Billing"},"MetricDescriptor":{"id":"MetricDescriptor","description":"Defines a metric type and its schema. Once a metric descriptor is created,\ndeleting or altering it stops data collection and makes the metric type's\nexisting data unusable.","type":"object","properties":{"unit":{"description":"The unit in which the metric value is reported. It is only applicable\nif the `value_type` is `INT64`, `DOUBLE`, or `DISTRIBUTION`. The\nsupported units are a subset of [The Unified Code for Units of\nMeasure](http://unitsofmeasure.org/ucum.html) standard:\n\n**Basic units (UNIT)**\n\n* `bit`   bit\n* `By`    byte\n* `s`     second\n* `min`   minute\n* `h`     hour\n* `d`     day\n\n**Prefixes (PREFIX)**\n\n* `k`     kilo    (10**3)\n* `M`     mega    (10**6)\n* `G`     giga    (10**9)\n* `T`     tera    (10**12)\n* `P`     peta    (10**15)\n* `E`     exa     (10**18)\n* `Z`     zetta   (10**21)\n* `Y`     yotta   (10**24)\n* `m`     milli   (10**-3)\n* `u`     micro   (10**-6)\n* `n`     nano    (10**-9)\n* `p`     pico    (10**-12)\n* `f`     femto   (10**-15)\n* `a`     atto    (10**-18)\n* `z`     zepto   (10**-21)\n* `y`     yocto   (10**-24)\n* `Ki`    kibi    (2**10)\n* `Mi`    mebi    (2**20)\n* `Gi`    gibi    (2**30)\n* `Ti`    tebi    (2**40)\n\n**Grammar**\n\nThe grammar also includes these connectors:\n\n* `/`    division (as an infix operator, e.g. `1/s`).\n* `.`    multiplication (as an infix operator, e.g. `GBy.d`)\n\nThe grammar for a unit is as follows:\n\n    Expression = Component { \".\" Component } { \"/\" Component } ;\n\n    Component = ( [ PREFIX ] UNIT | \"%\" ) [ Annotation ]\n              | Annotation\n              | \"1\"\n              ;\n\n    Annotation = \"{\" NAME \"}\" ;\n\nNotes:\n\n* `Annotation` is just a comment if it follows a `UNIT` and is\n   equivalent to `1` if it is used alone. For examples,\n   `{requests}/s == 1/s`, `By{transmitted}/s == By/s`.\n* `NAME` is a sequence of non-blank printable ASCII characters not\n   containing '{' or '}'.\n* `1` represents dimensionless value 1, such as in `1/s`.\n* `%` represents dimensionless value 1/100, and annotates values giving\n   a percentage.","type":"string"},"labels":{"description":"The set of labels that can be used to describe a specific\ninstance of this metric type. For example, the\n`appengine.googleapis.com/http/server/response_latencies` metric\ntype has a label for the HTTP response code, `response_code`, so\nyou can look at latencies for successful responses or just\nfor responses that failed.","type":"array","items":{"$ref":"LabelDescriptor"}},"launchStage":{"enum":["LAUNCH_STAGE_UNSPECIFIED","EARLY_ACCESS","ALPHA","BETA","GA","DEPRECATED"],"description":"Optional. The launch stage of the metric definition.","type":"string","enumDescriptions":["Do not use this default value.","Early Access features are limited to a closed group of testers. To use\nthese features, you must sign up in advance and sign a Trusted Tester\nagreement (which includes confidentiality provisions). These features may\nbe unstable, changed in backward-incompatible ways, and are not\nguaranteed to be released.","Alpha is a limited availability test for releases before they are cleared\nfor widespread use. By Alpha, all significant design issues are resolved\nand we are in the process of verifying functionality. Alpha customers\nneed to apply for access, agree to applicable terms, and have their\nprojects whitelisted. Alpha releases don’t have to be feature complete,\nno SLAs are provided, and there are no technical support obligations, but\nthey will be far enough along that customers can actually use them in\ntest environments or for limited-use tests -- just like they would in\nnormal production cases.","Beta is the point at which we are ready to open a release for any\ncustomer to use. There are no SLA or technical support obligations in a\nBeta release. Products will be complete from a feature perspective, but\nmay have some open outstanding issues. Beta releases are suitable for\nlimited production use cases.","GA features are open to all developers and are considered stable and\nfully qualified for production use.","Deprecated features are scheduled to be shut down and removed. For more\ninformation, see the “Deprecation Policy” section of our [Terms of\nService](https://cloud.google.com/terms/)\nand the [Google Cloud Platform Subject to the Deprecation\nPolicy](https://cloud.google.com/terms/deprecation) documentation."]},"name":{"description":"The resource name of the metric descriptor.","type":"string"},"metadata":{"$ref":"MetricDescriptorMetadata","description":"Optional. Metadata which can be used to guide usage of the metric."},"type":{"type":"string","description":"The metric type, including its DNS name prefix. The type is not\nURL-encoded.  All user-defined metric types have the DNS name\n`custom.googleapis.com` or `external.googleapis.com`.  Metric types should\nuse a natural hierarchical grouping. For example:\n\n    \"custom.googleapis.com/invoice/paid/amount\"\n    \"external.googleapis.com/prometheus/up\"\n    \"appengine.googleapis.com/http/server/response_latencies\""},"valueType":{"description":"Whether the measurement is an integer, a floating-point number, etc.\nSome combinations of `metric_kind` and `value_type` might not be supported.","type":"string","enumDescriptions":["Do not use this default value.","The value is a boolean.\nThis value type can be used only if the metric kind is `GAUGE`.","The value is a signed 64-bit integer.","The value is a double precision floating point number.","The value is a text string.\nThis value type can be used only if the metric kind is `GAUGE`.","The value is a `Distribution`.","The value is money."],"enum":["VALUE_TYPE_UNSPECIFIED","BOOL","INT64","DOUBLE","STRING","DISTRIBUTION","MONEY"]},"metricKind":{"enum":["METRIC_KIND_UNSPECIFIED","GAUGE","DELTA","CUMULATIVE"],"description":"Whether the metric records instantaneous values, changes to a value, etc.\nSome combinations of `metric_kind` and `value_type` might not be supported.","type":"string","enumDescriptions":["Do not use this default value.","An instantaneous measurement of a value.","The change in a value during a time interval.","A value accumulated over a time interval.  Cumulative\nmeasurements in a time series should have the same start time\nand increasing end times, until an event resets the cumulative\nvalue to zero and sets a new start time for the following\npoints."]},"description":{"description":"A detailed description of the metric, which can be used in documentation.","type":"string"},"displayName":{"description":"A concise name for the metric, which can be displayed in user interfaces.\nUse sentence case without an ending period, for example \"Request count\".\nThis field is optional but it is recommended to be set for any metrics\nassociated with user-visible concepts, such as Quota.","type":"string"}}},"SourceContext":{"type":"object","properties":{"fileName":{"description":"The path-qualified name of the .proto file that contained the associated\nprotobuf element.  For example: `\"google/protobuf/source_context.proto\"`.","type":"string"}},"id":"SourceContext","description":"`SourceContext` represents information about the source of a\nprotobuf element, like the file in which it is defined."},"Expr":{"id":"Expr","description":"Represents an expression text. Example:\n\n    title: \"User account presence\"\n    description: \"Determines whether the request has a user account\"\n    expression: \"size(request.user) > 0\"","type":"object","properties":{"description":{"type":"string","description":"An optional description of the expression. This is a longer text which\ndescribes the expression, e.g. when hovered over it in a UI."},"expression":{"description":"Textual representation of an expression in\nCommon Expression Language syntax.\n\nThe application context of the containing message determines which\nwell-known feature set of CEL is supported.","type":"string"},"title":{"type":"string","description":"An optional title for the expression, i.e. a short string describing\nits purpose. This can be used e.g. in UIs which allow to enter the\nexpression."},"location":{"description":"An optional string indicating the location of the expression for error\nreporting, e.g. a file name and a position in the file.","type":"string"}}},"ListServicesResponse":{"description":"Response message for `ListServices` method.","type":"object","properties":{"services":{"description":"The returned services will only have the name field set.","type":"array","items":{"$ref":"ManagedService"}},"nextPageToken":{"description":"Token that can be passed to `ListServices` to resume a paginated query.","type":"string"}},"id":"ListServicesResponse"},"Endpoint":{"type":"object","properties":{"name":{"description":"The canonical name of this endpoint.","type":"string"},"target":{"description":"The specification of an Internet routable address of API frontend that will\nhandle requests to this [API\nEndpoint](https://cloud.google.com/apis/design/glossary). It should be\neither a valid IPv4 address or a fully-qualified domain name. For example,\n\"8.8.8.8\" or \"myservice.appspot.com\".","type":"string"},"aliases":{"description":"DEPRECATED: This field is no longer supported. Instead of using aliases,\nplease specify multiple google.api.Endpoint for each of the intended\naliases.\n\nAdditional names that this endpoint will be hosted on.","type":"array","items":{"type":"string"}},"features":{"description":"The list of features enabled on this endpoint.","type":"array","items":{"type":"string"}},"allowCors":{"type":"boolean","description":"Allowing\n[CORS](https://en.wikipedia.org/wiki/Cross-origin_resource_sharing), aka\ncross-domain traffic, would allow the backends served from this endpoint to\nreceive and respond to HTTP OPTIONS requests. The response will be used by\nthe browser to determine whether the subsequent cross-origin request is\nallowed to proceed."}},"id":"Endpoint","description":"`Endpoint` describes a network endpoint that serves a set of APIs.\nA service may expose any number of endpoints, and all endpoints share the\nsame service configuration, such as quota configuration and monitoring\nconfiguration.\n\nExample service configuration:\n\n    name: library-example.googleapis.com\n    endpoints:\n      # Below entry makes 'google.example.library.v1.Library'\n      # API be served from endpoint address library-example.googleapis.com.\n      # It also allows HTTP OPTIONS calls to be passed to the backend, for\n      # it to decide whether the subsequent cross-origin request is\n      # allowed to proceed.\n    - name: library-example.googleapis.com\n      allow_cors: true"},"OAuthRequirements":{"description":"OAuth scopes are a way to define data and permissions on data. For example,\nthere are scopes defined for \"Read-only access to Google Calendar\" and\n\"Access to Cloud Platform\". Users can consent to a scope for an application,\ngiving it permission to access that data on their behalf.\n\nOAuth scope specifications should be fairly coarse grained; a user will need\nto see and understand the text description of what your scope means.\n\nIn most cases: use one or at most two OAuth scopes for an entire family of\nproducts. If your product has multiple APIs, you should probably be sharing\nthe OAuth scope across all of those APIs.\n\nWhen you need finer grained OAuth consent screens: talk with your product\nmanagement about how developers will use them in practice.\n\nPlease note that even though each of the canonical scopes is enough for a\nrequest to be accepted and passed to the backend, a request can still fail\ndue to the backend requiring additional scopes or permissions.","type":"object","properties":{"canonicalScopes":{"description":"The list of publicly documented OAuth scopes that are allowed access. An\nOAuth token containing any of these scopes will be accepted.\n\nExample:\n\n     canonical_scopes: https://www.googleapis.com/auth/calendar,\n                       https://www.googleapis.com/auth/calendar.read","type":"string"}},"id":"OAuthRequirements"},"Usage":{"id":"Usage","description":"Configuration controlling usage of a service.","type":"object","properties":{"producerNotificationChannel":{"type":"string","description":"The full resource name of a channel used for sending notifications to the\nservice producer.\n\nGoogle Service Management currently only supports\n[Google Cloud Pub/Sub](https://cloud.google.com/pubsub) as a notification\nchannel. To use Google Cloud Pub/Sub as the channel, this must be the name\nof a Cloud Pub/Sub topic that uses the Cloud Pub/Sub topic name format\ndocumented in https://cloud.google.com/pubsub/docs/overview."},"rules":{"description":"A list of usage rules that apply to individual API methods.\n\n**NOTE:** All service configuration rules follow \"last one wins\" order.","type":"array","items":{"$ref":"UsageRule"}},"requirements":{"type":"array","items":{"type":"string"},"description":"Requirements that must be satisfied before a consumer project can use the\nservice. Each requirement is of the form <service.name>/<requirement-id>;\nfor example 'serviceusage.googleapis.com/billing-enabled'."}}},"GetIamPolicyRequest":{"description":"Request message for `GetIamPolicy` method.","type":"object","properties":{},"id":"GetIamPolicyRequest"},"TestIamPermissionsResponse":{"id":"TestIamPermissionsResponse","description":"Response message for `TestIamPermissions` method.","type":"object","properties":{"permissions":{"description":"A subset of `TestPermissionsRequest.permissions` that the caller is\nallowed.","type":"array","items":{"type":"string"}}}},"Context":{"id":"Context","description":"`Context` defines which contexts an API requests.\n\nExample:\n\n    context:\n      rules:\n      - selector: \"*\"\n        requested:\n        - google.rpc.context.ProjectContext\n        - google.rpc.context.OriginContext\n\nThe above specifies that all methods in the API request\n`google.rpc.context.ProjectContext` and\n`google.rpc.context.OriginContext`.\n\nAvailable context types are defined in package\n`google.rpc.context`.\n\nThis also provides mechanism to whitelist any protobuf message extension that\ncan be sent in grpc metadata using “x-goog-ext-<extension_id>-bin” and\n“x-goog-ext-<extension_id>-jspb” format. For example, list any service\nspecific protobuf types that can appear in grpc metadata as follows in your\nyaml file:\n\nExample:\n\n    context:\n      rules:\n       - selector: \"google.example.library.v1.LibraryService.CreateBook\"\n         allowed_request_extensions:\n         - google.foo.v1.NewExtension\n         allowed_response_extensions:\n         - google.foo.v1.NewExtension\n\nYou can also specify extension ID instead of fully qualified extension name\nhere.","type":"object","properties":{"rules":{"description":"A list of RPC context rules that apply to individual API methods.\n\n**NOTE:** All service configuration rules follow \"last one wins\" order.","type":"array","items":{"$ref":"ContextRule"}}}},"LogDescriptor":{"type":"object","properties":{"name":{"description":"The name of the log. It must be less than 512 characters long and can\ninclude the following characters: upper- and lower-case alphanumeric\ncharacters [A-Za-z0-9], and punctuation characters including\nslash, underscore, hyphen, period [/_-.].","type":"string"},"description":{"type":"string","description":"A human-readable description of this log. This information appears in\nthe documentation and can contain details."},"displayName":{"type":"string","description":"The human-readable name for this log. This information appears on\nthe user interface and should be concise."},"labels":{"type":"array","items":{"$ref":"LabelDescriptor"},"description":"The set of labels that are available to describe a specific log entry.\nRuntime requests that contain labels not specified here are\nconsidered invalid."}},"id":"LogDescriptor","description":"A description of a log type. Example in YAML format:\n\n    - name: library.googleapis.com/activity_history\n      description: The history of borrowing and returning library items.\n      display_name: Activity\n      labels:\n      - key: /customer_id\n        description: Identifier of a library customer"},"ConfigFile":{"description":"Generic specification of a source configuration file","type":"object","properties":{"filePath":{"type":"string","description":"The file name of the configuration file (full or relative path)."},"fileType":{"enum":["FILE_TYPE_UNSPECIFIED","SERVICE_CONFIG_YAML","OPEN_API_JSON","OPEN_API_YAML","FILE_DESCRIPTOR_SET_PROTO","PROTO_FILE"],"description":"The type of configuration file this represents.","type":"string","enumDescriptions":["Unknown file type.","YAML-specification of service.","OpenAPI specification, serialized in JSON.","OpenAPI specification, serialized in YAML.","FileDescriptorSet, generated by protoc.\n\nTo generate, use protoc with imports and source info included.\nFor an example test.proto file, the following command would put the value\nin a new file named out.pb.\n\n$protoc --include_imports --include_source_info test.proto -o out.pb","Uncompiled Proto file. Used for storage and display purposes only,\ncurrently server-side compilation is not supported. Should match the\ninputs to 'protoc' command used to generated FILE_DESCRIPTOR_SET_PROTO. A\nfile of this type can only be included if at least one file of type\nFILE_DESCRIPTOR_SET_PROTO is included."]},"fileContents":{"description":"The bytes that constitute the file.","format":"byte","type":"string"}},"id":"ConfigFile"},"MonitoredResourceDescriptor":{"type":"object","properties":{"name":{"type":"string","description":"Optional. The resource name of the monitored resource descriptor:\n`\"projects/{project_id}/monitoredResourceDescriptors/{type}\"` where\n{type} is the value of the `type` field in this object and\n{project_id} is a project ID that provides API-specific context for\naccessing the type.  APIs that do not use project information can use the\nresource name format `\"monitoredResourceDescriptors/{type}\"`."},"type":{"description":"Required. The monitored resource type. For example, the type\n`\"cloudsql_database\"` represents databases in Google Cloud SQL.\nThe maximum length of this value is 256 characters.","type":"string"},"description":{"description":"Optional. A detailed description of the monitored resource type that might\nbe used in documentation.","type":"string"},"displayName":{"type":"string","description":"Optional. A concise name for the monitored resource type that might be\ndisplayed in user interfaces. It should be a Title Cased Noun Phrase,\nwithout any article or other determiners. For example,\n`\"Google Cloud SQL Database\"`."},"launchStage":{"type":"string","enumDescriptions":["Do not use this default value.","Early Access features are limited to a closed group of testers. To use\nthese features, you must sign up in advance and sign a Trusted Tester\nagreement (which includes confidentiality provisions). These features may\nbe unstable, changed in backward-incompatible ways, and are not\nguaranteed to be released.","Alpha is a limited availability test for releases before they are cleared\nfor widespread use. By Alpha, all significant design issues are resolved\nand we are in the process of verifying functionality. Alpha customers\nneed to apply for access, agree to applicable terms, and have their\nprojects whitelisted. Alpha releases don’t have to be feature complete,\nno SLAs are provided, and there are no technical support obligations, but\nthey will be far enough along that customers can actually use them in\ntest environments or for limited-use tests -- just like they would in\nnormal production cases.","Beta is the point at which we are ready to open a release for any\ncustomer to use. There are no SLA or technical support obligations in a\nBeta release. Products will be complete from a feature perspective, but\nmay have some open outstanding issues. Beta releases are suitable for\nlimited production use cases.","GA features are open to all developers and are considered stable and\nfully qualified for production use.","Deprecated features are scheduled to be shut down and removed. For more\ninformation, see the “Deprecation Policy” section of our [Terms of\nService](https://cloud.google.com/terms/)\nand the [Google Cloud Platform Subject to the Deprecation\nPolicy](https://cloud.google.com/terms/deprecation) documentation."],"enum":["LAUNCH_STAGE_UNSPECIFIED","EARLY_ACCESS","ALPHA","BETA","GA","DEPRECATED"],"description":"Optional. The launch stage of the monitored resource definition."},"labels":{"description":"Required. A set of labels used to describe instances of this monitored\nresource type. For example, an individual Google Cloud SQL database is\nidentified by values for the labels `\"database_id\"` and `\"zone\"`.","type":"array","items":{"$ref":"LabelDescriptor"}}},"id":"MonitoredResourceDescriptor","description":"An object that describes the schema of a MonitoredResource object using a\ntype name and a set of labels.  For example, the monitored resource\ndescriptor for Google Compute Engine VM instances has a type of\n`\"gce_instance\"` and specifies the use of the labels `\"instance_id\"` and\n`\"zone\"` to identify particular VM instances.\n\nDifferent APIs can support different monitored resource types. APIs generally\nprovide a `list` method that returns the monitored resource descriptors used\nby the API."},"CustomErrorRule":{"type":"object","properties":{"selector":{"description":"Selects messages to which this rule applies.\n\nRefer to selector for syntax details.","type":"string"},"isErrorType":{"type":"boolean","description":"Mark this message as possible payload in error response.  Otherwise,\nobjects of this type will be filtered when they appear in error payload."}},"id":"CustomErrorRule","description":"A custom error rule."},"ChangeReport":{"description":"Change report associated with a particular service configuration.\n\nIt contains a list of ConfigChanges based on the comparison between\ntwo service configurations.","type":"object","properties":{"configChanges":{"description":"List of changes between two service configurations.\nThe changes will be alphabetically sorted based on the identifier\nof each change.\nA ConfigChange identifier is a dot separated path to the configuration.\nExample: visibility.rules[selector='LibraryService.CreateBook'].restriction","type":"array","items":{"$ref":"ConfigChange"}}},"id":"ChangeReport"},"FlowErrorDetails":{"type":"object","properties":{"exceptionType":{"description":"The type of exception (as a class name).","type":"string"},"flowStepId":{"description":"The step that failed.","type":"string"}},"id":"FlowErrorDetails","description":"Encapsulation of flow-specific error details for debugging.\nUsed as a details field on an error Status, not intended for external use."},"DisableServiceRequest":{"type":"object","properties":{"consumerId":{"description":"The identity of consumer resource which service disablement will be\napplied to.\n\nThe Google Service Management implementation accepts the following\nforms:\n- \"project:<project_id>\"\n\nNote: this is made compatible with\ngoogle.api.servicecontrol.v1.Operation.consumer_id.","type":"string"}},"id":"DisableServiceRequest","description":"Request message for DisableService method."},"SubmitConfigSourceResponse":{"type":"object","properties":{"serviceConfig":{"$ref":"Service","description":"The generated service configuration."}},"id":"SubmitConfigSourceResponse","description":"Response message for SubmitConfigSource method."},"BillingDestination":{"description":"Configuration of a specific billing destination (Currently only support\nbill against consumer project).","type":"object","properties":{"metrics":{"description":"Names of the metrics to report to this billing destination.\nEach name must be defined in Service.metrics section.","type":"array","items":{"type":"string"}},"monitoredResource":{"type":"string","description":"The monitored resource type. The type must be defined in\nService.monitored_resources section."}},"id":"BillingDestination"},"Advice":{"description":"Generated advice about this change, used for providing more\ninformation about how a change will affect the existing service.","type":"object","properties":{"description":{"type":"string","description":"Useful description for why this advice was applied and what actions should\nbe taken to mitigate any implied risks."}},"id":"Advice"},"ManagedService":{"id":"ManagedService","description":"The full representation of a Service that is managed by\nGoogle Service Management.","type":"object","properties":{"producerProjectId":{"type":"string","description":"ID of the project that produces and owns this service."},"serviceName":{"type":"string","description":"The name of the service. See the [overview](/service-management/overview)\nfor naming requirements."}}},"UsageRule":{"id":"UsageRule","description":"Usage configuration rules for the service.\n\nNOTE: Under development.\n\n\nUse this rule to configure unregistered calls for the service. Unregistered\ncalls are calls that do not contain consumer project identity.\n(Example: calls that do not contain an API key).\nBy default, API methods do not allow unregistered calls, and each method call\nmust be identified by a consumer project identity. Use this rule to\nallow/disallow unregistered calls.\n\nExample of an API that wants to allow unregistered calls for entire service.\n\n    usage:\n      rules:\n      - selector: \"*\"\n        allow_unregistered_calls: true\n\nExample of a method that wants to allow unregistered calls.\n\n    usage:\n      rules:\n      - selector: \"google.example.library.v1.LibraryService.CreateBook\"\n        allow_unregistered_calls: true","type":"object","properties":{"selector":{"description":"Selects the methods to which this rule applies. Use '*' to indicate all\nmethods in all APIs.\n\nRefer to selector for syntax details.","type":"string"},"skipServiceControl":{"description":"If true, the selected method should skip service control and the control\nplane features, such as quota and billing, will not be available.\nThis flag is used by Google Cloud Endpoints to bypass checks for internal\nmethods, such as service health check methods.","type":"boolean"},"allowUnregisteredCalls":{"type":"boolean","description":"If true, the selected method allows unregistered calls, e.g. calls\nthat don't identify any user or application."}}},"AuthRequirement":{"type":"object","properties":{"providerId":{"type":"string","description":"id from authentication provider.\n\nExample:\n\n    provider_id: bookstore_auth"},"audiences":{"type":"string","description":"NOTE: This will be deprecated soon, once AuthProvider.audiences is\nimplemented and accepted in all the runtime components.\n\nThe list of JWT\n[audiences](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.3).\nthat are allowed to access. A JWT containing any of these audiences will\nbe accepted. When this setting is absent, only JWTs with audience\n\"https://Service_name/API_name\"\nwill be accepted. For example, if no audiences are in the setting,\nLibraryService API will only accept JWTs with the following audience\n\"https://library-example.googleapis.com/google.example.library.v1.LibraryService\".\n\nExample:\n\n    audiences: bookstore_android.apps.googleusercontent.com,\n               bookstore_web.apps.googleusercontent.com"}},"id":"AuthRequirement","description":"User-defined authentication requirements, including support for\n[JSON Web Token\n(JWT)](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32)."},"TrafficPercentStrategy":{"id":"TrafficPercentStrategy","description":"Strategy that specifies how clients of Google Service Controller want to\nsend traffic to use different config versions. This is generally\nused by API proxy to split traffic based on your configured precentage for\neach config version.\n\nOne example of how to gradually rollout a new service configuration using\nthis\nstrategy:\nDay 1\n\n    Rollout {\n      id: \"example.googleapis.com/rollout_20160206\"\n      traffic_percent_strategy {\n        percentages: {\n          \"example.googleapis.com/20160201\": 70.00\n          \"example.googleapis.com/20160206\": 30.00\n        }\n      }\n    }\n\nDay 2\n\n    Rollout {\n      id: \"example.googleapis.com/rollout_20160207\"\n      traffic_percent_strategy: {\n        percentages: {\n          \"example.googleapis.com/20160206\": 100.00\n        }\n      }\n    }","type":"object","properties":{"percentages":{"description":"Maps service configuration IDs to their corresponding traffic percentage.\nKey is the service configuration ID, Value is the traffic percentage\nwhich must be greater than 0.0 and the sum must equal to 100.0.","type":"object","additionalProperties":{"type":"number","format":"double"}}}},"Documentation":{"id":"Documentation","description":"`Documentation` provides the information for describing a service.\n\nExample:\n<pre><code>documentation:\n  summary: >\n    The Google Calendar API gives access\n    to most calendar features.\n  pages:\n  - name: Overview\n    content: &#40;== include google/foo/overview.md ==&#41;\n  - name: Tutorial\n    content: &#40;== include google/foo/tutorial.md ==&#41;\n    subpages;\n    - name: Java\n      content: &#40;== include google/foo/tutorial_java.md ==&#41;\n  rules:\n  - selector: google.calendar.Calendar.Get\n    description: >\n      ...\n  - selector: google.calendar.Calendar.Put\n    description: >\n      ...\n</code></pre>\nDocumentation is provided in markdown syntax. In addition to\nstandard markdown features, definition lists, tables and fenced\ncode blocks are supported. Section headers can be provided and are\ninterpreted relative to the section nesting of the context where\na documentation fragment is embedded.\n\nDocumentation from the IDL is merged with documentation defined\nvia the config at normalization time, where documentation provided\nby config rules overrides IDL provided.\n\nA number of constructs specific to the API platform are supported\nin documentation text.\n\nIn order to reference a proto element, the following\nnotation can be used:\n<pre><code>&#91;fully.qualified.proto.name]&#91;]</code></pre>\nTo override the display text used for the link, this can be used:\n<pre><code>&#91;display text]&#91;fully.qualified.proto.name]</code></pre>\nText can be excluded from doc using the following notation:\n<pre><code>&#40;-- internal comment --&#41;</code></pre>\n\nA few directives are available in documentation. Note that\ndirectives must appear on a single line to be properly\nidentified. The `include` directive includes a markdown file from\nan external source:\n<pre><code>&#40;== include path/to/file ==&#41;</code></pre>\nThe `resource_for` directive marks a message to be the resource of\na collection in REST view. If it is not specified, tools attempt\nto infer the resource from the operations in a collection:\n<pre><code>&#40;== resource_for v1.shelves.books ==&#41;</code></pre>\nThe directive `suppress_warning` does not directly affect documentation\nand is documented together with service config validation.","type":"object","properties":{"summary":{"description":"A short summary of what the service does. Can only be provided by\nplain text.","type":"string"},"documentationRootUrl":{"description":"The URL to the root of documentation.","type":"string"},"rules":{"description":"A list of documentation rules that apply to individual API elements.\n\n**NOTE:** All service configuration rules follow \"last one wins\" order.","type":"array","items":{"$ref":"DocumentationRule"}},"overview":{"description":"Declares a single overview page. For example:\n<pre><code>documentation:\n  summary: ...\n  overview: &#40;== include overview.md ==&#41;\n</code></pre>\nThis is a shortcut for the following declaration (using pages style):\n<pre><code>documentation:\n  summary: ...\n  pages:\n  - name: Overview\n    content: &#40;== include overview.md ==&#41;\n</code></pre>\nNote: you cannot specify both `overview` field and `pages` field.","type":"string"},"pages":{"description":"The top level pages for the documentation set.","type":"array","items":{"$ref":"Page"}}}},"AuditLogConfig":{"type":"object","properties":{"logType":{"enumDescriptions":["Default case. Should never be this.","Admin reads. Example: CloudIAM getIamPolicy","Data writes. Example: CloudSQL Users create","Data reads. Example: CloudSQL Users list"],"enum":["LOG_TYPE_UNSPECIFIED","ADMIN_READ","DATA_WRITE","DATA_READ"],"description":"The log type that this config enables.","type":"string"},"exemptedMembers":{"type":"array","items":{"type":"string"},"description":"Specifies the identities that do not cause logging for this type of\npermission.\nFollows the same format of Binding.members."}},"id":"AuditLogConfig","description":"Provides the configuration for logging a type of permissions.\nExample:\n\n    {\n      \"audit_log_configs\": [\n        {\n          \"log_type\": \"DATA_READ\",\n          \"exempted_members\": [\n            \"user:foo@gmail.com\"\n          ]\n        },\n        {\n          \"log_type\": \"DATA_WRITE\",\n        }\n      ]\n    }\n\nThis enables 'DATA_READ' and 'DATA_WRITE' logging, while exempting\nfoo@gmail.com from DATA_READ logging."},"ConfigSource":{"id":"ConfigSource","description":"Represents a source file which is used to generate the service configuration\ndefined by `google.api.Service`.","type":"object","properties":{"id":{"description":"A unique ID for a specific instance of this message, typically assigned\nby the client for tracking purpose. If empty, the server may choose to\ngenerate one instead.","type":"string"},"files":{"description":"Set of source configuration files that are used to generate a service\nconfiguration (`google.api.Service`).","type":"array","items":{"$ref":"ConfigFile"}}}}},"icons":{"x16":"http://www.google.com/images/icons/product/search-16.gif","x32":"http://www.google.com/images/icons/product/search-32.gif"},"protocol":"rest","canonicalName":"Service Management","auth":{"oauth2":{"scopes":{"https://www.googleapis.com/auth/service.management":{"description":"Manage your Google API service configuration"},"https://www.googleapis.com/auth/cloud-platform.read-only":{"description":"View your data across Google Cloud Platform services"},"https://www.googleapis.com/auth/service.management.readonly":{"description":"View your Google API service configuration"},"https://www.googleapis.com/auth/cloud-platform":{"description":"View and manage your data across Google Cloud Platform services"}}}},"rootUrl":"https://servicemanagement.googleapis.com/","ownerDomain":"google.com","name":"servicemanagement","batchPath":"batch","fullyEncodeReservedExpansion":true,"title":"Service Management API","ownerName":"Google","resources":{"operations":{"methods":{"list":{"response":{"$ref":"ListOperationsResponse"},"parameterOrder":[],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"parameters":{"name":{"location":"query","description":"Not used.","type":"string"},"pageToken":{"type":"string","location":"query","description":"The standard list page token."},"pageSize":{"type":"integer","location":"query","description":"The maximum number of operations to return. If unspecified, defaults to\n50. The maximum value is 100.","format":"int32"},"filter":{"type":"string","location":"query","description":"A string for filtering Operations.\n  The following filter fields are supported&#58;\n\n  * serviceName&#58; Required. Only `=` operator is allowed.\n  * startTime&#58; The time this job was started, in ISO 8601 format.\n    Allowed operators are `>=`,  `>`, `<=`, and `<`.\n  * status&#58; Can be `done`, `in_progress`, or `failed`. Allowed\n    operators are `=`, and `!=`.\n\n  Filter expression supports conjunction (AND) and disjunction (OR)\n  logical operators. However, the serviceName restriction must be at the\n  top-level and can only be combined with other restrictions via the AND\n  logical operator.\n\n  Examples&#58;\n\n  * `serviceName={some-service}.googleapis.com`\n  * `serviceName={some-service}.googleapis.com AND startTime>=\"2017-02-01\"`\n  * `serviceName={some-service}.googleapis.com AND status=done`\n  * `serviceName={some-service}.googleapis.com AND (status=done OR startTime>=\"2017-02-01\")`"}},"flatPath":"v1/operations","path":"v1/operations","id":"servicemanagement.operations.list","description":"Lists service operations that match the specified filter in the request."},"get":{"description":"Gets the latest state of a long-running operation.  Clients can use this\nmethod to poll the operation result at intervals as recommended by the API\nservice.","response":{"$ref":"Operation"},"parameterOrder":["name"],"httpMethod":"GET","parameters":{"name":{"required":true,"type":"string","pattern":"^operations/.+$","location":"path","description":"The name of the operation resource."}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"flatPath":"v1/operations/{operationsId}","path":"v1/{+name}","id":"servicemanagement.operations.get"}}},"services":{"methods":{"undelete":{"httpMethod":"POST","parameterOrder":["serviceName"],"response":{"$ref":"Operation"},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"parameters":{"serviceName":{"required":true,"type":"string","location":"path","description":"The name of the service. See the [overview](/service-management/overview)\nfor naming requirements. For example: `example.googleapis.com`."}},"flatPath":"v1/services/{serviceName}:undelete","id":"servicemanagement.services.undelete","path":"v1/services/{serviceName}:undelete","description":"Revives a previously deleted managed service. The method restores the\nservice using the configuration at the time the service was deleted.\nThe target service must exist and must have been deleted within the\nlast 30 days.\n\nOperation<response: UndeleteServiceResponse>"},"list":{"parameters":{"consumerId":{"type":"string","location":"query","description":"Include services consumed by the specified consumer.\n\nThe Google Service Management implementation accepts the following\nforms:\n- project:<project_id>"},"pageToken":{"type":"string","location":"query","description":"Token identifying which result to start with; returned by a previous list\ncall."},"pageSize":{"description":"The max number of items to include in the response list. Page size is 50\nif not specified. Maximum value is 100.","format":"int32","type":"integer","location":"query"},"producerProjectId":{"type":"string","location":"query","description":"Include services produced by the specified project."}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloud-platform.read-only","https://www.googleapis.com/auth/service.management","https://www.googleapis.com/auth/service.management.readonly"],"flatPath":"v1/services","path":"v1/services","id":"servicemanagement.services.list","description":"Lists managed services.\n\nReturns all public services. For authenticated users, also returns all\nservices the calling user has \"servicemanagement.services.get\" permission\nfor.\n\n**BETA:** If the caller specifies the `consumer_id`, it returns only the\nservices enabled on the consumer. The `consumer_id` must have the format\nof \"project:{PROJECT-ID}\".","response":{"$ref":"ListServicesResponse"},"parameterOrder":[],"httpMethod":"GET"},"create":{"httpMethod":"POST","parameterOrder":[],"response":{"$ref":"Operation"},"parameters":{},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"flatPath":"v1/services","id":"servicemanagement.services.create","path":"v1/services","description":"Creates a new managed service.\nPlease note one producer project can own no more than 20 services.\n\nOperation<response: ManagedService>","request":{"$ref":"ManagedService"}},"generateConfigReport":{"httpMethod":"POST","parameterOrder":[],"response":{"$ref":"GenerateConfigReportResponse"},"parameters":{},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"flatPath":"v1/services:generateConfigReport","id":"servicemanagement.services.generateConfigReport","path":"v1/services:generateConfigReport","description":"Generates and returns a report (errors, warnings and changes from\nexisting configurations) associated with\nGenerateConfigReportRequest.new_value\n\nIf GenerateConfigReportRequest.old_value is specified,\nGenerateConfigReportRequest will contain a single ChangeReport based on the\ncomparison between GenerateConfigReportRequest.new_value and\nGenerateConfigReportRequest.old_value.\nIf GenerateConfigReportRequest.old_value is not specified, this method\nwill compare GenerateConfigReportRequest.new_value with the last pushed\nservice configuration.","request":{"$ref":"GenerateConfigReportRequest"}},"get":{"description":"Gets a managed service. Authentication is required unless the service is\npublic.","response":{"$ref":"ManagedService"},"parameterOrder":["serviceName"],"httpMethod":"GET","parameters":{"serviceName":{"location":"path","description":"The name of the service.  See the `ServiceManager` overview for naming\nrequirements.  For example: `example.googleapis.com`.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloud-platform.read-only","https://www.googleapis.com/auth/service.management","https://www.googleapis.com/auth/service.management.readonly"],"flatPath":"v1/services/{serviceName}","path":"v1/services/{serviceName}","id":"servicemanagement.services.get"},"testIamPermissions":{"httpMethod":"POST","parameterOrder":["resource"],"response":{"$ref":"TestIamPermissionsResponse"},"parameters":{"resource":{"location":"path","description":"REQUIRED: The resource for which the policy detail is being requested.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string","pattern":"^services/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloud-platform.read-only","https://www.googleapis.com/auth/service.management","https://www.googleapis.com/auth/service.management.readonly"],"flatPath":"v1/services/{servicesId}:testIamPermissions","id":"servicemanagement.services.testIamPermissions","path":"v1/{+resource}:testIamPermissions","description":"Returns permissions that a caller has on the specified resource.\nIf the resource does not exist, this will return an empty set of\npermissions, not a NOT_FOUND error.\n\nNote: This operation is designed to be used for building permission-aware\nUIs and command-line tools, not for authorization checking. This operation\nmay \"fail open\" without warning.","request":{"$ref":"TestIamPermissionsRequest"}},"getConfig":{"httpMethod":"GET","parameterOrder":["serviceName"],"response":{"$ref":"Service"},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloud-platform.read-only","https://www.googleapis.com/auth/service.management","https://www.googleapis.com/auth/service.management.readonly"],"parameters":{"serviceName":{"description":"The name of the service.  See the [overview](/service-management/overview)\nfor naming requirements.  For example: `example.googleapis.com`.","required":true,"type":"string","location":"path"},"configId":{"location":"query","description":"The id of the service configuration resource.\n\nThis field must be specified for the server to return all fields, including\n`SourceInfo`.","type":"string"},"view":{"description":"Specifies which parts of the Service Config should be returned in the\nresponse.","type":"string","location":"query","enum":["BASIC","FULL"]}},"flatPath":"v1/services/{serviceName}/config","id":"servicemanagement.services.getConfig","path":"v1/services/{serviceName}/config","description":"Gets a service configuration (version) for a managed service."},"enable":{"flatPath":"v1/services/{serviceName}:enable","path":"v1/services/{serviceName}:enable","id":"servicemanagement.services.enable","request":{"$ref":"EnableServiceRequest"},"description":"Enables a service for a project, so it can be used\nfor the project. See\n[Cloud Auth Guide](https://cloud.google.com/docs/authentication) for\nmore information.\n\nOperation<response: EnableServiceResponse>","response":{"$ref":"Operation"},"parameterOrder":["serviceName"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"parameters":{"serviceName":{"location":"path","description":"Name of the service to enable. Specifying an unknown service name will\ncause the request to fail.","required":true,"type":"string"}}},"delete":{"response":{"$ref":"Operation"},"parameterOrder":["serviceName"],"httpMethod":"DELETE","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"parameters":{"serviceName":{"required":true,"type":"string","location":"path","description":"The name of the service.  See the [overview](/service-management/overview)\nfor naming requirements.  For example: `example.googleapis.com`."}},"flatPath":"v1/services/{serviceName}","path":"v1/services/{serviceName}","id":"servicemanagement.services.delete","description":"Deletes a managed service. This method will change the service to the\n`Soft-Delete` state for 30 days. Within this period, service producers may\ncall UndeleteService to restore the service.\nAfter 30 days, the service will be permanently deleted.\n\nOperation<response: google.protobuf.Empty>"},"setIamPolicy":{"httpMethod":"POST","parameterOrder":["resource"],"response":{"$ref":"Policy"},"parameters":{"resource":{"required":true,"type":"string","pattern":"^services/[^/]+$","location":"path","description":"REQUIRED: The resource for which the policy is being specified.\nSee the operation documentation for the appropriate value for this field."}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"flatPath":"v1/services/{servicesId}:setIamPolicy","id":"servicemanagement.services.setIamPolicy","path":"v1/{+resource}:setIamPolicy","description":"Sets the access control policy on the specified resource. Replaces any\nexisting policy.","request":{"$ref":"SetIamPolicyRequest"}},"disable":{"request":{"$ref":"DisableServiceRequest"},"description":"Disables a service for a project, so it can no longer be\nbe used for the project. It prevents accidental usage that may cause\nunexpected billing charges or security leaks.\n\nOperation<response: DisableServiceResponse>","response":{"$ref":"Operation"},"parameterOrder":["serviceName"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"parameters":{"serviceName":{"description":"Name of the service to disable. Specifying an unknown service name\nwill cause the request to fail.","required":true,"type":"string","location":"path"}},"flatPath":"v1/services/{serviceName}:disable","path":"v1/services/{serviceName}:disable","id":"servicemanagement.services.disable"},"getIamPolicy":{"httpMethod":"POST","parameterOrder":["resource"],"response":{"$ref":"Policy"},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloud-platform.read-only","https://www.googleapis.com/auth/service.management","https://www.googleapis.com/auth/service.management.readonly"],"parameters":{"resource":{"pattern":"^services/[^/]+$","location":"path","description":"REQUIRED: The resource for which the policy is being requested.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string"}},"flatPath":"v1/services/{servicesId}:getIamPolicy","id":"servicemanagement.services.getIamPolicy","path":"v1/{+resource}:getIamPolicy","request":{"$ref":"GetIamPolicyRequest"},"description":"Gets the access control policy for a resource.\nReturns an empty policy if the resource exists and does not have a policy\nset."}},"resources":{"consumers":{"methods":{"setIamPolicy":{"description":"Sets the access control policy on the specified resource. Replaces any\nexisting policy.","request":{"$ref":"SetIamPolicyRequest"},"httpMethod":"POST","parameterOrder":["resource"],"response":{"$ref":"Policy"},"parameters":{"resource":{"pattern":"^services/[^/]+/consumers/[^/]+$","location":"path","description":"REQUIRED: The resource for which the policy is being specified.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"flatPath":"v1/services/{servicesId}/consumers/{consumersId}:setIamPolicy","id":"servicemanagement.services.consumers.setIamPolicy","path":"v1/{+resource}:setIamPolicy"},"testIamPermissions":{"response":{"$ref":"TestIamPermissionsResponse"},"parameterOrder":["resource"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloud-platform.read-only","https://www.googleapis.com/auth/service.management","https://www.googleapis.com/auth/service.management.readonly"],"parameters":{"resource":{"location":"path","description":"REQUIRED: The resource for which the policy detail is being requested.\nSee the operation documentation for the appropriate value for this field.","required":true,"type":"string","pattern":"^services/[^/]+/consumers/[^/]+$"}},"flatPath":"v1/services/{servicesId}/consumers/{consumersId}:testIamPermissions","path":"v1/{+resource}:testIamPermissions","id":"servicemanagement.services.consumers.testIamPermissions","request":{"$ref":"TestIamPermissionsRequest"},"description":"Returns permissions that a caller has on the specified resource.\nIf the resource does not exist, this will return an empty set of\npermissions, not a NOT_FOUND error.\n\nNote: This operation is designed to be used for building permission-aware\nUIs and command-line tools, not for authorization checking. This operation\nmay \"fail open\" without warning."},"getIamPolicy":{"response":{"$ref":"Policy"},"parameterOrder":["resource"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloud-platform.read-only","https://www.googleapis.com/auth/service.management","https://www.googleapis.com/auth/service.management.readonly"],"parameters":{"resource":{"required":true,"type":"string","pattern":"^services/[^/]+/consumers/[^/]+$","location":"path","description":"REQUIRED: The resource for which the policy is being requested.\nSee the operation documentation for the appropriate value for this field."}},"flatPath":"v1/services/{servicesId}/consumers/{consumersId}:getIamPolicy","path":"v1/{+resource}:getIamPolicy","id":"servicemanagement.services.consumers.getIamPolicy","request":{"$ref":"GetIamPolicyRequest"},"description":"Gets the access control policy for a resource.\nReturns an empty policy if the resource exists and does not have a policy\nset."}}},"rollouts":{"methods":{"create":{"parameters":{"serviceName":{"description":"The name of the service.  See the [overview](/service-management/overview)\nfor naming requirements.  For example: `example.googleapis.com`.","required":true,"type":"string","location":"path"},"baseRolloutId":{"location":"query","description":"Unimplemented. Do not use this feature until this comment is removed.\n\nThe rollout id that rollout to be created based on.\n\nRollout should be constructed based on current successful rollout, this\nfield indicates the current successful rollout id that new rollout based on\nto construct, if current successful rollout changed when server receives\nthe request, request will be rejected for safety.","type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"flatPath":"v1/services/{serviceName}/rollouts","path":"v1/services/{serviceName}/rollouts","id":"servicemanagement.services.rollouts.create","description":"Creates a new service configuration rollout. Based on rollout, the\nGoogle Service Management will roll out the service configurations to\ndifferent backend services. For example, the logging configuration will be\npushed to Google Cloud Logging.\n\nPlease note that any previous pending and running Rollouts and associated\nOperations will be automatically cancelled so that the latest Rollout will\nnot be blocked by previous Rollouts.\n\nOnly the 100 most recent (in any state) and the last 10 successful (if not\nalready part of the set of 100 most recent) rollouts are kept for each\nservice. The rest will be deleted eventually.\n\nOperation<response: Rollout>","request":{"$ref":"Rollout"},"response":{"$ref":"Operation"},"parameterOrder":["serviceName"],"httpMethod":"POST"},"list":{"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloud-platform.read-only","https://www.googleapis.com/auth/service.management","https://www.googleapis.com/auth/service.management.readonly"],"parameters":{"pageToken":{"description":"The token of the page to retrieve.","type":"string","location":"query"},"pageSize":{"type":"integer","location":"query","description":"The max number of items to include in the response list. Page size is 50\nif not specified. Maximum value is 100.","format":"int32"},"filter":{"description":"Use `filter` to return subset of rollouts.\nThe following filters are supported:\n  -- To limit the results to only those in\n     [status](google.api.servicemanagement.v1.RolloutStatus) 'SUCCESS',\n     use filter='status=SUCCESS'\n  -- To limit the results to those in\n     [status](google.api.servicemanagement.v1.RolloutStatus) 'CANCELLED'\n     or 'FAILED', use filter='status=CANCELLED OR status=FAILED'","type":"string","location":"query"},"serviceName":{"location":"path","description":"The name of the service.  See the [overview](/service-management/overview)\nfor naming requirements.  For example: `example.googleapis.com`.","required":true,"type":"string"}},"flatPath":"v1/services/{serviceName}/rollouts","id":"servicemanagement.services.rollouts.list","path":"v1/services/{serviceName}/rollouts","description":"Lists the history of the service configuration rollouts for a managed\nservice, from the newest to the oldest.","httpMethod":"GET","parameterOrder":["serviceName"],"response":{"$ref":"ListServiceRolloutsResponse"}},"get":{"response":{"$ref":"Rollout"},"parameterOrder":["serviceName","rolloutId"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloud-platform.read-only","https://www.googleapis.com/auth/service.management","https://www.googleapis.com/auth/service.management.readonly"],"parameters":{"serviceName":{"required":true,"type":"string","location":"path","description":"The name of the service.  See the [overview](/service-management/overview)\nfor naming requirements.  For example: `example.googleapis.com`."},"rolloutId":{"location":"path","description":"The id of the rollout resource.","required":true,"type":"string"}},"flatPath":"v1/services/{serviceName}/rollouts/{rolloutId}","path":"v1/services/{serviceName}/rollouts/{rolloutId}","id":"servicemanagement.services.rollouts.get","description":"Gets a service configuration rollout."}}},"configs":{"methods":{"create":{"description":"Creates a new service configuration (version) for a managed service.\nThis method only stores the service configuration. To roll out the service\nconfiguration to backend systems please call\nCreateServiceRollout.\n\nOnly the 100 most recent service configurations and ones referenced by\nexisting rollouts are kept for each service. The rest will be deleted\neventually.","request":{"$ref":"Service"},"httpMethod":"POST","parameterOrder":["serviceName"],"response":{"$ref":"Service"},"parameters":{"serviceName":{"required":true,"type":"string","location":"path","description":"The name of the service.  See the [overview](/service-management/overview)\nfor naming requirements.  For example: `example.googleapis.com`."}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"flatPath":"v1/services/{serviceName}/configs","id":"servicemanagement.services.configs.create","path":"v1/services/{serviceName}/configs"},"submit":{"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"parameters":{"serviceName":{"description":"The name of the service.  See the [overview](/service-management/overview)\nfor naming requirements.  For example: `example.googleapis.com`.","required":true,"type":"string","location":"path"}},"flatPath":"v1/services/{serviceName}/configs:submit","path":"v1/services/{serviceName}/configs:submit","id":"servicemanagement.services.configs.submit","request":{"$ref":"SubmitConfigSourceRequest"},"description":"Creates a new service configuration (version) for a managed service based\non\nuser-supplied configuration source files (for example: OpenAPI\nSpecification). This method stores the source configurations as well as the\ngenerated service configuration. To rollout the service configuration to\nother services,\nplease call CreateServiceRollout.\n\nOnly the 100 most recent configuration sources and ones referenced by\nexisting service configurtions are kept for each service. The rest will be\ndeleted eventually.\n\nOperation<response: SubmitConfigSourceResponse>","response":{"$ref":"Operation"},"parameterOrder":["serviceName"],"httpMethod":"POST"},"list":{"path":"v1/services/{serviceName}/configs","id":"servicemanagement.services.configs.list","description":"Lists the history of the service configuration for a managed service,\nfrom the newest to the oldest.","response":{"$ref":"ListServiceConfigsResponse"},"parameterOrder":["serviceName"],"httpMethod":"GET","parameters":{"serviceName":{"location":"path","description":"The name of the service.  See the [overview](/service-management/overview)\nfor naming requirements.  For example: `example.googleapis.com`.","required":true,"type":"string"},"pageToken":{"location":"query","description":"The token of the page to retrieve.","type":"string"},"pageSize":{"type":"integer","location":"query","description":"The max number of items to include in the response list. Page size is 50\nif not specified. Maximum value is 100.","format":"int32"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloud-platform.read-only","https://www.googleapis.com/auth/service.management","https://www.googleapis.com/auth/service.management.readonly"],"flatPath":"v1/services/{serviceName}/configs"},"get":{"description":"Gets a service configuration (version) for a managed service.","httpMethod":"GET","parameterOrder":["serviceName","configId"],"response":{"$ref":"Service"},"parameters":{"configId":{"description":"The id of the service configuration resource.\n\nThis field must be specified for the server to return all fields, including\n`SourceInfo`.","required":true,"type":"string","location":"path"},"view":{"description":"Specifies which parts of the Service Config should be returned in the\nresponse.","type":"string","location":"query","enum":["BASIC","FULL"]},"serviceName":{"location":"path","description":"The name of the service.  See the [overview](/service-management/overview)\nfor naming requirements.  For example: `example.googleapis.com`.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/cloud-platform.read-only","https://www.googleapis.com/auth/service.management","https://www.googleapis.com/auth/service.management.readonly"],"flatPath":"v1/services/{serviceName}/configs/{configId}","id":"servicemanagement.services.configs.get","path":"v1/services/{serviceName}/configs/{configId}"}}}}}},"parameters":{"access_token":{"location":"query","description":"OAuth access token.","type":"string"},"key":{"location":"query","description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.","type":"string"},"upload_protocol":{"location":"query","description":"Upload protocol for media (e.g. \"raw\", \"multipart\").","type":"string"},"quotaUser":{"location":"query","description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.","type":"string"},"prettyPrint":{"description":"Returns response with indentations and line breaks.","type":"boolean","default":"true","location":"query"},"fields":{"location":"query","description":"Selector specifying which fields to include in a partial response.","type":"string"},"uploadType":{"type":"string","location":"query","description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\")."},"callback":{"description":"JSONP","type":"string","location":"query"},"oauth_token":{"description":"OAuth 2.0 token for the current user.","type":"string","location":"query"},"$.xgafv":{"type":"string","enumDescriptions":["v1 error format","v2 error format"],"location":"query","enum":["1","2"],"description":"V1 error format."},"alt":{"location":"query","description":"Data format for response.","default":"json","enum":["json","media","proto"],"type":"string","enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"]}},"version":"v1","baseUrl":"https://servicemanagement.googleapis.com/","servicePath":"","description":"Google Service Management allows service producers to publish their services on Google Cloud Platform so that they can be discovered and used by service consumers.","kind":"discovery#restDescription","basePath":""};