export default {"version_module":true,"schemas":{"SystemParameters":{"id":"SystemParameters","description":"### System parameter configuration\n\nA system parameter is a special kind of parameter defined by the API\nsystem, not by an individual API. It is typically mapped to an HTTP header\nand/or a URL query parameter. This configuration specifies which methods\nchange the names of the system parameters.","type":"object","properties":{"rules":{"type":"array","items":{"$ref":"SystemParameterRule"},"description":"Define system parameters.\n\nThe parameters defined here will override the default parameters\nimplemented by the system. If this field is missing from the service\nconfig, default system parameters will be used. Default system parameters\nand names is implementation-dependent.\n\nExample: define api key for all methods\n\n    system_parameters\n      rules:\n        - selector: \"*\"\n          parameters:\n            - name: api_key\n              url_query_parameter: api_key\n\n\nExample: define 2 api key names for a specific method.\n\n    system_parameters\n      rules:\n        - selector: \"/ListShelves\"\n          parameters:\n            - name: api_key\n              http_header: Api-Key1\n            - name: api_key\n              http_header: Api-Key2\n\n**NOTE:** All service configuration rules follow \"last one wins\" order."}}},"Quota":{"description":"Quota configuration helps to achieve fairness and budgeting in service\nusage.\n\nThe metric based quota configuration works this way:\n- The service configuration defines a set of metrics.\n- For API calls, the quota.metric_rules maps methods to metrics with\n  corresponding costs.\n- The quota.limits defines limits on the metrics, which will be used for\n  quota checks at runtime.\n\nAn example quota configuration in yaml format:\n\n   quota:\n     limits:\n\n     - name: apiWriteQpsPerProject\n       metric: library.googleapis.com/write_calls\n       unit: \"1/min/{project}\"  # rate limit for consumer projects\n       values:\n         STANDARD: 10000\n\n\n     # The metric rules bind all methods to the read_calls metric,\n     # except for the UpdateBook and DeleteBook methods. These two methods\n     # are mapped to the write_calls metric, with the UpdateBook method\n     # consuming at twice rate as the DeleteBook method.\n     metric_rules:\n     - selector: \"*\"\n       metric_costs:\n         library.googleapis.com/read_calls: 1\n     - selector: google.example.library.v1.LibraryService.UpdateBook\n       metric_costs:\n         library.googleapis.com/write_calls: 2\n     - selector: google.example.library.v1.LibraryService.DeleteBook\n       metric_costs:\n         library.googleapis.com/write_calls: 1\n\n Corresponding Metric definition:\n\n     metrics:\n     - name: library.googleapis.com/read_calls\n       display_name: Read requests\n       metric_kind: DELTA\n       value_type: INT64\n\n     - name: library.googleapis.com/write_calls\n       display_name: Write requests\n       metric_kind: DELTA\n       value_type: INT64\n\n","type":"object","properties":{"limits":{"description":"List of `QuotaLimit` definitions for the service.","type":"array","items":{"$ref":"QuotaLimit"}},"metricRules":{"description":"List of `MetricRule` definitions, each one mapping a selected method to one\nor more metrics.","type":"array","items":{"$ref":"MetricRule"}}},"id":"Quota"},"GoogleCloudServicenetworkingV1betaSubnetwork":{"id":"GoogleCloudServicenetworkingV1betaSubnetwork","description":"Represents a subnet that was created or discovered by a private access\nmanagement service.","type":"object","properties":{"name":{"description":"Subnetwork name.\nSee https://cloud.google.com/compute/docs/vpc/","type":"string"},"network":{"description":"In the Shared VPC host project, the VPC network that's peered with the\nconsumer network. For example:\n`projects/1234321/global/networks/host-network`","type":"string"},"ipCidrRange":{"type":"string","description":"Subnetwork CIDR range in `10.x.x.x/y` format."},"outsideAllocation":{"description":"This is a discovered subnet that is not within the current consumer\nallocated ranges.","type":"boolean"}}},"LoggingDestination":{"id":"LoggingDestination","description":"Configuration of a specific logging destination (the producer project\nor the consumer project).","type":"object","properties":{"logs":{"description":"Names of the logs to be sent to this destination. Each name must\nbe defined in the Service.logs section. If the log name is\nnot a domain scoped name, it will be automatically prefixed with\nthe service name followed by \"/\".","type":"array","items":{"type":"string"}},"monitoredResource":{"description":"The monitored resource type. The type must be defined in the\nService.monitored_resources section.","type":"string"}}},"Option":{"description":"A protocol buffer option, which can be attached to a message, field,\nenumeration, etc.","type":"object","properties":{"name":{"description":"The option's name. For protobuf built-in options (options defined in\ndescriptor.proto), this is the short name. For example, `\"map_entry\"`.\nFor custom options, it should be the fully-qualified name. For example,\n`\"google.api.http\"`.","type":"string"},"value":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"description":"The option's value packed in an Any message. If the value is a primitive,\nthe corresponding wrapper type defined in google/protobuf/wrappers.proto\nshould be used. If the value is an enum, it should be stored as an int32\nvalue using the google.protobuf.Int32Value type.","type":"object"}},"id":"Option"},"Logging":{"id":"Logging","description":"Logging configuration of the service.\n\nThe following example shows how to configure logs to be sent to the\nproducer and consumer projects. In the example, the `activity_history`\nlog is sent to both the producer and consumer projects, whereas the\n`purchase_history` log is only sent to the producer project.\n\n    monitored_resources:\n    - type: library.googleapis.com/branch\n      labels:\n      - key: /city\n        description: The city where the library branch is located in.\n      - key: /name\n        description: The name of the branch.\n    logs:\n    - name: activity_history\n      labels:\n      - key: /customer_id\n    - name: purchase_history\n    logging:\n      producer_destinations:\n      - monitored_resource: library.googleapis.com/branch\n        logs:\n        - activity_history\n        - purchase_history\n      consumer_destinations:\n      - monitored_resource: library.googleapis.com/branch\n        logs:\n        - activity_history","type":"object","properties":{"consumerDestinations":{"description":"Logging configurations for sending logs to the consumer project.\nThere can be multiple consumer destinations, each one must have a\ndifferent monitored resource type. A log can be used in at most\none consumer destination.","type":"array","items":{"$ref":"LoggingDestination"}},"producerDestinations":{"description":"Logging configurations for sending logs to the producer project.\nThere can be multiple producer destinations, each one must have a\ndifferent monitored resource type. A log can be used in at most\none producer destination.","type":"array","items":{"$ref":"LoggingDestination"}}}},"Method":{"description":"Method represents a method of an API interface.","type":"object","properties":{"options":{"description":"Any metadata attached to the method.","type":"array","items":{"$ref":"Option"}},"responseStreaming":{"description":"If true, the response is streamed.","type":"boolean"},"name":{"type":"string","description":"The simple name of this method."},"requestTypeUrl":{"type":"string","description":"A URL of the input message type."},"requestStreaming":{"type":"boolean","description":"If true, the request is streamed."},"syntax":{"description":"The source syntax of this method.","type":"string","enumDescriptions":["Syntax `proto2`.","Syntax `proto3`."],"enum":["SYNTAX_PROTO2","SYNTAX_PROTO3"]},"responseTypeUrl":{"description":"The URL of the output message type.","type":"string"}},"id":"Method"},"QuotaLimit":{"description":"`QuotaLimit` defines a specific limit that applies over a specified duration\nfor a limit type. There can be at most one limit for a duration and limit\ntype combination defined within a `QuotaGroup`.","type":"object","properties":{"defaultLimit":{"description":"Default number of tokens that can be consumed during the specified\nduration. This is the number of tokens assigned when a client\napplication developer activates the service for his/her project.\n\nSpecifying a value of 0 will block all requests. This can be used if you\nare provisioning quota to selected consumers and blocking others.\nSimilarly, a value of -1 will indicate an unlimited quota. No other\nnegative values are allowed.\n\nUsed by group-based quotas only.","format":"int64","type":"string"},"displayName":{"type":"string","description":"User-visible display name for this limit.\nOptional. If not set, the UI will provide a default display name based on\nthe quota configuration. This field can be used to override the default\ndisplay name generated from the configuration."},"metric":{"description":"The name of the metric this quota limit applies to. The quota limits with\nthe same metric will be checked together during runtime. The metric must be\ndefined within the service config.","type":"string"},"description":{"description":"Optional. User-visible, extended description for this quota limit.\nShould be used only when more context is needed to understand this limit\nthan provided by the limit's display name (see: `display_name`).","type":"string"},"values":{"description":"Tiered limit values. You must specify this as a key:value pair, with an\ninteger value that is the maximum number of requests allowed for the\nspecified unit. Currently only STANDARD is supported.","type":"object","additionalProperties":{"format":"int64","type":"string"}},"unit":{"description":"Specify the unit of the quota limit. It uses the same syntax as\nMetric.unit. The supported unit kinds are determined by the quota\nbackend system.\n\nHere are some examples:\n* \"1/min/{project}\" for quota per minute per project.\n\nNote: the order of unit components is insignificant.\nThe \"1\" at the beginning is required to follow the metric unit syntax.","type":"string"},"maxLimit":{"type":"string","description":"Maximum number of tokens that can be consumed during the specified\nduration. Client application developers can override the default limit up\nto this maximum. If specified, this value cannot be set to a value less\nthan the default limit. If not specified, it is set to the default limit.\n\nTo allow clients to apply overrides with no upper bound, set this to -1,\nindicating unlimited maximum quota.\n\nUsed by group-based quotas only.","format":"int64"},"name":{"description":"Name of the quota limit.\n\nThe name must be provided, and it must be unique within the service. The\nname can only include alphanumeric characters as well as '-'.\n\nThe maximum length of the limit name is 64 characters.","type":"string"},"freeTier":{"description":"Free tier value displayed in the Developers Console for this limit.\nThe free tier is the number of tokens that will be subtracted from the\nbilled amount when billing is enabled.\nThis field can only be set on a limit with duration \"1d\", in a billable\ngroup; it is invalid on any other limit. If this field is not set, it\ndefaults to 0, indicating that there is no free tier for this service.\n\nUsed by group-based quotas only.","format":"int64","type":"string"},"duration":{"description":"Duration of this limit in textual notation. Example: \"100s\", \"24h\", \"1d\".\nFor duration longer than a day, only multiple of days is supported. We\nsupport only \"100s\" and \"1d\" for now. Additional support will be added in\nthe future. \"0\" indicates indefinite duration.\n\nUsed by group-based quotas only.","type":"string"}},"id":"QuotaLimit"},"Mixin":{"description":"Declares an API Interface to be included in this interface. The including\ninterface must redeclare all the methods from the included interface, but\ndocumentation and options are inherited as follows:\n\n- If after comment and whitespace stripping, the documentation\n  string of the redeclared method is empty, it will be inherited\n  from the original method.\n\n- Each annotation belonging to the service config (http,\n  visibility) which is not set in the redeclared method will be\n  inherited.\n\n- If an http annotation is inherited, the path pattern will be\n  modified as follows. Any version prefix will be replaced by the\n  version of the including interface plus the root path if\n  specified.\n\nExample of a simple mixin:\n\n    package google.acl.v1;\n    service AccessControl {\n      // Get the underlying ACL object.\n      rpc GetAcl(GetAclRequest) returns (Acl) {\n        option (google.api.http).get = \"/v1/{resource=**}:getAcl\";\n      }\n    }\n\n    package google.storage.v2;\n    service Storage {\n      //       rpc GetAcl(GetAclRequest) returns (Acl);\n\n      // Get a data record.\n      rpc GetData(GetDataRequest) returns (Data) {\n        option (google.api.http).get = \"/v2/{resource=**}\";\n      }\n    }\n\nExample of a mixin configuration:\n\n    apis:\n    - name: google.storage.v2.Storage\n      mixins:\n      - name: google.acl.v1.AccessControl\n\nThe mixin construct implies that all methods in `AccessControl` are\nalso declared with same name and request/response types in\n`Storage`. A documentation generator or annotation processor will\nsee the effective `Storage.GetAcl` method after inherting\ndocumentation and annotations as follows:\n\n    service Storage {\n      // Get the underlying ACL object.\n      rpc GetAcl(GetAclRequest) returns (Acl) {\n        option (google.api.http).get = \"/v2/{resource=**}:getAcl\";\n      }\n      ...\n    }\n\nNote how the version in the path pattern changed from `v1` to `v2`.\n\nIf the `root` field in the mixin is specified, it should be a\nrelative path under which inherited HTTP paths are placed. Example:\n\n    apis:\n    - name: google.storage.v2.Storage\n      mixins:\n      - name: google.acl.v1.AccessControl\n        root: acls\n\nThis implies the following inherited HTTP annotation:\n\n    service Storage {\n      // Get the underlying ACL object.\n      rpc GetAcl(GetAclRequest) returns (Acl) {\n        option (google.api.http).get = \"/v2/acls/{resource=**}:getAcl\";\n      }\n      ...\n    }","type":"object","properties":{"name":{"description":"The fully qualified name of the interface which is included.","type":"string"},"root":{"description":"If non-empty specifies a path under which inherited HTTP paths\nare rooted.","type":"string"}},"id":"Mixin"},"CustomError":{"description":"Customize service error responses.  For example, list any service\nspecific protobuf types that can appear in error detail lists of\nerror responses.\n\nExample:\n\n    custom_error:\n      types:\n      - google.foo.v1.CustomError\n      - google.foo.v1.AnotherError","type":"object","properties":{"rules":{"type":"array","items":{"$ref":"CustomErrorRule"},"description":"The list of custom error rules that apply to individual API messages.\n\n**NOTE:** All service configuration rules follow \"last one wins\" order."},"types":{"description":"The list of custom error detail types, e.g. 'google.foo.v1.CustomError'.","type":"array","items":{"type":"string"}}},"id":"CustomError"},"Http":{"type":"object","properties":{"fullyDecodeReservedExpansion":{"description":"When set to true, URL path parameters will be fully URI-decoded except in\ncases of single segment matches in reserved expansion, where \"%2F\" will be\nleft encoded.\n\nThe default behavior is to not decode RFC 6570 reserved characters in multi\nsegment matches.","type":"boolean"},"rules":{"description":"A list of HTTP configuration rules that apply to individual API methods.\n\n**NOTE:** All service configuration rules follow \"last one wins\" order.","type":"array","items":{"$ref":"HttpRule"}}},"id":"Http","description":"Defines the HTTP configuration for an API service. It contains a list of\nHttpRule, each specifying the mapping of an RPC method\nto one or more HTTP REST API methods."},"SourceInfo":{"description":"Source information used to create a Service Config","type":"object","properties":{"sourceFiles":{"description":"All files used during config generation.","type":"array","items":{"additionalProperties":{"type":"any","description":"Properties of the object. Contains field @type with type URL."},"type":"object"}}},"id":"SourceInfo"},"Control":{"id":"Control","description":"Selects and configures the service controller used by the service.  The\nservice controller handles features like abuse, quota, billing, logging,\nmonitoring, etc.","type":"object","properties":{"environment":{"description":"The service control environment to use. If empty, no control plane\nfeature (like quota and billing) will be enabled.","type":"string"}}},"SystemParameter":{"type":"object","properties":{"httpHeader":{"description":"Define the HTTP header name to use for the parameter. It is case\ninsensitive.","type":"string"},"name":{"type":"string","description":"Define the name of the parameter, such as \"api_key\" . It is case sensitive."},"urlQueryParameter":{"description":"Define the URL query parameter name to use for the parameter. It is case\nsensitive.","type":"string"}},"id":"SystemParameter","description":"Define a parameter's name and location. The parameter may be passed as either\nan HTTP header or a URL query parameter, and if both are passed the behavior\nis implementation-dependent."},"Field":{"description":"A single field of a message type.","type":"object","properties":{"number":{"description":"The field number.","format":"int32","type":"integer"},"jsonName":{"description":"The field JSON name.","type":"string"},"kind":{"enumDescriptions":["Field type unknown.","Field type double.","Field type float.","Field type int64.","Field type uint64.","Field type int32.","Field type fixed64.","Field type fixed32.","Field type bool.","Field type string.","Field type group. Proto2 syntax only, and deprecated.","Field type message.","Field type bytes.","Field type uint32.","Field type enum.","Field type sfixed32.","Field type sfixed64.","Field type sint32.","Field type sint64."],"enum":["TYPE_UNKNOWN","TYPE_DOUBLE","TYPE_FLOAT","TYPE_INT64","TYPE_UINT64","TYPE_INT32","TYPE_FIXED64","TYPE_FIXED32","TYPE_BOOL","TYPE_STRING","TYPE_GROUP","TYPE_MESSAGE","TYPE_BYTES","TYPE_UINT32","TYPE_ENUM","TYPE_SFIXED32","TYPE_SFIXED64","TYPE_SINT32","TYPE_SINT64"],"description":"The field type.","type":"string"},"options":{"description":"The protocol buffer options.","type":"array","items":{"$ref":"Option"}},"oneofIndex":{"description":"The index of the field type in `Type.oneofs`, for message or enumeration\ntypes. The first type has index 1; zero means the type is not in the list.","format":"int32","type":"integer"},"cardinality":{"type":"string","enumDescriptions":["For fields with unknown cardinality.","For optional fields.","For required fields. Proto2 syntax only.","For repeated fields."],"enum":["CARDINALITY_UNKNOWN","CARDINALITY_OPTIONAL","CARDINALITY_REQUIRED","CARDINALITY_REPEATED"],"description":"The field cardinality."},"packed":{"type":"boolean","description":"Whether to use alternative packed wire representation."},"defaultValue":{"description":"The string value of the default value of this field. Proto2 syntax only.","type":"string"},"name":{"description":"The field name.","type":"string"},"typeUrl":{"description":"The field type URL, without the scheme, for message or enumeration\ntypes. Example: `\"type.googleapis.com/google.protobuf.Timestamp\"`.","type":"string"}},"id":"Field"},"Monitoring":{"description":"Monitoring configuration of the service.\n\nThe example below shows how to configure monitored resources and metrics\nfor monitoring. In the example, a monitored resource and two metrics are\ndefined. The `library.googleapis.com/book/returned_count` metric is sent\nto both producer and consumer projects, whereas the\n`library.googleapis.com/book/overdue_count` metric is only sent to the\nconsumer project.\n\n    monitored_resources:\n    - type: library.googleapis.com/branch\n      labels:\n      - key: /city\n        description: The city where the library branch is located in.\n      - key: /name\n        description: The name of the branch.\n    metrics:\n    - name: library.googleapis.com/book/returned_count\n      metric_kind: DELTA\n      value_type: INT64\n      labels:\n      - key: /customer_id\n    - name: library.googleapis.com/book/overdue_count\n      metric_kind: GAUGE\n      value_type: INT64\n      labels:\n      - key: /customer_id\n    monitoring:\n      producer_destinations:\n      - monitored_resource: library.googleapis.com/branch\n        metrics:\n        - library.googleapis.com/book/returned_count\n      consumer_destinations:\n      - monitored_resource: library.googleapis.com/branch\n        metrics:\n        - library.googleapis.com/book/returned_count\n        - library.googleapis.com/book/overdue_count","type":"object","properties":{"consumerDestinations":{"type":"array","items":{"$ref":"MonitoringDestination"},"description":"Monitoring configurations for sending metrics to the consumer project.\nThere can be multiple consumer destinations. A monitored resouce type may\nappear in multiple monitoring destinations if different aggregations are\nneeded for different sets of metrics associated with that monitored\nresource type. A monitored resource and metric pair may only be used once\nin the Monitoring configuration."},"producerDestinations":{"description":"Monitoring configurations for sending metrics to the producer project.\nThere can be multiple producer destinations. A monitored resouce type may\nappear in multiple monitoring destinations if different aggregations are\nneeded for different sets of metrics associated with that monitored\nresource type. A monitored resource and metric pair may only be used once\nin the Monitoring configuration.","type":"array","items":{"$ref":"MonitoringDestination"}}},"id":"Monitoring"},"Enum":{"description":"Enum type definition.","type":"object","properties":{"name":{"description":"Enum type name.","type":"string"},"enumvalue":{"description":"Enum value definitions.","type":"array","items":{"$ref":"EnumValue"}},"options":{"description":"Protocol buffer options.","type":"array","items":{"$ref":"Option"}},"sourceContext":{"$ref":"SourceContext","description":"The source context."},"syntax":{"enum":["SYNTAX_PROTO2","SYNTAX_PROTO3"],"description":"The source syntax.","type":"string","enumDescriptions":["Syntax `proto2`.","Syntax `proto3`."]}},"id":"Enum"},"LabelDescriptor":{"description":"A description of a label.","type":"object","properties":{"key":{"type":"string","description":"The label key."},"description":{"description":"A human-readable description for the label.","type":"string"},"valueType":{"type":"string","enumDescriptions":["A variable-length string. This is the default.","Boolean; true or false.","A 64-bit signed integer."],"enum":["STRING","BOOL","INT64"],"description":"The type of data that can be assigned to the label."}},"id":"LabelDescriptor"},"Type":{"description":"A protocol buffer message type.","type":"object","properties":{"fields":{"description":"The list of fields.","type":"array","items":{"$ref":"Field"}},"name":{"type":"string","description":"The fully qualified message name."},"oneofs":{"description":"The list of types appearing in `oneof` definitions in this type.","type":"array","items":{"type":"string"}},"sourceContext":{"description":"The source context.","$ref":"SourceContext"},"syntax":{"enum":["SYNTAX_PROTO2","SYNTAX_PROTO3"],"description":"The source syntax.","type":"string","enumDescriptions":["Syntax `proto2`.","Syntax `proto3`."]},"options":{"type":"array","items":{"$ref":"Option"},"description":"The protocol buffer options."}},"id":"Type"},"Backend":{"type":"object","properties":{"rules":{"description":"A list of API backend rules that apply to individual API methods.\n\n**NOTE:** All service configuration rules follow \"last one wins\" order.","type":"array","items":{"$ref":"BackendRule"}}},"id":"Backend","description":"`Backend` defines the backend configuration for a service."},"DocumentationRule":{"description":"A documentation rule provides information about individual API elements.","type":"object","properties":{"description":{"description":"Description of the selected API(s).","type":"string"},"deprecationDescription":{"description":"Deprecation description of the selected element(s). It can be provided if\nan element is marked as `deprecated`.","type":"string"},"selector":{"type":"string","description":"The selector is a comma-separated list of patterns. Each pattern is a\nqualified name of the element which may end in \"*\", indicating a wildcard.\nWildcards are only allowed at the end and for a whole component of the\nqualified name, i.e. \"foo.*\" is ok, but not \"foo.b*\" or \"foo.*.bar\". A\nwildcard will match one or more components. To specify a default for all\napplicable elements, the whole pattern \"*\" is used."}},"id":"DocumentationRule"},"ContextRule":{"id":"ContextRule","description":"A context rule provides information about the context for an individual API\nelement.","type":"object","properties":{"requested":{"type":"array","items":{"type":"string"},"description":"A list of full type names of requested contexts."},"allowedRequestExtensions":{"type":"array","items":{"type":"string"},"description":"A list of full type names or extension IDs of extensions allowed in grpc\nside channel from client to backend."},"allowedResponseExtensions":{"description":"A list of full type names or extension IDs of extensions allowed in grpc\nside channel from backend to client.","type":"array","items":{"type":"string"}},"selector":{"type":"string","description":"Selects the methods to which this rule applies.\n\nRefer to selector for syntax details."},"provided":{"description":"A list of full type names of provided contexts.","type":"array","items":{"type":"string"}}}},"Billing":{"description":"Billing related configuration of the service.\n\nThe following example shows how to configure monitored resources and metrics\nfor billing:\n\n    monitored_resources:\n    - type: library.googleapis.com/branch\n      labels:\n      - key: /city\n        description: The city where the library branch is located in.\n      - key: /name\n        description: The name of the branch.\n    metrics:\n    - name: library.googleapis.com/book/borrowed_count\n      metric_kind: DELTA\n      value_type: INT64\n    billing:\n      consumer_destinations:\n      - monitored_resource: library.googleapis.com/branch\n        metrics:\n        - library.googleapis.com/book/borrowed_count","type":"object","properties":{"consumerDestinations":{"description":"Billing configurations for sending metrics to the consumer project.\nThere can be multiple consumer destinations per service, each one must have\na different monitored resource type. A metric can be used in at most\none consumer destination.","type":"array","items":{"$ref":"BillingDestination"}}},"id":"Billing"},"MetricDescriptor":{"type":"object","properties":{"name":{"description":"The resource name of the metric descriptor.","type":"string"},"type":{"description":"The metric type, including its DNS name prefix. The type is not\nURL-encoded.  All user-defined metric types have the DNS name\n`custom.googleapis.com` or `external.googleapis.com`.  Metric types should\nuse a natural hierarchical grouping. For example:\n\n    \"custom.googleapis.com/invoice/paid/amount\"\n    \"external.googleapis.com/prometheus/up\"\n    \"appengine.googleapis.com/http/server/response_latencies\"","type":"string"},"metadata":{"$ref":"MetricDescriptorMetadata","description":"Optional. Metadata which can be used to guide usage of the metric."},"valueType":{"enum":["VALUE_TYPE_UNSPECIFIED","BOOL","INT64","DOUBLE","STRING","DISTRIBUTION","MONEY"],"description":"Whether the measurement is an integer, a floating-point number, etc.\nSome combinations of `metric_kind` and `value_type` might not be supported.","type":"string","enumDescriptions":["Do not use this default value.","The value is a boolean.\nThis value type can be used only if the metric kind is `GAUGE`.","The value is a signed 64-bit integer.","The value is a double precision floating point number.","The value is a text string.\nThis value type can be used only if the metric kind is `GAUGE`.","The value is a `Distribution`.","The value is money."]},"metricKind":{"type":"string","enumDescriptions":["Do not use this default value.","An instantaneous measurement of a value.","The change in a value during a time interval.","A value accumulated over a time interval.  Cumulative\nmeasurements in a time series should have the same start time\nand increasing end times, until an event resets the cumulative\nvalue to zero and sets a new start time for the following\npoints."],"enum":["METRIC_KIND_UNSPECIFIED","GAUGE","DELTA","CUMULATIVE"],"description":"Whether the metric records instantaneous values, changes to a value, etc.\nSome combinations of `metric_kind` and `value_type` might not be supported."},"description":{"description":"A detailed description of the metric, which can be used in documentation.","type":"string"},"displayName":{"description":"A concise name for the metric, which can be displayed in user interfaces.\nUse sentence case without an ending period, for example \"Request count\".\nThis field is optional but it is recommended to be set for any metrics\nassociated with user-visible concepts, such as Quota.","type":"string"},"unit":{"type":"string","description":"The unit in which the metric value is reported. It is only applicable\nif the `value_type` is `INT64`, `DOUBLE`, or `DISTRIBUTION`. The\nsupported units are a subset of [The Unified Code for Units of\nMeasure](http://unitsofmeasure.org/ucum.html) standard:\n\n**Basic units (UNIT)**\n\n* `bit`   bit\n* `By`    byte\n* `s`     second\n* `min`   minute\n* `h`     hour\n* `d`     day\n\n**Prefixes (PREFIX)**\n\n* `k`     kilo    (10**3)\n* `M`     mega    (10**6)\n* `G`     giga    (10**9)\n* `T`     tera    (10**12)\n* `P`     peta    (10**15)\n* `E`     exa     (10**18)\n* `Z`     zetta   (10**21)\n* `Y`     yotta   (10**24)\n* `m`     milli   (10**-3)\n* `u`     micro   (10**-6)\n* `n`     nano    (10**-9)\n* `p`     pico    (10**-12)\n* `f`     femto   (10**-15)\n* `a`     atto    (10**-18)\n* `z`     zepto   (10**-21)\n* `y`     yocto   (10**-24)\n* `Ki`    kibi    (2**10)\n* `Mi`    mebi    (2**20)\n* `Gi`    gibi    (2**30)\n* `Ti`    tebi    (2**40)\n\n**Grammar**\n\nThe grammar also includes these connectors:\n\n* `/`    division (as an infix operator, e.g. `1/s`).\n* `.`    multiplication (as an infix operator, e.g. `GBy.d`)\n\nThe grammar for a unit is as follows:\n\n    Expression = Component { \".\" Component } { \"/\" Component } ;\n\n    Component = ( [ PREFIX ] UNIT | \"%\" ) [ Annotation ]\n              | Annotation\n              | \"1\"\n              ;\n\n    Annotation = \"{\" NAME \"}\" ;\n\nNotes:\n\n* `Annotation` is just a comment if it follows a `UNIT` and is\n   equivalent to `1` if it is used alone. For examples,\n   `{requests}/s == 1/s`, `By{transmitted}/s == By/s`.\n* `NAME` is a sequence of non-blank printable ASCII characters not\n   containing '{' or '}'.\n* `1` represents dimensionless value 1, such as in `1/s`.\n* `%` represents dimensionless value 1/100, and annotates values giving\n   a percentage."},"launchStage":{"description":"Optional. The launch stage of the metric definition.","type":"string","enumDescriptions":["Do not use this default value.","Early Access features are limited to a closed group of testers. To use\nthese features, you must sign up in advance and sign a Trusted Tester\nagreement (which includes confidentiality provisions). These features may\nbe unstable, changed in backward-incompatible ways, and are not\nguaranteed to be released.","Alpha is a limited availability test for releases before they are cleared\nfor widespread use. By Alpha, all significant design issues are resolved\nand we are in the process of verifying functionality. Alpha customers\nneed to apply for access, agree to applicable terms, and have their\nprojects whitelisted. Alpha releases don’t have to be feature complete,\nno SLAs are provided, and there are no technical support obligations, but\nthey will be far enough along that customers can actually use them in\ntest environments or for limited-use tests -- just like they would in\nnormal production cases.","Beta is the point at which we are ready to open a release for any\ncustomer to use. There are no SLA or technical support obligations in a\nBeta release. Products will be complete from a feature perspective, but\nmay have some open outstanding issues. Beta releases are suitable for\nlimited production use cases.","GA features are open to all developers and are considered stable and\nfully qualified for production use.","Deprecated features are scheduled to be shut down and removed. For more\ninformation, see the “Deprecation Policy” section of our [Terms of\nService](https://cloud.google.com/terms/)\nand the [Google Cloud Platform Subject to the Deprecation\nPolicy](https://cloud.google.com/terms/deprecation) documentation."],"enum":["LAUNCH_STAGE_UNSPECIFIED","EARLY_ACCESS","ALPHA","BETA","GA","DEPRECATED"]},"labels":{"type":"array","items":{"$ref":"LabelDescriptor"},"description":"The set of labels that can be used to describe a specific\ninstance of this metric type. For example, the\n`appengine.googleapis.com/http/server/response_latencies` metric\ntype has a label for the HTTP response code, `response_code`, so\nyou can look at latencies for successful responses or just\nfor responses that failed."}},"id":"MetricDescriptor","description":"Defines a metric type and its schema. Once a metric descriptor is created,\ndeleting or altering it stops data collection and makes the metric type's\nexisting data unusable."},"SourceContext":{"description":"`SourceContext` represents information about the source of a\nprotobuf element, like the file in which it is defined.","type":"object","properties":{"fileName":{"type":"string","description":"The path-qualified name of the .proto file that contained the associated\nprotobuf element.  For example: `\"google/protobuf/source_context.proto\"`."}},"id":"SourceContext"},"Endpoint":{"description":"`Endpoint` describes a network endpoint that serves a set of APIs.\nA service may expose any number of endpoints, and all endpoints share the\nsame service configuration, such as quota configuration and monitoring\nconfiguration.\n\nExample service configuration:\n\n    name: library-example.googleapis.com\n    endpoints:\n      # Below entry makes 'google.example.library.v1.Library'\n      # API be served from endpoint address library-example.googleapis.com.\n      # It also allows HTTP OPTIONS calls to be passed to the backend, for\n      # it to decide whether the subsequent cross-origin request is\n      # allowed to proceed.\n    - name: library-example.googleapis.com\n      allow_cors: true","type":"object","properties":{"aliases":{"type":"array","items":{"type":"string"},"description":"DEPRECATED: This field is no longer supported. Instead of using aliases,\nplease specify multiple google.api.Endpoint for each of the intended\naliases.\n\nAdditional names that this endpoint will be hosted on."},"features":{"type":"array","items":{"type":"string"},"description":"The list of features enabled on this endpoint."},"allowCors":{"type":"boolean","description":"Allowing\n[CORS](https://en.wikipedia.org/wiki/Cross-origin_resource_sharing), aka\ncross-domain traffic, would allow the backends served from this endpoint to\nreceive and respond to HTTP OPTIONS requests. The response will be used by\nthe browser to determine whether the subsequent cross-origin request is\nallowed to proceed."},"name":{"description":"The canonical name of this endpoint.","type":"string"},"target":{"description":"The specification of an Internet routable address of API frontend that will\nhandle requests to this [API\nEndpoint](https://cloud.google.com/apis/design/glossary). It should be\neither a valid IPv4 address or a fully-qualified domain name. For example,\n\"8.8.8.8\" or \"myservice.appspot.com\".","type":"string"}},"id":"Endpoint"},"OAuthRequirements":{"type":"object","properties":{"canonicalScopes":{"description":"The list of publicly documented OAuth scopes that are allowed access. An\nOAuth token containing any of these scopes will be accepted.\n\nExample:\n\n     canonical_scopes: https://www.googleapis.com/auth/calendar,\n                       https://www.googleapis.com/auth/calendar.read","type":"string"}},"id":"OAuthRequirements","description":"OAuth scopes are a way to define data and permissions on data. For example,\nthere are scopes defined for \"Read-only access to Google Calendar\" and\n\"Access to Cloud Platform\". Users can consent to a scope for an application,\ngiving it permission to access that data on their behalf.\n\nOAuth scope specifications should be fairly coarse grained; a user will need\nto see and understand the text description of what your scope means.\n\nIn most cases: use one or at most two OAuth scopes for an entire family of\nproducts. If your product has multiple APIs, you should probably be sharing\nthe OAuth scope across all of those APIs.\n\nWhen you need finer grained OAuth consent screens: talk with your product\nmanagement about how developers will use them in practice.\n\nPlease note that even though each of the canonical scopes is enough for a\nrequest to be accepted and passed to the backend, a request can still fail\ndue to the backend requiring additional scopes or permissions."},"Usage":{"id":"Usage","description":"Configuration controlling usage of a service.","type":"object","properties":{"rules":{"description":"A list of usage rules that apply to individual API methods.\n\n**NOTE:** All service configuration rules follow \"last one wins\" order.","type":"array","items":{"$ref":"UsageRule"}},"requirements":{"description":"Requirements that must be satisfied before a consumer project can use the\nservice. Each requirement is of the form <service.name>/<requirement-id>;\nfor example 'serviceusage.googleapis.com/billing-enabled'.","type":"array","items":{"type":"string"}},"producerNotificationChannel":{"description":"The full resource name of a channel used for sending notifications to the\nservice producer.\n\nGoogle Service Management currently only supports\n[Google Cloud Pub/Sub](https://cloud.google.com/pubsub) as a notification\nchannel. To use Google Cloud Pub/Sub as the channel, this must be the name\nof a Cloud Pub/Sub topic that uses the Cloud Pub/Sub topic name format\ndocumented in https://cloud.google.com/pubsub/docs/overview.","type":"string"}}},"Context":{"id":"Context","description":"`Context` defines which contexts an API requests.\n\nExample:\n\n    context:\n      rules:\n      - selector: \"*\"\n        requested:\n        - google.rpc.context.ProjectContext\n        - google.rpc.context.OriginContext\n\nThe above specifies that all methods in the API request\n`google.rpc.context.ProjectContext` and\n`google.rpc.context.OriginContext`.\n\nAvailable context types are defined in package\n`google.rpc.context`.\n\nThis also provides mechanism to whitelist any protobuf message extension that\ncan be sent in grpc metadata using “x-goog-ext-<extension_id>-bin” and\n“x-goog-ext-<extension_id>-jspb” format. For example, list any service\nspecific protobuf types that can appear in grpc metadata as follows in your\nyaml file:\n\nExample:\n\n    context:\n      rules:\n       - selector: \"google.example.library.v1.LibraryService.CreateBook\"\n         allowed_request_extensions:\n         - google.foo.v1.NewExtension\n         allowed_response_extensions:\n         - google.foo.v1.NewExtension\n\nYou can also specify extension ID instead of fully qualified extension name\nhere.","type":"object","properties":{"rules":{"type":"array","items":{"$ref":"ContextRule"},"description":"A list of RPC context rules that apply to individual API methods.\n\n**NOTE:** All service configuration rules follow \"last one wins\" order."}}},"SearchRangeRequest":{"id":"SearchRangeRequest","description":"Request to search for an unused range within allocated ranges.","type":"object","properties":{"network":{"description":"Network name in the consumer project.   This network must have been\nalready peered with a shared VPC network using CreateConnection\nmethod.\nMust be in a form 'projects/{project}/global/networks/{network}'.\n{project} is a project number, as in '12345'\n{network} is network name.","type":"string"},"ipPrefixLength":{"type":"integer","description":"Required. The prefix length of the IP range.\nUse usual CIDR range notation.\nFor example, '30' to find unused x.x.x.x/30 CIDR range.\nActual range will be determined using allocated range for the consumer\npeered network and returned in the result.","format":"int32"}}},"AddSubnetworkRequest":{"description":"Request to create a subnetwork in a previously peered service network.","type":"object","properties":{"requestedAddress":{"description":"Optional. The starting address of a range. The address must be a valid\nIPv4 address in the x.x.x.x format. This value combined with the IP prefix\nrange is the CIDR range for the subnet. The range must be within the\nallocated range that is assigned to the private connection. If the CIDR\nrange isn't available, the call fails.","type":"string"},"subnetworkUsers":{"description":"A list of members that are granted the `compute.networkUser`\nrole on the subnet.","type":"array","items":{"type":"string"}},"consumer":{"description":"Required. A resource that represents the service consumer, such as\n`projects/123456`. The project number can be different from the\nvalue in the consumer network parameter. For example, the network might be\npart of a Shared VPC network. In those cases, Service Networking validates\nthat this resource belongs to that Shared VPC.","type":"string"},"region":{"description":"Required. The name of a [region](/compute/docs/regions-zones)\nfor the subnet, such `europe-west1`.","type":"string"},"ipPrefixLength":{"description":"Required. The prefix length of the subnet's IP address range.  Use CIDR\nrange notation, such as `30` to provision a subnet with an\n`x.x.x.x/30` CIDR range. The IP address range is drawn from a\npool of available ranges in the service consumer's allocated range.","format":"int32","type":"integer"},"subnetwork":{"description":"Required. A name for the new subnet. For information about the naming\nrequirements, see [subnetwork](/compute/docs/reference/rest/v1/subnetworks)\nin the Compute API documentation.","type":"string"},"consumerNetwork":{"description":"Required. The name of the service consumer's VPC network. The network\nmust have an existing private connection that was provisioned through the\nconnections.create method. The name must be in the following format:\n`projects/{project}/global/networks/{network}`, where {project}\nis a project number, such as `12345`. {network} is the name of a\nVPC network in the project.","type":"string"},"description":{"type":"string","description":"An optional description of the subnet."}},"id":"AddSubnetworkRequest"},"LogDescriptor":{"description":"A description of a log type. Example in YAML format:\n\n    - name: library.googleapis.com/activity_history\n      description: The history of borrowing and returning library items.\n      display_name: Activity\n      labels:\n      - key: /customer_id\n        description: Identifier of a library customer","type":"object","properties":{"name":{"type":"string","description":"The name of the log. It must be less than 512 characters long and can\ninclude the following characters: upper- and lower-case alphanumeric\ncharacters [A-Za-z0-9], and punctuation characters including\nslash, underscore, hyphen, period [/_-.]."},"description":{"description":"A human-readable description of this log. This information appears in\nthe documentation and can contain details.","type":"string"},"displayName":{"type":"string","description":"The human-readable name for this log. This information appears on\nthe user interface and should be concise."},"labels":{"type":"array","items":{"$ref":"LabelDescriptor"},"description":"The set of labels that are available to describe a specific log entry.\nRuntime requests that contain labels not specified here are\nconsidered invalid."}},"id":"LogDescriptor"},"MonitoredResourceDescriptor":{"description":"An object that describes the schema of a MonitoredResource object using a\ntype name and a set of labels.  For example, the monitored resource\ndescriptor for Google Compute Engine VM instances has a type of\n`\"gce_instance\"` and specifies the use of the labels `\"instance_id\"` and\n`\"zone\"` to identify particular VM instances.\n\nDifferent APIs can support different monitored resource types. APIs generally\nprovide a `list` method that returns the monitored resource descriptors used\nby the API.","type":"object","properties":{"name":{"description":"Optional. The resource name of the monitored resource descriptor:\n`\"projects/{project_id}/monitoredResourceDescriptors/{type}\"` where\n{type} is the value of the `type` field in this object and\n{project_id} is a project ID that provides API-specific context for\naccessing the type.  APIs that do not use project information can use the\nresource name format `\"monitoredResourceDescriptors/{type}\"`.","type":"string"},"type":{"description":"Required. The monitored resource type. For example, the type\n`\"cloudsql_database\"` represents databases in Google Cloud SQL.\nThe maximum length of this value is 256 characters.","type":"string"},"displayName":{"type":"string","description":"Optional. A concise name for the monitored resource type that might be\ndisplayed in user interfaces. It should be a Title Cased Noun Phrase,\nwithout any article or other determiners. For example,\n`\"Google Cloud SQL Database\"`."},"description":{"description":"Optional. A detailed description of the monitored resource type that might\nbe used in documentation.","type":"string"},"launchStage":{"enum":["LAUNCH_STAGE_UNSPECIFIED","EARLY_ACCESS","ALPHA","BETA","GA","DEPRECATED"],"description":"Optional. The launch stage of the monitored resource definition.","type":"string","enumDescriptions":["Do not use this default value.","Early Access features are limited to a closed group of testers. To use\nthese features, you must sign up in advance and sign a Trusted Tester\nagreement (which includes confidentiality provisions). These features may\nbe unstable, changed in backward-incompatible ways, and are not\nguaranteed to be released.","Alpha is a limited availability test for releases before they are cleared\nfor widespread use. By Alpha, all significant design issues are resolved\nand we are in the process of verifying functionality. Alpha customers\nneed to apply for access, agree to applicable terms, and have their\nprojects whitelisted. Alpha releases don’t have to be feature complete,\nno SLAs are provided, and there are no technical support obligations, but\nthey will be far enough along that customers can actually use them in\ntest environments or for limited-use tests -- just like they would in\nnormal production cases.","Beta is the point at which we are ready to open a release for any\ncustomer to use. There are no SLA or technical support obligations in a\nBeta release. Products will be complete from a feature perspective, but\nmay have some open outstanding issues. Beta releases are suitable for\nlimited production use cases.","GA features are open to all developers and are considered stable and\nfully qualified for production use.","Deprecated features are scheduled to be shut down and removed. For more\ninformation, see the “Deprecation Policy” section of our [Terms of\nService](https://cloud.google.com/terms/)\nand the [Google Cloud Platform Subject to the Deprecation\nPolicy](https://cloud.google.com/terms/deprecation) documentation."]},"labels":{"description":"Required. A set of labels used to describe instances of this monitored\nresource type. For example, an individual Google Cloud SQL database is\nidentified by values for the labels `\"database_id\"` and `\"zone\"`.","type":"array","items":{"$ref":"LabelDescriptor"}}},"id":"MonitoredResourceDescriptor"},"CustomErrorRule":{"type":"object","properties":{"isErrorType":{"description":"Mark this message as possible payload in error response.  Otherwise,\nobjects of this type will be filtered when they appear in error payload.","type":"boolean"},"selector":{"type":"string","description":"Selects messages to which this rule applies.\n\nRefer to selector for syntax details."}},"id":"CustomErrorRule","description":"A custom error rule."},"Connection":{"description":"Represents a private connection resource. A private connection is implemented\nas a VPC Network Peering connection between a service producer's VPC network\nand a service consumer's VPC network.","type":"object","properties":{"reservedPeeringRanges":{"description":"The name of one or more allocated IP address ranges for this service\nproducer of type `PEERING`.\nNote that invoking this method with a different range when connection is\nalready established will not modify already provisioned service\nproducer subnetworks.","type":"array","items":{"type":"string"}},"service":{"description":"Output only.\nThe name of the peering service that's associated with this connection, in\nthe following format: `services/{service name}`.","type":"string"},"network":{"description":"The name of service consumer's VPC network that's connected with service\nproducer network, in the following format:\n`projects/{project}/global/networks/{network}`.\n`{project}` is a project number, such as in `12345` that includes\nthe VPC service consumer's VPC network. `{network}` is the name of the\nservice consumer's VPC network.","type":"string"},"peering":{"description":"Output only.\nThe name of the VPC Network Peering connection that was created by the\nservice producer.","type":"string"}},"id":"Connection"},"BillingDestination":{"id":"BillingDestination","description":"Configuration of a specific billing destination (Currently only support\nbill against consumer project).","type":"object","properties":{"monitoredResource":{"type":"string","description":"The monitored resource type. The type must be defined in\nService.monitored_resources section."},"metrics":{"description":"Names of the metrics to report to this billing destination.\nEach name must be defined in Service.metrics section.","type":"array","items":{"type":"string"}}}},"UsageRule":{"description":"Usage configuration rules for the service.\n\nNOTE: Under development.\n\n\nUse this rule to configure unregistered calls for the service. Unregistered\ncalls are calls that do not contain consumer project identity.\n(Example: calls that do not contain an API key).\nBy default, API methods do not allow unregistered calls, and each method call\nmust be identified by a consumer project identity. Use this rule to\nallow/disallow unregistered calls.\n\nExample of an API that wants to allow unregistered calls for entire service.\n\n    usage:\n      rules:\n      - selector: \"*\"\n        allow_unregistered_calls: true\n\nExample of a method that wants to allow unregistered calls.\n\n    usage:\n      rules:\n      - selector: \"google.example.library.v1.LibraryService.CreateBook\"\n        allow_unregistered_calls: true","type":"object","properties":{"selector":{"description":"Selects the methods to which this rule applies. Use '*' to indicate all\nmethods in all APIs.\n\nRefer to selector for syntax details.","type":"string"},"skipServiceControl":{"type":"boolean","description":"If true, the selected method should skip service control and the control\nplane features, such as quota and billing, will not be available.\nThis flag is used by Google Cloud Endpoints to bypass checks for internal\nmethods, such as service health check methods."},"allowUnregisteredCalls":{"description":"If true, the selected method allows unregistered calls, e.g. calls\nthat don't identify any user or application.","type":"boolean"}},"id":"UsageRule"},"AuthRequirement":{"type":"object","properties":{"audiences":{"description":"NOTE: This will be deprecated soon, once AuthProvider.audiences is\nimplemented and accepted in all the runtime components.\n\nThe list of JWT\n[audiences](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.3).\nthat are allowed to access. A JWT containing any of these audiences will\nbe accepted. When this setting is absent, only JWTs with audience\n\"https://Service_name/API_name\"\nwill be accepted. For example, if no audiences are in the setting,\nLibraryService API will only accept JWTs with the following audience\n\"https://library-example.googleapis.com/google.example.library.v1.LibraryService\".\n\nExample:\n\n    audiences: bookstore_android.apps.googleusercontent.com,\n               bookstore_web.apps.googleusercontent.com","type":"string"},"providerId":{"description":"id from authentication provider.\n\nExample:\n\n    provider_id: bookstore_auth","type":"string"}},"id":"AuthRequirement","description":"User-defined authentication requirements, including support for\n[JSON Web Token\n(JWT)](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32)."},"Documentation":{"description":"`Documentation` provides the information for describing a service.\n\nExample:\n<pre><code>documentation:\n  summary: >\n    The Google Calendar API gives access\n    to most calendar features.\n  pages:\n  - name: Overview\n    content: &#40;== include google/foo/overview.md ==&#41;\n  - name: Tutorial\n    content: &#40;== include google/foo/tutorial.md ==&#41;\n    subpages;\n    - name: Java\n      content: &#40;== include google/foo/tutorial_java.md ==&#41;\n  rules:\n  - selector: google.calendar.Calendar.Get\n    description: >\n      ...\n  - selector: google.calendar.Calendar.Put\n    description: >\n      ...\n</code></pre>\nDocumentation is provided in markdown syntax. In addition to\nstandard markdown features, definition lists, tables and fenced\ncode blocks are supported. Section headers can be provided and are\ninterpreted relative to the section nesting of the context where\na documentation fragment is embedded.\n\nDocumentation from the IDL is merged with documentation defined\nvia the config at normalization time, where documentation provided\nby config rules overrides IDL provided.\n\nA number of constructs specific to the API platform are supported\nin documentation text.\n\nIn order to reference a proto element, the following\nnotation can be used:\n<pre><code>&#91;fully.qualified.proto.name]&#91;]</code></pre>\nTo override the display text used for the link, this can be used:\n<pre><code>&#91;display text]&#91;fully.qualified.proto.name]</code></pre>\nText can be excluded from doc using the following notation:\n<pre><code>&#40;-- internal comment --&#41;</code></pre>\n\nA few directives are available in documentation. Note that\ndirectives must appear on a single line to be properly\nidentified. The `include` directive includes a markdown file from\nan external source:\n<pre><code>&#40;== include path/to/file ==&#41;</code></pre>\nThe `resource_for` directive marks a message to be the resource of\na collection in REST view. If it is not specified, tools attempt\nto infer the resource from the operations in a collection:\n<pre><code>&#40;== resource_for v1.shelves.books ==&#41;</code></pre>\nThe directive `suppress_warning` does not directly affect documentation\nand is documented together with service config validation.","type":"object","properties":{"summary":{"description":"A short summary of what the service does. Can only be provided by\nplain text.","type":"string"},"documentationRootUrl":{"type":"string","description":"The URL to the root of documentation."},"rules":{"description":"A list of documentation rules that apply to individual API elements.\n\n**NOTE:** All service configuration rules follow \"last one wins\" order.","type":"array","items":{"$ref":"DocumentationRule"}},"overview":{"type":"string","description":"Declares a single overview page. For example:\n<pre><code>documentation:\n  summary: ...\n  overview: &#40;== include overview.md ==&#41;\n</code></pre>\nThis is a shortcut for the following declaration (using pages style):\n<pre><code>documentation:\n  summary: ...\n  pages:\n  - name: Overview\n    content: &#40;== include overview.md ==&#41;\n</code></pre>\nNote: you cannot specify both `overview` field and `pages` field."},"pages":{"type":"array","items":{"$ref":"Page"},"description":"The top level pages for the documentation set."}},"id":"Documentation"},"Subnetwork":{"type":"object","properties":{"ipCidrRange":{"description":"Subnetwork CIDR range in `10.x.x.x/y` format.","type":"string"},"outsideAllocation":{"description":"This is a discovered subnet that is not within the current consumer\nallocated ranges.","type":"boolean"},"name":{"type":"string","description":"Subnetwork name.\nSee https://cloud.google.com/compute/docs/vpc/"},"network":{"description":"In the Shared VPC host project, the VPC network that's peered with the\nconsumer network. For example:\n`projects/1234321/global/networks/host-network`","type":"string"}},"id":"Subnetwork","description":"Represents a subnet that was created or discovered by a private access\nmanagement service."},"AuthenticationRule":{"description":"Authentication rules for the service.\n\nBy default, if a method has any authentication requirements, every request\nmust include a valid credential matching one of the requirements.\nIt's an error to include more than one kind of credential in a single\nrequest.\n\nIf a method doesn't have any auth requirements, request credentials will be\nignored.","type":"object","properties":{"requirements":{"type":"array","items":{"$ref":"AuthRequirement"},"description":"Requirements for additional authentication providers."},"selector":{"description":"Selects the methods to which this rule applies.\n\nRefer to selector for syntax details.","type":"string"},"allowWithoutCredential":{"description":"If true, the service accepts API keys without any other credential.","type":"boolean"},"oauth":{"$ref":"OAuthRequirements","description":"The requirements for OAuth credentials."}},"id":"AuthenticationRule"},"BackendRule":{"type":"object","properties":{"deadline":{"description":"The number of seconds to wait for a response from a request.  The default\ndeadline for gRPC is infinite (no deadline) and HTTP requests is 5 seconds.","format":"double","type":"number"},"minDeadline":{"description":"Minimum deadline in seconds needed for this method. Calls having deadline\nvalue lower than this will be rejected.","format":"double","type":"number"},"pathTranslation":{"enum":["PATH_TRANSLATION_UNSPECIFIED","CONSTANT_ADDRESS","APPEND_PATH_TO_ADDRESS"],"type":"string","enumDescriptions":["","Use the backend address as-is, with no modification to the path. If the\nURL pattern contains variables, the variable names and values will be\nappended to the query string. If a query string parameter and a URL\npattern variable have the same name, this may result in duplicate keys in\nthe query string.\n\n# Examples\n\nGiven the following operation config:\n\n    Method path:        /api/company/{cid}/user/{uid}\n    Backend address:    https://example.cloudfunctions.net/getUser\n\nRequests to the following request paths will call the backend at the\ntranslated path:\n\n    Request path: /api/company/widgetworks/user/johndoe\n    Translated:\n    https://example.cloudfunctions.net/getUser?cid=widgetworks&uid=johndoe\n\n    Request path: /api/company/widgetworks/user/johndoe?timezone=EST\n    Translated:\n    https://example.cloudfunctions.net/getUser?timezone=EST&cid=widgetworks&uid=johndoe","The request path will be appended to the backend address.\n\n# Examples\n\nGiven the following operation config:\n\n    Method path:        /api/company/{cid}/user/{uid}\n    Backend address:    https://example.appspot.com\n\nRequests to the following request paths will call the backend at the\ntranslated path:\n\n    Request path: /api/company/widgetworks/user/johndoe\n    Translated:\n    https://example.appspot.com/api/company/widgetworks/user/johndoe\n\n    Request path: /api/company/widgetworks/user/johndoe?timezone=EST\n    Translated:\n    https://example.appspot.com/api/company/widgetworks/user/johndoe?timezone=EST"]},"address":{"description":"The address of the API backend.","type":"string"},"jwtAudience":{"description":"The JWT audience is used when generating a JWT id token for the backend.","type":"string"},"selector":{"description":"Selects the methods to which this rule applies.\n\nRefer to selector for syntax details.","type":"string"},"operationDeadline":{"type":"number","description":"The number of seconds to wait for the completion of a long running\noperation. The default is no deadline.","format":"double"}},"id":"BackendRule","description":"A backend rule provides configuration for an individual API element."},"Api":{"type":"object","properties":{"methods":{"description":"The methods of this interface, in unspecified order.","type":"array","items":{"$ref":"Method"}},"name":{"description":"The fully qualified name of this interface, including package name\nfollowed by the interface's simple name.","type":"string"},"sourceContext":{"description":"Source context for the protocol buffer service represented by this\nmessage.","$ref":"SourceContext"},"syntax":{"enum":["SYNTAX_PROTO2","SYNTAX_PROTO3"],"description":"The source syntax of the service.","type":"string","enumDescriptions":["Syntax `proto2`.","Syntax `proto3`."]},"version":{"type":"string","description":"A version string for this interface. If specified, must have the form\n`major-version.minor-version`, as in `1.10`. If the minor version is\nomitted, it defaults to zero. If the entire version field is empty, the\nmajor version is derived from the package name, as outlined below. If the\nfield is not empty, the version in the package name will be verified to be\nconsistent with what is provided here.\n\nThe versioning schema uses [semantic\nversioning](http://semver.org) where the major version number\nindicates a breaking change and the minor version an additive,\nnon-breaking change. Both version numbers are signals to users\nwhat to expect from different versions, and should be carefully\nchosen based on the product plan.\n\nThe major version is also reflected in the package name of the\ninterface, which must end in `v<major-version>`, as in\n`google.feature.v1`. For major versions 0 and 1, the suffix can\nbe omitted. Zero major versions must only be used for\nexperimental, non-GA interfaces.\n"},"mixins":{"description":"Included interfaces. See Mixin.","type":"array","items":{"$ref":"Mixin"}},"options":{"description":"Any metadata attached to the interface.","type":"array","items":{"$ref":"Option"}}},"id":"Api","description":"Api is a light-weight descriptor for an API Interface.\n\nInterfaces are also described as \"protocol buffer services\" in some contexts,\nsuch as by the \"service\" keyword in a .proto file, but they are different\nfrom API Services, which represent a concrete implementation of an interface\nas opposed to simply a description of methods and bindings. They are also\nsometimes simply referred to as \"APIs\" in other contexts, such as the name of\nthis message itself. See https://cloud.google.com/apis/design/glossary for\ndetailed terminology."},"MetricRule":{"id":"MetricRule","description":"Bind API methods to metrics. Binding a method to a metric causes that\nmetric's configured quota behaviors to apply to the method call.","type":"object","properties":{"selector":{"description":"Selects the methods to which this rule applies.\n\nRefer to selector for syntax details.","type":"string"},"metricCosts":{"additionalProperties":{"format":"int64","type":"string"},"description":"Metrics to update when the selected methods are called, and the associated\ncost applied to each metric.\n\nThe key of the map is the metric name, and the values are the amount\nincreased for the metric against which the quota limits are defined.\nThe value must not be negative.","type":"object"}}},"ListConnectionsResponse":{"description":"ListConnectionsResponse is the response to list peering states for the\ngiven service and consumer project.","type":"object","properties":{"connections":{"description":"The list of Connections.","type":"array","items":{"$ref":"Connection"}}},"id":"ListConnectionsResponse"},"Authentication":{"description":"`Authentication` defines the authentication configuration for an API.\n\nExample for an API targeted for external use:\n\n    name: calendar.googleapis.com\n    authentication:\n      providers:\n      - id: google_calendar_auth\n        jwks_uri: https://www.googleapis.com/oauth2/v1/certs\n        issuer: https://securetoken.google.com\n      rules:\n      - selector: \"*\"\n        requirements:\n          provider_id: google_calendar_auth","type":"object","properties":{"rules":{"description":"A list of authentication rules that apply to individual API methods.\n\n**NOTE:** All service configuration rules follow \"last one wins\" order.","type":"array","items":{"$ref":"AuthenticationRule"}},"providers":{"description":"Defines a set of authentication providers that a service supports.","type":"array","items":{"$ref":"AuthProvider"}}},"id":"Authentication"},"Operation":{"description":"This resource represents a long-running operation that is the result of a\nnetwork API call.","type":"object","properties":{"done":{"description":"If the value is `false`, it means the operation is still in progress.\nIf `true`, the operation is completed, and either `error` or `response` is\navailable.","type":"boolean"},"response":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"description":"The normal response of the operation in case of success.  If the original\nmethod returns no data on success, such as `Delete`, the response is\n`google.protobuf.Empty`.  If the original method is standard\n`Get`/`Create`/`Update`, the response should be the resource.  For other\nmethods, the response should have the type `XxxResponse`, where `Xxx`\nis the original method name.  For example, if the original method name\nis `TakeSnapshot()`, the inferred response type is\n`TakeSnapshotResponse`.","type":"object"},"name":{"type":"string","description":"The server-assigned name, which is only unique within the same service that\noriginally returns it. If you use the default HTTP mapping, the\n`name` should be a resource name ending with `operations/{unique_id}`."},"error":{"$ref":"Status","description":"The error result of the operation in case of failure or cancellation."},"metadata":{"additionalProperties":{"type":"any","description":"Properties of the object. Contains field @type with type URL."},"description":"Service-specific metadata associated with the operation.  It typically\ncontains progress information and common metadata such as create time.\nSome services might not provide such metadata.  Any method that returns a\nlong-running operation should document the metadata type, if any.","type":"object"}},"id":"Operation"},"Page":{"type":"object","properties":{"name":{"description":"The name of the page. It will be used as an identity of the page to\ngenerate URI of the page, text of the link to this page in navigation,\netc. The full page name (start from the root page name to this page\nconcatenated with `.`) can be used as reference to the page in your\ndocumentation. For example:\n<pre><code>pages:\n- name: Tutorial\n  content: &#40;== include tutorial.md ==&#41;\n  subpages:\n  - name: Java\n    content: &#40;== include tutorial_java.md ==&#41;\n</code></pre>\nYou can reference `Java` page using Markdown reference link syntax:\n`Java`.","type":"string"},"content":{"description":"The Markdown content of the page. You can use <code>&#40;== include {path}\n==&#41;</code> to include content from a Markdown file.","type":"string"},"subpages":{"description":"Subpages of this page. The order of subpages specified here will be\nhonored in the generated docset.","type":"array","items":{"$ref":"Page"}}},"id":"Page","description":"Represents a documentation page. A page can contain subpages to represent\nnested documentation set structure."},"Status":{"id":"Status","description":"The `Status` type defines a logical error model that is suitable for\ndifferent programming environments, including REST APIs and RPC APIs. It is\nused by [gRPC](https://github.com/grpc). Each `Status` message contains\nthree pieces of data: error code, error message, and error details.\n\nYou can find out more about this error model and how to work with it in the\n[API Design Guide](https://cloud.google.com/apis/design/errors).","type":"object","properties":{"code":{"description":"The status code, which should be an enum value of google.rpc.Code.","format":"int32","type":"integer"},"message":{"description":"A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.","type":"string"},"details":{"type":"array","items":{"additionalProperties":{"type":"any","description":"Properties of the object. Contains field @type with type URL."},"type":"object"},"description":"A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use."}}},"AuthProvider":{"description":"Configuration for an authentication provider, including support for\n[JSON Web Token\n(JWT)](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32).","type":"object","properties":{"id":{"description":"The unique identifier of the auth provider. It will be referred to by\n`AuthRequirement.provider_id`.\n\nExample: \"bookstore_auth\".","type":"string"},"issuer":{"type":"string","description":"Identifies the principal that issued the JWT. See\nhttps://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.1\nUsually a URL or an email address.\n\nExample: https://securetoken.google.com\nExample: 1234567-compute@developer.gserviceaccount.com"},"authorizationUrl":{"type":"string","description":"Redirect URL if JWT token is required but not present or is expired.\nImplement authorizationUrl of securityDefinitions in OpenAPI spec."},"jwksUri":{"description":"URL of the provider's public key set to validate signature of the JWT. See\n[OpenID\nDiscovery](https://openid.net/specs/openid-connect-discovery-1_0.html#ProviderMetadata).\nOptional if the key set document:\n - can be retrieved from\n   [OpenID\n   Discovery](https://openid.net/specs/openid-connect-discovery-1_0.html of\n   the issuer.\n - can be inferred from the email domain of the issuer (e.g. a Google\n service account).\n\nExample: https://www.googleapis.com/oauth2/v1/certs","type":"string"},"audiences":{"description":"The list of JWT\n[audiences](https://tools.ietf.org/html/draft-ietf-oauth-json-web-token-32#section-4.1.3).\nthat are allowed to access. A JWT containing any of these audiences will\nbe accepted. When this setting is absent, only JWTs with audience\n\"https://Service_name/API_name\"\nwill be accepted. For example, if no audiences are in the setting,\nLibraryService API will only accept JWTs with the following audience\n\"https://library-example.googleapis.com/google.example.library.v1.LibraryService\".\n\nExample:\n\n    audiences: bookstore_android.apps.googleusercontent.com,\n               bookstore_web.apps.googleusercontent.com","type":"string"}},"id":"AuthProvider"},"Range":{"type":"object","properties":{"ipCidrRange":{"type":"string","description":"CIDR range in \"10.x.x.x/y\" format that is within the\nallocated ranges and currently unused."},"network":{"description":"In the Shared VPC host project, the VPC network that's peered with the\nconsumer network. For example:\n`projects/1234321/global/networks/host-network`","type":"string"}},"id":"Range","description":"Represents a found unused range."},"EnumValue":{"type":"object","properties":{"name":{"description":"Enum value name.","type":"string"},"options":{"description":"Protocol buffer options.","type":"array","items":{"$ref":"Option"}},"number":{"type":"integer","description":"Enum value number.","format":"int32"}},"id":"EnumValue","description":"Enum value definition."},"Service":{"description":"`Service` is the root object of Google service configuration schema. It\ndescribes basic information about a service, such as the name and the\ntitle, and delegates other aspects to sub-sections. Each sub-section is\neither a proto message or a repeated proto message that configures a\nspecific aspect, such as auth. See each proto message definition for details.\n\nExample:\n\n    type: google.api.Service\n    config_version: 3\n    name: calendar.googleapis.com\n    title: Google Calendar API\n    apis:\n    - name: google.calendar.v3.Calendar\n    authentication:\n      providers:\n      - id: google_calendar_auth\n        jwks_uri: https://www.googleapis.com/oauth2/v1/certs\n        issuer: https://securetoken.google.com\n      rules:\n      - selector: \"*\"\n        requirements:\n          provider_id: google_calendar_auth","type":"object","properties":{"usage":{"$ref":"Usage","description":"Configuration controlling usage of this service."},"metrics":{"type":"array","items":{"$ref":"MetricDescriptor"},"description":"Defines the metrics used by this service."},"authentication":{"$ref":"Authentication","description":"Auth configuration."},"control":{"$ref":"Control","description":"Configuration for the service control plane."},"configVersion":{"description":"The semantic version of the service configuration. The config version\naffects the interpretation of the service configuration. For example,\ncertain features are enabled by default for certain config versions.\nThe latest config version is `3`.","format":"uint32","type":"integer"},"monitoring":{"$ref":"Monitoring","description":"Monitoring configuration."},"systemTypes":{"description":"A list of all proto message types included in this API service.\nIt serves similar purpose as [google.api.Service.types], except that\nthese types are not needed by user-defined APIs. Therefore, they will not\nshow up in the generated discovery doc. This field should only be used\nto define system APIs in ESF.","type":"array","items":{"$ref":"Type"}},"producerProjectId":{"description":"The Google project that owns this service.","type":"string"},"quota":{"description":"Quota configuration.","$ref":"Quota"},"billing":{"$ref":"Billing","description":"Billing configuration."},"name":{"description":"The service name, which is a DNS-like logical identifier for the\nservice, such as `calendar.googleapis.com`. The service name\ntypically goes through DNS verification to make sure the owner\nof the service also owns the DNS name.","type":"string"},"customError":{"description":"Custom error configuration.","$ref":"CustomError"},"title":{"description":"The product title for this service.","type":"string"},"endpoints":{"type":"array","items":{"$ref":"Endpoint"},"description":"Configuration for network endpoints.  If this is empty, then an endpoint\nwith the same name as the service is automatically generated to service all\ndefined APIs."},"logs":{"description":"Defines the logs used by this service.","type":"array","items":{"$ref":"LogDescriptor"}},"apis":{"type":"array","items":{"$ref":"Api"},"description":"A list of API interfaces exported by this service. Only the `name` field\nof the google.protobuf.Api needs to be provided by the configuration\nauthor, as the remaining fields will be derived from the IDL during the\nnormalization process. It is an error to specify an API interface here\nwhich cannot be resolved against the associated IDL files."},"types":{"description":"A list of all proto message types included in this API service.\nTypes referenced directly or indirectly by the `apis` are\nautomatically included.  Messages which are not referenced but\nshall be included, such as types used by the `google.protobuf.Any` type,\nshould be listed here by name. Example:\n\n    types:\n    - name: google.protobuf.Int32","type":"array","items":{"$ref":"Type"}},"sourceInfo":{"$ref":"SourceInfo","description":"Output only. The source information for this configuration if available."},"http":{"$ref":"Http","description":"HTTP configuration."},"systemParameters":{"description":"System parameter configuration.","$ref":"SystemParameters"},"backend":{"$ref":"Backend","description":"API backend configuration."},"documentation":{"$ref":"Documentation","description":"Additional API documentation."},"monitoredResources":{"description":"Defines the monitored resources used by this service. This is required\nby the Service.monitoring and Service.logging configurations.","type":"array","items":{"$ref":"MonitoredResourceDescriptor"}},"logging":{"description":"Logging configuration.","$ref":"Logging"},"enums":{"type":"array","items":{"$ref":"Enum"},"description":"A list of all enum types included in this API service.  Enums\nreferenced directly or indirectly by the `apis` are automatically\nincluded.  Enums which are not referenced but shall be included\nshould be listed here by name. Example:\n\n    enums:\n    - name: google.someapi.v1.SomeEnum"},"context":{"description":"Context configuration.","$ref":"Context"},"id":{"type":"string","description":"A unique ID for a specific instance of this message, typically assigned\nby the client for tracking purpose. If empty, the server may choose to\ngenerate one instead. Must be no longer than 60 characters."}},"id":"Service"},"CustomHttpPattern":{"description":"A custom pattern is used for defining custom HTTP verb.","type":"object","properties":{"path":{"description":"The path matched by this custom verb.","type":"string"},"kind":{"description":"The name of this custom HTTP verb.","type":"string"}},"id":"CustomHttpPattern"},"SystemParameterRule":{"description":"Define a system parameter rule mapping system parameter definitions to\nmethods.","type":"object","properties":{"selector":{"type":"string","description":"Selects the methods to which this rule applies. Use '*' to indicate all\nmethods in all APIs.\n\nRefer to selector for syntax details."},"parameters":{"type":"array","items":{"$ref":"SystemParameter"},"description":"Define parameters. Multiple names may be defined for a parameter.\nFor a given method call, only one of them should be used. If multiple\nnames are used the behavior is implementation-dependent.\nIf none of the specified names are present the behavior is\nparameter-dependent."}},"id":"SystemParameterRule"},"MetricDescriptorMetadata":{"type":"object","properties":{"ingestDelay":{"description":"The delay of data points caused by ingestion. Data points older than this\nage are guaranteed to be ingested and available to be read, excluding\ndata loss due to errors.","format":"google-duration","type":"string"},"launchStage":{"description":"Deprecated. Please use the MetricDescriptor.launch_stage instead.\nThe launch stage of the metric definition.","type":"string","enumDescriptions":["Do not use this default value.","Early Access features are limited to a closed group of testers. To use\nthese features, you must sign up in advance and sign a Trusted Tester\nagreement (which includes confidentiality provisions). These features may\nbe unstable, changed in backward-incompatible ways, and are not\nguaranteed to be released.","Alpha is a limited availability test for releases before they are cleared\nfor widespread use. By Alpha, all significant design issues are resolved\nand we are in the process of verifying functionality. Alpha customers\nneed to apply for access, agree to applicable terms, and have their\nprojects whitelisted. Alpha releases don’t have to be feature complete,\nno SLAs are provided, and there are no technical support obligations, but\nthey will be far enough along that customers can actually use them in\ntest environments or for limited-use tests -- just like they would in\nnormal production cases.","Beta is the point at which we are ready to open a release for any\ncustomer to use. There are no SLA or technical support obligations in a\nBeta release. Products will be complete from a feature perspective, but\nmay have some open outstanding issues. Beta releases are suitable for\nlimited production use cases.","GA features are open to all developers and are considered stable and\nfully qualified for production use.","Deprecated features are scheduled to be shut down and removed. For more\ninformation, see the “Deprecation Policy” section of our [Terms of\nService](https://cloud.google.com/terms/)\nand the [Google Cloud Platform Subject to the Deprecation\nPolicy](https://cloud.google.com/terms/deprecation) documentation."],"enum":["LAUNCH_STAGE_UNSPECIFIED","EARLY_ACCESS","ALPHA","BETA","GA","DEPRECATED"]},"samplePeriod":{"description":"The sampling period of metric data points. For metrics which are written\nperiodically, consecutive data points are stored at this time interval,\nexcluding data loss due to errors. Metrics with a higher granularity have\na smaller sampling period.","format":"google-duration","type":"string"}},"id":"MetricDescriptorMetadata","description":"Additional annotations that can be used to guide the usage of a metric."},"HttpRule":{"description":"# gRPC Transcoding\n\ngRPC Transcoding is a feature for mapping between a gRPC method and one or\nmore HTTP REST endpoints. It allows developers to build a single API service\nthat supports both gRPC APIs and REST APIs. Many systems, including [Google\nAPIs](https://github.com/googleapis/googleapis),\n[Cloud Endpoints](https://cloud.google.com/endpoints), [gRPC\nGateway](https://github.com/grpc-ecosystem/grpc-gateway),\nand [Envoy](https://github.com/envoyproxy/envoy) proxy support this feature\nand use it for large scale production services.\n\n`HttpRule` defines the schema of the gRPC/REST mapping. The mapping specifies\nhow different portions of the gRPC request message are mapped to the URL\npath, URL query parameters, and HTTP request body. It also controls how the\ngRPC response message is mapped to the HTTP response body. `HttpRule` is\ntypically specified as an `google.api.http` annotation on the gRPC method.\n\nEach mapping specifies a URL path template and an HTTP method. The path\ntemplate may refer to one or more fields in the gRPC request message, as long\nas each field is a non-repeated field with a primitive (non-message) type.\nThe path template controls how fields of the request message are mapped to\nthe URL path.\n\nExample:\n\n    service Messaging {\n      rpc GetMessage(GetMessageRequest) returns (Message) {\n        option (google.api.http) = {\n            get: \"/v1/{name=messages/*}\"\n        };\n      }\n    }\n    message GetMessageRequest {\n      string name = 1; // Mapped to URL path.\n    }\n    message Message {\n      string text = 1; // The resource content.\n    }\n\nThis enables an HTTP REST to gRPC mapping as below:\n\nHTTP | gRPC\n-----|-----\n`GET /v1/messages/123456`  | `GetMessage(name: \"messages/123456\")`\n\nAny fields in the request message which are not bound by the path template\nautomatically become HTTP query parameters if there is no HTTP request body.\nFor example:\n\n    service Messaging {\n      rpc GetMessage(GetMessageRequest) returns (Message) {\n        option (google.api.http) = {\n            get:\"/v1/messages/{message_id}\"\n        };\n      }\n    }\n    message GetMessageRequest {\n      message SubMessage {\n        string subfield = 1;\n      }\n      string message_id = 1; // Mapped to URL path.\n      int64 revision = 2;    // Mapped to URL query parameter `revision`.\n      SubMessage sub = 3;    // Mapped to URL query parameter `sub.subfield`.\n    }\n\nThis enables a HTTP JSON to RPC mapping as below:\n\nHTTP | gRPC\n-----|-----\n`GET /v1/messages/123456?revision=2&sub.subfield=foo` |\n`GetMessage(message_id: \"123456\" revision: 2 sub: SubMessage(subfield:\n\"foo\"))`\n\nNote that fields which are mapped to URL query parameters must have a\nprimitive type or a repeated primitive type or a non-repeated message type.\nIn the case of a repeated type, the parameter can be repeated in the URL\nas `...?param=A&param=B`. In the case of a message type, each field of the\nmessage is mapped to a separate parameter, such as\n`...?foo.a=A&foo.b=B&foo.c=C`.\n\nFor HTTP methods that allow a request body, the `body` field\nspecifies the mapping. Consider a REST update method on the\nmessage resource collection:\n\n    service Messaging {\n      rpc UpdateMessage(UpdateMessageRequest) returns (Message) {\n        option (google.api.http) = {\n          patch: \"/v1/messages/{message_id}\"\n          body: \"message\"\n        };\n      }\n    }\n    message UpdateMessageRequest {\n      string message_id = 1; // mapped to the URL\n      Message message = 2;   // mapped to the body\n    }\n\nThe following HTTP JSON to RPC mapping is enabled, where the\nrepresentation of the JSON in the request body is determined by\nprotos JSON encoding:\n\nHTTP | gRPC\n-----|-----\n`PATCH /v1/messages/123456 { \"text\": \"Hi!\" }` | `UpdateMessage(message_id:\n\"123456\" message { text: \"Hi!\" })`\n\nThe special name `*` can be used in the body mapping to define that\nevery field not bound by the path template should be mapped to the\nrequest body.  This enables the following alternative definition of\nthe update method:\n\n    service Messaging {\n      rpc UpdateMessage(Message) returns (Message) {\n        option (google.api.http) = {\n          patch: \"/v1/messages/{message_id}\"\n          body: \"*\"\n        };\n      }\n    }\n    message Message {\n      string message_id = 1;\n      string text = 2;\n    }\n\n\nThe following HTTP JSON to RPC mapping is enabled:\n\nHTTP | gRPC\n-----|-----\n`PATCH /v1/messages/123456 { \"text\": \"Hi!\" }` | `UpdateMessage(message_id:\n\"123456\" text: \"Hi!\")`\n\nNote that when using `*` in the body mapping, it is not possible to\nhave HTTP parameters, as all fields not bound by the path end in\nthe body. This makes this option more rarely used in practice when\ndefining REST APIs. The common usage of `*` is in custom methods\nwhich don't use the URL at all for transferring data.\n\nIt is possible to define multiple HTTP methods for one RPC by using\nthe `additional_bindings` option. Example:\n\n    service Messaging {\n      rpc GetMessage(GetMessageRequest) returns (Message) {\n        option (google.api.http) = {\n          get: \"/v1/messages/{message_id}\"\n          additional_bindings {\n            get: \"/v1/users/{user_id}/messages/{message_id}\"\n          }\n        };\n      }\n    }\n    message GetMessageRequest {\n      string message_id = 1;\n      string user_id = 2;\n    }\n\nThis enables the following two alternative HTTP JSON to RPC mappings:\n\nHTTP | gRPC\n-----|-----\n`GET /v1/messages/123456` | `GetMessage(message_id: \"123456\")`\n`GET /v1/users/me/messages/123456` | `GetMessage(user_id: \"me\" message_id:\n\"123456\")`\n\n## Rules for HTTP mapping\n\n1. Leaf request fields (recursive expansion nested messages in the request\n   message) are classified into three categories:\n   - Fields referred by the path template. They are passed via the URL path.\n   - Fields referred by the HttpRule.body. They are passed via the HTTP\n     request body.\n   - All other fields are passed via the URL query parameters, and the\n     parameter name is the field path in the request message. A repeated\n     field can be represented as multiple query parameters under the same\n     name.\n 2. If HttpRule.body is \"*\", there is no URL query parameter, all fields\n    are passed via URL path and HTTP request body.\n 3. If HttpRule.body is omitted, there is no HTTP request body, all\n    fields are passed via URL path and URL query parameters.\n\n### Path template syntax\n\n    Template = \"/\" Segments [ Verb ] ;\n    Segments = Segment { \"/\" Segment } ;\n    Segment  = \"*\" | \"**\" | LITERAL | Variable ;\n    Variable = \"{\" FieldPath [ \"=\" Segments ] \"}\" ;\n    FieldPath = IDENT { \".\" IDENT } ;\n    Verb     = \":\" LITERAL ;\n\nThe syntax `*` matches a single URL path segment. The syntax `**` matches\nzero or more URL path segments, which must be the last part of the URL path\nexcept the `Verb`.\n\nThe syntax `Variable` matches part of the URL path as specified by its\ntemplate. A variable template must not contain other variables. If a variable\nmatches a single path segment, its template may be omitted, e.g. `{var}`\nis equivalent to `{var=*}`.\n\nThe syntax `LITERAL` matches literal text in the URL path. If the `LITERAL`\ncontains any reserved character, such characters should be percent-encoded\nbefore the matching.\n\nIf a variable contains exactly one path segment, such as `\"{var}\"` or\n`\"{var=*}\"`, when such a variable is expanded into a URL path on the client\nside, all characters except `[-_.~0-9a-zA-Z]` are percent-encoded. The\nserver side does the reverse decoding. Such variables show up in the\n[Discovery\nDocument](https://developers.google.com/discovery/v1/reference/apis) as\n`{var}`.\n\nIf a variable contains multiple path segments, such as `\"{var=foo/*}\"`\nor `\"{var=**}\"`, when such a variable is expanded into a URL path on the\nclient side, all characters except `[-_.~/0-9a-zA-Z]` are percent-encoded.\nThe server side does the reverse decoding, except \"%2F\" and \"%2f\" are left\nunchanged. Such variables show up in the\n[Discovery\nDocument](https://developers.google.com/discovery/v1/reference/apis) as\n`{+var}`.\n\n## Using gRPC API Service Configuration\n\ngRPC API Service Configuration (service config) is a configuration language\nfor configuring a gRPC service to become a user-facing product. The\nservice config is simply the YAML representation of the `google.api.Service`\nproto message.\n\nAs an alternative to annotating your proto file, you can configure gRPC\ntranscoding in your service config YAML files. You do this by specifying a\n`HttpRule` that maps the gRPC method to a REST endpoint, achieving the same\neffect as the proto annotation. This can be particularly useful if you\nhave a proto that is reused in multiple services. Note that any transcoding\nspecified in the service config will override any matching transcoding\nconfiguration in the proto.\n\nExample:\n\n    http:\n      rules:\n        # Selects a gRPC method and applies HttpRule to it.\n        - selector: example.v1.Messaging.GetMessage\n          get: /v1/messages/{message_id}/{sub.subfield}\n\n## Special notes\n\nWhen gRPC Transcoding is used to map a gRPC to JSON REST endpoints, the\nproto to JSON conversion must follow the [proto3\nspecification](https://developers.google.com/protocol-buffers/docs/proto3#json).\n\nWhile the single segment variable follows the semantics of\n[RFC 6570](https://tools.ietf.org/html/rfc6570) Section 3.2.2 Simple String\nExpansion, the multi segment variable **does not** follow RFC 6570 Section\n3.2.3 Reserved Expansion. The reason is that the Reserved Expansion\ndoes not expand special characters like `?` and `#`, which would lead\nto invalid URLs. As the result, gRPC Transcoding uses a custom encoding\nfor multi segment variables.\n\nThe path variables **must not** refer to any repeated or mapped field,\nbecause client libraries are not capable of handling such variable expansion.\n\nThe path variables **must not** capture the leading \"/\" character. The reason\nis that the most common use case \"{var}\" does not capture the leading \"/\"\ncharacter. For consistency, all path variables must share the same behavior.\n\nRepeated message fields must not be mapped to URL query parameters, because\nno client library can support such complicated mapping.\n\nIf an API needs to use a JSON array for request or response body, it can map\nthe request or response body to a repeated field. However, some gRPC\nTranscoding implementations may not support this feature.","type":"object","properties":{"body":{"type":"string","description":"The name of the request field whose value is mapped to the HTTP request\nbody, or `*` for mapping all request fields not captured by the path\npattern to the HTTP body, or omitted for not having any HTTP request body.\n\nNOTE: the referred field must be present at the top-level of the request\nmessage type."},"selector":{"type":"string","description":"Selects a method to which this rule applies.\n\nRefer to selector for syntax details."},"custom":{"$ref":"CustomHttpPattern","description":"The custom pattern is used for specifying an HTTP method that is not\nincluded in the `pattern` field, such as HEAD, or \"*\" to leave the\nHTTP method unspecified for this rule. The wild-card rule is useful\nfor services that provide content to Web (HTML) clients."},"post":{"description":"Maps to HTTP POST. Used for creating a resource or performing an action.","type":"string"},"get":{"type":"string","description":"Maps to HTTP GET. Used for listing and getting information about\nresources."},"patch":{"type":"string","description":"Maps to HTTP PATCH. Used for updating a resource."},"put":{"description":"Maps to HTTP PUT. Used for replacing a resource.","type":"string"},"delete":{"type":"string","description":"Maps to HTTP DELETE. Used for deleting a resource."},"additionalBindings":{"description":"Additional HTTP bindings for the selector. Nested bindings must\nnot contain an `additional_bindings` field themselves (that is,\nthe nesting may only be one level deep).","type":"array","items":{"$ref":"HttpRule"}},"responseBody":{"type":"string","description":"Optional. The name of the response field whose value is mapped to the HTTP\nresponse body. When omitted, the entire response message will be used\nas the HTTP response body.\n\nNOTE: The referred field must be present at the top-level of the response\nmessage type."}},"id":"HttpRule"},"MonitoringDestination":{"description":"Configuration of a specific monitoring destination (the producer project\nor the consumer project).","type":"object","properties":{"monitoredResource":{"type":"string","description":"The monitored resource type. The type must be defined in\nService.monitored_resources section."},"metrics":{"description":"Types of the metrics to report to this monitoring destination.\nEach type must be defined in Service.metrics section.","type":"array","items":{"type":"string"}}},"id":"MonitoringDestination"}},"protocol":"rest","icons":{"x16":"http://www.google.com/images/icons/product/search-16.gif","x32":"http://www.google.com/images/icons/product/search-32.gif"},"canonicalName":"Service Networking","auth":{"oauth2":{"scopes":{"https://www.googleapis.com/auth/cloud-platform":{"description":"View and manage your data across Google Cloud Platform services"},"https://www.googleapis.com/auth/service.management":{"description":"Manage your Google API service configuration"}}}},"rootUrl":"https://servicenetworking.googleapis.com/","ownerDomain":"google.com","name":"servicenetworking","batchPath":"batch","fullyEncodeReservedExpansion":true,"title":"Service Networking API","ownerName":"Google","resources":{"operations":{"methods":{"get":{"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"parameters":{"name":{"required":true,"type":"string","pattern":"^operations/[^/]+$","location":"path","description":"The name of the operation resource."}},"flatPath":"v1beta/operations/{operationsId}","path":"v1beta/{+name}","id":"servicenetworking.operations.get","description":"Gets the latest state of a long-running operation.  Clients can use this\nmethod to poll the operation result at intervals as recommended by the API\nservice.","response":{"$ref":"Operation"},"parameterOrder":["name"],"httpMethod":"GET"}}},"services":{"methods":{"updateConnections":{"path":"v1beta/{+name}/connections","id":"servicenetworking.services.updateConnections","description":"Updates the allocated ranges that are assigned to a connection.\nThe response from the `get` operation will be of type `Connection` if the\noperation successfully completes.","request":{"$ref":"Connection"},"response":{"$ref":"Operation"},"parameterOrder":["name"],"httpMethod":"PATCH","parameters":{"name":{"location":"path","description":"The service producer peering service that is managing peering connectivity\nfor a service producer organization.\nFor Google services that support this functionality, this is\n`services/servicenetworking.googleapis.com`.","required":true,"type":"string","pattern":"^services/[^/]+$"},"updateMask":{"description":"The update mask. If this is omitted, it defaults to \"*\". You can only\nupdate the listed peering ranges.","format":"google-fieldmask","type":"string","location":"query"},"force":{"description":"If a previously defined allocated range is removed, force flag must be\nset to true.","type":"boolean","location":"query"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"flatPath":"v1beta/services/{servicesId}/connections"},"addSubnetwork":{"response":{"$ref":"Operation"},"parameterOrder":["parent"],"httpMethod":"POST","parameters":{"parent":{"location":"path","description":"Required. A tenant project in the service producer organization, in the\nfollowing format: services/{service}/{collection-id}/{resource-id}.\n{collection-id} is the cloud resource collection type that represents the\ntenant project. Only `projects` are supported.\n{resource-id} is the tenant project numeric id, such as\n`123456`. {service} the name of the peering service, such as\n`service-peering.example.com`. This service must already be\nenabled in the service consumer's project.","required":true,"type":"string","pattern":"^services/[^/]+/[^/]+/[^/]+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"flatPath":"v1beta/services/{servicesId}/{servicesId1}/{servicesId2}:addSubnetwork","path":"v1beta/{+parent}:addSubnetwork","id":"servicenetworking.services.addSubnetwork","description":"For service producers, provisions a new subnet in a\npeered service's shared VPC network in the requested region and with the\nrequested size that's expressed as a CIDR range (number of leading bits of\nipV4 network mask). The method checks against the assigned allocated ranges\nto find a non-conflicting IP address range. The method will reuse a subnet\nif subsequent calls contain the same subnet name, region, and prefix\nlength. This method will make producer's tenant project to be a shared VPC\nservice project as needed. The response from the `get` operation will be of\ntype `Subnetwork` if the operation successfully completes.","request":{"$ref":"AddSubnetworkRequest"}},"searchRange":{"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"parameters":{"parent":{"location":"path","description":"Required. This is in a form services/{service}.\n{service} the name of the private access management service, for example\n'service-peering.example.com'.","required":true,"type":"string","pattern":"^services/[^/]+$"}},"flatPath":"v1beta/services/{servicesId}:searchRange","path":"v1beta/{+parent}:searchRange","id":"servicenetworking.services.searchRange","request":{"$ref":"SearchRangeRequest"},"description":"Service producers can use this method to find a currently unused range\nwithin consumer allocated ranges.   This returned range is not reserved,\nand not guaranteed to remain unused.\nIt will validate previously provided allocated ranges, find\nnon-conflicting sub-range of requested size (expressed in\nnumber of leading bits of ipv4 network mask, as in CIDR range\nnotation).\nOperation<response: Range>","response":{"$ref":"Operation"},"parameterOrder":["parent"],"httpMethod":"POST"}},"resources":{"connections":{"methods":{"create":{"request":{"$ref":"Connection"},"description":"Creates a private connection that establishes a VPC Network Peering\nconnection to a VPC network in the service producer's organization.\nThe administrator of the service consumer's VPC network invokes this\nmethod. The administrator must assign one or more allocated IP ranges for\nprovisioning subnetworks in the service producer's VPC network. This\nconnection is used for all supported services in the service producer's\norganization, so it only needs to be invoked once. The response from the\n`get` operation will be of type `Connection` if the operation successfully\ncompletes.","response":{"$ref":"Operation"},"parameterOrder":["parent"],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"parameters":{"parent":{"pattern":"^services/[^/]+$","location":"path","description":"The service that is managing peering connectivity for a service producer's\norganization. For Google services that support this functionality, this\nvalue is `services/servicenetworking.googleapis.com`.","required":true,"type":"string"}},"flatPath":"v1beta/services/{servicesId}/connections","path":"v1beta/{+parent}/connections","id":"servicenetworking.services.connections.create"},"list":{"httpMethod":"GET","response":{"$ref":"ListConnectionsResponse"},"parameterOrder":["parent"],"parameters":{"network":{"type":"string","location":"query","description":"The name of service consumer's VPC network that's connected with service\nproducer network through a private connection. The network name must be in\nthe following format:\n`projects/{project}/global/networks/{network}`. {project} is a\nproject number, such as in `12345` that includes the VPC service\nconsumer's VPC network. {network} is the name of the service consumer's VPC\nnetwork."},"parent":{"pattern":"^services/[^/]+$","location":"path","description":"The service that is managing peering connectivity for a service producer's\norganization. For Google services that support this functionality, this\nvalue is `services/servicenetworking.googleapis.com`.\nIf you specify `-` as the parameter value, all configured public peering\nservices are listed.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform","https://www.googleapis.com/auth/service.management"],"flatPath":"v1beta/services/{servicesId}/connections","id":"servicenetworking.services.connections.list","path":"v1beta/{+parent}/connections","description":"List the private connections that are configured in a service consumer's\nVPC network."}}}}}},"parameters":{"alt":{"enum":["json","media","proto"],"type":"string","enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"],"location":"query","description":"Data format for response.","default":"json"},"key":{"location":"query","description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.","type":"string"},"access_token":{"location":"query","description":"OAuth access token.","type":"string"},"upload_protocol":{"type":"string","location":"query","description":"Upload protocol for media (e.g. \"raw\", \"multipart\")."},"quotaUser":{"location":"query","description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.","type":"string"},"prettyPrint":{"location":"query","description":"Returns response with indentations and line breaks.","type":"boolean","default":"true"},"uploadType":{"location":"query","description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\").","type":"string"},"fields":{"type":"string","location":"query","description":"Selector specifying which fields to include in a partial response."},"callback":{"description":"JSONP","type":"string","location":"query"},"oauth_token":{"description":"OAuth 2.0 token for the current user.","type":"string","location":"query"},"$.xgafv":{"enumDescriptions":["v1 error format","v2 error format"],"location":"query","enum":["1","2"],"description":"V1 error format.","type":"string"}},"version":"v1beta","baseUrl":"https://servicenetworking.googleapis.com/","servicePath":"","kind":"discovery#restDescription","description":"Provides automatic management of network configurations necessary for certain services.","basePath":"","revision":"20190625","documentationLink":"https://cloud.google.com/service-infrastructure/docs/service-networking/getting-started","id":"servicenetworking:v1beta","discoveryVersion":"v1"};