export default {"discoveryVersion":"v1","version_module":true,"schemas":{"HttpData":{"type":"object","properties":{"listUrl":{"description":"Required. The URL that points to the file that stores the object list\nentries. This file must allow public access.  Currently, only URLs with\nHTTP and HTTPS schemes are supported.","type":"string"}},"id":"HttpData","description":"An HttpData resource specifies a list of objects on the web to be transferred\nover HTTP.  The information of the objects to be transferred is contained in\na file referenced by a URL. The first line in the file must be\n\"TsvHttpData-1.0\", which specifies the format of the file.  Subsequent lines\nspecify the information of the list of objects, one object per list entry.\nEach entry has the following tab-delimited fields:\n\n* HTTP URL - The location of the object.\n\n* Length - The size of the object in bytes.\n\n* MD5 - The base64-encoded MD5 hash of the object.\n\nFor an example of a valid TSV file, see\n[Transferring data from\nURLs](https://cloud.google.com/storage/transfer/create-url-list).\n\nWhen transferring data based on a URL list, keep the following in mind:\n\n* When an object located at `http(s)://hostname:port/<URL-path>` is\ntransferred to a data sink, the name of the object at the data sink is\n`<hostname>/<URL-path>`.\n\n* If the specified size of an object does not match the actual size of the\nobject fetched, the object will not be transferred.\n\n* If the specified MD5 does not match the MD5 computed from the transferred\nbytes, the object transfer will fail. For more information, see\n[Generating MD5 hashes](https://cloud.google.com/storage/transfer/#md5)\n\n* Ensure that each URL you specify is publicly accessible. For\nexample, in Google Cloud Storage you can\n[share an object publicly]\n(https://cloud.google.com/storage/docs/cloud-console#_sharingdata) and get\na link to it.\n\n* Storage Transfer Service obeys `robots.txt` rules and requires the source\nHTTP server to support `Range` requests and to return a `Content-Length`\nheader in each response.\n\n* [ObjectConditions](#ObjectConditions) have no effect when filtering objects\nto transfer."},"GcsData":{"description":"In a GcsData resource, an object's name is the Google Cloud Storage object's\nname and its `lastModificationTime` refers to the object's updated time,\nwhich changes when the content or the metadata of the object is updated.","type":"object","properties":{"bucketName":{"description":"Required. Google Cloud Storage bucket name (see\n[Bucket Name\nRequirements](https://cloud.google.com/storage/docs/naming#requirements)).","type":"string"}},"id":"GcsData"},"ListTransferJobsResponse":{"description":"Response from ListTransferJobs.","type":"object","properties":{"nextPageToken":{"description":"The list next page token.","type":"string"},"transferJobs":{"description":"A list of transfer jobs.","type":"array","items":{"$ref":"TransferJob"}}},"id":"ListTransferJobsResponse"},"UpdateTransferJobRequest":{"id":"UpdateTransferJobRequest","description":"Request passed to UpdateTransferJob.","type":"object","properties":{"transferJob":{"$ref":"TransferJob","description":"Required. The job to update. `transferJob` is expected to specify only\nthree fields: `description`, `transferSpec`, and `status`.  An\nUpdateTransferJobRequest that specifies other fields will be rejected with\nan error `INVALID_ARGUMENT`."},"projectId":{"description":"Required. The ID of the Google Cloud Platform Console project that owns the\njob.","type":"string"},"updateTransferJobFieldMask":{"description":"The field mask of the fields in `transferJob` that are to be updated in\nthis request.  Fields in `transferJob` that can be updated are:\n`description`, `transferSpec`, and `status`.  To update the `transferSpec`\nof the job, a complete transfer specification has to be provided. An\nincomplete specification which misses any required fields will be rejected\nwith the error `INVALID_ARGUMENT`.","format":"google-fieldmask","type":"string"}}},"ObjectConditions":{"type":"object","properties":{"maxTimeElapsedSinceLastModification":{"description":"If specified, only objects with a `lastModificationTime` on or after\n`NOW` - `maxTimeElapsedSinceLastModification` and objects that don't have\na `lastModificationTime` are transferred.\n\nNote that, for each `TransferOperation` started by this `TransferJob`,\n`NOW` refers to the `start_time` of the 'TransferOperation`. Also,\n`lastModificationTime` refers to the time of the last change to the\nobject's content or metadata - specifically, this would be the `updated`\nproperty of GCS objects and the `LastModified` field of S3 objects.","format":"google-duration","type":"string"},"includePrefixes":{"description":"If `includePrefixes` is specified, objects that satisfy the object\nconditions must have names that start with one of the `includePrefixes`\nand that do not start with any of the `excludePrefixes`. If\n`includePrefixes` is not specified, all objects except those that have\nnames starting with one of the `excludePrefixes` must satisfy the object\nconditions.\n\nRequirements:\n\n  * Each include-prefix and exclude-prefix can contain any sequence of\n    Unicode characters, of max length 1024 bytes when UTF8-encoded, and\n    must not contain Carriage Return or Line Feed characters.  Wildcard\n    matching and regular expression matching are not supported.\n\n  * Each include-prefix and exclude-prefix must omit the leading slash.\n    For example, to include the `requests.gz` object in a transfer from\n    `s3://my-aws-bucket/logs/y=2015/requests.gz`, specify the include\n    prefix as `logs/y=2015/requests.gz`.\n\n  * None of the include-prefix or the exclude-prefix values can be empty,\n    if specified.\n\n  * Each include-prefix must include a distinct portion of the object\n    namespace, i.e., no include-prefix may be a prefix of another\n    include-prefix.\n\n  * Each exclude-prefix must exclude a distinct portion of the object\n    namespace, i.e., no exclude-prefix may be a prefix of another\n    exclude-prefix.\n\n  * If `includePrefixes` is specified, then each exclude-prefix must start\n    with the value of a path explicitly included by `includePrefixes`.\n\nThe max size of `includePrefixes` is 1000.","type":"array","items":{"type":"string"}},"minTimeElapsedSinceLastModification":{"description":"If specified, only objects with a `lastModificationTime` before\n`NOW` - `minTimeElapsedSinceLastModification` and objects that don't have a\n`lastModificationTime` are transferred.\n\nNote that, for each `TransferOperation` started by this `TransferJob`,\n`NOW` refers to the `start_time` of the 'TransferOperation`. Also,\n`lastModificationTime` refers to the time of the last change to the\nobject's content or metadata - specifically, this would be the `updated`\nproperty of GCS objects and the `LastModified` field of S3 objects.","format":"google-duration","type":"string"},"excludePrefixes":{"description":"`excludePrefixes` must follow the requirements described for\n`includePrefixes`.\n\nThe max size of `excludePrefixes` is 1000.","type":"array","items":{"type":"string"}}},"id":"ObjectConditions","description":"Conditions that determine which objects will be transferred. Applies only\nto S3 and GCS objects."},"Operation":{"description":"This resource represents a long-running operation that is the result of a\nnetwork API call.","type":"object","properties":{"name":{"type":"string","description":"The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the `name` should have the format of `transferOperations/some/unique/name`."},"error":{"$ref":"Status","description":"The error result of the operation in case of failure or cancellation."},"metadata":{"description":"Represents the transfer operation object.","type":"object","additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"}},"done":{"description":"If the value is `false`, it means the operation is still in progress.\nIf `true`, the operation is completed, and either `error` or `response` is\navailable.","type":"boolean"},"response":{"type":"object","additionalProperties":{"type":"any","description":"Properties of the object. Contains field @type with type URL."},"description":"The normal response of the operation in case of success.  If the original\nmethod returns no data on success, such as `Delete`, the response is\n`google.protobuf.Empty`.  If the original method is standard\n`Get`/`Create`/`Update`, the response should be the resource.  For other\nmethods, the response should have the type `XxxResponse`, where `Xxx`\nis the original method name.  For example, if the original method name\nis `TakeSnapshot()`, the inferred response type is\n`TakeSnapshotResponse`."}},"id":"Operation"},"TransferOptions":{"type":"object","properties":{"deleteObjectsUniqueInSink":{"description":"Whether objects that exist only in the sink should be deleted.  Note that\nthis option and `deleteObjectsFromSourceAfterTransfer` are mutually\nexclusive.","type":"boolean"},"overwriteObjectsAlreadyExistingInSink":{"type":"boolean","description":"Whether overwriting objects that already exist in the sink is allowed."},"deleteObjectsFromSourceAfterTransfer":{"description":"Whether objects should be deleted from the source after they are\ntransferred to the sink.  Note that this option and\n`deleteObjectsUniqueInSink` are mutually exclusive.","type":"boolean"}},"id":"TransferOptions","description":"TransferOptions uses three boolean parameters to define the actions\nto be performed on objects in a transfer."},"TransferSpec":{"id":"TransferSpec","description":"Configuration for running a transfer.","type":"object","properties":{"httpDataSource":{"$ref":"HttpData","description":"An HTTP URL data source."},"objectConditions":{"$ref":"ObjectConditions","description":"Only objects that satisfy these object conditions are included in the set\nof data source and data sink objects.  Object conditions based on\nobjects' `lastModificationTime` do not exclude objects in a data sink."},"gcsDataSink":{"$ref":"GcsData","description":"A Google Cloud Storage data sink."},"gcsDataSource":{"$ref":"GcsData","description":"A Google Cloud Storage data source."},"transferOptions":{"$ref":"TransferOptions","description":"If the option `deleteObjectsUniqueInSink` is `true`, object conditions\nbased on objects' `lastModificationTime` are ignored and do not exclude\nobjects in a data source or a data sink."},"awsS3DataSource":{"$ref":"AwsS3Data","description":"An AWS S3 data source."}}},"ResumeTransferOperationRequest":{"type":"object","properties":{},"id":"ResumeTransferOperationRequest","description":"Request passed to ResumeTransferOperation."},"Status":{"description":"The `Status` type defines a logical error model that is suitable for\ndifferent programming environments, including REST APIs and RPC APIs. It is\nused by [gRPC](https://github.com/grpc). Each `Status` message contains\nthree pieces of data: error code, error message, and error details.\n\nYou can find out more about this error model and how to work with it in the\n[API Design Guide](https://cloud.google.com/apis/design/errors).","type":"object","properties":{"message":{"description":"A developer-facing error message, which should be in English. Any\nuser-facing error message should be localized and sent in the\ngoogle.rpc.Status.details field, or localized by the client.","type":"string"},"details":{"description":"A list of messages that carry the error details.  There is a common set of\nmessage types for APIs to use.","type":"array","items":{"additionalProperties":{"description":"Properties of the object. Contains field @type with type URL.","type":"any"},"type":"object"}},"code":{"description":"The status code, which should be an enum value of google.rpc.Code.","format":"int32","type":"integer"}},"id":"Status"},"ListOperationsResponse":{"description":"The response message for Operations.ListOperations.","type":"object","properties":{"nextPageToken":{"description":"The standard List next-page token.","type":"string"},"operations":{"description":"A list of operations that matches the specified filter in the request.","type":"array","items":{"$ref":"Operation"}}},"id":"ListOperationsResponse"},"GoogleServiceAccount":{"type":"object","properties":{"accountEmail":{"description":"Email address of the service account.","type":"string"}},"id":"GoogleServiceAccount","description":"Google service account"},"TimeOfDay":{"description":"Represents a time of day. The date and time zone are either not significant\nor are specified elsewhere. An API may choose to allow leap seconds. Related\ntypes are google.type.Date and `google.protobuf.Timestamp`.","type":"object","properties":{"minutes":{"description":"Minutes of hour of day. Must be from 0 to 59.","format":"int32","type":"integer"},"hours":{"description":"Hours of day in 24 hour format. Should be from 0 to 23. An API may choose\nto allow the value \"24:00:00\" for scenarios like business closing time.","format":"int32","type":"integer"},"nanos":{"description":"Fractions of seconds in nanoseconds. Must be from 0 to 999,999,999.","format":"int32","type":"integer"},"seconds":{"description":"Seconds of minutes of the time. Must normally be from 0 to 59. An API may\nallow the value 60 if it allows leap-seconds.","format":"int32","type":"integer"}},"id":"TimeOfDay"},"ErrorLogEntry":{"description":"An entry describing an error that has occurred.","type":"object","properties":{"url":{"description":"Required. A URL that refers to the target (a data source, a data sink,\nor an object) with which the error is associated.","type":"string"},"errorDetails":{"description":"A list of messages that carry the error details.","type":"array","items":{"type":"string"}}},"id":"ErrorLogEntry"},"TransferJob":{"description":"This resource represents the configuration of a transfer job that runs\nperiodically.","type":"object","properties":{"projectId":{"description":"The ID of the Google Cloud Platform Project that owns the job.","type":"string"},"lastModificationTime":{"description":"Output only. The time that the transfer job was last modified.","format":"google-datetime","type":"string"},"description":{"type":"string","description":"A description provided by the user for the job. Its max length is 1024\nbytes when Unicode-encoded."},"creationTime":{"description":"Output only. The time that the transfer job was created.","format":"google-datetime","type":"string"},"transferSpec":{"$ref":"TransferSpec","description":"Transfer specification."},"status":{"enumDescriptions":["Zero is an illegal value.","New transfers will be performed based on the schedule.","New transfers will not be scheduled.","This is a soft delete state. After a transfer job is set to this\nstate, the job and all the transfer executions are subject to\ngarbage collection. Transfer jobs become eligible for garbage collection\n30 days after their status is set to `DELETED`."],"enum":["STATUS_UNSPECIFIED","ENABLED","DISABLED","DELETED"],"description":"Status of the job. This value MUST be specified for\n`CreateTransferJobRequests`.\n\nNOTE: The effect of the new job status takes place during a subsequent job\nrun. For example, if you change the job status from `ENABLED` to\n`DISABLED`, and an operation spawned by the transfer is running, the status\nchange would not affect the current operation.","type":"string"},"schedule":{"description":"Schedule specification.","$ref":"Schedule"},"name":{"description":"A globally unique name assigned by Storage Transfer Service when the\njob is created. This field should be left empty in requests to create a new\ntransfer job; otherwise, the requests result in an `INVALID_ARGUMENT`\nerror.","type":"string"},"deletionTime":{"description":"Output only. The time that the transfer job was deleted.","format":"google-datetime","type":"string"}},"id":"TransferJob"},"Schedule":{"id":"Schedule","description":"Transfers can be scheduled to recur or to run just once.","type":"object","properties":{"scheduleStartDate":{"$ref":"Date","description":"Required. The first day the recurring transfer is scheduled to run. If\n`scheduleStartDate` is in the past, the transfer will run for the first\ntime on the following day."},"scheduleEndDate":{"description":"The last day the recurring transfer will be run. If `scheduleEndDate`\nis the same as `scheduleStartDate`, the transfer will be executed only\nonce.","$ref":"Date"},"startTimeOfDay":{"$ref":"TimeOfDay","description":"The time in UTC at which the transfer will be scheduled to start in a day.\nTransfers may start later than this time. If not specified, recurring and\none-time transfers that are scheduled to run today will run immediately;\nrecurring transfers that are scheduled to run on a future date will start\nat approximately midnight UTC on that date. Note that when configuring a\ntransfer with the Cloud Platform Console, the transfer's start time in a\nday is specified in your local timezone."}}},"Date":{"id":"Date","description":"Represents a whole or partial calendar date, e.g. a birthday. The time of day\nand time zone are either specified elsewhere or are not significant. The date\nis relative to the Proleptic Gregorian Calendar. This can represent:\n\n* A full date, with non-zero year, month and day values\n* A month and day value, with a zero year, e.g. an anniversary\n* A year on its own, with zero month and day values\n* A year and month value, with a zero day, e.g. a credit card expiration date\n\nRelated types are google.type.TimeOfDay and `google.protobuf.Timestamp`.","type":"object","properties":{"year":{"type":"integer","description":"Year of date. Must be from 1 to 9999, or 0 if specifying a date without\na year.","format":"int32"},"day":{"description":"Day of month. Must be from 1 to 31 and valid for the year and month, or 0\nif specifying a year by itself or a year and month where the day is not\nsignificant.","format":"int32","type":"integer"},"month":{"type":"integer","description":"Month of year. Must be from 1 to 12, or 0 if specifying a year without a\nmonth and day.","format":"int32"}}},"TransferOperation":{"id":"TransferOperation","description":"A description of the execution of a transfer.","type":"object","properties":{"name":{"description":"A globally unique ID assigned by the system.","type":"string"},"projectId":{"type":"string","description":"The ID of the Google Cloud Platform Project that owns the operation."},"endTime":{"description":"End time of this transfer execution.","format":"google-datetime","type":"string"},"startTime":{"description":"Start time of this transfer execution.","format":"google-datetime","type":"string"},"transferJobName":{"description":"The name of the transfer job that triggers this transfer operation.","type":"string"},"transferSpec":{"$ref":"TransferSpec","description":"Transfer specification."},"status":{"type":"string","enumDescriptions":["Zero is an illegal value.","In progress.","Paused.","Completed successfully.","Terminated due to an unrecoverable failure.","Aborted by the user."],"enum":["STATUS_UNSPECIFIED","IN_PROGRESS","PAUSED","SUCCESS","FAILED","ABORTED"],"description":"Status of the transfer operation."},"counters":{"$ref":"TransferCounters","description":"Information about the progress of the transfer operation."},"errorBreakdowns":{"description":"Summarizes errors encountered with sample error log entries.","type":"array","items":{"$ref":"ErrorSummary"}}}},"AwsS3Data":{"id":"AwsS3Data","description":"An AwsS3Data resource can be a data source, but not a data sink.\nIn an AwsS3Data resource, an object's name is the S3 object's key name.","type":"object","properties":{"bucketName":{"description":"Required. S3 Bucket name (see\n[Creating a\nbucket](http://docs.aws.amazon.com/AmazonS3/latest/dev/create-bucket-get-location-example.html)).","type":"string"},"awsAccessKey":{"$ref":"AwsAccessKey","description":"Required. AWS access key used to sign the API requests to the AWS S3\nbucket. Permissions on the bucket must be granted to the access ID of the\nAWS access key."}}},"Empty":{"description":"A generic empty message that you can re-use to avoid defining duplicated\nempty messages in your APIs. A typical example is to use it as the request\nor the response type of an API method. For instance:\n\n    service Foo {\n      rpc Bar(google.protobuf.Empty) returns (google.protobuf.Empty);\n    }\n\nThe JSON representation for `Empty` is empty JSON object `{}`.","type":"object","properties":{},"id":"Empty"},"AwsAccessKey":{"id":"AwsAccessKey","description":"AWS access key (see\n[AWS Security\nCredentials](http://docs.aws.amazon.com/general/latest/gr/aws-security-credentials.html)).","type":"object","properties":{"accessKeyId":{"description":"Required. AWS access key ID.","type":"string"},"secretAccessKey":{"type":"string","description":"Required. AWS secret access key. This field is not returned in RPC\nresponses."}}},"PauseTransferOperationRequest":{"id":"PauseTransferOperationRequest","description":"Request passed to PauseTransferOperation.","type":"object","properties":{}},"TransferCounters":{"description":"A collection of counters that report the progress of a transfer operation.","type":"object","properties":{"objectsFoundFromSource":{"description":"Objects found in the data source that are scheduled to be transferred,\nexcluding any that are filtered based on object conditions or skipped due\nto sync.","format":"int64","type":"string"},"bytesDeletedFromSource":{"description":"Bytes that are deleted from the data source.","format":"int64","type":"string"},"objectsFailedToDeleteFromSink":{"type":"string","description":"Objects that failed to be deleted from the data sink.","format":"int64"},"objectsDeletedFromSink":{"description":"Objects that are deleted from the data sink.","format":"int64","type":"string"},"objectsFoundOnlyFromSink":{"description":"Objects found only in the data sink that are scheduled to be deleted.","format":"int64","type":"string"},"bytesFromSourceSkippedBySync":{"description":"Bytes in the data source that are not transferred because they already\nexist in the data sink.","format":"int64","type":"string"},"bytesDeletedFromSink":{"description":"Bytes that are deleted from the data sink.","format":"int64","type":"string"},"bytesFailedToDeleteFromSink":{"description":"Bytes that failed to be deleted from the data sink.","format":"int64","type":"string"},"bytesFromSourceFailed":{"description":"Bytes in the data source that failed to be transferred or that failed to\nbe deleted after being transferred.","format":"int64","type":"string"},"objectsCopiedToSink":{"type":"string","description":"Objects that are copied to the data sink.","format":"int64"},"objectsFromSourceFailed":{"description":"Objects in the data source that failed to be transferred or that failed\nto be deleted after being transferred.","format":"int64","type":"string"},"bytesFoundOnlyFromSink":{"description":"Bytes found only in the data sink that are scheduled to be deleted.","format":"int64","type":"string"},"objectsDeletedFromSource":{"description":"Objects that are deleted from the data source.","format":"int64","type":"string"},"bytesCopiedToSink":{"description":"Bytes that are copied to the data sink.","format":"int64","type":"string"},"objectsFromSourceSkippedBySync":{"type":"string","description":"Objects in the data source that are not transferred because they already\nexist in the data sink.","format":"int64"},"bytesFoundFromSource":{"type":"string","description":"Bytes found in the data source that are scheduled to be transferred,\nexcluding any that are filtered based on object conditions or skipped due\nto sync.","format":"int64"}},"id":"TransferCounters"},"ErrorSummary":{"id":"ErrorSummary","description":"A summary of errors by error code, plus a count and sample error log\nentries.","type":"object","properties":{"errorCode":{"enum":["OK","CANCELLED","UNKNOWN","INVALID_ARGUMENT","DEADLINE_EXCEEDED","NOT_FOUND","ALREADY_EXISTS","PERMISSION_DENIED","UNAUTHENTICATED","RESOURCE_EXHAUSTED","FAILED_PRECONDITION","ABORTED","OUT_OF_RANGE","UNIMPLEMENTED","INTERNAL","UNAVAILABLE","DATA_LOSS"],"description":"Required.","type":"string","enumDescriptions":["Not an error; returned on success\n\nHTTP Mapping: 200 OK","The operation was cancelled, typically by the caller.\n\nHTTP Mapping: 499 Client Closed Request","Unknown error.  For example, this error may be returned when\na `Status` value received from another address space belongs to\nan error space that is not known in this address space.  Also\nerrors raised by APIs that do not return enough error information\nmay be converted to this error.\n\nHTTP Mapping: 500 Internal Server Error","The client specified an invalid argument.  Note that this differs\nfrom `FAILED_PRECONDITION`.  `INVALID_ARGUMENT` indicates arguments\nthat are problematic regardless of the state of the system\n(e.g., a malformed file name).\n\nHTTP Mapping: 400 Bad Request","The deadline expired before the operation could complete. For operations\nthat change the state of the system, this error may be returned\neven if the operation has completed successfully.  For example, a\nsuccessful response from a server could have been delayed long\nenough for the deadline to expire.\n\nHTTP Mapping: 504 Gateway Timeout","Some requested entity (e.g., file or directory) was not found.\n\nNote to server developers: if a request is denied for an entire class\nof users, such as gradual feature rollout or undocumented whitelist,\n`NOT_FOUND` may be used. If a request is denied for some users within\na class of users, such as user-based access control, `PERMISSION_DENIED`\nmust be used.\n\nHTTP Mapping: 404 Not Found","The entity that a client attempted to create (e.g., file or directory)\nalready exists.\n\nHTTP Mapping: 409 Conflict","The caller does not have permission to execute the specified\noperation. `PERMISSION_DENIED` must not be used for rejections\ncaused by exhausting some resource (use `RESOURCE_EXHAUSTED`\ninstead for those errors). `PERMISSION_DENIED` must not be\nused if the caller can not be identified (use `UNAUTHENTICATED`\ninstead for those errors). This error code does not imply the\nrequest is valid or the requested entity exists or satisfies\nother pre-conditions.\n\nHTTP Mapping: 403 Forbidden","The request does not have valid authentication credentials for the\noperation.\n\nHTTP Mapping: 401 Unauthorized","Some resource has been exhausted, perhaps a per-user quota, or\nperhaps the entire file system is out of space.\n\nHTTP Mapping: 429 Too Many Requests","The operation was rejected because the system is not in a state\nrequired for the operation's execution.  For example, the directory\nto be deleted is non-empty, an rmdir operation is applied to\na non-directory, etc.\n\nService implementors can use the following guidelines to decide\nbetween `FAILED_PRECONDITION`, `ABORTED`, and `UNAVAILABLE`:\n (a) Use `UNAVAILABLE` if the client can retry just the failing call.\n (b) Use `ABORTED` if the client should retry at a higher level\n     (e.g., when a client-specified test-and-set fails, indicating the\n     client should restart a read-modify-write sequence).\n (c) Use `FAILED_PRECONDITION` if the client should not retry until\n     the system state has been explicitly fixed.  E.g., if an \"rmdir\"\n     fails because the directory is non-empty, `FAILED_PRECONDITION`\n     should be returned since the client should not retry unless\n     the files are deleted from the directory.\n\nHTTP Mapping: 400 Bad Request","The operation was aborted, typically due to a concurrency issue such as\na sequencer check failure or transaction abort.\n\nSee the guidelines above for deciding between `FAILED_PRECONDITION`,\n`ABORTED`, and `UNAVAILABLE`.\n\nHTTP Mapping: 409 Conflict","The operation was attempted past the valid range.  E.g., seeking or\nreading past end-of-file.\n\nUnlike `INVALID_ARGUMENT`, this error indicates a problem that may\nbe fixed if the system state changes. For example, a 32-bit file\nsystem will generate `INVALID_ARGUMENT` if asked to read at an\noffset that is not in the range [0,2^32-1], but it will generate\n`OUT_OF_RANGE` if asked to read from an offset past the current\nfile size.\n\nThere is a fair bit of overlap between `FAILED_PRECONDITION` and\n`OUT_OF_RANGE`.  We recommend using `OUT_OF_RANGE` (the more specific\nerror) when it applies so that callers who are iterating through\na space can easily look for an `OUT_OF_RANGE` error to detect when\nthey are done.\n\nHTTP Mapping: 400 Bad Request","The operation is not implemented or is not supported/enabled in this\nservice.\n\nHTTP Mapping: 501 Not Implemented","Internal errors.  This means that some invariants expected by the\nunderlying system have been broken.  This error code is reserved\nfor serious errors.\n\nHTTP Mapping: 500 Internal Server Error","The service is currently unavailable.  This is most likely a\ntransient condition, which can be corrected by retrying with\na backoff. Note that it is not always safe to retry\nnon-idempotent operations.\n\nSee the guidelines above for deciding between `FAILED_PRECONDITION`,\n`ABORTED`, and `UNAVAILABLE`.\n\nHTTP Mapping: 503 Service Unavailable","Unrecoverable data loss or corruption.\n\nHTTP Mapping: 500 Internal Server Error"]},"errorCount":{"type":"string","description":"Required. Count of this type of error.","format":"int64"},"errorLogEntries":{"description":"Error samples.\n\nNo more than 100 error log entries may be recorded for a given\nerror code for a single task.","type":"array","items":{"$ref":"ErrorLogEntry"}}}}},"icons":{"x16":"http://www.google.com/images/icons/product/search-16.gif","x32":"http://www.google.com/images/icons/product/search-32.gif"},"protocol":"rest","auth":{"oauth2":{"scopes":{"https://www.googleapis.com/auth/cloud-platform":{"description":"View and manage your data across Google Cloud Platform services"}}}},"rootUrl":"https://storagetransfer.googleapis.com/","ownerDomain":"google.com","name":"storagetransfer","batchPath":"batch","fullyEncodeReservedExpansion":true,"title":"Storage Transfer API","ownerName":"Google","resources":{"googleServiceAccounts":{"methods":{"get":{"flatPath":"v1/googleServiceAccounts/{projectId}","id":"storagetransfer.googleServiceAccounts.get","path":"v1/googleServiceAccounts/{projectId}","description":"Returns the Google service account that is used by Storage Transfer\nService to access buckets in the project where transfers\nrun or in other projects. Each Google service account is associated\nwith one Google Cloud Platform Console project. Users\nshould add this service account to the Google Cloud Storage bucket\nACLs to grant access to Storage Transfer Service. This service\naccount is created and owned by Storage Transfer Service and can\nonly be used by Storage Transfer Service.","httpMethod":"GET","parameterOrder":["projectId"],"response":{"$ref":"GoogleServiceAccount"},"parameters":{"projectId":{"location":"path","description":"Required. The ID of the Google Cloud Platform Console project that the\nGoogle service account is associated with.","required":true,"type":"string"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"]}}},"transferJobs":{"methods":{"create":{"path":"v1/transferJobs","id":"storagetransfer.transferJobs.create","request":{"$ref":"TransferJob"},"description":"Creates a transfer job that runs periodically.","response":{"$ref":"TransferJob"},"parameterOrder":[],"httpMethod":"POST","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{},"flatPath":"v1/transferJobs"},"patch":{"flatPath":"v1/transferJobs/{transferJobsId}","id":"storagetransfer.transferJobs.patch","path":"v1/{+jobName}","request":{"$ref":"UpdateTransferJobRequest"},"description":"Updates a transfer job. Updating a job's transfer spec does not affect\ntransfer operations that are running already. Updating the scheduling\nof a job is not allowed.","httpMethod":"PATCH","parameterOrder":["jobName"],"response":{"$ref":"TransferJob"},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"jobName":{"required":true,"type":"string","pattern":"^transferJobs/.+$","location":"path","description":"Required. The name of job to update."}}},"get":{"flatPath":"v1/transferJobs/{transferJobsId}","id":"storagetransfer.transferJobs.get","path":"v1/{+jobName}","description":"Gets a transfer job.","httpMethod":"GET","parameterOrder":["jobName"],"response":{"$ref":"TransferJob"},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"jobName":{"pattern":"^transferJobs/.+$","location":"path","description":"Required. The job to get.","required":true,"type":"string"},"projectId":{"type":"string","location":"query","description":"Required. The ID of the Google Cloud Platform Console project that owns the\njob."}}},"list":{"response":{"$ref":"ListTransferJobsResponse"},"parameterOrder":[],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"filter":{"location":"query","description":"Required. A list of query parameters specified as JSON text in the form of:\n{\"project_id\":\"my_project_id\",\n \"job_names\":[\"jobid1\",\"jobid2\",...],\n \"job_statuses\":[\"status1\",\"status2\",...]}.\nSince `job_names` and `job_statuses` support multiple values, their values\nmust be specified with array notation. `project_id` is required.\n`job_names` and `job_statuses` are optional.  The valid values for\n`job_statuses` are case-insensitive: `ENABLED`, `DISABLED`, and `DELETED`.","type":"string"},"pageToken":{"description":"The list page token.","type":"string","location":"query"},"pageSize":{"location":"query","description":"The list page size. The max allowed value is 256.","format":"int32","type":"integer"}},"flatPath":"v1/transferJobs","path":"v1/transferJobs","id":"storagetransfer.transferJobs.list","description":"Lists transfer jobs."}}},"transferOperations":{"methods":{"pause":{"id":"storagetransfer.transferOperations.pause","path":"v1/{+name}:pause","description":"Pauses a transfer operation.","request":{"$ref":"PauseTransferOperationRequest"},"httpMethod":"POST","parameterOrder":["name"],"response":{"$ref":"Empty"},"parameters":{"name":{"location":"path","description":"Required. The name of the transfer operation.","required":true,"type":"string","pattern":"^transferOperations/.+$"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1/transferOperations/{transferOperationsId}:pause"},"delete":{"flatPath":"v1/transferOperations/{transferOperationsId}","id":"storagetransfer.transferOperations.delete","path":"v1/{+name}","description":"This method is not supported and the server returns `UNIMPLEMENTED`.","httpMethod":"DELETE","parameterOrder":["name"],"response":{"$ref":"Empty"},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"location":"path","description":"The name of the operation resource to be deleted.","required":true,"type":"string","pattern":"^transferOperations/.+$"}}},"list":{"response":{"$ref":"ListOperationsResponse"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"filter":{"location":"query","description":"Required. A list of query parameters specified as JSON text in the form of: {\"project_id\":\"my_project_id\",\n \"job_names\":[\"jobid1\",\"jobid2\",...],\n \"operation_names\":[\"opid1\",\"opid2\",...],\n \"transfer_statuses\":[\"status1\",\"status2\",...]}.\nSince `job_names`, `operation_names`, and `transfer_statuses` support multiple values, they must be specified with array notation. `project_id` is required. `job_names`, `operation_names`, and `transfer_statuses` are optional. The valid values for `transfer_statuses` are case-insensitive: `IN_PROGRESS`, `PAUSED`, `SUCCESS`, `FAILED`, and `ABORTED`.","type":"string"},"name":{"location":"path","description":"Required. The value `transferOperations`.","required":true,"type":"string","pattern":"^transferOperations$"},"pageToken":{"description":"The list page token.","type":"string","location":"query"},"pageSize":{"description":"The list page size. The max allowed value is 256.","format":"int32","type":"integer","location":"query"}},"flatPath":"v1/transferOperations","path":"v1/{+name}","id":"storagetransfer.transferOperations.list","description":"Lists operations that match the specified filter in the request. If the\nserver doesn't support this method, it returns `UNIMPLEMENTED`.\n\nNOTE: the `name` binding allows API services to override the binding\nto use different resource name schemes, such as `users/*/operations`. To\noverride the binding, API services can add a binding such as\n`\"/v1/{name=users/*}/operations\"` to their service configuration.\nFor backwards compatibility, the default name includes the operations\ncollection id, however overriding users must ensure the name binding\nis the parent resource, without the operations collection id."},"resume":{"response":{"$ref":"Empty"},"parameterOrder":["name"],"httpMethod":"POST","parameters":{"name":{"description":"Required. The name of the transfer operation.","required":true,"type":"string","pattern":"^transferOperations/.+$","location":"path"}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1/transferOperations/{transferOperationsId}:resume","path":"v1/{+name}:resume","id":"storagetransfer.transferOperations.resume","description":"Resumes a transfer operation that is paused.","request":{"$ref":"ResumeTransferOperationRequest"}},"cancel":{"response":{"$ref":"Empty"},"parameterOrder":["name"],"httpMethod":"POST","parameters":{"name":{"required":true,"type":"string","pattern":"^transferOperations/.+$","location":"path","description":"The name of the operation resource to be cancelled."}},"scopes":["https://www.googleapis.com/auth/cloud-platform"],"flatPath":"v1/transferOperations/{transferOperationsId}:cancel","path":"v1/{+name}:cancel","id":"storagetransfer.transferOperations.cancel","description":"Cancels a transfer. Use the get method to check whether the cancellation succeeded or whether the operation completed despite cancellation."},"get":{"response":{"$ref":"Operation"},"parameterOrder":["name"],"httpMethod":"GET","scopes":["https://www.googleapis.com/auth/cloud-platform"],"parameters":{"name":{"pattern":"^transferOperations/.+$","location":"path","description":"The name of the operation resource.","required":true,"type":"string"}},"flatPath":"v1/transferOperations/{transferOperationsId}","path":"v1/{+name}","id":"storagetransfer.transferOperations.get","description":"Gets the latest state of a long-running operation.  Clients can use this\nmethod to poll the operation result at intervals as recommended by the API\nservice."}}}},"parameters":{"key":{"description":"API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.","type":"string","location":"query"},"access_token":{"location":"query","description":"OAuth access token.","type":"string"},"upload_protocol":{"location":"query","description":"Upload protocol for media (e.g. \"raw\", \"multipart\").","type":"string"},"quotaUser":{"location":"query","description":"Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.","type":"string"},"prettyPrint":{"location":"query","description":"Returns response with indentations and line breaks.","type":"boolean","default":"true"},"uploadType":{"type":"string","location":"query","description":"Legacy upload protocol for media (e.g. \"media\", \"multipart\")."},"fields":{"description":"Selector specifying which fields to include in a partial response.","type":"string","location":"query"},"callback":{"type":"string","location":"query","description":"JSONP"},"oauth_token":{"description":"OAuth 2.0 token for the current user.","type":"string","location":"query"},"$.xgafv":{"location":"query","enum":["1","2"],"description":"V1 error format.","type":"string","enumDescriptions":["v1 error format","v2 error format"]},"alt":{"type":"string","enumDescriptions":["Responses with Content-Type of application/json","Media download with context-dependent Content-Type","Responses with Content-Type of application/x-protobuf"],"location":"query","description":"Data format for response.","default":"json","enum":["json","media","proto"]}},"version":"v1","baseUrl":"https://storagetransfer.googleapis.com/","description":"Transfers data from external data sources to a Google Cloud Storage bucket or between Google Cloud Storage buckets.","kind":"discovery#restDescription","servicePath":"","basePath":"","revision":"20190622","documentationLink":"https://cloud.google.com/storage-transfer/docs","id":"storagetransfer:v1"};